// Copyright (c) 2013-2016 CoolGames

/******************************************************************************
 * Spine Runtimes Software License
 * Version 2.3
 * 
 * Copyright (c) 2013-2015, Esoteric Software
 * All rights reserved.
 * 
 * You are granted a perpetual, non-exclusive, non-sublicensable and
 * non-transferable license to use, install, execute and perform the Spine
 * Runtimes Software (the "Software") and derivative works solely for personal
 * or internal use. Without the written permission of Esoteric Software (see
 * Section 2 of the Spine Software License Agreement), you may not (a) modify,
 * translate, adapt or otherwise create derivative works, improvements of the
 * Software or develop new applications using the Software or (b) remove,
 * delete, alter or obscure any trademarks or any copyright, trademark, patent
 * or other intellectual property or proprietary rights notices on or in the
 * Software, including any copy thereof. Redistributions in binary or source
 * form must include this license and terms.
 * 
 * THIS SOFTWARE IS PROVIDED BY ESOTERIC SOFTWARE "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL ESOTERIC SOFTWARE BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

var spine = {
	radDeg: 180 / Math.PI,
	degRad: Math.PI / 180,
	temp: [],
    Float32Array: (typeof(Float32Array) === 'undefined') ? Array : Float32Array,
    Uint16Array: (typeof(Uint16Array) === 'undefined') ? Array : Uint16Array
};

spine.BoneData = function (name, parent) {
	this.name = name;
	this.parent = parent;
};
spine.BoneData.prototype = {
	length: 0,
	x: 0, y: 0,
	rotation: 0,
	scaleX: 1, scaleY: 1,
	inheritScale: true,
	inheritRotation: true,
	flipX: false, flipY: false
};

spine.BlendMode = {
	normal: 0,
	additive: 1,
	multiply: 2,
	screen: 3
};

spine.SlotData = function (name, boneData) {
	this.name = name;
	this.boneData = boneData;
};
spine.SlotData.prototype = {
	r: 1, g: 1, b: 1, a: 1,
	attachmentName: null,
	blendMode: spine.BlendMode.normal
};

spine.IkConstraintData = function (name) {
	this.name = name;
	this.bones = [];
};
spine.IkConstraintData.prototype = {
	target: null,
	bendDirection: 1,
	mix: 1
};

spine.Bone = function (boneData, skeleton, parent) {
	this.data = boneData;
	this.skeleton = skeleton;
	this.parent = parent;
	this.setToSetupPose();
};
spine.Bone.yDown = false;
spine.Bone.prototype = {
	x: 0, y: 0,
	rotation: 0, rotationIK: 0,
	scaleX: 1, scaleY: 1,
	flipX: false, flipY: false,
	m00: 0, m01: 0, worldX: 0, // a b x
	m10: 0, m11: 0, worldY: 0, // c d y
	worldRotation: 0,
	worldScaleX: 1, worldScaleY: 1,
	worldFlipX: false, worldFlipY: false,
	updateWorldTransform: function () {
		var parent = this.parent;
		if (parent) {
			this.worldX = this.x * parent.m00 + this.y * parent.m01 + parent.worldX;
			this.worldY = this.x * parent.m10 + this.y * parent.m11 + parent.worldY;
			if (this.data.inheritScale) {
				this.worldScaleX = parent.worldScaleX * this.scaleX;
				this.worldScaleY = parent.worldScaleY * this.scaleY;
			} else {
				this.worldScaleX = this.scaleX;
				this.worldScaleY = this.scaleY;
			}
			this.worldRotation = this.data.inheritRotation ? (parent.worldRotation + this.rotationIK) : this.rotationIK;
			this.worldFlipX = parent.worldFlipX != this.flipX;
			this.worldFlipY = parent.worldFlipY != this.flipY;
		} else {
			var skeletonFlipX = this.skeleton.flipX, skeletonFlipY = this.skeleton.flipY;
			this.worldX = skeletonFlipX ? -this.x : this.x;
			this.worldY = (skeletonFlipY != spine.Bone.yDown) ? -this.y : this.y;
			this.worldScaleX = this.scaleX;
			this.worldScaleY = this.scaleY;
			this.worldRotation = this.rotationIK;
			this.worldFlipX = skeletonFlipX != this.flipX;
			this.worldFlipY = skeletonFlipY != this.flipY;
		}
		var radians = this.worldRotation * spine.degRad;
		var cos = Math.cos(radians);
		var sin = Math.sin(radians);
		if (this.worldFlipX) {
			this.m00 = -cos * this.worldScaleX;
			this.m01 = sin * this.worldScaleY;
		} else {
			this.m00 = cos * this.worldScaleX;
			this.m01 = -sin * this.worldScaleY;
		}
		if (this.worldFlipY != spine.Bone.yDown) {
			this.m10 = -sin * this.worldScaleX;
			this.m11 = -cos * this.worldScaleY;
		} else {
			this.m10 = sin * this.worldScaleX;
			this.m11 = cos * this.worldScaleY;
		}
	},
	setToSetupPose: function () {
		var data = this.data;
		this.x = data.x;
		this.y = data.y;
		this.rotation = data.rotation;
		this.rotationIK = this.rotation;
		this.scaleX = data.scaleX;
		this.scaleY = data.scaleY;
		this.flipX = data.flipX;
		this.flipY = data.flipY;
	},
	worldToLocal: function (world) {
		var dx = world[0] - this.worldX, dy = world[1] - this.worldY;
		var m00 = this.m00, m10 = this.m10, m01 = this.m01, m11 = this.m11;
		if (this.worldFlipX != (this.worldFlipY != spine.Bone.yDown)) {
			m00 = -m00;
			m11 = -m11;
		}
		var invDet = 1 / (m00 * m11 - m01 * m10);
		world[0] = dx * m00 * invDet - dy * m01 * invDet;
		world[1] = dy * m11 * invDet - dx * m10 * invDet;
	},
	localToWorld: function (local) {
		var localX = local[0], localY = local[1];
		local[0] = localX * this.m00 + localY * this.m01 + this.worldX;
		local[1] = localX * this.m10 + localY * this.m11 + this.worldY;
	}
};

spine.Slot = function (slotData, bone) {
	this.data = slotData;
	this.bone = bone;
	this.setToSetupPose();
};
spine.Slot.prototype = {
	r: 1, g: 1, b: 1, a: 1,
	_attachmentTime: 0,
	attachment: null,
	attachmentVertices: [],
	setAttachment: function (attachment) {
		if (this.attachment == attachment) return;
		this.attachment = attachment;
		this._attachmentTime = this.bone.skeleton.time;
		this.attachmentVertices.length = 0;
	},
	setAttachmentTime: function (time) {
		this._attachmentTime = this.bone.skeleton.time - time;
	},
	getAttachmentTime: function () {
		return this.bone.skeleton.time - this._attachmentTime;
	},
	setToSetupPose: function () {
		var data = this.data;
		this.r = data.r;
		this.g = data.g;
		this.b = data.b;
		this.a = data.a;

		if (!data.attachmentName)
			this.setAttachment(null);
		else {
			var slotDatas = this.bone.skeleton.data.slots;
			for (var i = 0, n = slotDatas.length; i < n; i++) {
				if (slotDatas[i] == data) {
					this.attachment = null;
					this.setAttachment(this.bone.skeleton.getAttachmentBySlotIndex(i, data.attachmentName));
					break;
				}
			}
		}
	}
};

spine.IkConstraint = function (data, skeleton) {
	this.data = data;
	this.mix = data.mix;
	this.bendDirection = data.bendDirection;

	this.bones = [];
	for (var i = 0, n = data.bones.length; i < n; i++)
		this.bones.push(skeleton.findBone(data.bones[i].name));
	this.target = skeleton.findBone(data.target.name);
};
spine.IkConstraint.prototype = {
	apply: function () {
		var target = this.target;
		var bones = this.bones;
		switch (bones.length) {
		case 1:
			spine.IkConstraint.apply1(bones[0], target.worldX, target.worldY, this.mix);
			break;
		case 2:
			spine.IkConstraint.apply2(bones[0], bones[1], target.worldX, target.worldY, this.bendDirection, this.mix);
			break;
		}
	}
};
/** Adjusts the bone rotation so the tip is as close to the target position as possible. The target is specified in the world
 * coordinate system. */
spine.IkConstraint.apply1 = function (bone, targetX, targetY, alpha) {
	var parentRotation = (!bone.data.inheritRotation || !bone.parent) ? 0 : bone.parent.worldRotation;
	var rotation = bone.rotation;
	var rotationIK = Math.atan2(targetY - bone.worldY, targetX - bone.worldX) * spine.radDeg;
	if (bone.worldFlipX != (bone.worldFlipY != spine.Bone.yDown)) rotationIK = -rotationIK;
	rotationIK -= parentRotation;
	bone.rotationIK = rotation + (rotationIK - rotation) * alpha;
};
/** Adjusts the parent and child bone rotations so the tip of the child is as close to the target position as possible. The
 * target is specified in the world coordinate system.
 * @param child Any descendant bone of the parent. */
spine.IkConstraint.apply2 = function (parent, child, targetX, targetY, bendDirection, alpha) {
	var childRotation = child.rotation, parentRotation = parent.rotation;
	if (!alpha) {
		child.rotationIK = childRotation;
		parent.rotationIK = parentRotation;
		return;
	}
	var positionX, positionY, tempPosition = spine.temp;
	var parentParent = parent.parent;
	if (parentParent) {
		tempPosition[0] = targetX;
		tempPosition[1] = targetY;
		parentParent.worldToLocal(tempPosition);
		targetX = (tempPosition[0] - parent.x) * parentParent.worldScaleX;
		targetY = (tempPosition[1] - parent.y) * parentParent.worldScaleY;
	} else {
		targetX -= parent.x;
		targetY -= parent.y;
	}
	if (child.parent == parent) {
		positionX = child.x;
		positionY = child.y;
	} else {
		tempPosition[0] = child.x;
		tempPosition[1] = child.y;
		child.parent.localToWorld(tempPosition);
		parent.worldToLocal(tempPosition);
		positionX = tempPosition[0];
		positionY = tempPosition[1];
	}
	var childX = positionX * parent.worldScaleX, childY = positionY * parent.worldScaleY;
	var offset = Math.atan2(childY, childX);
	var len1 = Math.sqrt(childX * childX + childY * childY), len2 = child.data.length * child.worldScaleX;
	// Based on code by Ryan Juckett with permission: Copyright (c) 2008-2009 Ryan Juckett, http://www.ryanjuckett.com/
	var cosDenom = 2 * len1 * len2;
	if (cosDenom < 0.0001) {
		child.rotationIK = childRotation + (Math.atan2(targetY, targetX) * spine.radDeg - parentRotation - childRotation) * alpha;
		return;
	}
	var cos = (targetX * targetX + targetY * targetY - len1 * len1 - len2 * len2) / cosDenom;
	if (cos < -1)
		cos = -1;
	else if (cos > 1)
		cos = 1;
	var childAngle = Math.acos(cos) * bendDirection;
	var adjacent = len1 + len2 * cos, opposite = len2 * Math.sin(childAngle);
	var parentAngle = Math.atan2(targetY * adjacent - targetX * opposite, targetX * adjacent + targetY * opposite);
	var rotation = (parentAngle - offset) * spine.radDeg - parentRotation;
	if (rotation > 180)
		rotation -= 360;
	else if (rotation < -180) //
		rotation += 360;
	parent.rotationIK = parentRotation + rotation * alpha;
	rotation = (childAngle + offset) * spine.radDeg - childRotation;
	if (rotation > 180)
		rotation -= 360;
	else if (rotation < -180) //
		rotation += 360;
	child.rotationIK = childRotation + (rotation + parent.worldRotation - child.parent.worldRotation) * alpha;
};

spine.Skin = function (name) {
	this.name = name;
	this.attachments = {};
};
spine.Skin.prototype = {
	addAttachment: function (slotIndex, name, attachment) {
		this.attachments[slotIndex + ":" + name] = attachment;
	},
	getAttachment: function (slotIndex, name) {
		return this.attachments[slotIndex + ":" + name];
	},
	_attachAll: function (skeleton, oldSkin) {
		for (var key in oldSkin.attachments) {
			var colon = key.indexOf(":");
			var slotIndex = parseInt(key.substring(0, colon));
			var name = key.substring(colon + 1);
			var slot = skeleton.slots[slotIndex];
			if (slot.attachment && slot.attachment.name == name) {
				var attachment = this.getAttachment(slotIndex, name);
				if (attachment) slot.setAttachment(attachment);
			}
		}
	}
};

spine.Animation = function (name, timelines, duration) {
	this.name = name;
	this.timelines = timelines;
	this.duration = duration;
};
spine.Animation.prototype = {
	apply: function (skeleton, lastTime, time, loop, events) {
		if (loop && this.duration != 0) {
			time %= this.duration;
			lastTime %= this.duration;
		}
		var timelines = this.timelines;
		for (var i = 0, n = timelines.length; i < n; i++)
			timelines[i].apply(skeleton, lastTime, time, events, 1);
	},
	mix: function (skeleton, lastTime, time, loop, events, alpha) {
		if (loop && this.duration != 0) {
			time %= this.duration;
			lastTime %= this.duration;
		}
		var timelines = this.timelines;
		for (var i = 0, n = timelines.length; i < n; i++)
			timelines[i].apply(skeleton, lastTime, time, events, alpha);
	}
};
spine.Animation.binarySearch = function (values, target, step) {
	var low = 0;
	var high = Math.floor(values.length / step) - 2;
	if (!high) return step;
	var current = high >>> 1;
	while (true) {
		if (values[(current + 1) * step] <= target)
			low = current + 1;
		else
			high = current;
		if (low == high) return (low + 1) * step;
		current = (low + high) >>> 1;
	}
};
spine.Animation.binarySearch1 = function (values, target) {
	var low = 0;
	var high = values.length - 2;
	if (!high) return 1;
	var current = high >>> 1;
	while (true) {
		if (values[current + 1] <= target)
			low = current + 1;
		else
			high = current;
		if (low == high) return low + 1;
		current = (low + high) >>> 1;
	}
};
spine.Animation.linearSearch = function (values, target, step) {
	for (var i = 0, last = values.length - step; i <= last; i += step)
		if (values[i] > target) return i;
	return -1;
};

spine.Curves = function (frameCount) {
	this.curves = []; // type, x, y, ...
	//this.curves.length = (frameCount - 1) * 19/*BEZIER_SIZE*/;
};
spine.Curves.prototype = {
	setLinear: function (frameIndex) {
		this.curves[frameIndex * 19/*BEZIER_SIZE*/] = 0/*LINEAR*/;
	},
	setStepped: function (frameIndex) {
		this.curves[frameIndex * 19/*BEZIER_SIZE*/] = 1/*STEPPED*/;
	},
	/** Sets the control handle positions for an interpolation bezier curve used to transition from this keyframe to the next.
	 * cx1 and cx2 are from 0 to 1, representing the percent of time between the two keyframes. cy1 and cy2 are the percent of
	 * the difference between the keyframe's values. */
	setCurve: function (frameIndex, cx1, cy1, cx2, cy2) {
		var subdiv1 = 1 / 10/*BEZIER_SEGMENTS*/, subdiv2 = subdiv1 * subdiv1, subdiv3 = subdiv2 * subdiv1;
		var pre1 = 3 * subdiv1, pre2 = 3 * subdiv2, pre4 = 6 * subdiv2, pre5 = 6 * subdiv3;
		var tmp1x = -cx1 * 2 + cx2, tmp1y = -cy1 * 2 + cy2, tmp2x = (cx1 - cx2) * 3 + 1, tmp2y = (cy1 - cy2) * 3 + 1;
		var dfx = cx1 * pre1 + tmp1x * pre2 + tmp2x * subdiv3, dfy = cy1 * pre1 + tmp1y * pre2 + tmp2y * subdiv3;
		var ddfx = tmp1x * pre4 + tmp2x * pre5, ddfy = tmp1y * pre4 + tmp2y * pre5;
		var dddfx = tmp2x * pre5, dddfy = tmp2y * pre5;

		var i = frameIndex * 19/*BEZIER_SIZE*/;
		var curves = this.curves;
		curves[i++] = 2/*BEZIER*/;
		
		var x = dfx, y = dfy;
		for (var n = i + 19/*BEZIER_SIZE*/ - 1; i < n; i += 2) {
			curves[i] = x;
			curves[i + 1] = y;
			dfx += ddfx;
			dfy += ddfy;
			ddfx += dddfx;
			ddfy += dddfy;
			x += dfx;
			y += dfy;
		}
	},
	getCurvePercent: function (frameIndex, percent) {
		percent = percent < 0 ? 0 : (percent > 1 ? 1 : percent);
		var curves = this.curves;
		var i = frameIndex * 19/*BEZIER_SIZE*/;
		var type = curves[i];
		if (type === 0/*LINEAR*/) return percent;
		if (type == 1/*STEPPED*/) return 0;
		i++;
		var x = 0;
		for (var start = i, n = i + 19/*BEZIER_SIZE*/ - 1; i < n; i += 2) {
			x = curves[i];
			if (x >= percent) {
				var prevX, prevY;
				if (i == start) {
					prevX = 0;
					prevY = 0;
				} else {
					prevX = curves[i - 2];
					prevY = curves[i - 1];
				}
				return prevY + (curves[i + 1] - prevY) * (percent - prevX) / (x - prevX);
			}
		}
		var y = curves[i - 1];
		return y + (1 - y) * (percent - x) / (1 - x); // Last point is 1,1.
	}
};

spine.RotateTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, angle, ...
	this.frames.length = frameCount * 2;
};
spine.RotateTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, angle) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = angle;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 2]) { // Time is after last frame.
			var amount = bone.data.rotation + frames[frames.length - 1] - bone.rotation;
			while (amount > 180)
				amount -= 360;
			while (amount < -180)
				amount += 360;
			bone.rotation += amount * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 2);
		var prevFrameValue = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex - 2/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 2 - 1, percent);

		var amount = frames[frameIndex + 1/*FRAME_VALUE*/] - prevFrameValue;
		while (amount > 180)
			amount -= 360;
		while (amount < -180)
			amount += 360;
		amount = bone.data.rotation + (prevFrameValue + amount * percent) - bone.rotation;
		while (amount > 180)
			amount -= 360;
		while (amount < -180)
			amount += 360;
		bone.rotation += amount * alpha;
	}
};

spine.TranslateTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, x, y, ...
	this.frames.length = frameCount * 3;
};
spine.TranslateTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, x, y) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = x;
		this.frames[frameIndex + 2] = y;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			bone.x += (bone.data.x + frames[frames.length - 2] - bone.x) * alpha;
			bone.y += (bone.data.y + frames[frames.length - 1] - bone.y) * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameX = frames[frameIndex - 2];
		var prevFrameY = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		bone.x += (bone.data.x + prevFrameX + (frames[frameIndex + 1/*FRAME_X*/] - prevFrameX) * percent - bone.x) * alpha;
		bone.y += (bone.data.y + prevFrameY + (frames[frameIndex + 2/*FRAME_Y*/] - prevFrameY) * percent - bone.y) * alpha;
	}
};

spine.ScaleTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, x, y, ...
	this.frames.length = frameCount * 3;
};
spine.ScaleTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, x, y) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = x;
		this.frames[frameIndex + 2] = y;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			bone.scaleX += (bone.data.scaleX * frames[frames.length - 2] - bone.scaleX) * alpha;
			bone.scaleY += (bone.data.scaleY * frames[frames.length - 1] - bone.scaleY) * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameX = frames[frameIndex - 2];
		var prevFrameY = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		bone.scaleX += (bone.data.scaleX * (prevFrameX + (frames[frameIndex + 1/*FRAME_X*/] - prevFrameX) * percent) - bone.scaleX) * alpha;
		bone.scaleY += (bone.data.scaleY * (prevFrameY + (frames[frameIndex + 2/*FRAME_Y*/] - prevFrameY) * percent) - bone.scaleY) * alpha;
	}
};

spine.ColorTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, r, g, b, a, ...
	this.frames.length = frameCount * 5;
};
spine.ColorTimeline.prototype = {
	slotIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 5;
	},
	setFrame: function (frameIndex, time, r, g, b, a) {
		frameIndex *= 5;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = r;
		this.frames[frameIndex + 2] = g;
		this.frames[frameIndex + 3] = b;
		this.frames[frameIndex + 4] = a;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var r, g, b, a;
		if (time >= frames[frames.length - 5]) {
			// Time is after last frame.
			var i = frames.length - 1;
			r = frames[i - 3];
			g = frames[i - 2];
			b = frames[i - 1];
			a = frames[i];
		} else {
			// Interpolate between the previous frame and the current frame.
			var frameIndex = spine.Animation.binarySearch(frames, time, 5);
			var prevFrameR = frames[frameIndex - 4];
			var prevFrameG = frames[frameIndex - 3];
			var prevFrameB = frames[frameIndex - 2];
			var prevFrameA = frames[frameIndex - 1];
			var frameTime = frames[frameIndex];
			var percent = 1 - (time - frameTime) / (frames[frameIndex - 5/*PREV_FRAME_TIME*/] - frameTime);
			percent = this.curves.getCurvePercent(frameIndex / 5 - 1, percent);

			r = prevFrameR + (frames[frameIndex + 1/*FRAME_R*/] - prevFrameR) * percent;
			g = prevFrameG + (frames[frameIndex + 2/*FRAME_G*/] - prevFrameG) * percent;
			b = prevFrameB + (frames[frameIndex + 3/*FRAME_B*/] - prevFrameB) * percent;
			a = prevFrameA + (frames[frameIndex + 4/*FRAME_A*/] - prevFrameA) * percent;
		}
		var slot = skeleton.slots[this.slotIndex];
		if (alpha < 1) {
			slot.r += (r - slot.r) * alpha;
			slot.g += (g - slot.g) * alpha;
			slot.b += (b - slot.b) * alpha;
			slot.a += (a - slot.a) * alpha;
		} else {
			slot.r = r;
			slot.g = g;
			slot.b = b;
			slot.a = a;
		}
	}
};

spine.AttachmentTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.attachmentNames = [];
	this.attachmentNames.length = frameCount;
};
spine.AttachmentTimeline.prototype = {
	slotIndex: 0,
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, attachmentName) {
		this.frames[frameIndex] = time;
		this.attachmentNames[frameIndex] = attachmentName;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;

		var frameIndex = time >= frames[frames.length - 1] ? frames.length - 1 : spine.Animation.binarySearch1(frames, time) - 1;
		if (frames[frameIndex] < lastTime) return;

		var attachmentName = this.attachmentNames[frameIndex];
		skeleton.slots[this.slotIndex].setAttachment(
			!attachmentName ? null : skeleton.getAttachmentBySlotIndex(this.slotIndex, attachmentName));
	}
};

spine.EventTimeline = function (frameCount) {
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.events = [];
	this.events.length = frameCount;
};
spine.EventTimeline.prototype = {
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, event) {
		this.frames[frameIndex] = time;
		this.events[frameIndex] = event;
	},
	/** Fires events for frames > lastTime and <= time. */
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		if (!firedEvents) return;

		var frames = this.frames;
		var frameCount = frames.length;

		if (lastTime > time) { // Fire events after last time for looped animations.
			this.apply(skeleton, lastTime, Number.MAX_VALUE, firedEvents, alpha);
			lastTime = -1;
		} else if (lastTime >= frames[frameCount - 1]) // Last time is after last frame.
			return;
		if (time < frames[0]) return; // Time is before first frame.

		var frameIndex;
		if (lastTime < frames[0])
			frameIndex = 0;
		else {
			frameIndex = spine.Animation.binarySearch1(frames, lastTime);
			var frame = frames[frameIndex];
			while (frameIndex > 0) { // Fire multiple events with the same frame.
				if (frames[frameIndex - 1] != frame) break;
				frameIndex--;
			}
		}
		var events = this.events;
		for (; frameIndex < frameCount && time >= frames[frameIndex]; frameIndex++)
			firedEvents.push(events[frameIndex]);
	}
};

spine.DrawOrderTimeline = function (frameCount) {
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.drawOrders = [];
	this.drawOrders.length = frameCount;
};
spine.DrawOrderTimeline.prototype = {
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, drawOrder) {
		this.frames[frameIndex] = time;
		this.drawOrders[frameIndex] = drawOrder;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var frameIndex;
		if (time >= frames[frames.length - 1]) // Time is after last frame.
			frameIndex = frames.length - 1;
		else
			frameIndex = spine.Animation.binarySearch1(frames, time) - 1;

		var drawOrder = skeleton.drawOrder;
		var slots = skeleton.slots;
		var drawOrderToSetupIndex = this.drawOrders[frameIndex];
		if (!drawOrderToSetupIndex) {
			for (var i = 0, n = slots.length; i < n; i++)
				drawOrder[i] = slots[i];
		} else {
			for (var i = 0, n = drawOrderToSetupIndex.length; i < n; i++)
				drawOrder[i] = skeleton.slots[drawOrderToSetupIndex[i]];
		}

	}
};

spine.FfdTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = [];
	this.frames.length = frameCount;
	this.frameVertices = [];
	this.frameVertices.length = frameCount;
};
spine.FfdTimeline.prototype = {
	slotIndex: 0,
	attachment: 0,
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, vertices) {
		this.frames[frameIndex] = time;
		this.frameVertices[frameIndex] = vertices;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var slot = skeleton.slots[this.slotIndex];
		if (slot.attachment != this.attachment) return;

		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var frameVertices = this.frameVertices;
		var vertexCount = frameVertices[0].length;

		var vertices = slot.attachmentVertices;
		if (vertices.length != vertexCount) alpha = 1;
		vertices.length = vertexCount;

		if (time >= frames[frames.length - 1]) { // Time is after last frame.
			var lastVertices = frameVertices[frames.length - 1];
			if (alpha < 1) {
				for (var i = 0; i < vertexCount; i++)
					vertices[i] += (lastVertices[i] - vertices[i]) * alpha;
			} else {
				for (var i = 0; i < vertexCount; i++)
					vertices[i] = lastVertices[i];
			}
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch1(frames, time);
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex - 1] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex - 1, percent < 0 ? 0 : (percent > 1 ? 1 : percent));

		var prevVertices = frameVertices[frameIndex - 1];
		var nextVertices = frameVertices[frameIndex];

		if (alpha < 1) {
			for (var i = 0; i < vertexCount; i++) {
				var prev = prevVertices[i];
				vertices[i] += (prev + (nextVertices[i] - prev) * percent - vertices[i]) * alpha;
			}
		} else {
			for (var i = 0; i < vertexCount; i++) {
				var prev = prevVertices[i];
				vertices[i] = prev + (nextVertices[i] - prev) * percent;
			}
		}
	}
};

spine.IkConstraintTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, mix, bendDirection, ...
	this.frames.length = frameCount * 3;
};
spine.IkConstraintTimeline.prototype = {
	ikConstraintIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, mix, bendDirection) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = mix;
		this.frames[frameIndex + 2] = bendDirection;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var ikConstraint = skeleton.ikConstraints[this.ikConstraintIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			ikConstraint.mix += (frames[frames.length - 2] - ikConstraint.mix) * alpha;
			ikConstraint.bendDirection = frames[frames.length - 1];
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameMix = frames[frameIndex + -2/*PREV_FRAME_MIX*/];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		var mix = prevFrameMix + (frames[frameIndex + 1/*FRAME_MIX*/] - prevFrameMix) * percent;
		ikConstraint.mix += (mix - ikConstraint.mix) * alpha;
		ikConstraint.bendDirection = frames[frameIndex + -1/*PREV_FRAME_BEND_DIRECTION*/];
	}
};

spine.FlipXTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, flip, ...
	this.frames.length = frameCount * 2;
};
spine.FlipXTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, flip) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = flip ? 1 : 0;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;
		var frameIndex = (time >= frames[frames.length - 2] ? frames.length : spine.Animation.binarySearch(frames, time, 2)) - 2;
		if (frames[frameIndex] < lastTime) return;
		skeleton.bones[this.boneIndex].flipX = frames[frameIndex + 1] != 0;
	}
};

spine.FlipYTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, flip, ...
	this.frames.length = frameCount * 2;
};
spine.FlipYTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, flip) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = flip ? 1 : 0;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;
		var frameIndex = (time >= frames[frames.length - 2] ? frames.length : spine.Animation.binarySearch(frames, time, 2)) - 2;
		if (frames[frameIndex] < lastTime) return;
		skeleton.bones[this.boneIndex].flipY = frames[frameIndex + 1] != 0;
	}
};

spine.SkeletonData = function () {
	this.bones = [];
	this.slots = [];
	this.skins = [];
	this.events = [];
	this.animations = [];
	this.ikConstraints = [];
};
spine.SkeletonData.prototype = {
	name: null,
	defaultSkin: null,
	width: 0, height: 0,
	version: null, hash: null,
	/** @return May be null. */
	findBone: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].name == boneName) return bones[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findBoneIndex: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].name == boneName) return i;
		return -1;
	},
	/** @return May be null. */
	findSlot: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++) {
			if (slots[i].name == slotName) return slot[i];
		}
		return null;
	},
	/** @return -1 if the bone was not found. */
	findSlotIndex: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].name == slotName) return i;
		return -1;
	},
	/** @return May be null. */
	findSkin: function (skinName) {
		var skins = this.skins;
		for (var i = 0, n = skins.length; i < n; i++)
			if (skins[i].name == skinName) return skins[i];
		return null;
	},
	/** @return May be null. */
	findEvent: function (eventName) {
		var events = this.events;
		for (var i = 0, n = events.length; i < n; i++)
			if (events[i].name == eventName) return events[i];
		return null;
	},
	/** @return May be null. */
	findAnimation: function (animationName) {
		var animations = this.animations;
		for (var i = 0, n = animations.length; i < n; i++)
			if (animations[i].name == animationName) return animations[i];
		return null;
	},
	/** @return May be null. */
	findIkConstraint: function (ikConstraintName) {
		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++)
			if (ikConstraints[i].name == ikConstraintName) return ikConstraints[i];
		return null;
	}
};

spine.Skeleton = function (skeletonData) {
	this.data = skeletonData;

	this.bones = [];
	for (var i = 0, n = skeletonData.bones.length; i < n; i++) {
		var boneData = skeletonData.bones[i];
		var parent = !boneData.parent ? null : this.bones[skeletonData.bones.indexOf(boneData.parent)];
		this.bones.push(new spine.Bone(boneData, this, parent));
	}

	this.slots = [];
	this.drawOrder = [];
	for (var i = 0, n = skeletonData.slots.length; i < n; i++) {
		var slotData = skeletonData.slots[i];
		var bone = this.bones[skeletonData.bones.indexOf(slotData.boneData)];
		var slot = new spine.Slot(slotData, bone);
		this.slots.push(slot);
		this.drawOrder.push(slot);
	}
	
	this.ikConstraints = [];
	for (var i = 0, n = skeletonData.ikConstraints.length; i < n; i++)
		this.ikConstraints.push(new spine.IkConstraint(skeletonData.ikConstraints[i], this));

	this.boneCache = [];
	this.updateCache();
};
spine.Skeleton.prototype = {
	x: 0, y: 0,
	skin: null,
	r: 1, g: 1, b: 1, a: 1,
	time: 0,
	flipX: false, flipY: false,
	/** Caches information about bones and IK constraints. Must be called if bones or IK constraints are added or removed. */
	updateCache: function () {
		var ikConstraints = this.ikConstraints;
		var ikConstraintsCount = ikConstraints.length;

		var arrayCount = ikConstraintsCount + 1;
		var boneCache = this.boneCache;
		if (boneCache.length > arrayCount) boneCache.length = arrayCount;
		for (var i = 0, n = boneCache.length; i < n; i++)
			boneCache[i].length = 0;
		while (boneCache.length < arrayCount)
			boneCache[boneCache.length] = [];

		var nonIkBones = boneCache[0];
		var bones = this.bones;

		outer:
		for (var i = 0, n = bones.length; i < n; i++) {
			var bone = bones[i];
			var current = bone;
			do {
				for (var ii = 0; ii < ikConstraintsCount; ii++) {
					var ikConstraint = ikConstraints[ii];
					var parent = ikConstraint.bones[0];
					var child= ikConstraint.bones[ikConstraint.bones.length - 1];
					while (true) {
						if (current == child) {
							boneCache[ii].push(bone);
							boneCache[ii + 1].push(bone);
							continue outer;
						}
						if (child == parent) break;
						child = child.parent;
					}
				}
				current = current.parent;
			} while (current);
			nonIkBones[nonIkBones.length] = bone;
		}
	},
	/** Updates the world transform for each bone. */
	updateWorldTransform: function () {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++) {
			var bone = bones[i];
			bone.rotationIK = bone.rotation;
		}
		var i = 0, last = this.boneCache.length - 1;
		while (true) {
			var cacheBones = this.boneCache[i];
			for (var ii = 0, nn = cacheBones.length; ii < nn; ii++)
				cacheBones[ii].updateWorldTransform();
			if (i == last) break;
			this.ikConstraints[i].apply();
			i++;
		}
	},
	/** Sets the bones and slots to their setup pose values. */
	setToSetupPose: function () {
		this.setBonesToSetupPose();
		this.setSlotsToSetupPose();
	},
	setBonesToSetupPose: function () {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			bones[i].setToSetupPose();

		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++) {
			var ikConstraint = ikConstraints[i];
			ikConstraint.bendDirection = ikConstraint.data.bendDirection;
			ikConstraint.mix = ikConstraint.data.mix;
		}
	},
	setSlotsToSetupPose: function () {
		var slots = this.slots;
		var drawOrder = this.drawOrder;
		for (var i = 0, n = slots.length; i < n; i++) {
			drawOrder[i] = slots[i];
			slots[i].setToSetupPose(i);
		}
	},
	/** @return May return null. */
	getRootBone: function () {
		return this.bones.length ? this.bones[0] : null;
	},
	/** @return May be null. */
	findBone: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].data.name == boneName) return bones[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findBoneIndex: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].data.name == boneName) return i;
		return -1;
	},
	/** @return May be null. */
	findSlot: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].data.name == slotName) return slots[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findSlotIndex: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].data.name == slotName) return i;
		return -1;
	},
	setSkinByName: function (skinName) {
		var skin = this.data.findSkin(skinName);
		if (!skin) throw "Skin not found: " + skinName;
		this.setSkin(skin);
	},
	/** Sets the skin used to look up attachments before looking in the {@link SkeletonData#getDefaultSkin() default skin}. 
	 * Attachments from the new skin are attached if the corresponding attachment from the old skin was attached. If there was 
	 * no old skin, each slot's setup mode attachment is attached from the new skin.
	 * @param newSkin May be null. */
	setSkin: function (newSkin) {
		if (newSkin) {
			if (this.skin)
				newSkin._attachAll(this, this.skin);
			else {
				var slots = this.slots;
				for (var i = 0, n = slots.length; i < n; i++) {
					var slot = slots[i];
					var name = slot.data.attachmentName;
					if (name) {
						var attachment = newSkin.getAttachment(i, name);
						if (attachment) slot.setAttachment(attachment);
					}
				}
			}
		}
		this.skin = newSkin;
	},
	/** @return May be null. */
	getAttachmentBySlotName: function (slotName, attachmentName) {
		return this.getAttachmentBySlotIndex(this.data.findSlotIndex(slotName), attachmentName);
	},
	/** @return May be null. */
	getAttachmentBySlotIndex: function (slotIndex, attachmentName) {
		if (this.skin) {
			var attachment = this.skin.getAttachment(slotIndex, attachmentName);
			if (attachment) return attachment;
		}
		if (this.data.defaultSkin) return this.data.defaultSkin.getAttachment(slotIndex, attachmentName);
		return null;
	},
	/** @param attachmentName May be null. */
	setAttachment: function (slotName, attachmentName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++) {
			var slot = slots[i];
			if (slot.data.name == slotName) {
				var attachment = null;
				if (attachmentName) {
					attachment = this.getAttachmentBySlotIndex(i, attachmentName);
					if (!attachment) throw "Attachment not found: " + attachmentName + ", for slot: " + slotName;
				}
				slot.setAttachment(attachment);
				return;
			}
		}
		throw "Slot not found: " + slotName;
	},
	/** @return May be null. */
	findIkConstraint: function (ikConstraintName) {
		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++)
			if (ikConstraints[i].data.name == ikConstraintName) return ikConstraints[i];
		return null;
	},
	update: function (delta) {
		this.time += delta;
	}
};

spine.EventData = function (name) {
	this.name = name;
};
spine.EventData.prototype = {
	intValue: 0,
	floatValue: 0,
	stringValue: null
};

spine.Event = function (data) {
	this.data = data;
};
spine.Event.prototype = {
	intValue: 0,
	floatValue: 0,
	stringValue: null
};

spine.AttachmentType = {
	region: 0,
	boundingbox: 1,
	mesh: 2,
	skinnedmesh: 3
};

spine.RegionAttachment = function (name) {
	this.name = name;
	this.offset = [];
	this.offset.length = 8;
	this.uvs = [];
	this.uvs.length = 8;
};
spine.RegionAttachment.prototype = {
	type: spine.AttachmentType.region,
	x: 0, y: 0,
	rotation: 0,
	scaleX: 1, scaleY: 1,
	width: 0, height: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	setUVs: function (u, v, u2, v2, rotate) {
		var uvs = this.uvs;
		if (rotate) {
			uvs[2/*X2*/] = u;
			uvs[3/*Y2*/] = v2;
			uvs[4/*X3*/] = u;
			uvs[5/*Y3*/] = v;
			uvs[6/*X4*/] = u2;
			uvs[7/*Y4*/] = v;
			uvs[0/*X1*/] = u2;
			uvs[1/*Y1*/] = v2;
		} else {
			uvs[0/*X1*/] = u;
			uvs[1/*Y1*/] = v2;
			uvs[2/*X2*/] = u;
			uvs[3/*Y2*/] = v;
			uvs[4/*X3*/] = u2;
			uvs[5/*Y3*/] = v;
			uvs[6/*X4*/] = u2;
			uvs[7/*Y4*/] = v2;
		}
	},
	updateOffset: function () {
		var regionScaleX = this.width / this.regionOriginalWidth * this.scaleX;
		var regionScaleY = this.height / this.regionOriginalHeight * this.scaleY;
		var localX = -this.width / 2 * this.scaleX + this.regionOffsetX * regionScaleX;
		var localY = -this.height / 2 * this.scaleY + this.regionOffsetY * regionScaleY;
		var localX2 = localX + this.regionWidth * regionScaleX;
		var localY2 = localY + this.regionHeight * regionScaleY;
		var radians = this.rotation * spine.degRad;
		var cos = Math.cos(radians);
		var sin = Math.sin(radians);
		var localXCos = localX * cos + this.x;
		var localXSin = localX * sin;
		var localYCos = localY * cos + this.y;
		var localYSin = localY * sin;
		var localX2Cos = localX2 * cos + this.x;
		var localX2Sin = localX2 * sin;
		var localY2Cos = localY2 * cos + this.y;
		var localY2Sin = localY2 * sin;
		var offset = this.offset;
		offset[0/*X1*/] = localXCos - localYSin;
		offset[1/*Y1*/] = localYCos + localXSin;
		offset[2/*X2*/] = localXCos - localY2Sin;
		offset[3/*Y2*/] = localY2Cos + localXSin;
		offset[4/*X3*/] = localX2Cos - localY2Sin;
		offset[5/*Y3*/] = localY2Cos + localX2Sin;
		offset[6/*X4*/] = localX2Cos - localYSin;
		offset[7/*Y4*/] = localYCos + localX2Sin;
	},
	computeVertices: function (x, y, bone, vertices) {
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var offset = this.offset;
		vertices[0/*X1*/] = offset[0/*X1*/] * m00 + offset[1/*Y1*/] * m01 + x;
		vertices[1/*Y1*/] = offset[0/*X1*/] * m10 + offset[1/*Y1*/] * m11 + y;
		vertices[2/*X2*/] = offset[2/*X2*/] * m00 + offset[3/*Y2*/] * m01 + x;
		vertices[3/*Y2*/] = offset[2/*X2*/] * m10 + offset[3/*Y2*/] * m11 + y;
		vertices[4/*X3*/] = offset[4/*X3*/] * m00 + offset[5/*X3*/] * m01 + x;
		vertices[5/*X3*/] = offset[4/*X3*/] * m10 + offset[5/*X3*/] * m11 + y;
		vertices[6/*X4*/] = offset[6/*X4*/] * m00 + offset[7/*Y4*/] * m01 + x;
		vertices[7/*Y4*/] = offset[6/*X4*/] * m10 + offset[7/*Y4*/] * m11 + y;
	}
};

spine.MeshAttachment = function (name) {
	this.name = name;
};
spine.MeshAttachment.prototype = {
	type: spine.AttachmentType.mesh,
	vertices: null,
	uvs: null,
	regionUVs: null,
	triangles: null,
	hullLength: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionU: 0, regionV: 0, regionU2: 0, regionV2: 0, regionRotate: false,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	edges: null,
	width: 0, height: 0,
	updateUVs: function () {
		var width = this.regionU2 - this.regionU, height = this.regionV2 - this.regionV;
		var n = this.regionUVs.length;
		if (!this.uvs || this.uvs.length != n) {
            this.uvs = new spine.Float32Array(n);
		}
		if (this.regionRotate) {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i + 1] * width;
                this.uvs[i + 1] = this.regionV + height - this.regionUVs[i] * height;
			}
		} else {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i] * width;
                this.uvs[i + 1] = this.regionV + this.regionUVs[i + 1] * height;
			}
		}
	},
	computeWorldVertices: function (x, y, slot, worldVertices) {
		var bone = slot.bone;
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var vertices = this.vertices;
		var verticesCount = vertices.length;
		if (slot.attachmentVertices.length == verticesCount) vertices = slot.attachmentVertices;
		for (var i = 0; i < verticesCount; i += 2) {
			var vx = vertices[i];
			var vy = vertices[i + 1];
			worldVertices[i] = vx * m00 + vy * m01 + x;
			worldVertices[i + 1] = vx * m10 + vy * m11 + y;
		}
	}
};

spine.SkinnedMeshAttachment = function (name) {
	this.name = name;
};
spine.SkinnedMeshAttachment.prototype = {
	type: spine.AttachmentType.skinnedmesh,
	bones: null,
	weights: null,
	uvs: null,
	regionUVs: null,
	triangles: null,
	hullLength: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionU: 0, regionV: 0, regionU2: 0, regionV2: 0, regionRotate: false,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	edges: null,
	width: 0, height: 0,
	updateUVs: function (u, v, u2, v2, rotate) {
		var width = this.regionU2 - this.regionU, height = this.regionV2 - this.regionV;
		var n = this.regionUVs.length;
		if (!this.uvs || this.uvs.length != n) {
            this.uvs = new spine.Float32Array(n);
		}
		if (this.regionRotate) {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i + 1] * width;
                this.uvs[i + 1] = this.regionV + height - this.regionUVs[i] * height;
			}
		} else {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i] * width;
                this.uvs[i + 1] = this.regionV + this.regionUVs[i + 1] * height;
			}
		}
	},
	computeWorldVertices: function (x, y, slot, worldVertices) {
		var skeletonBones = slot.bone.skeleton.bones;
		var weights = this.weights;
		var bones = this.bones;

		var w = 0, v = 0, b = 0, f = 0, n = bones.length, nn;
		var wx, wy, bone, vx, vy, weight;
		if (!slot.attachmentVertices.length) {
			for (; v < n; w += 2) {
				wx = 0;
				wy = 0;
				nn = bones[v++] + v;
				for (; v < nn; v++, b += 3) {
					bone = skeletonBones[bones[v]];
					vx = weights[b];
					vy = weights[b + 1];
					weight = weights[b + 2];
					wx += (vx * bone.m00 + vy * bone.m01 + bone.worldX) * weight;
					wy += (vx * bone.m10 + vy * bone.m11 + bone.worldY) * weight;
				}
				worldVertices[w] = wx + x;
				worldVertices[w + 1] = wy + y;
			}
		} else {
			var ffd = slot.attachmentVertices;
			for (; v < n; w += 2) {
				wx = 0;
				wy = 0;
				nn = bones[v++] + v;
				for (; v < nn; v++, b += 3, f += 2) {
					bone = skeletonBones[bones[v]];
					vx = weights[b] + ffd[f];
					vy = weights[b + 1] + ffd[f + 1];
					weight = weights[b + 2];
					wx += (vx * bone.m00 + vy * bone.m01 + bone.worldX) * weight;
					wy += (vx * bone.m10 + vy * bone.m11 + bone.worldY) * weight;
				}
				worldVertices[w] = wx + x;
				worldVertices[w + 1] = wy + y;
			}
		}
	}
};

spine.BoundingBoxAttachment = function (name) {
	this.name = name;
	this.vertices = [];
};
spine.BoundingBoxAttachment.prototype = {
	type: spine.AttachmentType.boundingbox,
	computeWorldVertices: function (x, y, bone, worldVertices) {
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var vertices = this.vertices;
		for (var i = 0, n = vertices.length; i < n; i += 2) {
			var px = vertices[i];
			var py = vertices[i + 1];
			worldVertices[i] = px * m00 + py * m01 + x;
			worldVertices[i + 1] = px * m10 + py * m11 + y;
		}
	}
};

spine.AnimationStateData = function (skeletonData) {
	this.skeletonData = skeletonData;
	this.animationToMixTime = {};
};
spine.AnimationStateData.prototype = {
	defaultMix: 0,
	setMixByName: function (fromName, toName, duration) {
		var from = this.skeletonData.findAnimation(fromName);
		if (!from) throw "Animation not found: " + fromName;
		var to = this.skeletonData.findAnimation(toName);
		if (!to) throw "Animation not found: " + toName;
		this.setMix(from, to, duration);
	},
	setMix: function (from, to, duration) {
		this.animationToMixTime[from.name + ":" + to.name] = duration;
	},
	getMix: function (from, to) {
		var key = from.name + ":" + to.name;
		return this.animationToMixTime.hasOwnProperty(key) ? this.animationToMixTime[key] : this.defaultMix;
	}
};

spine.TrackEntry = function () {};
spine.TrackEntry.prototype = {
	next: null, previous: null,
	animation: null,
	loop: false,
	delay: 0, time: 0, lastTime: -1, endTime: 0,
	timeScale: 1,
	mixTime: 0, mixDuration: 0, mix: 1,
	onStart: null, onEnd: null, onComplete: null, onEvent: null
};

spine.AnimationState = function (stateData) {
	this.data = stateData;
	this.tracks = [];
	this.events = [];
};
spine.AnimationState.prototype = {
	onStart: null,
	onEnd: null,
	onComplete: null,
	onEvent: null,
	timeScale: 1,
	update: function (delta) {
		delta *= this.timeScale;
		for (var i = 0; i < this.tracks.length; i++) {
			var current = this.tracks[i];
			if (!current) continue;

			current.time += delta * current.timeScale;
			if (current.previous) {
				var previousDelta = delta * current.previous.timeScale;
				current.previous.time += previousDelta;
				current.mixTime += previousDelta;
			}

			var next = current.next;
			if (next) {
				next.time = current.lastTime - next.delay;
				if (next.time >= 0) this.setCurrent(i, next);
			} else {
				// End non-looping animation when it reaches its end time and there is no next entry.
				if (!current.loop && current.lastTime >= current.endTime) this.clearTrack(i);
			}
		}
	},
	apply: function (skeleton) {
		for (var i = 0; i < this.tracks.length; i++) {
			var current = this.tracks[i];
			if (!current) continue;

			this.events.length = 0;

			var time = current.time;
			var lastTime = current.lastTime;
			var endTime = current.endTime;
			var loop = current.loop;
			if (!loop && time > endTime) time = endTime;

			var previous = current.previous;
			if (!previous) {
				if (current.mix == 1)
					current.animation.apply(skeleton, current.lastTime, time, loop, this.events);
				else
					current.animation.mix(skeleton, current.lastTime, time, loop, this.events, current.mix);
			} else {
				var previousTime = previous.time;
				if (!previous.loop && previousTime > previous.endTime) previousTime = previous.endTime;
				previous.animation.apply(skeleton, previousTime, previousTime, previous.loop, null);

				var alpha = current.mixTime / current.mixDuration * current.mix;
				if (alpha >= 1) {
					alpha = 1;
					current.previous = null;
				}
				current.animation.mix(skeleton, current.lastTime, time, loop, this.events, alpha);
			}

			for (var ii = 0, nn = this.events.length; ii < nn; ii++) {
				var event = this.events[ii];
				if (current.onEvent) current.onEvent(i, event);
				if (this.onEvent) this.onEvent(i, event);
			}

			// Check if completed the animation or a loop iteration.
			if (loop ? (lastTime % endTime > time % endTime) : (lastTime < endTime && time >= endTime)) {
				var count = Math.floor(time / endTime);
				if (current.onComplete) current.onComplete(i, count);
				if (this.onComplete) this.onComplete(i, count);
			}

			current.lastTime = current.time;
		}
	},
	clearTracks: function () {
		for (var i = 0, n = this.tracks.length; i < n; i++)
			this.clearTrack(i);
		this.tracks.length = 0; 
	},
	clearTrack: function (trackIndex) {
		if (trackIndex >= this.tracks.length) return;
		var current = this.tracks[trackIndex];
		if (!current) return;

		if (current.onEnd) current.onEnd(trackIndex);
		if (this.onEnd) this.onEnd(trackIndex);

		this.tracks[trackIndex] = null;
	},
	_expandToIndex: function (index) {
		if (index < this.tracks.length) return this.tracks[index];
		while (index >= this.tracks.length)
			this.tracks.push(null);
		return null;
	},
	setCurrent: function (index, entry) {
		var current = this._expandToIndex(index);
		if (current) {
			var previous = current.previous;
			current.previous = null;

			if (current.onEnd) current.onEnd(index);
			if (this.onEnd) this.onEnd(index);

			entry.mixDuration = this.data.getMix(current.animation, entry.animation);
			if (entry.mixDuration > 0) {
				entry.mixTime = 0;
				// If a mix is in progress, mix from the closest animation.
				if (previous && current.mixTime / current.mixDuration < 0.5)
					entry.previous = previous;
				else
					entry.previous = current;
			}
		}

		this.tracks[index] = entry;

		if (entry.onStart) entry.onStart(index);
		if (this.onStart) this.onStart(index);
	},
	setAnimationByName: function (trackIndex, animationName, loop) {
		var animation = this.data.skeletonData.findAnimation(animationName);
		if (!animation) throw "Animation not found: " + animationName;
		return this.setAnimation(trackIndex, animation, loop);
	},
	/** Set the current animation. Any queued animations are cleared. */
	setAnimation: function (trackIndex, animation, loop) {
		var entry = new spine.TrackEntry();
		entry.animation = animation;
		entry.loop = loop;
		entry.endTime = animation.duration;
		this.setCurrent(trackIndex, entry);
		return entry;
	},
	addAnimationByName: function (trackIndex, animationName, loop, delay) {
		var animation = this.data.skeletonData.findAnimation(animationName);
		if (!animation) throw "Animation not found: " + animationName;
		return this.addAnimation(trackIndex, animation, loop, delay);
	},
	/** Adds an animation to be played delay seconds after the current or last queued animation.
	 * @param delay May be <= 0 to use duration of previous animation minus any mix duration plus the negative delay. */
	addAnimation: function (trackIndex, animation, loop, delay) {
		var entry = new spine.TrackEntry();
		entry.animation = animation;
		entry.loop = loop;
		entry.endTime = animation.duration;

		var last = this._expandToIndex(trackIndex);
		if (last) {
			while (last.next)
				last = last.next;
			last.next = entry;
		} else
			this.tracks[trackIndex] = entry;

		if (delay <= 0) {
			if (last)
				delay += last.endTime - this.data.getMix(last.animation, animation);
			else
				delay = 0;
		}
		entry.delay = delay;

		return entry;
	},
	/** May be null. */
	getCurrent: function (trackIndex) {
		if (trackIndex >= this.tracks.length) return null;
		return this.tracks[trackIndex];
	}
};

spine.SkeletonJson = function (attachmentLoader) {
	this.attachmentLoader = attachmentLoader;
};
spine.SkeletonJson.prototype = {
	scale: 1,
	readSkeletonData: function (root, name) {
		var skeletonData = new spine.SkeletonData();
		skeletonData.name = name;

		// Skeleton.
		var skeletonMap = root["skeleton"];
		if (skeletonMap) {
			skeletonData.hash = skeletonMap["hash"];
			skeletonData.version = skeletonMap["spine"];
			skeletonData.width = skeletonMap["width"] || 0;
			skeletonData.height = skeletonMap["height"] || 0;
		}

		// Bones.
		var bones = root["bones"];
		for (var i = 0, n = bones.length; i < n; i++) {
			var boneMap = bones[i];
			var parent = null;
			if (boneMap["parent"]) {
				parent = skeletonData.findBone(boneMap["parent"]);
				if (!parent) throw "Parent bone not found: " + boneMap["parent"];
			}
			var boneData = new spine.BoneData(boneMap["name"], parent);
			boneData.length = (boneMap["length"] || 0) * this.scale;
			boneData.x = (boneMap["x"] || 0) * this.scale;
			boneData.y = (boneMap["y"] || 0) * this.scale;
			boneData.rotation = (boneMap["rotation"] || 0);
			boneData.scaleX = boneMap.hasOwnProperty("scaleX") ? boneMap["scaleX"] : 1;
			boneData.scaleY = boneMap.hasOwnProperty("scaleY") ? boneMap["scaleY"] : 1;
			boneData.inheritScale = boneMap.hasOwnProperty("inheritScale") ? boneMap["inheritScale"] : true;
			boneData.inheritRotation = boneMap.hasOwnProperty("inheritRotation") ? boneMap["inheritRotation"] : true;
			skeletonData.bones.push(boneData);
		}

		// IK constraints.
		var ik = root["ik"];
		if (ik) {
			for (var i = 0, n = ik.length; i < n; i++) {
				var ikMap = ik[i];
				var ikConstraintData = new spine.IkConstraintData(ikMap["name"]);

				var bones = ikMap["bones"];
				for (var ii = 0, nn = bones.length; ii < nn; ii++) {
					var bone = skeletonData.findBone(bones[ii]);
					if (!bone) throw "IK bone not found: " + bones[ii];
					ikConstraintData.bones.push(bone);
				}

				ikConstraintData.target = skeletonData.findBone(ikMap["target"]);
				if (!ikConstraintData.target) throw "Target bone not found: " + ikMap["target"];

				ikConstraintData.bendDirection = (!ikMap.hasOwnProperty("bendPositive") || ikMap["bendPositive"]) ? 1 : -1;
				ikConstraintData.mix = ikMap.hasOwnProperty("mix") ? ikMap["mix"] : 1;

				skeletonData.ikConstraints.push(ikConstraintData);
			}
		}

		// Slots.
		var slots = root["slots"];
		for (var i = 0, n = slots.length; i < n; i++) {
			var slotMap = slots[i];
			var boneData = skeletonData.findBone(slotMap["bone"]);
			if (!boneData) throw "Slot bone not found: " + slotMap["bone"];
			var slotData = new spine.SlotData(slotMap["name"], boneData);

			var color = slotMap["color"];
			if (color) {
				slotData.r = this.toColor(color, 0);
				slotData.g = this.toColor(color, 1);
				slotData.b = this.toColor(color, 2);
				slotData.a = this.toColor(color, 3);
			}

			slotData.attachmentName = slotMap["attachment"];
			slotData.blendMode = spine.BlendMode[slotMap["blend"] || "normal"];

			skeletonData.slots.push(slotData);
		}

		// Skins.
		var skins = root["skins"];
		for (var skinName in skins) {
			if (!skins.hasOwnProperty(skinName)) continue;
			var skinMap = skins[skinName];
			var skin = new spine.Skin(skinName);
			for (var slotName in skinMap) {
				if (!skinMap.hasOwnProperty(slotName)) continue;
				var slotIndex = skeletonData.findSlotIndex(slotName);
				var slotEntry = skinMap[slotName];
				for (var attachmentName in slotEntry) {
					if (!slotEntry.hasOwnProperty(attachmentName)) continue;
					var attachment = this.readAttachment(skin, attachmentName, slotEntry[attachmentName]);
					if (attachment) skin.addAttachment(slotIndex, attachmentName, attachment);
				}
			}
			skeletonData.skins.push(skin);
			if (skin.name == "default") skeletonData.defaultSkin = skin;
		}

		// Events.
		var events = root["events"];
		for (var eventName in events) {
			if (!events.hasOwnProperty(eventName)) continue;
			var eventMap = events[eventName];
			var eventData = new spine.EventData(eventName);
			eventData.intValue = eventMap["int"] || 0;
			eventData.floatValue = eventMap["float"] || 0;
			eventData.stringValue = eventMap["string"] || null;
			skeletonData.events.push(eventData);
		}

		// Animations.
		var animations = root["animations"];
		for (var animationName in animations) {
			if (!animations.hasOwnProperty(animationName)) continue;
			this.readAnimation(animationName, animations[animationName], skeletonData);
		}

		return skeletonData;
	},
	readAttachment: function (skin, name, map) {
		name = map["name"] || name;

		var type = spine.AttachmentType[map["type"] || "region"];
		var path = map["path"] || name;
		
		var scale = this.scale;
		if (type == spine.AttachmentType.region) {
			var region = this.attachmentLoader.newRegionAttachment(skin, name, path);
			if (!region) return null;
			region.path = path;
			region.x = (map["x"] || 0) * scale;
			region.y = (map["y"] || 0) * scale;
			region.scaleX = map.hasOwnProperty("scaleX") ? map["scaleX"] : 1;
			region.scaleY = map.hasOwnProperty("scaleY") ? map["scaleY"] : 1;
			region.rotation = map["rotation"] || 0;
			region.width = (map["width"] || 0) * scale;
			region.height = (map["height"] || 0) * scale;

			var color = map["color"];
			if (color) {
				region.r = this.toColor(color, 0);
				region.g = this.toColor(color, 1);
				region.b = this.toColor(color, 2);
				region.a = this.toColor(color, 3);
			}

			region.updateOffset();
			return region;
		} else if (type == spine.AttachmentType.mesh) {
			var mesh = this.attachmentLoader.newMeshAttachment(skin, name, path);
			if (!mesh) return null;
			mesh.path = path; 
			mesh.vertices = this.getFloatArray(map, "vertices", scale);
			mesh.triangles = this.getIntArray(map, "triangles");
			mesh.regionUVs = this.getFloatArray(map, "uvs", 1);
			mesh.updateUVs();

			color = map["color"];
			if (color) {
				mesh.r = this.toColor(color, 0);
				mesh.g = this.toColor(color, 1);
				mesh.b = this.toColor(color, 2);
				mesh.a = this.toColor(color, 3);
			}

			mesh.hullLength = (map["hull"] || 0) * 2;
			if (map["edges"]) mesh.edges = this.getIntArray(map, "edges");
			mesh.width = (map["width"] || 0) * scale;
			mesh.height = (map["height"] || 0) * scale;
			return mesh;
		} else if (type == spine.AttachmentType.skinnedmesh) {
			var mesh = this.attachmentLoader.newSkinnedMeshAttachment(skin, name, path);
			if (!mesh) return null;
			mesh.path = path;

			var uvs = this.getFloatArray(map, "uvs", 1);
			var vertices = this.getFloatArray(map, "vertices", 1);
			var weights = [];
			var bones = [];
			for (var i = 0, n = vertices.length; i < n; ) {
				var boneCount = vertices[i++] | 0;
				bones[bones.length] = boneCount;
				for (var nn = i + boneCount * 4; i < nn; ) {
					bones[bones.length] = vertices[i];
					weights[weights.length] = vertices[i + 1] * scale;
					weights[weights.length] = vertices[i + 2] * scale;
					weights[weights.length] = vertices[i + 3];
					i += 4;
				}
			}
			mesh.bones = bones;
			mesh.weights = weights;
			mesh.triangles = this.getIntArray(map, "triangles");
			mesh.regionUVs = uvs;
			mesh.updateUVs();
			
			color = map["color"];
			if (color) {
				mesh.r = this.toColor(color, 0);
				mesh.g = this.toColor(color, 1);
				mesh.b = this.toColor(color, 2);
				mesh.a = this.toColor(color, 3);
			}
			
			mesh.hullLength = (map["hull"] || 0) * 2;
			if (map["edges"]) mesh.edges = this.getIntArray(map, "edges");
			mesh.width = (map["width"] || 0) * scale;
			mesh.height = (map["height"] || 0) * scale;
			return mesh;
		} else if (type == spine.AttachmentType.boundingbox) {
			var attachment = this.attachmentLoader.newBoundingBoxAttachment(skin, name);
			var vertices = map["vertices"];
			for (var i = 0, n = vertices.length; i < n; i++)
				attachment.vertices.push(vertices[i] * scale);
			return attachment;
		}
		throw "Unknown attachment type: " + type;
	},
	readAnimation: function (name, map, skeletonData) {
		var timelines = [];
		var duration = 0;

		var slots = map["slots"];
		for (var slotName in slots) {
			if (!slots.hasOwnProperty(slotName)) continue;
			var slotMap = slots[slotName];
			var slotIndex = skeletonData.findSlotIndex(slotName);

			for (var timelineName in slotMap) {
				if (!slotMap.hasOwnProperty(timelineName)) continue;
				var values = slotMap[timelineName];
				if (timelineName == "color") {
					var timeline = new spine.ColorTimeline(values.length);
					timeline.slotIndex = slotIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var color = valueMap["color"];
						var r = this.toColor(color, 0);
						var g = this.toColor(color, 1);
						var b = this.toColor(color, 2);
						var a = this.toColor(color, 3);
						timeline.setFrame(frameIndex, valueMap["time"], r, g, b, a);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 5 - 5]);

				} else if (timelineName == "attachment") {
					var timeline = new spine.AttachmentTimeline(values.length);
					timeline.slotIndex = slotIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex++, valueMap["time"], valueMap["name"]);
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);

				} else
					throw "Invalid timeline type for a slot: " + timelineName + " (" + slotName + ")";
			}
		}

		var bones = map["bones"];
		for (var boneName in bones) {
			if (!bones.hasOwnProperty(boneName)) continue;
			var boneIndex = skeletonData.findBoneIndex(boneName);
			if (boneIndex == -1) throw "Bone not found: " + boneName;
			var boneMap = bones[boneName];

			for (var timelineName in boneMap) {
				if (!boneMap.hasOwnProperty(timelineName)) continue;
				var values = boneMap[timelineName];
				if (timelineName == "rotate") {
					var timeline = new spine.RotateTimeline(values.length);
					timeline.boneIndex = boneIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex, valueMap["time"], valueMap["angle"]);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 2 - 2]);

				} else if (timelineName == "translate" || timelineName == "scale") {
					var timeline;
					var timelineScale = 1;
					if (timelineName == "scale")
						timeline = new spine.ScaleTimeline(values.length);
					else {
						timeline = new spine.TranslateTimeline(values.length);
						timelineScale = this.scale;
					}
					timeline.boneIndex = boneIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var x = (valueMap["x"] || 0) * timelineScale;
						var y = (valueMap["y"] || 0) * timelineScale;
						timeline.setFrame(frameIndex, valueMap["time"], x, y);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 3 - 3]);

				} else if (timelineName == "flipX" || timelineName == "flipY") {
					var x = timelineName == "flipX";
					var timeline = x ? new spine.FlipXTimeline(values.length) : new spine.FlipYTimeline(values.length);
					timeline.boneIndex = boneIndex;

					var field = x ? "x" : "y";
					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex, valueMap["time"], valueMap[field] || false);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 2 - 2]);
				} else
					throw "Invalid timeline type for a bone: " + timelineName + " (" + boneName + ")";
			}
		}

		var ikMap = map["ik"];
		for (var ikConstraintName in ikMap) {
			if (!ikMap.hasOwnProperty(ikConstraintName)) continue;
			var ikConstraint = skeletonData.findIkConstraint(ikConstraintName);
			var values = ikMap[ikConstraintName];
			var timeline = new spine.IkConstraintTimeline(values.length);
			timeline.ikConstraintIndex = skeletonData.ikConstraints.indexOf(ikConstraint);
			var frameIndex = 0;
			for (var i = 0, n = values.length; i < n; i++) {
				var valueMap = values[i];
				var mix = valueMap.hasOwnProperty("mix") ? valueMap["mix"] : 1;
				var bendDirection = (!valueMap.hasOwnProperty("bendPositive") || valueMap["bendPositive"]) ? 1 : -1;
				timeline.setFrame(frameIndex, valueMap["time"], mix, bendDirection);
				this.readCurve(timeline, frameIndex, valueMap);
				frameIndex++;
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.frameCount * 3 - 3]);
		}

		var ffd = map["ffd"];
		for (var skinName in ffd) {
			var skin = skeletonData.findSkin(skinName);
			var slotMap = ffd[skinName];
			for (slotName in slotMap) {
				var slotIndex = skeletonData.findSlotIndex(slotName);
				var meshMap = slotMap[slotName];
				for (var meshName in meshMap) {
					var values = meshMap[meshName];
					var timeline = new spine.FfdTimeline(values.length);
					var attachment = skin.getAttachment(slotIndex, meshName);
					if (!attachment) throw "FFD attachment not found: " + meshName;
					timeline.slotIndex = slotIndex;
					timeline.attachment = attachment;
					
					var isMesh = attachment.type == spine.AttachmentType.mesh;
					var vertexCount;
					if (isMesh)
						vertexCount = attachment.vertices.length;
					else
						vertexCount = attachment.weights.length / 3 * 2;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var vertices;
						if (!valueMap["vertices"]) {
							if (isMesh)
								vertices = attachment.vertices;
							else {
								vertices = [];
								vertices.length = vertexCount;
							}
						} else {
							var verticesValue = valueMap["vertices"];
							var vertices = [];
							vertices.length = vertexCount;
							var start = valueMap["offset"] || 0;
							var nn = verticesValue.length;
							if (this.scale == 1) {
								for (var ii = 0; ii < nn; ii++)
									vertices[ii + start] = verticesValue[ii];
							} else {
								for (var ii = 0; ii < nn; ii++)
									vertices[ii + start] = verticesValue[ii] * this.scale;
							}
							if (isMesh) {
								var meshVertices = attachment.vertices;
								for (var ii = 0, nn = vertices.length; ii < nn; ii++)
									vertices[ii] += meshVertices[ii];
							}
						}
						
						timeline.setFrame(frameIndex, valueMap["time"], vertices);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines[timelines.length] = timeline;
					duration = Math.max(duration, timeline.frames[timeline.frameCount - 1]);
				}
			}
		}

		var drawOrderValues = map["drawOrder"];
		if (!drawOrderValues) drawOrderValues = map["draworder"];
		if (drawOrderValues) {
			var timeline = new spine.DrawOrderTimeline(drawOrderValues.length);
			var slotCount = skeletonData.slots.length;
			var frameIndex = 0;
			for (var i = 0, n = drawOrderValues.length; i < n; i++) {
				var drawOrderMap = drawOrderValues[i];
				var drawOrder = null;
				if (drawOrderMap["offsets"]) {
					drawOrder = [];
					drawOrder.length = slotCount;
					for (var ii = slotCount - 1; ii >= 0; ii--)
						drawOrder[ii] = -1;
					var offsets = drawOrderMap["offsets"];
					var unchanged = [];
					unchanged.length = slotCount - offsets.length;
					var originalIndex = 0, unchangedIndex = 0;
					for (var ii = 0, nn = offsets.length; ii < nn; ii++) {
						var offsetMap = offsets[ii];
						var slotIndex = skeletonData.findSlotIndex(offsetMap["slot"]);
						if (slotIndex == -1) throw "Slot not found: " + offsetMap["slot"];
						// Collect unchanged items.
						while (originalIndex != slotIndex)
							unchanged[unchangedIndex++] = originalIndex++;
						// Set changed items.
						drawOrder[originalIndex + offsetMap["offset"]] = originalIndex++;
					}
					// Collect remaining unchanged items.
					while (originalIndex < slotCount)
						unchanged[unchangedIndex++] = originalIndex++;
					// Fill in unchanged items.
					for (var ii = slotCount - 1; ii >= 0; ii--)
						if (drawOrder[ii] == -1) drawOrder[ii] = unchanged[--unchangedIndex];
				}
				timeline.setFrame(frameIndex++, drawOrderMap["time"], drawOrder);
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);
		}

		var events = map["events"];
		if (events) {
			var timeline = new spine.EventTimeline(events.length);
			var frameIndex = 0;
			for (var i = 0, n = events.length; i < n; i++) {
				var eventMap = events[i];
				var eventData = skeletonData.findEvent(eventMap["name"]);
				if (!eventData) throw "Event not found: " + eventMap["name"];
				var event = new spine.Event(eventData);
				event.intValue = eventMap.hasOwnProperty("int") ? eventMap["int"] : eventData.intValue;
				event.floatValue = eventMap.hasOwnProperty("float") ? eventMap["float"] : eventData.floatValue;
				event.stringValue = eventMap.hasOwnProperty("string") ? eventMap["string"] : eventData.stringValue;
				timeline.setFrame(frameIndex++, eventMap["time"], event);
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);
		}

		skeletonData.animations.push(new spine.Animation(name, timelines, duration));
	},
	readCurve: function (timeline, frameIndex, valueMap) {
		var curve = valueMap["curve"];
		if (!curve) 
			timeline.curves.setLinear(frameIndex);
		else if (curve == "stepped")
			timeline.curves.setStepped(frameIndex);
		else if (curve instanceof Array)
			timeline.curves.setCurve(frameIndex, curve[0], curve[1], curve[2], curve[3]);
	},
	toColor: function (hexString, colorIndex) {
		if (hexString.length != 8) throw "Color hexidecimal length must be 8, recieved: " + hexString;
		return parseInt(hexString.substring(colorIndex * 2, (colorIndex * 2) + 2), 16) / 255;
	},
	getFloatArray: function (map, name, scale) {
		var list = map[name];
		var values = new spine.Float32Array(list.length);
		var i = 0, n = list.length;
		if (scale == 1) {
			for (; i < n; i++)
				values[i] = list[i];
		} else {
			for (; i < n; i++)
				values[i] = list[i] * scale;
		}
		return values;
	},
	getIntArray: function (map, name) {
		var list = map[name];
		var values = new spine.Uint16Array(list.length);
		for (var i = 0, n = list.length; i < n; i++)
			values[i] = list[i] | 0;
		return values;
	}
};

spine.Atlas = function (atlasText, textureLoader) {
	this.textureLoader = textureLoader;
	this.pages = [];
	this.regions = [];

	var reader = new spine.AtlasReader(atlasText);
	var tuple = [];
	tuple.length = 4;
	var page = null;
	while (true) {
		var line = reader.readLine();
		if (line === null) break;
		line = reader.trim(line);
		if (!line.length)
			page = null;
		else if (!page) {
			page = new spine.AtlasPage();
			page.name = line;

			if (reader.readTuple(tuple) == 2) { // size is only optional for an atlas packed with an old TexturePacker.
				page.width = parseInt(tuple[0]);
				page.height = parseInt(tuple[1]);
				reader.readTuple(tuple);
			}
			page.format = spine.Atlas.Format[tuple[0]];

			reader.readTuple(tuple);
			page.minFilter = spine.Atlas.TextureFilter[tuple[0]];
			page.magFilter = spine.Atlas.TextureFilter[tuple[1]];

			var direction = reader.readValue();
			page.uWrap = spine.Atlas.TextureWrap.clampToEdge;
			page.vWrap = spine.Atlas.TextureWrap.clampToEdge;
			if (direction == "x")
				page.uWrap = spine.Atlas.TextureWrap.repeat;
			else if (direction == "y")
				page.vWrap = spine.Atlas.TextureWrap.repeat;
			else if (direction == "xy")
				page.uWrap = page.vWrap = spine.Atlas.TextureWrap.repeat;

			textureLoader.load(page, line, this);

			this.pages.push(page);

		} else {
			var region = new spine.AtlasRegion();
			region.name = line;
			region.page = page;

			region.rotate = reader.readValue() == "true";

			reader.readTuple(tuple);
			var x = parseInt(tuple[0]);
			var y = parseInt(tuple[1]);

			reader.readTuple(tuple);
			var width = parseInt(tuple[0]);
			var height = parseInt(tuple[1]);

			region.u = x / page.width;
			region.v = y / page.height;
			if (region.rotate) {
				region.u2 = (x + height) / page.width;
				region.v2 = (y + width) / page.height;
			} else {
				region.u2 = (x + width) / page.width;
				region.v2 = (y + height) / page.height;
			}
			region.x = x;
			region.y = y;
			region.width = Math.abs(width);
			region.height = Math.abs(height);

			if (reader.readTuple(tuple) == 4) { // split is optional
				region.splits = [parseInt(tuple[0]), parseInt(tuple[1]), parseInt(tuple[2]), parseInt(tuple[3])];

				if (reader.readTuple(tuple) == 4) { // pad is optional, but only present with splits
					region.pads = [parseInt(tuple[0]), parseInt(tuple[1]), parseInt(tuple[2]), parseInt(tuple[3])];

					reader.readTuple(tuple);
				}
			}

			region.originalWidth = parseInt(tuple[0]);
			region.originalHeight = parseInt(tuple[1]);

			reader.readTuple(tuple);
			region.offsetX = parseInt(tuple[0]);
			region.offsetY = parseInt(tuple[1]);

			region.index = parseInt(reader.readValue());

			this.regions.push(region);
		}
	}
};
spine.Atlas.prototype = {
	findRegion: function (name) {
		var regions = this.regions;
		for (var i = 0, n = regions.length; i < n; i++)
			if (regions[i].name == name) return regions[i];
		return null;
	},
	dispose: function () {
		var pages = this.pages;
		for (var i = 0, n = pages.length; i < n; i++)
			this.textureLoader.unload(pages[i].rendererObject);
	},
	updateUVs: function (page) {
		var regions = this.regions;
		for (var i = 0, n = regions.length; i < n; i++) {
			var region = regions[i];
			if (region.page != page) continue;
			region.u = region.x / page.width;
			region.v = region.y / page.height;
			if (region.rotate) {
				region.u2 = (region.x + region.height) / page.width;
				region.v2 = (region.y + region.width) / page.height;
			} else {
				region.u2 = (region.x + region.width) / page.width;
				region.v2 = (region.y + region.height) / page.height;
			}
		}
	}
};

spine.Atlas.Format = {
	alpha: 0,
	intensity: 1,
	luminanceAlpha: 2,
	rgb565: 3,
	rgba4444: 4,
	rgb888: 5,
	rgba8888: 6
};

spine.Atlas.TextureFilter = {
	nearest: 0,
	linear: 1,
	mipMap: 2,
	mipMapNearestNearest: 3,
	mipMapLinearNearest: 4,
	mipMapNearestLinear: 5,
	mipMapLinearLinear: 6
};

spine.Atlas.TextureWrap = {
	mirroredRepeat: 0,
	clampToEdge: 1,
	repeat: 2
};

spine.AtlasPage = function () {};
spine.AtlasPage.prototype = {
	name: null,
	format: null,
	minFilter: null,
	magFilter: null,
	uWrap: null,
	vWrap: null,
	rendererObject: null,
	width: 0,
	height: 0
};

spine.AtlasRegion = function () {};
spine.AtlasRegion.prototype = {
	page: null,
	name: null,
	x: 0, y: 0,
	width: 0, height: 0,
	u: 0, v: 0, u2: 0, v2: 0,
	offsetX: 0, offsetY: 0,
	originalWidth: 0, originalHeight: 0,
	index: 0,
	rotate: false,
	splits: null,
	pads: null
};

spine.AtlasReader = function (text) {
	this.lines = text.split(/\r\n|\r|\n/);
};
spine.AtlasReader.prototype = {
	index: 0,
	trim: function (value) {
		return value.replace(/^\s+|\s+$/g, "");
	},
	readLine: function () {
		if (this.index >= this.lines.length) return null;
		return this.lines[this.index++];
	},
	readValue: function () {
		var line = this.readLine();
		var colon = line.indexOf(":");
		if (colon == -1) throw "Invalid line: " + line;
		return this.trim(line.substring(colon + 1));
	},
	/** Returns the number of tuple values read (1, 2 or 4). */
	readTuple: function (tuple) {
		var line = this.readLine();
		var colon = line.indexOf(":");
		if (colon == -1) throw "Invalid line: " + line;
		var i = 0, lastMatch = colon + 1;
		for (; i < 3; i++) {
			var comma = line.indexOf(",", lastMatch);
			if (comma == -1) break;
			tuple[i] = this.trim(line.substr(lastMatch, comma - lastMatch));
			lastMatch = comma + 1;
		}
		tuple[i] = this.trim(line.substring(lastMatch));
		return i + 1;
	}
};

spine.AtlasAttachmentLoader = function (atlas) {
	this.atlas = atlas;
};
spine.AtlasAttachmentLoader.prototype = {
	newRegionAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (region attachment: " + name + ")";
		var attachment = new spine.RegionAttachment(name);
		attachment.rendererObject = region;
		attachment.setUVs(region.u, region.v, region.u2, region.v2, region.rotate);
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newMeshAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (mesh attachment: " + name + ")";
		var attachment = new spine.MeshAttachment(name);
		attachment.rendererObject = region;
		attachment.regionU = region.u;
		attachment.regionV = region.v;
		attachment.regionU2 = region.u2;
		attachment.regionV2 = region.v2;
		attachment.regionRotate = region.rotate;
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newSkinnedMeshAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (skinned mesh attachment: " + name + ")";
		var attachment = new spine.SkinnedMeshAttachment(name);
		attachment.rendererObject = region;
		attachment.regionU = region.u;
		attachment.regionV = region.v;
		attachment.regionU2 = region.u2;
		attachment.regionV2 = region.v2;
		attachment.regionRotate = region.rotate;
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newBoundingBoxAttachment: function (skin, name) {
		return new spine.BoundingBoxAttachment(name);
	}
};

spine.SkeletonBounds = function () {
	this.polygonPool = [];
	this.polygons = [];
	this.boundingBoxes = [];
};
spine.SkeletonBounds.prototype = {
	minX: 0, minY: 0, maxX: 0, maxY: 0,
	update: function (skeleton, updateAabb) {
		var slots = skeleton.slots;
		var slotCount = slots.length;
		var x = skeleton.x, y = skeleton.y;
		var boundingBoxes = this.boundingBoxes;
		var polygonPool = this.polygonPool;
		var polygons = this.polygons;

		boundingBoxes.length = 0;
		for (var i = 0, n = polygons.length; i < n; i++)
			polygonPool.push(polygons[i]);
		polygons.length = 0;

		for (var i = 0; i < slotCount; i++) {
			var slot = slots[i];
			var boundingBox = slot.attachment;
			if (boundingBox.type != spine.AttachmentType.boundingbox) continue;
			boundingBoxes.push(boundingBox);

			var poolCount = polygonPool.length, polygon;
			if (poolCount > 0) {
				polygon = polygonPool[poolCount - 1];
				polygonPool.splice(poolCount - 1, 1);
			} else
				polygon = [];
			polygons.push(polygon);

			polygon.length = boundingBox.vertices.length;
			boundingBox.computeWorldVertices(x, y, slot.bone, polygon);
		}

		if (updateAabb) this.aabbCompute();
	},
	aabbCompute: function () {
		var polygons = this.polygons;
		var minX = Number.MAX_VALUE, minY = Number.MAX_VALUE, maxX = Number.MIN_VALUE, maxY = Number.MIN_VALUE;
		for (var i = 0, n = polygons.length; i < n; i++) {
			var vertices = polygons[i];
			for (var ii = 0, nn = vertices.length; ii < nn; ii += 2) {
				var x = vertices[ii];
				var y = vertices[ii + 1];
				minX = Math.min(minX, x);
				minY = Math.min(minY, y);
				maxX = Math.max(maxX, x);
				maxY = Math.max(maxY, y);
			}
		}
		this.minX = minX;
		this.minY = minY;
		this.maxX = maxX;
		this.maxY = maxY;
	},
	/** Returns true if the axis aligned bounding box contains the point. */
	aabbContainsPoint: function (x, y) {
		return x >= this.minX && x <= this.maxX && y >= this.minY && y <= this.maxY;
	},
	/** Returns true if the axis aligned bounding box intersects the line segment. */
	aabbIntersectsSegment: function (x1, y1, x2, y2) {
		var minX = this.minX, minY = this.minY, maxX = this.maxX, maxY = this.maxY;
		if ((x1 <= minX && x2 <= minX) || (y1 <= minY && y2 <= minY) || (x1 >= maxX && x2 >= maxX) || (y1 >= maxY && y2 >= maxY))
			return false;
		var m = (y2 - y1) / (x2 - x1);
		var y = m * (minX - x1) + y1;
		if (y > minY && y < maxY) return true;
		y = m * (maxX - x1) + y1;
		if (y > minY && y < maxY) return true;
		var x = (minY - y1) / m + x1;
		if (x > minX && x < maxX) return true;
		x = (maxY - y1) / m + x1;
		if (x > minX && x < maxX) return true;
		return false;
	},
	/** Returns true if the axis aligned bounding box intersects the axis aligned bounding box of the specified bounds. */
	aabbIntersectsSkeleton: function (bounds) {
		return this.minX < bounds.maxX && this.maxX > bounds.minX && this.minY < bounds.maxY && this.maxY > bounds.minY;
	},
	/** Returns the first bounding box attachment that contains the point, or null. When doing many checks, it is usually more
	 * efficient to only call this method if {@link #aabbContainsPoint(float, float)} returns true. */
	containsPoint: function (x, y) {
		var polygons = this.polygons;
		for (var i = 0, n = polygons.length; i < n; i++)
			if (this.polygonContainsPoint(polygons[i], x, y)) return this.boundingBoxes[i];
		return null;
	},
	/** Returns the first bounding box attachment that contains the line segment, or null. When doing many checks, it is usually
	 * more efficient to only call this method if {@link #aabbIntersectsSegment(float, float, float, float)} returns true. */
	intersectsSegment: function (x1, y1, x2, y2) {
		var polygons = this.polygons;
		for (var i = 0, n = polygons.length; i < n; i++)
			if (polygons[i].intersectsSegment(x1, y1, x2, y2)) return this.boundingBoxes[i];
		return null;
	},
	/** Returns true if the polygon contains the point. */
	polygonContainsPoint: function (polygon, x, y) {
		var nn = polygon.length;
		var prevIndex = nn - 2;
		var inside = false;
		for (var ii = 0; ii < nn; ii += 2) {
			var vertexY = polygon[ii + 1];
			var prevY = polygon[prevIndex + 1];
			if ((vertexY < y && prevY >= y) || (prevY < y && vertexY >= y)) {
				var vertexX = polygon[ii];
				if (vertexX + (y - vertexY) / (prevY - vertexY) * (polygon[prevIndex] - vertexX) < x) inside = !inside;
			}
			prevIndex = ii;
		}
		return inside;
	},
	/** Returns true if the polygon contains the line segment. */
	polygonIntersectsSegment: function (polygon, x1, y1, x2, y2) {
		var nn = polygon.length;
		var width12 = x1 - x2, height12 = y1 - y2;
		var det1 = x1 * y2 - y1 * x2;
		var x3 = polygon[nn - 2], y3 = polygon[nn - 1];
		for (var ii = 0; ii < nn; ii += 2) {
			var x4 = polygon[ii], y4 = polygon[ii + 1];
			var det2 = x3 * y4 - y3 * x4;
			var width34 = x3 - x4, height34 = y3 - y4;
			var det3 = width12 * height34 - height12 * width34;
			var x = (det1 * width34 - width12 * det2) / det3;
			if (((x >= x3 && x <= x4) || (x >= x4 && x <= x3)) && ((x >= x1 && x <= x2) || (x >= x2 && x <= x1))) {
				var y = (det1 * height34 - height12 * det2) / det3;
				if (((y >= y3 && y <= y4) || (y >= y4 && y <= y3)) && ((y >= y1 && y <= y2) || (y >= y2 && y <= y1))) return true;
			}
			x3 = x4;
			y3 = y4;
		}
		return false;
	},
	getPolygon: function (attachment) {
		var index = this.boundingBoxes.indexOf(attachment);
		return index == -1 ? null : this.polygons[index];
	},
	getWidth: function () {
		return this.maxX - this.minX;
	},
	getHeight: function () {
		return this.maxY - this.minY;
	}
};
var a,aa=document.getElementById("canvasBackground"),ba="big landscape game_picross gameui_difficulty levelselectscreen endscreen_level theme_puzzles boostermedia2 final".split(" ");function f(b,c){var d=b.userAgent.match(c);return d&&1<d.length&&d[1]||""}
var l=new function(){this.userAgent=void 0;void 0===this.userAgent&&(this.userAgent=void 0!==navigator?navigator.userAgent:"");var b=f(this,/(ipod|iphone|ipad)/i).toLowerCase(),c=!/like android/i.test(this.userAgent)&&/android/i.test(this.userAgent),d=f(this,/version\/(\d+(\.\d+)?)/i),e=/tablet/i.test(this.userAgent),g=!e&&/[^-]mobi/i.test(this.userAgent);this.s={};this.xa={};this.Yc={};/opera|opr/i.test(this.userAgent)?(this.name="Opera",this.s.opera=!0,this.s.version=d||f(this,/(?:opera|opr)[\s\/](\d+(\.\d+)?)/i)):
/windows phone/i.test(this.userAgent)?(this.name="Windows Phone",this.xa.In=!0,this.s.Gj=!0,this.s.version=f(this,/iemobile\/(\d+(\.\d+)?)/i)):/msie|trident/i.test(this.userAgent)?(this.name="Internet Explorer",this.s.Gj=!0,this.s.version=f(this,/(?:msie |rv:)(\d+(\.\d+)?)/i)):/chrome|crios|crmo/i.test(this.userAgent)?(this.name="Chrome",this.s.chrome=!0,this.s.version=f(this,/(?:chrome|crios|crmo)\/(\d+(\.\d+)?)/i)):b?(this.name="iphone"==b?"iPhone":"ipad"==b?"iPad":"iPod",d&&(this.s.version=d)):
/sailfish/i.test(this.userAgent)?(this.name="Sailfish",this.s.fz=!0,this.s.version=f(this,/sailfish\s?browser\/(\d+(\.\d+)?)/i)):/seamonkey\//i.test(this.userAgent)?(this.name="SeaMonkey",this.s.uz=!0,this.s.version=f(this,/seamonkey\/(\d+(\.\d+)?)/i)):/firefox|iceweasel/i.test(this.userAgent)?(this.name="Firefox",this.s.ap=!0,this.s.version=f(this,/(?:firefox|iceweasel)[ \/](\d+(\.\d+)?)/i),/\((mobile|tablet);[^\)]*rv:[\d\.]+\)/i.test(this.userAgent)&&(this.xa.ex=!0)):/silk/i.test(this.userAgent)?
(this.name="Amazon Silk",this.s.Fq=!0,this.s.version=f(this,/silk\/(\d+(\.\d+)?)/i)):c?(this.name="Android",this.s.cg=!0,this.s.version=d):/phantom/i.test(this.userAgent)?(this.name="PhantomJS",this.s.Fy=!0,this.s.version=f(this,/phantomjs\/(\d+(\.\d+)?)/i)):/blackberry|\bbb\d+/i.test(this.userAgent)||/rim\stablet/i.test(this.userAgent)?(this.name="BlackBerry",this.s.so=!0,this.s.version=d||f(this,/blackberry[\d]+\/(\d+(\.\d+)?)/i)):/(web|hpw)os/i.test(this.userAgent)?(this.name="WebOS",this.s.Fr=
!0,this.s.version=d||f(this,/w(?:eb)?osbrowser\/(\d+(\.\d+)?)/i),/touchpad\//i.test(this.userAgent)&&(this.Yc.Uv=!0)):/bada/i.test(this.userAgent)?(this.name="Bada",this.s.ro=!0,this.s.version=f(this,/dolfin\/(\d+(\.\d+)?)/i)):/tizen/i.test(this.userAgent)?(this.name="Tizen",this.s.Tv=!0,this.s.version=f(this,/(?:tizen\s?)?browser\/(\d+(\.\d+)?)/i)||d):/safari/i.test(this.userAgent)&&(this.name="Safari",this.s.hn=!0,this.s.version=d);/(apple)?webkit/i.test(this.userAgent)?(this.name=this.name||"Webkit",
this.s.sA=!0,!this.s.version&&d&&(this.s.version=d)):!this.opera&&/gecko\//i.test(this.userAgent)&&(this.name=this.name||"Gecko",this.s.nx=!0,this.s.version=this.s.version||f(this,/gecko\/(\d+(\.\d+)?)/i));c||this.Fq?this.xa.qw=!0:b&&(this.xa.xj=!0);d="";b?(d=f(this,/os (\d+([_\s]\d+)*) like mac os x/i),d=d.replace(/[_\s]/g,".")):c?d=f(this,/android[ \/-](\d+(\.\d+)*)/i):this.In?d=f(this,/windows phone (?:os)?\s?(\d+(\.\d+)*)/i):this.Fr?d=f(this,/(?:web|hpw)os\/(\d+(\.\d+)*)/i):this.so?d=f(this,/rim\stablet\sos\s(\d+(\.\d+)*)/i):
this.ro?d=f(this,/bada\/(\d+(\.\d+)*)/i):this.Tv&&(d=f(this,/tizen[\/\s](\d+(\.\d+)*)/i));d&&(this.xa.version=d);d=d.split(".")[0];if(e||"ipad"==b||c&&(3==d||4==d&&!g)||this.Fq)this.Yc.xn=!0;else if(g||"iphone"==b||"ipod"==b||c||this.so||this.Fr||this.ro)this.Yc.Mm=!0;this.ee={Mg:!1,Zg:!1,x:!1};this.Gj&&10<=this.s.version||this.chrome&&20<=this.s.version||this.ap&&20<=this.s.version||this.hn&&6<=this.s.version||this.opera&&10<=this.s.version||this.xj&&this.xa.version&&6<=this.xa.version.split(".")[0]?
this.ee.Mg=!0:this.Gj&&10>this.s.version||this.chrome&&20>this.s.version||this.ap&&20>this.s.version||this.hn&&6>this.s.version||this.opera&&10>this.s.version||this.xj&&this.xa.version&&6>this.xa.version.split(".")[0]?this.ee.Zg=!0:this.ee.x=!0;try{this.s.Sd=this.s.version?parseFloat(this.s.version.match(/\d+(\.\d+)?/)[0],10):0}catch(h){this.s.Sd=0}try{this.xa.Sd=this.xa.version?parseFloat(this.xa.version.match(/\d+(\.\d+)?/)[0],10):0}catch(k){this.xa.Sd=0}};function ca(b,c){this.x=b;this.y=c}a=ca.prototype;
a.length=function(){return Math.sqrt(this.x*this.x+this.y*this.y)};a.direction=function(){return 180*Math.atan2(-this.y,this.x)/Math.PI};a.da=function(){return new ca(this.x,this.y)};a.add=function(b){return new ca(this.x+b.x,this.y+b.y)};a.scale=function(b){return new ca(b*this.x,b*this.y)};a.rotate=function(b){var c=Math.sin(b*Math.PI/180);b=Math.cos(b*Math.PI/180);return new ca(b*this.x+c*this.y,-c*this.x+b*this.y)};
a.normalize=function(){var b=Math.sqrt(this.x*this.x+this.y*this.y);return 0===b?new ca(0,0):new ca(this.x/b,this.y/b)};function da(b){return(new ca(b.y,-b.x)).normalize()}
a.pb=function(b,c,d){var e=Math.min(8,this.length()/4),g;g=this.normalize().scale(2*e);g=new ca(this.x-g.x,this.y-g.y);var h=g.add(da(this).scale(e)),e=g.add(da(this).scale(-e)),k=p.context;k.strokeStyle=d;k.beginPath();k.moveTo(b,c);k.lineTo(b+g.x,c+g.y);k.lineTo(b+h.x,c+h.y);k.lineTo(b+this.x,c+this.y);k.lineTo(b+e.x,c+e.y);k.lineTo(b+g.x,c+g.y);k.stroke()};function ea(b){this.Kh=4294967296;this.Mg=1664525;this.Zg=1013904223;this.state=void 0===b?Math.floor(Math.random()*(this.Kh-1)):b}
ea.prototype.da=function(){var b=new ea;b.Kh=this.Kh;b.Mg=this.Mg;b.Zg=this.Zg;b.state=this.state;return b};ea.prototype.random=function(b){var c=1;void 0!==b&&(c=b);this.state=(this.Mg*this.state+this.Zg)%this.Kh;return this.state/this.Kh*c};new ea;function fa(){this.Vd="";this.Ok=[];this.Lg=[];this.ve=[];this.pf=[];this.cc=[];this.rd("start");this.rd("load");this.rd("game")}function ga(b){var c=ia;c.Vd=b;""!==c.Vd&&"/"!==c.Vd[c.Vd.length-1]&&(c.Vd+="/")}a=fa.prototype;
a.rd=function(b){this.cc[b]||(this.Lg[b]=0,this.ve[b]=0,this.pf[b]=0,this.cc[b]=[],this.Ok[b]=!1)};a.loaded=function(b){return this.cc[b]?this.ve[b]:0};a.Ie=function(b){return this.cc[b]?this.pf[b]:0};a.complete=function(b){return this.cc[b]?this.ve[b]+this.pf[b]===this.Lg[b]:!0};function ja(b){var c=ia;return c.cc[b]?100*(c.ve[b]+c.pf[b])/c.Lg[b]:100}function ka(b){var c=ia;c.ve[b]+=1;c.complete(b)&&la("Load Complete",{Ga:b})}function ma(b){var c=ia;c.pf[b]+=1;la("Load Failed",{Ga:b})}
function na(b,c,d){var e=ia;e.cc[c]||e.rd(c);e.cc[c].push(b);e.Lg[c]+=d}a.ed=function(b){var c;if(!this.Ok[b])if(this.Ok[b]=!0,this.cc[b]&&0!==this.cc[b].length)for(c=0;c<this.cc[b].length;c+=1)this.cc[b][c].ed(b,this.Vd);else la("Load Complete",{Ga:b})};var ia=new fa;function oa(b){this.context=this.canvas=void 0;this.height=this.width=0;b&&this.nb(b)}oa.prototype.nb=function(b){this.canvas=b;this.context=b.getContext("2d");this.width=b.width;this.height=b.height};
oa.prototype.clear=function(){this.context.clearRect(0,0,this.width,this.height);this.context.beginPath();this.context.moveTo(0,0);this.context.lineTo(-1,-1);this.context.closePath();this.context.stroke()};
function pa(b,c,d,e,g,h){var k=p;k.context.save();!1===h?(k.context.fillStyle=g,k.context.fillRect(b,c,d,e)):!0===h?(k.context.strokeStyle=g,k.context.strokeRect(b,c,d,e)):(void 0!==g&&(k.context.fillStyle=g,k.context.fillRect(b,c,d,e)),void 0!==h&&(k.context.strokeStyle=h,k.context.strokeRect(b,c,d,e)));k.context.restore()}
function qa(b,c,d,e,g,h){var k=p;k.context.save();k.context.beginPath();k.context.moveTo(b,c);k.context.lineTo(d,e);h&&(k.context.lineWidth=h);k.context.strokeStyle=g;k.context.stroke();k.context.restore()}function ra(b,c,d,e){var g=p;g.context.save();g.context.font="16px Arial";void 0!==e&&(g.context.fillStyle=e,g.context.fillText(b,c,d));g.context.restore()}oa.prototype.Wa=function(b,c){this.context.font=c;return this.context.measureText(b).width};var p=new oa(aa);
function sa(b,c,d){this.name=b;this.G=c;this.Lt=d;this.ec=[];this.Bl=[];na(this,this.Lt,this.G)}sa.prototype.ed=function(b,c){function d(){ma(b)}function e(){ka(b)}var g,h;for(g=0;g<this.ec.length;g+=1)h=this.Bl[g],0!==h.toLowerCase().indexOf("http:")&&0!==h.toLowerCase().indexOf("https:")&&(h=c+h),this.ec[g].src=h,this.ec[g].addEventListener("load",e,!1),this.ec[g].addEventListener("error",d,!1)};
sa.prototype.complete=function(){var b;for(b=0;b<this.ec.length;b+=1)if(!this.ec[b].complete||0===this.ec[b].width)return!1;return!0};function ta(b,c,d){0<=c&&c<b.G&&(b.ec[c]=new Image,b.Bl[c]=d)}sa.prototype.c=function(b,c){0<=b&&b<this.G&&(this.ec[b]=c,this.Bl[b]="")};sa.prototype.I=function(b,c,d,e,g,h,k,m,n){this.ec[b]&&this.ec[b].complete&&(void 0===m&&(m=e),void 0===n&&(n=g),0>=e||0>=g||0!==Math.round(m)&&0!==Math.round(n)&&p.context.drawImage(this.ec[b],c,d,e,g,h,k,m,n))};
function w(b,c,d,e,g,h,k,m,n,q){this.name=b;this.Od=c;this.G=d;this.width=e;this.height=g;this.Ha=h;this.Ia=k;this.eh=m;this.yf=n;this.Sf=q;this.Ld=[];this.Md=[];this.Nd=[];this.gd=[];this.fd=[];this.hd=[];this.jd=[]}a=w.prototype;a.c=function(b,c,d,e,g,h,k,m){0<=b&&b<this.G&&(this.Ld[b]=c,this.Md[b]=d,this.Nd[b]=e,this.gd[b]=g,this.fd[b]=h,this.hd[b]=k,this.jd[b]=m)};a.complete=function(){return this.Od.complete()};
a.n=function(b,c,d){b=(Math.round(b)%this.G+this.G)%this.G;this.Od.I(this.Ld[b],this.Md[b],this.Nd[b],this.gd[b],this.fd[b],c-this.Ha+this.hd[b],d-this.Ia+this.jd[b])};a.kc=function(b,c,d,e){var g=p.context,h=g.globalAlpha;g.globalAlpha=e;b=(Math.round(b)%this.G+this.G)%this.G;this.Od.I(this.Ld[b],this.Md[b],this.Nd[b],this.gd[b],this.fd[b],c-this.Ha+this.hd[b],d-this.Ia+this.jd[b]);g.globalAlpha=h};
a.V=function(b,c,d,e,g,h,k){var m=p.context;1E-4>Math.abs(e)||1E-4>Math.abs(g)||(b=(Math.round(b)%this.G+this.G)%this.G,m.save(),m.translate(c,d),m.rotate(-h*Math.PI/180),m.scale(e,g),m.globalAlpha=k,this.Od.I(this.Ld[b],this.Md[b],this.Nd[b],this.gd[b],this.fd[b],this.hd[b]-this.Ha,this.jd[b]-this.Ia),m.restore())};
a.be=function(b,c,d,e,g,h,k,m,n,q){var v,z,B,r,s,t,u,C,N,K,P,U,X,ya,ha,Ya;0!==this.width&&0!==this.height&&(void 0===k&&(k=Math.floor(this.width/3)),void 0===m&&(m=Math.floor(this.width/3)),void 0===n&&(n=Math.floor(this.height/3)),void 0===q&&(q=Math.floor(this.height/3)),e<k+m&&(k=Math.round(k*e/(k+m)),m=e-k),g<n+q&&(n=Math.round(n*g/(n+q)),q=g-n),N=this.width,v=k,z=this.width-k-m,B=m,r=v+z,K=this.height,s=n,t=this.height-n-q,u=q,C=s+t,P=k,k=e-k-m,U=c+P,X=c+P+k,ya=n,n=g-n-q,ha=d+ya,Ya=d+ya+n,e===
this.width&&g===this.height?this.kc(b,c+this.Ha,d+this.Ia,h):g===this.height?(this.$a(b,v,0,z,K,U,d,k,g,h),this.I(b,0,0,v,K,c,d,h),this.I(b,r,0,B,K,X,d,h)):e===this.width?(this.$a(b,0,s,N,t,c,ha,e,n,h),this.I(b,0,0,N,s,c,d,h),this.I(b,0,C,N,u,c,Ya,h)):(this.$a(b,v,s,z,t,U,ha,k,n,h),this.$a(b,v,0,z,s,U,d,k,ya,h),this.$a(b,0,s,v,t,c,ha,P,n,h),this.$a(b,r,s,B,t,X,ha,m,n,h),this.$a(b,v,C,z,u,U,Ya,k,q,h),this.I(b,0,0,v,s,c,d,h),this.I(b,0,C,v,u,c,Ya,h),this.I(b,r,0,B,s,X,d,h),this.I(b,r,C,B,u,X,Ya,h)))};
a.yl=function(b,c,d,e,g,h,k,m){var n=p.context,q=n.globalAlpha,v,z,B,r,s,t,u,C,N;if(0!==this.width&&0!==this.height){b=(Math.round(b)%this.G+this.G)%this.G;n.globalAlpha=m;c=Math.round(c-this.Ha)%this.width;0<c&&(c-=this.width);d=Math.round(d-this.Ia)%this.height;0<d&&(d-=this.height);m=Math.ceil((h-c)/this.width);v=Math.ceil((k-d)/this.height);c+=e+this.hd[b];d+=g+this.jd[b];for(C=0;C<m;C+=1)for(N=0;N<v;N+=1)r=this.Md[b],s=this.Nd[b],t=this.gd[b],u=this.fd[b],z=c+C*this.width,B=d+N*this.height,z<
e&&(r+=e-z,t-=e-z,z=e),z+t>=e+h&&(t=e+h-z),B<g&&(s+=g-B,u-=g-B,B=g),B+u>=g+k&&(u=g+k-B),0<t&&0<u&&this.Od.I(this.Ld[b],r,s,t,u,z,B);n.globalAlpha=q}};a.kh=function(b,c,d,e,g,h){this.yl(b,0,0,c,d,e,g,h)};
a.I=function(b,c,d,e,g,h,k,m){var n=p.context,q=n.globalAlpha,v,z,B,r;b=(Math.round(b)%this.G+this.G)%this.G;v=this.hd[b];z=this.jd[b];B=this.gd[b];r=this.fd[b];c-=v;d-=z;0>=c+e||0>=d+g||c>=B||d>=r||(0>c&&(e+=c,h-=c,c=0),0>d&&(g+=d,k-=d,d=0),c+e>B&&(e=B-c),d+g>r&&(g=r-d),n.globalAlpha=m,this.Od.I(this.Ld[b],this.Md[b]+c,this.Nd[b]+d,e,g,h,k),n.globalAlpha=q)};
a.xl=function(b,c,d,e,g,h,k,m,n,q,v,z){var B,r,s,t,u,C,N,K,P,U;if(!(0>=h||0>=k))for(c=Math.round(c)%h,0<c&&(c-=h),d=Math.round(d)%k,0<d&&(d-=k),B=Math.ceil((q-c)/h),r=Math.ceil((v-d)/k),c+=m,d+=n,P=0;P<B;P+=1)for(U=0;U<r;U+=1)u=e,C=g,N=h,K=k,s=c+P*h,t=d+U*k,s<m&&(u+=m-s,N-=m-s,s=m),s+N>=m+q&&(N=m+q-s),t<n&&(C+=n-t,K-=n-t,t=n),t+K>=n+v&&(K=n+v-t),0<N&&0<K&&this.I(b,u,C,N,K,s,t,z)};a.Vi=function(b,c,d,e,g,h,k,m,n,q){this.xl(b,0,0,c,d,e,g,h,k,m,n,q)};
a.$a=function(b,c,d,e,g,h,k,m,n,q){var v=p.context,z=v.globalAlpha,B,r,s,t,u,C;b=(Math.round(b)%this.G+this.G)%this.G;B=m/e;r=n/g;s=this.hd[b];t=this.jd[b];u=this.gd[b];C=this.fd[b];c-=s;d-=t;0>=c+e||0>=d+g||c>=u||d>=C||(0>c&&(e+=c,m+=B*c,h-=B*c,c=0),0>d&&(g+=d,n+=r*d,k-=r*d,d=0),c+e>u&&(m-=B*(e-u+c),e=u-c),d+g>C&&(n-=r*(g-C+d),g=C-d),v.globalAlpha=q,this.Od.I(this.Ld[b],this.Md[b]+c,this.Nd[b]+d,e,g,h,k,m,n),v.globalAlpha=z)};
function ua(b,c,d){var e,g,h;for(e=0;e<b.G;e+=1)g=c+e%b.Sf*b.width,h=d+b.height*Math.floor(e/b.Sf),b.Od.I(b.Ld[e],b.Md[e],b.Nd[e],b.gd[e],b.fd[e],g-b.Ha+b.hd[e],h-b.Ia+b.jd[e])}function x(b,c){this.canvas=document.createElement("canvas");this.context=this.canvas.getContext("2d");this.width=b;this.height=c;this.Ia=this.Ha=0;this.canvas.width=b;this.canvas.height=c;this.clear();this.Hj=void 0}a=x.prototype;
a.da=function(){var b=new x(this.width,this.height);b.Ha=this.Ha;b.Ia=this.Ia;y(b);this.n(0,0);A(b);return b};function y(b){b.Hj=p.canvas;p.nb(b.canvas)}function A(b){p.canvas===b.canvas&&void 0!==b.Hj&&(p.nb(b.Hj),b.Hj=void 0)}a.clear=function(){this.context.clearRect(0,0,this.canvas.width,this.canvas.height)};a.n=function(b,c){p.context.drawImage(this.canvas,b-this.Ha,c-this.Ia)};
a.kc=function(b,c,d){var e=p.context,g=e.globalAlpha;e.globalAlpha=d;p.context.drawImage(this.canvas,b-this.Ha,c-this.Ia);e.globalAlpha=g};a.V=function(b,c,d,e,g,h){var k=p.context;1E-4>Math.abs(d)||1E-4>Math.abs(e)||(k.save(),k.translate(b,c),k.rotate(-g*Math.PI/180),k.scale(d,e),k.globalAlpha=h,p.context.drawImage(this.canvas,-this.Ha,-this.Ia),k.restore())};
a.be=function(b,c,d,e,g,h,k,m,n){var q,v,z,B,r,s,t,u,C,N,K,P,U,X,ya,ha;0!==this.width&&0!==this.height&&(void 0===h&&(h=Math.floor(this.width/3)),void 0===k&&(k=Math.floor(this.width/3)),void 0===m&&(m=Math.floor(this.height/3)),void 0===n&&(n=Math.floor(this.height/3)),d<h+k&&(h=Math.round(h*d/(h+k)),k=d-h),e<m+n&&(m=Math.round(m*e/(m+n)),n=e-m),C=this.width,q=h,v=this.width-h-k,z=k,B=q+v,N=this.height,r=m,s=this.height-m-n,t=n,u=r+s,K=h,h=d-h-k,P=b+K,U=b+K+h,X=m,m=e-m-n,ya=c+X,ha=c+X+m,d===this.width&&
e===this.height?this.kc(b+this.Ha,c+this.Ia,g):e===this.height?(this.$a(q,0,v,N,P,c,h,e,g),this.I(0,0,q,N,b,c,g),this.I(B,0,z,N,U,c,g)):d===this.width?(this.$a(0,r,C,s,b,ya,d,m,g),this.I(0,0,C,r,b,c,g),this.I(0,u,C,t,b,ha,g)):(this.$a(q,r,v,s,P,ya,h,m,g),this.$a(q,0,v,r,P,c,h,X,g),this.$a(0,r,q,s,b,ya,K,m,g),this.$a(B,r,z,s,U,ya,k,m,g),this.$a(q,u,v,t,P,ha,h,n,g),this.I(0,0,q,r,b,c,g),this.I(0,u,q,t,b,ha,g),this.I(B,0,z,r,U,c,g),this.I(B,u,z,t,U,ha,g)))};
a.yl=function(b,c,d,e,g,h,k){var m=p.context,n=m.globalAlpha,q,v,z,B,r,s,t,u,C;if(0!==this.width&&0!==this.height){m.globalAlpha=k;b=Math.round(b-this.Ha)%this.width;0<b&&(b-=this.width);c=Math.round(c-this.Ia)%this.height;0<c&&(c-=this.height);k=Math.ceil((g-b)/this.width);q=Math.ceil((h-c)/this.height);b+=d;c+=e;for(u=0;u<k;u+=1)for(C=0;C<q;C+=1)r=B=0,s=this.width,t=this.height,v=b+u*this.width,z=c+C*this.height,v<d&&(B+=d-v,s-=d-v,v=d),v+s>=d+g&&(s=d+g-v),z<e&&(r+=e-z,t-=e-z,z=e),z+t>=e+h&&(t=
e+h-z),0<s&&0<t&&p.context.drawImage(this.canvas,B,r,s,t,v,z,s,t);m.globalAlpha=n}};a.kh=function(b,c,d,e,g){this.yl(0,0,b,c,d,e,g)};a.I=function(b,c,d,e,g,h,k){var m=p.context,n=m.globalAlpha;0>=d||0>=e||(b+d>this.width&&(d=this.width-b),c+e>this.height&&(e=this.height-c),m.globalAlpha=k,p.context.drawImage(this.canvas,b,c,d,e,g,h,d,e),m.globalAlpha=n)};
a.xl=function(b,c,d,e,g,h,k,m,n,q,v){var z,B,r,s,t,u,C,N,K,P;if(!(0>=g||0>=h))for(d+g>this.width&&(g=this.width-d),e+h>this.height&&(h=this.height-e),b=Math.round(b)%g,0<b&&(b-=g),c=Math.round(c)%h,0<c&&(c-=h),z=Math.ceil((n-b)/g),B=Math.ceil((q-c)/h),b+=k,c+=m,K=0;K<z;K+=1)for(P=0;P<B;P+=1)t=d,u=e,C=g,N=h,r=b+K*g,s=c+P*h,r<k&&(t+=k-r,C-=k-r,r=k),r+C>=k+n&&(C=k+n-r),s<m&&(u+=m-s,N-=m-s,s=m),s+N>=m+q&&(N=m+q-s),0<C&&0<N&&this.I(t,u,C,N,r,s,v)};
a.Vi=function(b,c,d,e,g,h,k,m,n){this.xl(0,0,b,c,d,e,g,h,k,m,n)};a.$a=function(b,c,d,e,g,h,k,m,n){var q=p.context,v=q.globalAlpha;0>=d||0>=e||(b+d>this.width&&(d=this.width-b),c+e>this.height&&(e=this.height-c),0!==Math.round(k)&&0!==Math.round(m)&&(q.globalAlpha=n,p.context.drawImage(this.canvas,b,c,d,e,g,h,k,m),q.globalAlpha=v))};
function va(b,c,d,e){this.w=b;this.dw=c;this.Wv=d;this.oi=[{text:"MiHhX!@v&Qq",width:-1,font:"sans-serif"},{text:"MiHhX!@v&Qq",width:-1,font:"serif"},{text:"AaMm#@!Xx67",width:-1,font:"sans-serif"},{text:"AaMm#@!Xx67",width:-1,font:"serif"}];this.Xq=!1;na(this,e,1)}function wa(b,c,d){p.context.save();p.context.font="250pt "+b+", "+c;b=p.context.measureText(d).width;p.context.restore();return b}
function xa(b){var c,d,e;for(c=0;c<b.oi.length;c+=1)if(d=b.oi[c],e=wa(b.w,d.font,d.text),d.width!==e){ka(b.Kt);document.body.removeChild(b.Td);b.Xq=!0;return}window.setTimeout(function(){xa(b)},33)}
va.prototype.ed=function(b,c){var d="@font-face {font-family: "+this.w+";src: url('"+c+this.dw+"') format('woff'), url('"+c+this.Wv+"') format('truetype');}",e=document.createElement("style");e.id=this.w+"_fontface";e.type="text/css";e.styleSheet?e.styleSheet.cssText=d:e.appendChild(document.createTextNode(d));document.getElementsByTagName("head")[0].appendChild(e);this.Td=document.createElement("span");this.Td.style.position="absolute";this.Td.style.left="-9999px";this.Td.style.top="-9999px";this.Td.style.visibility=
"hidden";this.Td.style.fontSize="250pt";this.Td.id=this.w+"_loader";document.body.appendChild(this.Td);for(d=0;d<this.oi.length;d+=1)e=this.oi[d],e.width=wa(e.font,e.font,e.text);this.Kt=b;xa(this)};va.prototype.complete=function(){return this.Xq};
function za(b,c){this.w=b;this.lh=c;this.fontWeight=this.fontStyle="";this.nc="normal";this.fontSize=12;this.fill=!0;this.La=1;this.mc=0;this.fillColor="black";this.Hc={e:void 0,Aa:0,dn:!0,en:!0};this.Fa={hi:!0,G:3,Li:["red","white","blue"],size:.6,offset:0};this.fillStyle=void 0;this.stroke=!1;this.Na=1;this.dg=0;this.strokeColor="black";this.strokeStyle=void 0;this.Oc=1;this.qe=!1;this.ef="miter";this.J={j:!1,color:"rgba(10, 10, 10, 0.3)",offsetX:3,offsetY:3,blur:1};this.align="left";this.g="top";
this.fa=this.Ca=0}a=za.prototype;
a.da=function(){var b=new za(this.w,this.lh);b.fontStyle=this.fontStyle;b.fontWeight=this.fontWeight;b.nc=this.nc;b.fontSize=this.fontSize;b.fill=this.fill;b.La=this.La;b.mc=this.mc;b.fillColor=this.fillColor;b.Hc={e:this.Hc.e,dn:this.Hc.dn,en:this.Hc.en};b.Fa={hi:this.Fa.hi,G:this.Fa.G,Li:this.Fa.Li.slice(0),size:this.Fa.size,offset:this.Fa.offset};b.fillStyle=this.fillStyle;b.stroke=this.stroke;b.Na=this.Na;b.dg=this.dg;b.strokeColor=this.strokeColor;b.strokeStyle=this.strokeStyle;b.Oc=this.Oc;
b.qe=this.qe;b.ef=this.ef;b.J={j:this.J.j,color:this.J.color,offsetX:this.J.offsetX,offsetY:this.J.offsetY,blur:this.J.blur};b.align=this.align;b.g=this.g;b.Ca=this.Ca;b.fa=this.fa;return b};
function D(b,c){void 0!==c.w&&(b.w=c.w);void 0!==c.lh&&(b.lh=c.lh);void 0!==c.fontStyle&&(b.fontStyle=c.fontStyle);void 0!==c.fontWeight&&(b.fontWeight=c.fontWeight);void 0!==c.nc&&(b.nc=c.nc);void 0!==c.fontSize&&(b.fontSize=c.fontSize);void 0!==c.fill&&(b.fill=c.fill);void 0!==c.La&&(b.La=c.La);void 0!==c.fillColor&&(b.mc=0,b.fillColor=c.fillColor);void 0!==c.Hc&&(b.mc=1,b.Hc=c.Hc);void 0!==c.Fa&&(b.mc=2,b.Fa=c.Fa);void 0!==c.fillStyle&&(b.mc=3,b.fillStyle=c.fillStyle);void 0!==c.stroke&&(b.stroke=
c.stroke);void 0!==c.Na&&(b.Na=c.Na);void 0!==c.strokeColor&&(b.dg=0,b.strokeColor=c.strokeColor);void 0!==c.strokeStyle&&(b.dg=3,b.strokeStyle=c.strokeStyle);void 0!==c.Oc&&(b.Oc=c.Oc);void 0!==c.qe&&(b.qe=c.qe);void 0!==c.ef&&(b.ef=c.ef);void 0!==c.J&&(b.J=c.J);void 0!==c.align&&(b.align=c.align);void 0!==c.g&&(b.g=c.g);void 0!==c.Ca&&(b.Ca=c.Ca);void 0!==c.fa&&(b.fa=c.fa)}function Aa(b){b.fontWeight="normal"}function E(b,c){b.fontSize=void 0===c?12:c}
a.setFillColor=function(b){this.mc=0;this.fillColor=void 0===b?"black":b};function Ba(b,c,d,e,g){b.mc=2;b.Fa.hi=!0;b.Fa.G=c;b.Fa.Li=d.slice(0);b.Fa.size=void 0===e?.6:e;b.Fa.offset=void 0===g?0:g}function Ca(b,c){b.stroke=void 0===c?!1:c}a.setStrokeColor=function(b){this.dg=0;this.strokeColor=void 0===b?"black":b};function Da(b,c){b.Oc=void 0===c?1:c}function Ea(b,c){b.qe=void 0===c?!1:c}function Fa(b){b.ef="miter"}
function Ga(b,c,d){void 0===c?b.J.j=!0:b.J={j:!0,color:c,offsetX:0,offsetY:d,blur:2}}function Ha(b,c){b.align=void 0===c?"left":c}function Ia(b,c){b.g=void 0===c?"top":c}function Ja(b){return b.fontStyle+" "+b.fontWeight+" "+b.fontSize+"px "+b.w+", "+b.lh}function Ka(b){var c=0,d;for(d=0;d<b.length;d+=1)c=Math.max(c,b[d].width);return c}function La(b,c){return b.fontSize*c.length+b.fa*(c.length-1)}
function Ma(b,c,d){var e,g,h,k,m,n,q=[],v=p.context;v.font=Ja(b);switch(b.nc){case "upper":c=c.toUpperCase();break;case "lower":c=c.toLowerCase()}if(void 0===d){n=c.split("\n");for(b=0;b<n.length;b+=1)q.push({text:n[b],width:v.measureText(n[b]).width});return q}n=c.split("\n");h=v.measureText(" ").width;for(b=0;b<n.length;b+=1){g=n[b].split(" ");e=g[0];m=v.measureText(g[0]).width;for(c=1;c<g.length;c+=1)k=v.measureText(g[c]).width,m+h+k<d?(e+=" "+g[c],m+=h+k):(q.push({text:e,width:m}),e=g[c],m=k);
q.push({text:e,width:m})}return q}a.Wa=function(b,c){var d;p.context.save();d=Ka(Ma(this,b,c));p.context.restore();return d};function Na(b,c,d){p.context.save();b=La(b,Ma(b,c,d));p.context.restore();return b}function Oa(b,c,d,e,g,h){var k=b.fontSize;b.fontSize=c;c=h?Ma(b,d,e):Ma(b,d);e=Ka(c)<=e&&La(b,c)<=g;b.fontSize=k;return e}
function Pa(b,c,d,e,g){var h=0,k=32;void 0===g&&(g=!1);for(p.context.save();Oa(b,h+k,c,d,e,g);)h+=k;for(;2<=k;)k/=2,Oa(b,h+k,c,d,e,g)&&(h+=k);p.context.restore();return Math.max(4,h)}function Qa(b,c,d,e,g){var h=Math.max(.01,b.Fa.size),k=b.Fa.offset;b.Fa.hi?(k=g/2+k*g,h=.5*h*g,c=p.context.createLinearGradient(c,d+k-h,c,d+k+h)):(k=e/2+k*e,h=.5*h*e,c=p.context.createLinearGradient(c+k-h,d,c+k+h,d));d=1/(b.Fa.G-1);for(e=0;e<b.Fa.G;e+=1)c.addColorStop(e*d,b.Fa.Li[e]);return c}
function Ra(b,c,d,e,g,h,k){var m,n;!b.fill&&b.J.j?(c.shadowColor=b.J.color,c.shadowOffsetX=b.J.offsetX,c.shadowOffsetY=b.J.offsetY,c.shadowBlur=b.J.blur):(c.shadowColor=void 0,c.shadowOffsetX=0,c.shadowOffsetY=0,c.shadowBlur=0);c.globalAlpha=k*b.Na;switch(b.dg){case 0:c.strokeStyle=b.strokeColor;break;case 3:c.strokeStyle=b.strokeStyle}c.lineWidth=b.Oc;c.lineJoin=b.ef;for(k=0;k<d.length;k+=1){m=0;switch(b.align){case "right":m=h-d[k].width;break;case "center":m=(h-d[k].width)/2}n=b.fontSize*(k+1)+
b.fa*k;c.strokeText(d[k].text,e+m,g+n)}}
function Sa(b,c,d,e,g,h,k){d=Ma(b,d,k);k=Ka(d);var m=La(b,d);c.textAlign="left";c.textBaseline="bottom";switch(b.align){case "right":e+=-k;break;case "center":e+=-k/2}switch(b.g){case "base":case "bottom":g+=-m+Math.round(b.Ca*b.fontSize);break;case "middle":g+=-m/2+Math.round(b.Ca*b.fontSize/2)}c.font=Ja(b);b.stroke&&b.qe&&Ra(b,c,d,e,g,k,h);if(b.fill){var n=e,q=g,v,z;b.J.j?(c.shadowColor=b.J.color,c.shadowOffsetX=b.J.offsetX,c.shadowOffsetY=b.J.offsetY,c.shadowBlur=b.J.blur):(c.shadowColor=void 0,
c.shadowOffsetX=0,c.shadowOffsetY=0,c.shadowBlur=0);c.globalAlpha=h*b.La;switch(b.mc){case 0:c.fillStyle=b.fillColor;break;case 1:m=b.Hc.e;z=new x(m.width,m.height);var B=b.Hc.dn,r=b.Hc.en;B&&r?v="repeat":B&&!r?v="repeat-x":!B&&r?v="repeat-y":B||r||(v="no-repeat");y(z);m.n(b.Hc.Aa,0,0);A(z);v=p.context.createPattern(z.canvas,v);c.fillStyle=v;break;case 2:c.fillStyle=Qa(b,n,q,k,m);break;case 3:c.fillStyle=b.fillStyle;break;default:c.fillStyle=b.fillColor}for(v=0;v<d.length;v+=1){m=0;switch(b.align){case "right":m=
k-d[v].width;break;case "center":m=(k-d[v].width)/2}z=b.fontSize*(v+1)+b.fa*v;2===b.mc&&b.Fa.hi&&(c.fillStyle=Qa(b,n,q+z-b.fontSize,k,b.fontSize));c.fillText(d[v].text,n+m,q+z)}}b.stroke&&!b.qe&&Ra(b,c,d,e,g,k,h)}a.n=function(b,c,d,e){var g=p.context;this.fill&&1===this.mc?this.V(b,c,d,1,1,0,1,e):(g.save(),Sa(this,g,b,c,d,1,e),g.restore())};a.kc=function(b,c,d,e,g){var h=p.context;this.fill&&1===this.mc?this.V(b,c,d,1,1,0,e,g):(h.save(),Sa(this,h,b,c,d,e,g),h.restore())};
a.V=function(b,c,d,e,g,h,k,m){var n=p.context;n.save();n.translate(c,d);n.rotate(-h*Math.PI/180);n.scale(e,g);try{Sa(this,n,b,0,0,k,m)}catch(q){}n.restore()};
function Ta(){this.$t=10;this.si=-1;this.Tr="stop_lowest_prio";this.oo=this.Ea=this.Xa=!1;var b,c=this,d="undefined"!==typeof AudioContext?AudioContext:"undefined"!==typeof webkitAudioContext?webkitAudioContext:void 0;if(d)this.Xa=!0;else if("undefined"!==typeof Audio)try{"undefined"!==typeof(new Audio).canPlayType&&(this.Ea=!0)}catch(e){}this.oo=this.Xa||this.Ea;this.Ea&&l.s.cg&&(this.si=1);if(this.oo)try{b=new Audio,this.Qn={ogg:!!b.canPlayType('audio/ogg; codecs="vorbis"').replace(/^no$/,""),mp3:!!b.canPlayType("audio/mpeg;").replace(/^no$/,
""),opus:!!b.canPlayType('audio/ogg; codecs="opus"').replace(/^no$/,""),wav:!!b.canPlayType('audio/wav; codecs="1"').replace(/^no$/,""),m4a:!!(b.canPlayType("audio/x-m4a;")||b.canPlayType("audio/aac;")).replace(/^no$/,""),mp4:!!(b.canPlayType("audio/x-mp4;")||b.canPlayType("audio/aac;")).replace(/^no$/,""),weba:!!b.canPlayType('audio/webm; codecs="vorbis"').replace(/^no$/,"")}}catch(g){this.Qn={ogg:!1,mp3:!0,opus:!1,wav:!1,m4a:!1,mp4:!1,weba:!1}}this.Db=[];this.ue={};this.Qa={};this.Cc={};this.md=
[];this.Mb=0;this.Xa?(this.ld=new d,this.Rn="function"===typeof this.ld.createGain?function(){return c.ld.createGain()}:"function"===typeof this.ld.createGainNode?function(){return c.ld.createGainNode()}:function(){},this.se={},this.ri=this.Rn(),void 0===this.ri?(this.Ea=!0,this.xg=Ta.prototype.Nk):(this.ri.connect(this.ld.destination),this.se.master=this.ri,this.xg=Ta.prototype.Sr)):this.xg=this.Ea?Ta.prototype.Nk:function(){}}
function Ua(b){var c=F,d,e,g,h,k;for(d=0;d<c.Db.length;d+=1)if((e=c.Db[d])&&0===e.Al)if(e.paused)e.Vn&&(e.Pk+=b,e.Pk>=e.Vn&&c.Uh(e.id));else if(e.Rk+=b,e.of&&e.Rk>=e.Mq)e.of=!1,Va(c,e,e.od);else if(e.dd&&c.Ea&&c.am(e.id)>=e.duration)if(e.Hm)try{e.B.pause(),e.B.currentTime=e.od/1E3,4===e.B.readyState?e.B.play():(g=function(){var b=e;return{ready:function(){b.B.play();b.B.removeEventListener("canplaythrough",g.ready,!1)}}}(),e.B.addEventListener("canplaythrough",g.ready,!1))}catch(m){}else e.B.pause(),
Wa(e);for(d=c.md.length-1;0<=d;d-=1)h=c.md[d],c.Ep(h.id)||0!==h.Al||(h.t+=b,h.t>=h.duration?(Xa(F,h.id,h.ai),void 0!==c.Cc[h.id]&&(c.Cc[h.id]=h.ai),h.yb&&h.yb(),c.md.splice(d,1)):(k=h.Ra(h.t,h.start,h.ai-h.start,h.duration),Xa(F,h.id,k),void 0!==c.Cc[h.id]&&(c.Cc[h.id]=k)))}function Za(b,c){b.ue[c.Bb.p.name]?b.ue[c.Bb.p.name].length<b.$t&&b.ue[c.Bb.p.name].push(c.B):b.ue[c.Bb.p.name]=[c.B]}
function $a(b,c){var d,e,g;g=[];for(d=0;d<b.Db.length;d+=1)(e=b.Db[d])&&0<=e.ka.indexOf(c)&&g.push(e);return g}function ab(b,c){if(0<b.si&&b.Mb>=b.si)switch(b.Tr){case "cancel_new":return!1;case "stop_lowest_prio":var d,e,g;for(d=0;d<b.Db.length;d+=1)(e=b.Db[d])&&e.dd&&!e.paused&&(void 0===g||g.Tj<e.Tj)&&(g=e);if(g.Tj>c.Hg){b.stop(g.id);break}return!1}return!0}
function bb(b,c){var d,e=1;for(d=0;d<c.ka.length;d+=1)void 0!==F.Qa[c.ka[d]]&&(e*=F.Qa[c.ka[d]]);d=b.Rn();d.gain.value=e;d.connect(b.ri);b.se[c.id]=d;c.B.connect(d)}function cb(b,c){c.B.disconnect(0);b.se[c.id]&&(b.se[c.id].disconnect(0),delete b.se[c.id])}function db(b,c){var d;if(c.p&&c.p.xb){if(b.Xa)return d=b.ld.createBufferSource(),d.buffer=c.p.xb,d.loopStart=c.startOffset/1E3,d.loopEnd=(c.startOffset+c.duration)/1E3,d;if(b.Ea)return d=c.p.xb.cloneNode(!0),d.volume=0,d}}
function eb(b,c){var d,e;if(b.Xa)(d=db(b,c))&&(e=new fb(c,d));else if(b.Ea){d=b.ue[c.p.name];if(!d)return;0<d.length?e=new fb(c,d.pop()):(d=db(b,c))&&(e=new fb(c,d))}if(e){b.Xa&&bb(b,e);for(d=0;d<b.Db.length;d+=1)if(void 0===b.Db[d])return b.Db[d]=e;b.Db.push(e)}return e}function gb(b){var c=F,d,e;for(d=0;d<b.length;d+=1)if(e=b[d].split(".").pop(),c.Qn[e])return b[d];return!1}a=Ta.prototype;
a.Nk=function(b,c,d){function e(){var c;b.loaded=!0;ka(d);b.duration=Math.ceil(1E3*b.xb.duration);b.xb.removeEventListener("canplaythrough",e,!1);b.xb.removeEventListener("error",g,!1);c=b.xb.cloneNode(!0);F.ue[b.name].push(c)}function g(){ma(d)}(c=gb(c))?(b.xb=new Audio,b.xb.src=c,b.xb.autoplay=!1,b.xb.Hy="auto",b.xb.addEventListener("canplaythrough",e,!1),b.xb.addEventListener("error",g,!1),b.xb.load()):g()};
a.Sr=function(b,c,d){var e=gb(c),g=new XMLHttpRequest;g.open("GET",e,!0);g.responseType="arraybuffer";g.onload=function(){F.ld.decodeAudioData(g.response,function(c){c&&(b.xb=c,b.duration=1E3*c.duration,b.loaded=!0,ka(d))},function(){ma(d)})};g.onerror=function(){"undefined"!==typeof Audio&&(F.Xa=!1,F.Ea=!0,F.xg=Ta.prototype.Nk,F.xg(b,c,d))};try{g.send()}catch(h){}};
a.play=function(b,c,d,e){if(b instanceof hb){if(ab(this,b)){b=eb(this,b);if(!b)return-1;b.Mq=c||0;b.of=0<c;b.ib=d||0;b.yd=e||function(b,c,d,e){return 0==b?c:d*Math.pow(2,10*(b/e-1))+c};b.of||Va(this,b,b.od);return b.id}return-1}};
function Va(b,c,d){var e;"number"!==typeof d&&(d=0);ib(b,c.id);0<c.ib&&(e=jb(b,c.id),Xa(b,c.id,0),kb(b,c.id,e,c.ib,c.yd),c.ib=0,c.yd=void 0);if(b.Xa){e=d-c.od;c.Vr=1E3*b.ld.currentTime-e;c.B.onended=function(){Wa(c)};try{c.B.start?c.B.start(0,d/1E3,(c.duration-e)/1E3):c.B.noteGrainOn&&c.B.noteGrainOn(0,d/1E3,(c.duration-e)/1E3),c.Sc=!0,c.dd=!0,b.Mb+=1,c.B.loop=c.Hm}catch(g){}}else if(b.Ea){if(4!==c.B.readyState){var h=function(){return{ready:function(){c.B.currentTime=d/1E3;c.B.play();c.Sc=!0;c.B.removeEventListener("canplaythrough",
h.ready,!1)}}}();c.B.addEventListener("canplaythrough",h.ready,!1)}else c.B.currentTime=d/1E3,c.B.play(),c.Sc=!0;c.dd=!0;b.Mb+=1}}
a.Uh=function(b,c,d,e){var g,h,k,m,n=$a(this,b);for(g=0;g<n.length;g+=1)if(h=n[g],(h.paused||!h.dd)&&!e||!h.paused&&e){if(!e){for(g=this.md.length-1;0<=g;g-=1)if(b=this.md[g],b.id===h.id){m=b;c=0;d=void 0;break}h.paused=!1;h.ib=c||0;h.yd=d||function(b,c,d,e){return 0==b?c:d*Math.pow(2,10*(b/e-1))+c};h.vg&&(void 0===c&&(h.ib=h.vg.duration),void 0===d&&(h.yd=h.vg.Ra),k=h.vg.gain,h.vg=void 0)}this.Xa&&(b=db(this,h.Bb))&&(h.B=b,bb(this,h));void 0!==k&&Xa(F,h.id,k);Va(this,h,h.od+(h.ti||0));void 0!==m&&
(Xa(F,h.id,m.Ra(m.t,m.start,m.ai-m.start,m.duration)),kb(F,h.id,m.ai,m.duration-m.t,m.Ra,m.yb))}};
a.pause=function(b,c,d,e,g){var h,k,m=$a(this,b);for(b=0;b<m.length;b+=1)if(h=m[b],!h.paused)if(h.ib=d||0,0<h.ib)h.yd=e||function(b,c,d,e){return 0==b?c:d*Math.pow(2,10*(b/e-1))+c},h.vg={gain:lb(h.id),duration:h.ib,Ra:h.yd},kb(F,h.id,0,h.ib,h.yd,function(){F.pause(h.id,c)});else if(k=this.am(h.id),h.ti=k,g||(h.paused=!0,h.Pk=0,h.Vn=c,this.Mb-=1),this.Xa){h.B.onended=function(){};if(h.dd&&h.Sc){try{h.B.stop?h.B.stop(0):h.B.noteOff&&h.B.noteOff(0)}catch(n){}h.Sc=!1}cb(this,h)}else this.Ea&&h.B.pause()};
function Wa(b){var c=F;c.Qa[b.id]&&delete c.Qa[b.id];b.paused||(c.Mb-=1);c.Xa?(b.Sc=!1,b.dd=!1,cb(c,b)):c.Ea&&Za(c,b);c.Db[c.Db.indexOf(b)]=void 0}
a.stop=function(b,c,d){var e,g=$a(this,b);for(b=0;b<g.length;b+=1)if(e=g[b],e.ib=c||0,0<e.ib)e.yd=d||function(b,c,d,e){return 0==b?c:d*Math.pow(2,10*(b/e-1))+c},kb(F,e.id,0,e.ib,e.yd,function(){F.stop(e.id)});else{this.Qa[e.id]&&delete this.Qa[e.id];e.dd&&!e.paused&&(this.Mb-=1);if(this.Xa){if(e.dd&&!e.paused&&!e.of){if(e.Sc){try{e.B.stop?e.B.stop(0):e.B.noteOff&&e.B.noteOff(0)}catch(h){}e.Sc=!1}cb(this,e)}}else this.Ea&&(e.of||e.B.pause(),Za(this,e));this.Db[this.Db.indexOf(e)]=void 0;e.dd=!1}};
function kb(b,c,d,e,g,h){var k;for(k=0;k<b.md.length;k+=1)if(b.md[k].id===c){b.md.splice(k,1);break}b.md.push({id:c,ai:d,Ra:g||function(b,c,d,e){return b==e?c+d:d*(-Math.pow(2,-10*b/e)+1)+c},duration:e,t:0,start:jb(b,c),yb:h,Al:0})}function mb(b){var c=F,d;void 0===c.Cc[b]&&(d=void 0!==c.Qa[b]?c.Qa[b]:1,Xa(c,b,0),c.Cc[b]=d)}function nb(b){var c=F;void 0!==c.Cc[b]&&(Xa(c,b,c.Cc[b]),delete c.Cc[b])}
a.position=function(b,c){var d,e,g,h,k=$a(this,b);if(!isNaN(c)&&0<=c)for(d=0;d<k.length;d++)if(e=k[d],c%=e.duration,this.Xa)if(e.paused)e.ti=c;else{e.B.onended=function(){};if(e.Sc){try{e.B.stop?e.B.stop(0):e.B.noteOff&&e.B.noteOff(0)}catch(m){}e.Sc=!1}cb(this,e);this.Mb-=1;if(g=db(this,e.Bb))e.B=g,bb(this,e),Va(this,e,e.od+c)}else this.Ea&&(4===e.B.readyState?e.B.currentTime=(e.od+c)/1E3:(h=function(){var b=e,d=c;return{qp:function(){b.B.currentTime=(b.od+d)/1E3;b.B.removeEventListener("canplaythrough",
h.qp,!1)}}}(),e.B.addEventListener("canplaythrough",h.qp,!1)))};a.gn=function(b){F.position(b,0)};a.Bq=function(b,c){var d,e=$a(this,b);for(d=0;d<e.length;d+=1)e[d].Hm=c,this.Xa&&(e[d].B.loop=c)};function jb(b,c){return void 0!==b.Qa[c]?b.Qa[c]:1}function lb(b){var c=F,d=1,e=$a(c,b)[0];if(e)for(b=0;b<e.ka.length;b+=1)void 0!==c.Qa[e.ka[b]]&&(d*=c.Qa[e.ka[b]]);return Math.round(100*d)/100}
function Xa(b,c,d){var e,g,h=1,k=$a(b,c);b.Qa[c]=d;b.Cc[c]&&delete b.Cc[c];for(d=0;d<k.length;d+=1)if(e=k[d],0<=e.ka.indexOf(c)){for(g=0;g<e.ka.length;g+=1)void 0!==b.Qa[e.ka[g]]&&(h*=b.Qa[e.ka[g]]);h=Math.round(100*h)/100;b.Xa?b.se[e.id].gain.value=h:b.Ea&&(e.B.volume=h)}}function ib(b,c){var d,e,g,h=1,k=$a(b,c);for(d=0;d<k.length;d+=1){e=k[d];for(g=0;g<e.ka.length;g+=1)void 0!==b.Qa[e.ka[g]]&&(h*=b.Qa[e.ka[g]]);h=Math.round(100*h)/100;b.Xa?b.se[e.id].gain.value=h:b.Ea&&(e.B.volume=h)}}
a.ho=function(b,c){var d,e,g,h=$a(this,b);for(d=0;d<h.length;d+=1)for(e=h[d],c=[].concat(c),g=0;g<c.length;g+=1)0>e.ka.indexOf(c[g])&&e.ka.push(c[g]);ib(this,b)};a.Ep=function(b){if(b=$a(this,b)[0])return b.paused};a.am=function(b){if(b=$a(this,b)[0]){if(this.Xa)return b.paused?b.ti:(1E3*F.ld.currentTime-b.Vr)%b.duration;if(F.Ea)return Math.ceil(1E3*b.B.currentTime-b.od)}};var F=new Ta;function ob(b,c,d,e){this.name=b;this.su=c;this.yu=d;this.Vb=e;this.loaded=!1;this.xb=null;na(this,this.Vb,1)}
ob.prototype.ed=function(b,c){var d,e;d=this.su;0!==d.toLowerCase().indexOf("http:")&&0!==d.toLowerCase().indexOf("https:")&&(d=c+d);e=this.yu;0!==e.toLowerCase().indexOf("http:")&&0!==e.toLowerCase().indexOf("https:")&&(e=c+e);F.ue[this.name]=[];F.xg(this,[e,d],b)};ob.prototype.complete=function(){return this.loaded};
function hb(b,c,d,e,g,h,k){this.name=b;this.p=c;this.startOffset=d;this.duration=e;Xa(F,this.name,void 0!==g?g:1);this.Hg=void 0!==h?h:10;this.ka=[];k&&(this.ka=this.ka.concat(k));0>this.ka.indexOf(this.name)&&this.ka.push(this.name)}hb.prototype.complete=function(){return this.p.complete()};hb.prototype.Tj=function(b){void 0!==b&&(this.Hg=b);return this.Hg};hb.prototype.ho=function(b){var c;b=[].concat(b);for(c=0;c<b.length;c+=1)0>this.ka.indexOf(b[c])&&this.ka.push(b[c])};
function fb(b,c){this.Bb=b;this.od=this.Bb.startOffset;this.B=c;this.duration=this.Bb.duration;this.Lk()}fb.prototype.Lk=function(){this.id=Math.round(Date.now()*Math.random())+"";this.ka=["master",this.id].concat(this.Bb.ka);this.Tj=void 0!==this.Bb.Hg?this.Bb.Hg:10;this.paused=this.dd=this.Hm=!1;this.Rk=this.Al=0;this.Sc=this.of=!1;this.Mq=this.ti=0;var b,c=1;for(b=0;b<this.ka.length;b+=1)void 0!==F.Qa[this.ka[b]]&&(c*=F.Qa[this.ka[b]]);!F.Xa&&F.Ea&&(this.B.volume=c)};
function pb(b){this.name=b;this.text="";this.Ie=this.complete=!1}pb.prototype.ve=function(b){4===b.readyState&&(this.complete=!0,(this.Ie=200!==b.status)?la("Get Failed",{name:this.name}):(this.text=b.responseText,la("Get Complete",{name:this.name})))};
function qb(b,c){var d=new XMLHttpRequest;b.complete=!1;d.open("POST",c);d.setRequestHeader("Content-Type","text/plain;charset=UTF-8");d.onreadystatechange=function(){4===d.readyState&&(b.complete=!0,b.Ie=200!==d.status,b.Ie?la("Post Failed",{name:b.name}):la("Post Complete",{name:b.name}))};d.send(b.text)}function rb(b,c){var d=new XMLHttpRequest;d.open("GET",c,!1);try{d.send()}catch(e){return!1}b.complete=!0;b.Ie=200!==d.status;if(b.Ie)return!1;b.text=d.responseText;return!0}
function tb(b){b&&(this.Dd=b);this.clear();this.Eg=this.rf=this.Ac=this.Dg=this.Cg=this.Gg=this.zg=this.Fg=this.nd=this.Bg=this.Ag=0;ub(this,this);vb(this,this);wb(this,this);this.Ud=[];this.qg=[];this.Jg=[];this.D=0;this.Wn=!1;this.zj=this.startTime=Date.now();this.df=this.jj=0;this.bu=200;this.Vb="";window.ki(window.Nn)}tb.prototype.clear=function(){this.A=[];this.Kg=!1;this.wb=[];this.Kk=!1};
function ub(b,c){window.addEventListener("click",function(b){var e,g,h;if(void 0!==c.Dd&&!(0<c.D)&&(e=c.Dd,g=e.getBoundingClientRect(),h=e.width/g.width*(b.clientX-g.left),e=e.height/g.height*(b.clientY-g.top),b.preventDefault(),c.nf.x=h,c.nf.y=e,c.sg.push({x:c.nf.x,y:c.nf.y}),0<c.Dg))for(b=c.A.length-1;0<=b&&!((h=c.A[b])&&h.j&&0>=h.D&&h.gm&&(h=h.gm(c.nf.x,c.nf.y),!0===h));b-=1);},!1);xb(b)}function xb(b){b.nf={x:0,y:0};b.sg=[]}
function vb(b,c){window.addEventListener("mousedown",function(b){0<c.D||(b.preventDefault(),window.focus(),c.Un>=Date.now()-1E3||(yb(c,0,b.clientX,b.clientY),zb(c,0)))},!1);window.addEventListener("mouseup",function(b){0<c.D||(b.preventDefault(),c.qi>=Date.now()-1E3||(yb(c,0,b.clientX,b.clientY),Ab(c,0)))},!1);window.addEventListener("mousemove",function(b){0<c.D||(b.preventDefault(),yb(c,0,b.clientX,b.clientY))},!1);window.addEventListener("touchstart",function(b){var e=b.changedTouches;c.Un=Date.now();
if(!(0<c.D))for(b.preventDefault(),window.focus(),b=0;b<e.length;b+=1)yb(c,e[b].identifier,e[b].clientX,e[b].clientY),zb(c,e[b].identifier)},!1);window.addEventListener("touchend",function(b){var e=b.changedTouches;c.qi=Date.now();if(!(0<c.D))for(b.preventDefault(),b=0;b<e.length;b+=1)yb(c,e[b].identifier,e[b].clientX,e[b].clientY),Ab(c,e[b].identifier)},!1);window.addEventListener("touchmove",function(b){var e=b.changedTouches;if(!(0<c.D))for(b.preventDefault(),b=0;b<e.length;b+=1)yb(c,e[b].identifier,
e[b].clientX,e[b].clientY)},!1);window.addEventListener("touchleave",function(b){var e=b.changedTouches;c.qi=Date.now();if(!(0<c.D))for(b.preventDefault(),b=0;b<e.length;b+=1)yb(c,e[b].identifier,e[b].clientX,e[b].clientY),Ab(c,e[b].identifier)},!1);window.addEventListener("touchcancel",function(b){var e=b.changedTouches;c.qi=Date.now();if(!(0<c.D))for(b.preventDefault(),b=0;b<e.length;b+=1)yb(c,e[b].identifier,e[b].clientX,e[b].clientY),Ab(c,e[b].identifier)},!1);window.addEventListener("mousewheel",
function(b){Bb(c,b)},!1);window.addEventListener("DOMMouseScroll",function(b){Bb(c,b)},!1);Cb(b);b.Un=0;b.qi=0}function Cb(b){var c;b.ba=[];for(c=0;16>c;c+=1)b.ba[c]={id:-1,Za:!1,x:0,y:0};b.xe=[]}function Db(b,c){var d=-1,e;for(e=0;16>e;e+=1)if(b.ba[e].id===c){d=e;break}if(-1===d)for(e=0;16>e;e+=1)if(!b.ba[e].Za){d=e;b.ba[e].id=c;break}return d}
function yb(b,c,d,e){var g,h;void 0!==b.Dd&&(c=Db(b,c),-1!==c&&(g=b.Dd,h=g.getBoundingClientRect(),b.ba[c].x=g.width/h.width*(d-h.left),b.ba[c].y=g.height/h.height*(e-h.top)))}function zb(b,c){var d=Db(b,c),e,g;if(-1!==d&&!b.ba[d].Za&&(b.xe.push({Je:d,x:b.ba[d].x,y:b.ba[d].y,Za:!0}),b.ba[d].Za=!0,0<b.Ac))for(e=b.A.length-1;0<=e&&!((g=b.A[e])&&g.j&&0>=g.D&&g.Hf&&(g=g.Hf(d,b.ba[d].x,b.ba[d].y),!0===g));e-=1);}
function Ab(b,c){var d=Db(b,c),e,g;if(-1!==d&&b.ba[d].Za&&(b.xe.push({Je:d,x:b.ba[d].x,y:b.ba[d].y,Za:!1}),b.ba[d].Za=!1,0<b.Ac))for(e=b.A.length-1;0<=e&&!((g=b.A[e])&&g.j&&0>=g.D&&g.If&&(g=g.If(d,b.ba[d].x,b.ba[d].y),!0===g));e-=1);}
function Bb(b,c){var d;if(!(0<b.D)){c.preventDefault();window.focus();d=Math.max(-1,Math.min(1,c.wheelDelta||-c.detail));var e,g;b.xe.push({Je:0,x:b.ba[0].x,y:b.ba[0].y,wheelDelta:d});if(0<b.Ac)for(e=b.A.length-1;0<=e&&!((g=b.A[e])&&g.j&&0>=g.D&&g.jm&&(g=g.jm(d,b.ba[0].x,b.ba[0].y),!0===g));e-=1);}}function Eb(b){return G.ba[b].x}
function wb(b,c){window.addEventListener("keydown",function(b){0<c.D||(-1<[32,37,38,39,40].indexOf(b.keyCode)&&b.preventDefault(),Fb(c,b.keyCode))},!1);window.addEventListener("keyup",function(b){0<c.D||(-1<[32,37,38,39,40].indexOf(b.keyCode)&&b.preventDefault(),Gb(c,b.keyCode))},!1);Hb(b)}function Hb(b){var c;b.wg=[];for(c=0;256>c;c+=1)b.wg[c]=!1;b.qf=[]}
function Fb(b,c){var d,e;if(!b.wg[c]&&(b.qf.push({key:c,Za:!0}),b.wg[c]=!0,0<b.rf))for(d=0;d<b.A.length&&!((e=b.A[d])&&e.j&&0>=e.D&&e.hm&&(e=e.hm(c),!0===e));d+=1);}function Gb(b,c){var d,e;if(b.wg[c]&&(b.qf.push({key:c,Za:!1}),b.wg[c]=!1,0<b.rf))for(d=0;d<b.A.length&&!((e=b.A[d])&&e.j&&0>=e.D&&e.im&&(e=e.im(c),!0===e));d+=1);}function Ib(){var b=G,c;for(c=0;c<b.Ud.length;c+=1)b.Ud[c].paused+=1}
function la(b,c){var d,e=G,g,h;void 0===d&&(d=null);e.Jg.push({id:b,gs:c,kg:d});if(0<e.Eg)for(g=0;g<e.A.length&&(!((h=e.A[g])&&h.j&&0>=h.D&&h.km)||null!==d&&d!==h||(h=h.km(b,c),!0!==h));g+=1);}
function Jb(b,c){var d=b.wb[c];d.visible&&(void 0!==d.canvas&&d.canvas!==p.canvas&&p.nb(d.canvas),!1!==p.canvas.X||!0===d.Zc)&&(0===d.Tn&&(0>=d.D&&(d.Aa+=d.es*b.df/1E3),1===d.Dk&&1===d.Ek&&0===d.na?1===d.alpha?d.e.n(d.Aa,d.x,d.y):d.e.kc(d.Aa,d.x,d.y,d.alpha):d.e.V(d.Aa,d.x,d.y,d.Dk,d.Ek,d.na,d.alpha)),1===d.Tn&&(1===d.Dk&&1===d.Ek&&0===d.na?1===d.alpha?d.font.n(d.text,d.x,d.y):d.font.kc(d.text,d.x,d.y,d.alpha):d.font.V(d.text,d.x,d.y,d.Dk,d.Ek,d.na,d.alpha)))}
function Kb(b,c){var d=b.A[c];if(d.visible&&(void 0!==d.canvas&&d.canvas!==p.canvas&&p.nb(d.canvas),(!1!==p.canvas.X||!0===d.Zc)&&d.Ma))return d.Ma()}function Lb(b){for(var c=0,d=0;c<b.A.length||d<b.wb.length;)if(d===b.wb.length){if(!0===Kb(b,c))break;c+=1}else if(c===b.A.length)Jb(b,d),d+=1;else if(b.wb[d].ua>b.A[c].ua||b.wb[d].ua===b.A[c].ua&&b.wb[d].depth>b.A[c].depth)Jb(b,d),d+=1;else{if(!0===Kb(b,c))break;c+=1}}tb.prototype.pause=function(b){this.D+=1;void 0===b&&(b=!1);this.Wn=b};
tb.prototype.Uh=function(){0!==this.D&&(this.zj=Date.now(),this.D-=1)};tb.prototype.Ep=function(){return 0<this.D};window.Hk=0;window.Gk=0;window.On=0;window.Kr=0;window.Pn=0;window.Mr=60;window.Nr=0;window.Lr=!1;
window.Nn=function(){window.Hk=Date.now();window.Kr=window.Hk-window.Gk;var b=G,c;if(0<b.D)b.Wn&&(Mb(b),Lb(b));else{c=Date.now();"number"!==typeof c&&(c=b.zj);b.df=Math.min(b.bu,c-b.zj);b.jj+=b.df;""===b.Vb&&(b.Vb="start",ia.ed(b.Vb));"start"===b.Vb&&ia.complete(b.Vb)&&(b.Vb="load",ia.ed(b.Vb));"load"===b.Vb&&ia.complete(b.Vb)&&(b.Vb="game",ia.ed(b.Vb));"undefined"!==typeof F&&Ua(b.df);var d,e;if(0<b.Ag)for(d=0;d<b.A.length&&!((e=b.A[d])&&e.ma&&e.j&&0>=e.D&&!0===e.ma(b.df));d+=1);var g,h;if(0!==b.sg.length){if(0<
b.Bg)for(e=b.A.length-1;0<=e;e-=1)if((g=b.A[e])&&g.j&&0>=g.D&&g.em)for(d=0;d<b.sg.length;d+=1)h=b.sg[d],!0!==h.qc&&(h.qc=g.em(h.x,h.y));b.sg=[]}if(0!==b.xe.length){if(0<b.nd)for(e=b.A.length-1;0<=e;e-=1)if((g=b.A[e])&&g.j&&0>=g.D&&(g.ab||g.jb||g.rj))for(d=0;d<b.xe.length;d+=1)h=b.xe[d],!0!==h.qc&&(void 0!==h.wheelDelta&&g.rj?h.qc=g.rj(h.wheelDelta,h.x,h.y):h.Za&&g.ab?h.qc=g.ab(h.Je,h.x,h.y):void 0!==h.Za&&!h.Za&&g.jb&&(h.qc=g.jb(h.Je,h.x,h.y)));b.xe=[]}if(0!==b.qf.length){if(0<b.Fg)for(e=0;e<b.A.length;e+=
1)if((g=b.A[e])&&g.j&&0>=g.D&&(g.xh||g.Jf))for(d=0;d<b.qf.length;d+=1)h=b.qf[d],!0!==h.qc&&(h.Za&&g.xh?h.qc=void 0:!h.Za&&g.Jf&&(h.qc=g.Jf(h.key)));b.qf=[]}d=b.df;for(e=b.qg.length=0;e<b.Ud.length;e+=1)g=b.Ud[e],void 0!==g.id&&0===g.paused&&(0<g.fg||0<g.fn)&&(g.fg-=d,0>=g.fg&&(b.qg.push({id:g.id,kg:g.kg}),0<g.fn?(g.fn-=1,g.fg+=g.time):g.fg=0));if(0<b.zg&&0<b.qg.length)for(d=0;d<b.A.length;d+=1)if((e=b.A[d])&&e.dm&&e.j)for(g=0;g<b.qg.length;g+=1)h=b.qg[g],!0===h.qc||null!==h.kg&&h.kg!==e||(h.qc=e.dm(h.id));
if(0<b.Gg&&0<b.Jg.length)for(d=0;d<b.A.length;d+=1)if((g=b.A[d])&&g.Rb&&g.j&&0>=g.D)for(e=0;e<b.Jg.length;e+=1)h=b.Jg[e],!0===h.qc||null!==h.kg&&h.kg!==g||(h.qc=g.Rb(h.id,h.gs));b.Jg.length=0;if(0<b.Cg)for(d=0;d<b.A.length&&!((e=b.A[d])&&e.pc&&e.j&&0>=e.D&&!0===e.pc(b.df));d+=1);Mb(b);Lb(b);b.zj=c}window.Gk=Date.now();window.On=window.Gk-window.Hk;window.Pn=Math.max(window.Nr,1E3/window.Mr-window.On);window.ki(window.Nn)};window.ki=function(b){window.setTimeout(b,window.Pn)};
window.Lr||(window.ki=window.requestAnimationFrame||window.webkitRequestAnimationFrame||window.mozRequestAnimationFrame||window.msRequestAnimationFrame||window.oRequestAnimationFrame||window.ki);
function Mb(b){function c(b,c){return b.ua===c.ua?c.depth-b.depth:b.ua>c.ua?-1:1}var d,e;for(d=e=0;d<b.A.length;d+=1)b.A[d]&&(b.A[d].Ik&&(b.A[d].Ik=!1,b.A[d].j=!0),b.A[e]=b.A[d],e+=1);b.A.length=e;b.Kg&&b.A.sort(c);b.Kg=!1;for(d=e=0;d<b.wb.length;d+=1)b.wb[d]&&(b.wb[e]=b.wb[d],e+=1);b.wb.length=e;b.Kk&&b.wb.sort(c);b.Kk=!1}
function Nb(b,c){var d=G;void 0===b.group&&(b.group=0);void 0===b.visible&&(b.visible=!0);void 0===b.j&&(b.j=!0);void 0===b.depth&&(b.depth=0);void 0===b.ua&&(b.ua=0);void 0===b.D&&(b.D=0);void 0===b.we&&(b.we=[]);b.Ik=!1;void 0!==c&&!1===c&&(b.Ik=!0,b.j=!1);d.A.push(b);d.Kg=!0;b.ma&&(d.Ag+=1);b.em&&(d.Bg+=1);if(b.ab||b.jb)d.nd+=1;b.rj&&(d.nd+=1);if(b.xh||b.Jf)d.Fg+=1;b.dm&&(d.zg+=1);b.Rb&&(d.Gg+=1);b.pc&&(d.Cg+=1);b.gm&&(d.Dg+=1);if(b.Hf||b.If)d.Ac+=1;b.jm&&(d.Ac+=1);if(b.hm||b.im)d.rf+=1;b.km&&
(d.Eg+=1);b.Pb&&b.Pb()}function Ob(b,c){var d=G;b.depth!==c&&(d.Kg=!0);b.depth=c}function Pb(b,c){var d;c=[].concat(c);void 0===b.we&&(b.we=[]);for(d=c.length-1;0<=d;d-=1)0>b.we.indexOf(c[d])&&b.we.push(c[d])}
function Qb(b,c){var d=[],e,g;if(void 0===c||"all"===c||"master"===c)for(e=0;e<b.A.length;e+=1)g=b.A[e],void 0!==g&&d.push(g);else if("function"===typeof c)for(e=0;e<b.A.length;e+=1)g=b.A[e],void 0!==g&&c(g)&&d.push(g);else for(e=0;e<b.A.length;e+=1)g=b.A[e],void 0!==g&&0<=g.we.indexOf(c)&&d.push(g);return d}function Rb(b){var c=Qb(G,b);for(b=0;b<c.length;b+=1){var d=c[b];d.D+=1}}function Sb(b){var c=Qb(G,b);for(b=0;b<c.length;b+=1){var d=c[b];d.D=Math.max(0,d.D-1)}}
function H(b,c){var d=b.A.indexOf(c);if(!(0>d)){b.A[d].Qb&&b.A[d].Qb();var e=b.A[d];e.ma&&(b.Ag-=1);e.em&&(b.Bg-=1);if(e.ab||e.jb)b.nd-=1;e.rj&&(b.nd-=1);if(e.xh||e.Jf)b.Fg-=1;e.dm&&(b.zg-=1);e.Rb&&(b.Gg-=1);e.pc&&(b.Cg-=1);e.gm&&(b.Dg-=1);if(e.Hf||e.If)b.Ac-=1;e.jm&&(b.Ac-=1);if(e.hm||e.im)b.rf-=1;e.km&&(b.Eg-=1);b.A[d]=void 0}}
tb.prototype.c=function(b,c,d,e,g,h,k){void 0===k&&(k=0);this.wb.push({Tn:0,e:b,Aa:c,es:d,visible:!0,x:e,y:g,Dk:1,Ek:1,na:0,alpha:1,depth:h,ua:k,D:0,we:[]});this.Kk=!0;return this.wb[this.wb.length-1]};var G=new tb(aa);
function Tb(b,c){var d;this.kind=b;this.u=null;switch(this.kind){case 0:this.u={x:[c.x],y:[c.y]};this.oa=c.x;this.Ba=c.y;this.Ka=c.x;this.fb=c.y;break;case 2:this.u={x:[c.x,c.x+c.Pa-1,c.x+c.Pa-1,c.x,c.x],y:[c.y,c.y,c.y+c.Ta-1,c.y+c.Ta-1,c.y]};this.oa=c.x;this.Ba=c.y;this.Ka=c.x+c.Pa-1;this.fb=c.y+c.Ta-1;break;case 3:this.u={x:[],y:[]};this.oa=c.x-c.Yj;this.Ba=c.y-c.Yj;this.Ka=c.x+c.Yj;this.fb=c.y+c.Yj;break;case 1:this.u={x:[c.Jn,c.Kn],y:[c.Ln,c.Mn]};this.oa=Math.min(c.Jn,c.Kn);this.Ba=Math.min(c.Ln,
c.Mn);this.Ka=Math.max(c.Jn,c.Kn);this.fb=Math.max(c.Ln,c.Mn);break;case 4:this.u={x:[],y:[]};this.oa=c.x[0];this.Ba=c.y[0];this.Ka=c.x[0];this.fb=c.y[0];for(d=0;d<c.x.length;d+=1)this.u.x.push(c.x[d]),this.u.y.push(c.y[d]),this.oa=Math.min(this.oa,c.x[d]),this.Ba=Math.min(this.Ba,c.y[d]),this.Ka=Math.max(this.Ka,c.x[d]),this.fb=Math.max(this.fb,c.y[d]);this.u.x.push(c.x[0]);this.u.y.push(c.y[0]);break;default:this.Ba=this.oa=0,this.fb=this.Ka=-1}}
function Ub(b,c,d,e){return new Tb(2,{x:b,y:c,Pa:d,Ta:e})}function Vb(b){var c=1E6,d=-1E6,e=1E6,g=-1E6,h,k,m,n,q;for(h=0;h<b.G;h+=1)k=b.hd[h]-b.Ha,m=k+b.gd[h]-1,n=b.jd[h]-b.Ia,q=n+b.fd[h]-1,k<c&&(c=k),m>d&&(d=m),n<e&&(e=n),q>g&&(g=q);return new Tb(2,{x:c,y:e,Pa:d-c+1,Ta:g-e+1})}a=Tb.prototype;
a.da=function(){var b=new Tb(-1,{}),c;b.kind=this.kind;b.oa=this.oa;b.Ka=this.Ka;b.Ba=this.Ba;b.fb=this.fb;b.u={x:[],y:[]};for(c=0;c<this.u.x.length;c+=1)b.u.x[c]=this.u.x[c];for(c=0;c<this.u.y.length;c+=1)b.u.y[c]=this.u.y[c];return b};a.translate=function(b,c){var d=this.da(),e;d.oa+=b;d.Ka+=b;d.Ba+=c;d.fb+=c;for(e=0;e<d.u.x.length;e+=1)d.u.x[e]+=b;for(e=0;e<d.u.y.length;e+=1)d.u.y[e]+=c;return d};
a.scale=function(b){var c=this.da(),d;c.oa*=b;c.Ka*=b;c.Ba*=b;c.fb*=b;for(d=0;d<c.u.x.length;d+=1)c.u.x[d]*=b;for(d=0;d<c.u.y.length;d+=1)c.u.y[d]*=b;return c};
a.rotate=function(b){var c,d,e,g;switch(this.kind){case 0:return c=new ca(this.u.x[0],this.u.y[0]),c=c.rotate(b),new Tb(0,{x:c.x,y:c.y});case 1:return c=new ca(this.u.x[0],this.u.y[0]),c=c.rotate(b),d=new ca(this.u.x[1],this.u.y[1]),d=d.rotate(b),new Tb(1,{Jn:c.x,Ln:c.y,Kn:d.x,Mn:d.y});case 3:return c=(this.Ka-this.oa)/2,d=new ca(this.oa+c,this.Ba+c),d=d.rotate(b),new Tb(3,{x:d.x,y:d.y,Yj:c});default:d=[];e=[];for(g=0;g<this.u.x.length-1;g+=1)c=new ca(this.u.x[g],this.u.y[g]),c=c.rotate(b),d.push(c.x),
e.push(c.y);return new Tb(4,{x:d,y:e})}};
function Wb(b,c,d,e,g){var h,k,m,n,q;if(e<c+b.oa||e>c+b.Ka||g<d+b.Ba||g>d+b.fb)return!1;switch(b.kind){case 0:case 2:return!0;case 3:return m=(b.Ka-b.oa)/2,e-=c+b.oa+m,g-=d+b.Ba+m,e*e+g*g<=m*m;case 1:return m=c+b.u.x[0],n=d+b.u.y[0],c+=b.u.x[1],b=d+b.u.y[1],e===m?g===n:e===c?g===b:1>Math.abs(n+(e-m)*(b-n)/(c-m)-g);case 4:n=new ca(0,0);q=new ca(0,0);m=[];for(k=0;k<b.u.x.length-1;k+=1)n.x=b.u.x[k],n.y=b.u.y[k],q.x=b.u.x[k+1],q.y=b.u.y[k+1],m.push(da(new ca(n.x-q.x,n.y-q.y)));for(n=0;n<m.length;n+=1){q=
new ca(e,g);k=m[n];q=q.x*k.x+q.y*k.y;h=b;var v=c,z=d,B=m[n],r=new ca(0,0),s=void 0,t=1E9;k=-1E10;for(var u=void 0,u=0;u<h.u.x.length;u+=1)r.x=v+h.u.x[u],r.y=z+h.u.y[u],s=r.x*B.x+r.y*B.y,t=Math.min(t,s),k=Math.max(k,s);h=t;if(q<h||k<q)return!1}return!0;default:return!1}}
a.pb=function(b,c,d){var e=p.context;e.fillStyle=d;e.strokeStyle=d;switch(this.kind){case 0:e.fillRect(b+this.oa-1,c+this.Ba-1,3,3);break;case 2:e.fillRect(b+this.oa,c+this.Ba,this.Ka-this.oa+1,this.fb-this.Ba+1);break;case 3:d=(this.Ka-this.oa)/2;e.beginPath();e.arc(b+this.oa+d,c+this.Ba+d,d,0,2*Math.PI,!1);e.closePath();e.fill();break;case 1:e.beginPath();e.moveTo(b+this.u.x[0],c+this.u.y[0]);e.lineTo(b+this.u.x[1],c+this.u.y[1]);e.stroke();break;case 4:e.beginPath();e.moveTo(b+this.u.x[0],c+this.u.y[0]);
for(d=1;d<this.u.x.length-1;d+=1)e.lineTo(b+this.u.x[d],c+this.u.y[d]);e.closePath();e.fill()}};function Xb(){this.depth=1E7;this.visible=!1;this.j=!0;this.group="Engine";this.Z=[];this.yg=this.D=this.Ig=!1;this.Wd=1;this.dc=-1;this.aa=-1E6}a=Xb.prototype;a.da=function(){var b=new Xb,c;for(c=0;c<this.Z.length;c+=1)b.Z.push({Ga:this.Z[c].Ga,action:this.Z[c].action});b.yg=this.yg;return b};
a.rd=function(b,c){var d,e;if(0===this.Z.length||this.Z[this.Z.length-1].Ga<=b)this.Z.push({Ga:b,action:c});else{for(d=0;this.Z[d].Ga<=b;)d+=1;for(e=this.Z.length;e>d;e-=1)this.Z[e]=this.Z[e-1];this.Z[d]={Ga:b,action:c}}this.aa=-1E6};a.start=function(){this.Ig=!0;this.D=!1;this.dc=0>this.Wd&&0<this.Z.length?this.Z[this.Z.length-1].Ga+1:-1;this.aa=-1E6;H(G,this);Nb(this)};
a.gn=function(){if(0>this.Wd&&0<this.Z.length){var b=this.Z[this.Z.length-1].Ga;this.dc=0>this.Wd?b+1:b-1}else this.dc=0>this.Wd?1:-1;this.aa=-1E6};a.stop=function(){this.Ig=!1;H(G,this)};a.Id=function(){return this.Ig};a.pause=function(){this.D=!0;H(G,this)};a.Uh=function(){this.D=!1;H(G,this);Nb(this)};a.paused=function(){return this.Ig&&this.D};a.Bq=function(b){this.yg=b};
a.ma=function(b){if(this.Ig&&!this.D&&0!==this.Wd)if(0<this.Wd){0>this.aa&&(this.aa=0);for(;this.aa<this.Z.length&&this.Z[this.aa].Ga<=this.dc;)this.aa+=1;for(this.dc+=this.Wd*b;0<=this.aa&&this.aa<this.Z.length&&this.Z[this.aa].Ga<=this.dc;)this.Z[this.aa].action(this.Z[this.aa].Ga,this),this.aa+=1;this.aa>=this.Z.length&&(this.yg?this.gn():this.stop())}else{0>this.aa&&(this.aa=this.Z.length-1);for(;0<=this.aa&&this.Z[this.aa].Ga>=this.dc;)this.aa-=1;for(this.dc+=this.Wd*b;0<=this.aa&&this.Z[this.aa].Ga>=
this.dc;)this.Z[this.aa].action(this.Z[this.aa].Ga,this),this.aa-=1;0>this.aa&&0>=this.dc&&(this.yg?this.gn():this.stop())}};function Yb(){this.depth=1E7;this.visible=!1;this.j=!0;this.group="Engine";this.vb=[];this.re=[];this.clear();this.mv=!1;Nb(this)}a=Yb.prototype;a.ma=function(){var b,c,d,e,g;if(this.mv)for(b=0;16>b;b+=1)G.ba[b].Za&&(c=Eb(b),d=G.ba[b].y,e=this.re[b],g=this.vb[e],!(0<=e&&g&&g.selected)||g&&Wb(g.sc,0,0,c,d)||(Gb(G,g.keyCode),g.selected=!1,this.re[b]=-1),this.ab(b,c,d))};
a.ab=function(b,c,d){var e;if(!(0<=this.re[b]))for(e=0;e<this.vb.length;e+=1){var g;if(g=this.vb[e])g=(g=this.vb[e])?Wb(g.sc,0,0,c,d):!1;if(g&&!this.vb[e].selected){Fb(G,this.vb[e].keyCode);this.vb[e].selected=!0;this.re[b]=e;break}}};a.jb=function(b){var c=this.re[b];0<=c&&this.vb[c]&&this.vb[c].selected&&(Gb(G,this.vb[c].keyCode),this.vb[c].selected=!1);this.re[b]=-1};function Zb(b,c,d,e,g,h,k){d=Ub(d,e,g,h);b.vb.push({keyCode:k,sc:d,id:c,selected:!1})}
a.clear=function(){var b;for(b=this.vb.length=0;16>b;b+=1)this.re[b]=-1};a.pb=function(b,c,d){var e,g,h,k;for(e=0;e<this.vb.length;e+=1)if(g=this.vb[e])g.selected?g.sc.pb(0,0,c):g.sc.pb(0,0,b),h=(g.sc.oa+g.sc.Ka)/2,k=(g.sc.Ba+g.sc.fb)/2,ra("id: "+g.id,h-20,k-10,d),ra("key: "+g.keyCode,h-20,k+10,d)};new ea;function $b(b,c){return c}function ac(b,c,d,e){return c+b/e*d}function bc(b,c,d,e,g){void 0===g&&(g=3);return c+d*Math.pow(b/e,g)}function cc(b,c,d,e,g){return c+d*bc(e-b,1,-1,e,g)}
function dc(b,c,d,e){return bc(b,c,d,e,3)}function ec(b,c,d,e){return cc(b,c,d,e,3)}function fc(b,c,d,e){return c+d*(b<e/2?bc(b,0,.5,e/2,3):bc(e-b,1,-.5,e/2,3))}function gc(b,c,d,e){void 0===d&&(d=3);void 0===e&&(e=8);d=Math.sin(2*(1-b/c)*Math.PI*d+Math.PI/2);var g;void 0===e&&(e=8);g=Math.pow(2,-e);d*=0+(Math.pow(2,e*b/c-e)-g)/(1-g)*1;return 1+-1*d}function hc(b,c,d,e,g){void 0===g&&(g=1.70158);return c+d*((1+g)*Math.pow(b/e,3)-g*Math.pow(b/e,2))}
function ic(b,c,d,e,g){return c+d*hc(e-b,1,-1,e,g)}
function jc(b){switch(1){case 0:return function(c,d,e,g,h,k,m){return 0>c?d:c>g?d+e:b(c,d,e,g,h,k,m)};case 1:return function(c,d,e,g,h,k,m){return b(c-Math.floor(c/g)*g,d,e,g,h,k,m)};case 2:return function(c,d,e,g,h,k,m){c=0===Math.floor(c/g)%2?b(c-Math.floor(c/g)*g,0,1,g,h,k,m):b(g-c+Math.floor(c/g)*g,0,1,g,h,k,m);return d+e*c};case 3:return function(c,d,e,g,h,k,m){h=b(c-Math.floor(c/g)*g,0,1,g,h,k,m);0!==Math.floor(c/g)%2&&(h=1-h);return d+e*h};case 4:return function(c,d,e,g,h,k,m){var n=Math.floor(c/
g);c=b(c-Math.floor(c/g)*g,0,1,g,h,k,m);return d+e*(n+c)};case 5:return function(c,d,e,g,h,k,m){var n=Math.floor(c/g);c=0===Math.floor(c/g)%2?b(c-Math.floor(c/g)*g,0,1,g,h,k,m):b(g-c+Math.floor(c/g)*g,1,-1,g,h,k,m);return d+e*(n+c)};default:return function(c,d,e,g,h,k,m){return b(c,d,e,g,h,k,m)}}}
function kc(b,c,d){var e,g=0,h=1,k=[0],m=[0];for(void 0===c&&(c=[]);c.length<b.length;)c.push(!1);for(void 0===d&&(d=[]);d.length<b.length;)d.push(1/b.length);for(e=0;e<b.length;e+=1)g+=d[e];for(e=0;e<b.length;e+=1)d[e]/=g;for(e=0;e<b.length;e+=1)m.push(m[e]+d[e]),g=b[e]===$b?0:c[e]?-1:1,k.push(k[e]+g),h=Math.max(h,k[e+1]);return function(e,g,v,z,B,r,s){var t,u;t=b.length-1;for(u=0;u<b.length;u+=1)if(e/z<=m[u+1]){t=u;break}e=b[t](e/z-m[t],0,1,d[t],B,r,s);c[t]&&(e=-e);return g+(k[t]+e)*v/h}}
var I=window.TG_InitSettings||{};I.size=void 0!==I.size?I.size:"big";I.yr=I.usesFullScreen;I.jn="big"===I.size?1:.5;I.Le=20;I.ph=10;I.Df=0;I.uh=-10;I.Pl=-20;I.oc=-30;I.cp=-40;
function J(b,c){var d;if("number"===typeof b){a:switch(c){case "floor":d=Math.floor(I.jn*b);break a;case "round":d=Math.round(I.jn*b);break a;default:d=I.jn*b}return d}if("[object Array]"===Object.prototype.toString.call(b)){for(d=0;d<b.length;d++)b[d]=J(b[d],c);return b}if("object"===typeof b){for(d in b)b.hasOwnProperty(d)&&(b[d]=J(b[d],c));return b}}function L(b){return"big"===I.size?void 0!==b.big?b.big:b:void 0!==b.small?b.small:b}
var lc=function(){function b(b,d,e,g,h,k){this.orientation=d;this.Fu=e;this.Zv=g;this.nv=h;this.ml=k;this.Zr=b.adChannel;this.ct=b.gameCode;this.jp=b.gameName;this.jt=b.gameVersion;this.bt=b.gameCategory;this.Fs=b.developerId;this.at=b.gameAnalyticsId;this.Lv=b.tabIcon;var m=setInterval(function(){this.ready()&&(this.ev(),clearInterval(m))}.bind(this),100)}b.prototype.ready=function(){return window.Booster.ready&&window.Booster.Ad};b.prototype.ev=function(){new Booster.Init({orientation:this.orientation,
splash:!0,minimalUI:!0,rotationOnHide:function(){window.setTimeout(function(){I.b.rb()},400)},rotationOnShow:function(){I.b.$c()}});adSense=new Booster.Ad({type:"adsense",size:"300x250",channelID:this.Zr});community=new Booster.Community({position:1,gameCode:this.ct,tabIcon:this.Lv});analytics=new Booster.Analytics({gameName:this.jp,gameId:this.jt,gameCategory:this.bt,developer:this.Fs,gameAnalyticsId:this.at});moregames=new Booster.Moregames;try{freemium=new Booster.Freemium}catch(b){}var d=this;
Booster.onSplashFinishedEvent=function(){d.nv.call(d.ml)};Booster.onOpenTab=function(){d.Fu.call(d.ml)};Booster.onCloseTab=function(){d.Zv.call(d.ml)}};return b}(),mc={},nc={},M=new sa("GameTexture",1,"load");ta(M,0,"media/GameTexture0.png");var oc=new sa("GameStaticTexture",3,"load");ta(oc,0,"media/GameStaticTexture0.png");ta(oc,1,"media/GameStaticTexture1.png");ta(oc,2,"media/GameStaticTexture2.png");var pc=new sa("LevelMapScreenTexture",2,"load");ta(pc,0,"media/LevelMapScreenTexture0.png");
ta(pc,1,"media/LevelMapScreenTexture1.png");var qc=new sa("LevelEndTexture",3,"load");ta(qc,0,"media/LevelEndTexture0.png");ta(qc,1,"media/LevelEndTexture1.png");ta(qc,2,"media/LevelEndTexture2.png");var O=new sa("MenuTexture",2,"load");ta(O,0,"media/MenuTexture0.png");ta(O,1,"media/MenuTexture1.png");var rc=new sa("StartScreenTexture",2,"load");ta(rc,0,"media/StartScreenTexture0.png");ta(rc,1,"media/StartScreenTexture1.png");var sc=new sa("EndScreenTexture",2,"load");ta(sc,0,"media/EndScreenTexture0.png");
ta(sc,1,"media/EndScreenTexture1.png");var tc=new sa("TutorialTexture",1,"load");ta(tc,0,"media/TutorialTexture0.png");var uc=new sa("texture",1,"load");ta(uc,0,"media/texture0.png");(new w("s_ui_cup_highscore",M,1,32,28,0,0,32,28,1)).c(0,0,985,137,32,28,0,0);(new w("s_ui_cup_score",M,1,28,24,0,0,28,24,1)).c(0,0,985,169,28,24,0,0);var vc=new w("s_ui_divider",oc,1,94,2,0,0,94,2,1);vc.c(0,0,753,1,94,2,0,0);var wc=new w("s_ui_background_blank",oc,1,140,580,0,0,140,580,1);wc.c(0,0,609,1,140,580,0,0);
var xc=new w("s_ui_highscore",oc,1,26,36,13,12,26,36,1);xc.c(0,0,849,1,26,36,0,0);var yc=new w("s_ui_timeleft",oc,1,20,26,0,0,20,26,1);yc.c(0,0,881,1,20,26,0,0);var zc=new w("s_ui_smiley_hard",M,1,22,22,11,11,22,22,1);zc.c(0,0,1001,25,22,22,0,0);var Ac=new w("s_ui_smiley_medium",M,1,22,22,11,11,22,22,1);Ac.c(0,0,1001,49,22,22,0,0);var Bc=new w("s_ui_smiley_easy",M,1,22,22,11,11,22,22,1);Bc.c(0,0,1001,1,22,22,0,0);(new w("s_ui_crown",M,1,24,20,12,10,24,20,1)).c(0,0,449,265,24,20,0,0);
(new w("s_ui_heart",M,1,28,24,14,12,28,24,1)).c(0,0,417,265,26,23,1,1);var Cc=new w("s_level_stars",pc,1,126,46,0,0,126,46,1);Cc.c(0,0,721,137,126,45,0,1);var Dc=new w("s_level2_0",pc,1,84,87,0,0,84,87,1);Dc.c(0,0,937,137,84,87,0,0);var Ec=new w("s_level2_1",pc,1,84,87,0,0,84,87,1);Ec.c(0,0,721,185,84,87,0,0);var Fc=new w("s_level2_2",pc,1,84,87,0,0,84,87,1);Fc.c(0,0,809,233,84,87,0,0);var Gc=new w("s_level2_3",pc,1,84,87,0,0,84,87,1);Gc.c(0,0,897,233,84,87,0,0);
var Hc=new w("s_level2_lock",pc,1,84,87,0,0,84,87,1);Hc.c(0,0,849,137,84,87,0,0);var Ic=new w("s_pop_medal",qc,8,378,378,189,189,3024,378,8);Ic.c(0,0,609,1,349,241,3,69);Ic.c(1,0,609,529,346,267,5,54);Ic.c(2,0,609,249,348,276,20,56);Ic.c(3,1,609,1,342,288,26,50);Ic.c(4,1,1,625,319,292,22,46);Ic.c(5,1,609,609,337,304,14,41);Ic.c(6,0,1,625,343,305,12,41);Ic.c(7,1,609,297,341,304,13,41);(new w("s_medal_shadow",qc,1,195,208,0,0,195,208,1)).c(0,2,1,489,189,204,3,1);
var Jc=new w("s_medal_shine",qc,6,195,208,0,0,1170,208,6);Jc.c(0,0,801,801,193,207,1,1);Jc.c(1,2,529,265,193,207,1,1);Jc.c(2,2,201,273,193,207,1,1);Jc.c(3,2,1,273,193,207,1,1);Jc.c(4,2,401,481,193,207,1,1);Jc.c(5,0,601,801,193,207,1,1);var Kc=new w("s_icon_toggle_hard",O,1,67,67,0,0,67,67,1);Kc.c(0,0,937,193,67,67,0,0);var Lc=new w("s_icon_toggle_medium",O,1,67,67,0,0,67,67,1);Lc.c(0,0,953,713,67,67,0,0);var Mc=new w("s_icon_toggle_easy",O,1,67,67,0,0,67,67,1);Mc.c(0,0,97,945,67,67,0,0);
var Nc=new w("s_flagIcon_us",O,1,48,48,0,0,48,48,1);Nc.c(0,0,441,945,48,36,0,6);var Oc=new w("s_flagIcon_gb",O,1,48,48,0,0,48,48,1);Oc.c(0,0,385,945,48,36,0,6);var Pc=new w("s_flagIcon_nl",O,1,48,48,0,0,48,48,1);Pc.c(0,0,553,945,48,36,0,6);var Qc=new w("s_flagIcon_tr",O,1,48,48,0,0,48,48,1);Qc.c(0,0,777,945,48,36,0,6);var Rc=new w("s_flagIcon_de",O,1,48,48,0,0,48,48,1);Rc.c(0,0,385,985,48,36,0,6);var Sc=new w("s_flagIcon_fr",O,1,48,48,0,0,48,48,1);Sc.c(0,0,945,945,48,36,0,6);
var Tc=new w("s_flagIcon_br",O,1,48,48,0,0,48,48,1);Tc.c(0,0,889,945,48,36,0,6);var Uc=new w("s_flagIcon_es",O,1,48,48,0,0,48,48,1);Uc.c(0,0,833,945,48,36,0,6);var Vc=new w("s_flagIcon_jp",O,1,48,48,0,0,48,48,1);Vc.c(0,0,497,945,48,36,0,6);var Wc=new w("s_flagIcon_ru",O,1,48,48,0,0,48,48,1);Wc.c(0,0,665,945,48,36,0,6);var Xc=new w("s_flagIcon_ar",O,1,48,48,0,0,48,48,1);Xc.c(0,0,721,945,48,36,0,6);var Yc=new w("s_flagIcon_kr",O,1,48,48,0,0,48,48,1);Yc.c(0,0,609,945,48,36,0,6);
var Zc=new w("s_tutorialButton_close",O,1,66,65,0,0,66,65,1);Zc.c(0,0,313,945,65,65,0,0);var $c=new w("s_tutorialButton_next",O,1,66,65,0,0,66,65,1);$c.c(0,0,241,945,66,65,0,0);var ad=new w("s_tutorialButton_previous",O,1,66,65,0,0,66,65,1);ad.c(0,0,169,945,66,65,0,0);(new w("s_logo_tinglygames",O,1,240,240,0,0,240,240,1)).c(0,0,553,1,240,240,0,0);var bd=new w("s_logo_coolgames",O,1,240,240,0,0,240,240,1);bd.c(0,0,553,249,240,167,0,36);
(new w("s_logo_tinglygames_start",rc,1,156,54,0,0,156,54,1)).c(0,0,585,1,156,53,0,0);var cd=new w("s_logo_coolgames_start",rc,1,300,104,0,0,300,104,1);cd.c(0,0,745,1,150,104,75,0);(new w("s_star01_empty",qc,1,170,170,85,85,170,170,1)).c(0,2,601,505,163,168,2,2);(new w("s_star01_fill",qc,1,170,170,85,85,170,170,1)).c(0,2,769,673,142,147,14,17);(new w("s_star02_empty",qc,1,170,170,85,85,170,170,1)).c(0,2,769,505,168,162,1,1);
(new w("s_star02_fill",qc,1,170,170,85,85,170,170,1)).c(0,2,601,681,146,141,12,16);(new w("s_star03_empty",qc,1,170,170,85,85,170,170,1)).c(0,2,193,489,164,168,4,2);(new w("s_star03_fill",qc,1,170,170,85,85,170,170,1)).c(0,2,193,665,142,148,14,16);var dd=new w("s_sfx_star",qc,8,300,300,150,150,2400,300,8);dd.c(0,2,1,697,134,131,85,89);dd.c(1,2,745,257,250,244,19,27);dd.c(2,2,745,1,257,253,17,20);dd.c(3,2,257,1,266,263,12,15);dd.c(4,1,329,625,262,273,13,10);dd.c(5,2,1,1,251,270,19,12);
dd.c(6,2,529,1,213,260,38,16);dd.c(7,0,353,625,243,299,23,1);var ed=new w("s_icon_toggle_sfx_on",O,1,67,67,0,0,67,67,1);ed.c(0,0,857,385,49,31,7,17);var fd=new w("s_icon_toggle_sfx_off",O,1,67,67,0,0,67,67,1);fd.c(0,0,801,385,53,31,7,17);var gd=new w("s_icon_toggle_music_off",O,1,67,67,0,0,67,67,1);gd.c(0,0,953,785,51,41,8,16);var hd=new w("s_icon_toggle_music_on",O,1,67,67,0,0,67,67,1);hd.c(0,1,289,1,38,41,13,16);var id=new w("s_btn_small_exit",O,2,100,92,0,0,200,92,2);
id.c(0,0,129,849,100,92,0,0);id.c(1,0,233,849,100,92,0,0);var jd=new w("s_screen_start",rc,4,576,320,0,0,1152,640,2);jd.c(0,0,1,1,576,320,0,0);jd.c(1,0,1,329,576,320,0,0);jd.c(2,0,1,657,576,320,0,0);jd.c(3,1,1,1,576,320,0,0);var kd=new w("s_overlay_options",oc,1,606,618,0,0,606,618,1);kd.c(0,1,1,1,606,618,0,0);var ld=new w("s_tutorial",O,1,545,511,0,0,545,511,1);ld.c(0,0,1,1,545,511,0,0);var md=new w("s_screen_end",sc,4,576,320,0,0,1152,640,2);md.c(0,0,1,329,576,320,0,0);md.c(1,1,1,1,576,320,0,0);
md.c(2,0,1,1,576,320,0,0);md.c(3,0,1,657,576,320,0,0);var nd=new w("s_overlay_level_win",qc,1,606,618,0,0,606,618,1);nd.c(0,1,1,1,606,618,0,0);var od=new w("s_overlay_level_fail",qc,1,606,618,0,0,606,618,1);od.c(0,0,1,1,606,618,0,0);var pd=new w("s_screen_levelselect",pc,2,576,640,0,0,1152,640,2);pd.c(0,0,1,1,576,640,0,0);pd.c(1,1,1,1,576,640,0,0);var qd=new w("s_dialog",oc,1,606,618,0,0,606,618,1);qd.c(0,0,1,1,606,618,0,0);var rd=new w("s_btn_big_menu",O,2,132,132,0,0,264,132,2);
rd.c(0,0,273,713,132,132,0,0);rd.c(1,0,801,193,132,132,0,0);var sd=new w("s_btn_big_restart",O,2,132,132,0,0,264,132,2);sd.c(0,0,817,713,132,132,0,0);sd.c(1,0,409,713,132,132,0,0);var td=new w("s_btn_big_start",O,2,132,132,0,0,264,132,2);td.c(0,0,681,713,132,132,0,0);td.c(1,0,1,713,132,132,0,0);var ud=new w("s_btn_bigtext",O,2,133,132,0,0,266,132,2);ud.c(0,0,545,713,132,132,0,0);ud.c(1,0,137,713,132,132,1,0);var vd=new w("s_btn_small_block",O,2,88,88,0,0,176,88,2);vd.c(0,1,1,1,88,88,0,0);
vd.c(1,0,913,849,88,88,0,0);var wd=new w("s_btn_small_cross",O,2,88,88,0,0,176,88,2);wd.c(0,0,817,849,88,88,0,0);wd.c(1,0,337,849,88,88,0,0);var xd=new w("s_btn_small_hint",O,2,88,88,0,0,176,88,2);xd.c(0,0,929,617,88,88,0,0);xd.c(1,0,529,849,88,88,0,0);var yd=new w("s_btn_small_pause",O,2,88,88,0,0,176,88,2);yd.c(0,0,625,849,88,88,0,0);yd.c(1,0,721,849,88,88,0,0);var zd=new w("s_btn_small_options",O,2,88,88,0,0,176,88,2);zd.c(0,1,193,1,88,88,0,0);zd.c(1,0,433,849,88,88,0,0);
var Ad=new w("s_btn_small_retry",O,2,88,88,0,0,176,88,2);Ad.c(0,1,97,1,88,88,0,0);Ad.c(1,0,1,905,88,88,0,0);var Bd=new w("s_btn_standard",O,2,95,88,0,0,190,88,2);Bd.c(0,0,929,521,93,88,1,0);Bd.c(1,0,929,329,93,88,1,0);var Cd=new w("s_btn_video",O,2,227,88,0,0,454,88,2);Cd.c(0,0,553,425,225,88,1,0);Cd.c(1,0,233,521,225,88,1,0);var Dd=new w("s_icon_toggle_fxoff",O,2,227,88,0,0,454,88,2);Dd.c(0,0,785,425,225,88,1,0);Dd.c(1,0,1,521,225,88,1,0);var Ed=new w("s_icon_toggle_fxon",O,2,227,88,0,0,454,88,2);
Ed.c(0,0,465,521,225,88,1,0);Ed.c(1,0,697,521,225,88,1,0);var Fd=new w("s_icon_toggle_musicoff",O,2,227,88,0,0,454,88,2);Fd.c(0,0,465,617,225,88,1,0);Fd.c(1,0,233,617,225,88,1,0);var Gd=new w("s_icon_toggle_musicon",O,2,227,88,0,0,454,88,2);Gd.c(0,0,697,617,225,88,1,0);Gd.c(1,0,1,617,225,88,1,0);var Hd=new w("s_level_select_panel",O,2,119,49,0,0,238,49,2);Hd.c(0,0,1,849,119,49,0,0);Hd.c(1,0,801,329,119,49,0,0);var Id=new w("s_level2_arrow_left",O,2,50,57,0,0,100,57,2);Id.c(0,0,961,1,48,57,1,0);
Id.c(1,0,961,129,48,57,1,0);var Jd=new w("s_level2_arrow_right",O,2,50,57,0,0,100,57,2);Jd.c(0,0,937,265,48,57,1,0);Jd.c(1,0,961,65,48,57,1,0);var Kd=new w("s_btn_toggle",O,2,162,92,0,0,324,92,2);Kd.c(0,0,801,1,158,88,2,2);Kd.c(1,0,801,97,158,88,2,2);var Ld=new w("s_level_1",pc,1,133,132,0,0,133,132,1);Ld.c(0,0,721,1,132,132,1,0);var Md=new w("s_level_2",pc,1,133,132,0,0,133,132,1);Md.c(0,0,585,1,132,132,1,0);var Nd=new w("s_level_3",pc,1,133,132,0,0,133,132,1);Nd.c(0,0,857,1,132,132,1,0);
var Od=new w("s_level_lock",pc,1,39,51,0,0,39,51,1);Od.c(0,0,585,273,39,51,0,0);var Pd=new w("s_loadingbar_fill",rc,1,20,12,0,0,20,12,1);Pd.c(0,0,937,1,20,12,0,0);var Qd=new w("s_loadingbar_background",rc,1,42,32,0,0,42,32,1);Qd.c(0,0,897,1,38,28,2,1);var Rd=new w("s_logo",oc,1,312,200,0,0,312,200,1);Rd.c(0,0,609,585,312,200,0,0);var Sd=new w("s_tutorial_02",tc,1,350,190,0,0,350,190,1);Sd.c(0,0,1,1,350,190,0,0);var Td=new w("s_tutorial_03",tc,1,350,190,0,0,350,190,1);Td.c(0,0,1,385,350,190,0,0);
var Ud=new w("s_tutorial_04",tc,1,350,190,0,0,350,190,1);Ud.c(0,0,353,193,350,190,0,0);var Vd=new w("s_tutorial_05",tc,1,350,190,0,0,350,190,1);Vd.c(0,0,1,193,350,190,0,0);var Xd=new w("s_tutorial_01",tc,1,350,190,0,0,350,190,1);Xd.c(0,0,353,1,350,190,0,0);var Yd=new w("s_tutorial_00",tc,1,350,190,0,0,350,190,1);Yd.c(0,0,353,385,350,190,0,0);var Zd=new w("s_tutorial_06",uc,1,350,190,0,0,350,190,1);Zd.c(0,0,353,1,350,190,0,0);var $d=new w("s_tutorial_07",uc,1,350,190,0,0,350,190,1);
$d.c(0,0,1,1,350,190,0,0);var Q=new w("s_pallete",M,36,50,50,0,0,450,200,9);Q.c(0,0,761,153,50,50,0,0);Q.c(1,0,177,177,50,50,0,0);Q.c(2,0,289,193,50,50,0,0);Q.c(3,0,401,209,50,50,0,0);Q.c(4,0,233,177,50,50,0,0);Q.c(5,0,121,177,50,50,0,0);Q.c(6,0,121,233,50,50,0,0);Q.c(7,0,705,153,50,50,0,0);Q.c(8,0,817,153,50,50,0,0);Q.c(9,0,929,153,50,50,0,0);Q.c(10,0,345,193,50,50,0,0);Q.c(11,0,457,209,50,50,0,0);Q.c(12,0,905,209,50,50,0,0);Q.c(13,0,849,209,50,50,0,0);Q.c(14,0,961,209,50,50,0,0);
Q.c(15,0,793,209,50,50,0,0);Q.c(16,0,737,209,50,50,0,0);Q.c(17,0,513,209,50,50,0,0);Q.c(18,0,569,209,50,50,0,0);Q.c(19,0,625,209,50,50,0,0);Q.c(20,0,681,209,50,50,0,0);Q.c(21,0,873,153,50,50,0,0);Q.c(22,0,649,153,50,50,0,0);Q.c(23,0,537,153,50,50,0,0);Q.c(24,0,705,97,50,50,0,0);Q.c(25,0,761,97,50,50,0,0);Q.c(26,0,649,97,50,50,0,0);Q.c(27,0,537,97,50,50,0,0);Q.c(28,0,481,97,50,50,0,0);Q.c(29,0,313,81,50,50,0,0);Q.c(30,0,369,81,50,50,0,0);Q.c(31,0,593,97,50,50,0,0);Q.c(32,0,873,97,50,50,0,0);
Q.c(33,0,425,153,50,50,0,0);Q.c(34,0,593,153,50,50,0,0);Q.c(35,0,481,153,50,50,0,0);var ae=new w("s_outro_text_bg",M,2,150,75,25,25,150,150,1);ae.c(0,0,121,1,150,75,0,0);ae.c(1,0,273,1,150,75,0,0);var be=new w("s_outro_outline",M,1,45,45,0,0,45,45,1);be.c(0,0,369,265,45,45,0,0);var ce=new w("s_outro_exit",M,1,15,17,7,8,15,17,1);ce.c(0,0,1001,73,15,17,0,0);var de=new w("s_outro_particle",M,1,50,50,25,25,50,50,1);de.c(0,0,817,97,50,50,0,0);var ee=new w("s_outro_next",M,2,88,88,44,44,176,88,2);
ee.c(0,0,521,1,88,88,0,0);ee.c(1,0,617,1,88,88,0,0);var fe=new w("s_outro_retry",M,2,88,88,44,44,176,88,2);fe.c(0,0,713,1,88,88,0,0);fe.c(1,0,425,1,88,88,0,0);var ge=new w("s_btn_small_block_active",M,2,88,88,0,0,176,88,2);ge.c(0,0,217,81,88,88,0,0);ge.c(1,0,809,1,88,88,0,0);var he=new w("s_btn_small_cross_active",M,2,88,88,0,0,176,88,2);he.c(0,0,905,1,88,88,0,0);he.c(1,0,121,81,88,88,0,0);var ie=new w("s_filled",M,1,50,50,0,0,50,50,1);ie.c(0,0,313,137,50,50,0,0);
var je=new w("s_blocked",M,1,50,50,0,0,50,50,1);je.c(0,0,985,97,37,35,6,7);var R=new w("s_cell_background",M,3,50,50,0,0,50,150,1);R.c(0,0,425,97,50,50,0,0);R.c(1,0,929,97,50,50,0,0);R.c(2,0,369,137,50,50,0,0);var ke=new w("s_grid_mask",M,1,45,45,0,0,45,45,1);ke.c(0,0,321,249,45,45,0,0);var le=new w("s_grid_outline",M,1,45,45,0,0,45,45,1);le.c(0,0,273,249,45,45,0,0);var me=new w("s_preview_mask",M,1,45,45,0,0,45,45,1);me.c(0,0,225,233,45,45,0,0);
var ne=new w("s_preview_outline",M,1,45,45,0,0,45,45,1);ne.c(0,0,177,233,45,45,0,0);var oe=new w("s_level_0",pc,1,133,132,0,0,133,132,1);oe.c(0,0,585,137,132,132,1,0);var pe=new w("s_background",oc,4,576,320,0,0,1152,640,2);pe.c(0,2,1,329,576,320,0,0);pe.c(1,1,1,625,576,320,0,0);pe.c(2,0,1,625,576,320,0,0);pe.c(3,2,1,1,576,320,0,0);var qe=new w("s_background_ui",M,1,116,556,0,0,116,556,1);qe.c(0,0,1,1,116,556,0,0);var re=new w("s_overlay_assignment",oc,1,560,135,0,0,560,135,1);
re.c(0,2,1,657,560,135,0,0);new va("ff_opensans_bold","fonts/ff_opensans_bold.woff","fonts/ff_opensans_bold.ttf","fonts");new va("ff_opensans_bolditalic","fonts/ff_opensans_bolditalic.woff","fonts/ff_opensans_bolditalic.ttf","fonts");var se=new za("ff_opensans_bold","Arial");E(se,11);se.fill=!0;se.setFillColor("#799EC5");se.La=1;Ca(se,!1);se.setStrokeColor("White");Da(se,1);Fa(se);se.Na=1;Ea(se,!1);Ha(se,"center");Ia(se,"middle");se.Ca=0;se.fa=0;var te=new za("ff_opensans_bolditalic","Arial");
E(te,52);te.fill=!0;te.setFillColor("#172348");te.La=1;Ca(te,!1);te.setStrokeColor("Black");Da(te,1);Fa(te);te.Na=1;Ea(te,!1);Ha(te,"center");Ia(te,"middle");te.Ca=0;te.fa=0;new va("floaterFontFace","fonts/floaterFontFace.woff","fonts/floaterFontFace.ttf","fonts");new va("floaterNumberFontFace","fonts/floaterNumberFontFace.woff","fonts/floaterNumberFontFace.ttf","fonts");var ue=new za("floaterFontFace","Arial");E(ue,24);Aa(ue);ue.fill=!0;ue.setFillColor("#FFDE00");ue.La=1;Ca(ue,!0);ue.setStrokeColor("#6F1F00");
Da(ue,4);Fa(ue);ue.Na=1;Ea(ue,!0);Ga(ue,"rgba(57,0,0,0.46)",4);Ha(ue,"left");Ia(ue,"top");ue.Ca=0;ue.fa=0;var ve=new za("floaterFontFace","Arial");E(ve,28);Aa(ve);ve.fill=!0;Ba(ve,2,["#FFF600","#00DB48","blue"],.65,.02);ve.La=1;Ca(ve,!0);ve.setStrokeColor("#073400");Da(ve,4);Fa(ve);ve.Na=1;Ea(ve,!0);Ga(ve,"rgba(0,57,43,0.47)",4);Ha(ve,"left");Ia(ve,"top");ve.Ca=0;ve.fa=0;var we=new za("floaterFontFace","Arial");E(we,30);Aa(we);we.fill=!0;Ba(we,3,["#FFF600","#FF8236","#FF0096"],.71,-.1);we.La=1;
Ca(we,!0);we.setStrokeColor("#4F0027");Da(we,4);Fa(we);we.Na=1;Ea(we,!0);Ga(we,"rgba(41,0,0,0.48)",5);Ha(we,"left");Ia(we,"top");we.Ca=0;we.fa=0;var xe=new za("floaterFontFace","Arial");E(xe,34);Aa(xe);xe.fill=!0;Ba(xe,3,["#00FCFF","#893DFB","#FF00E4"],.72,-.04);xe.La=1;Ca(xe,!0);xe.setStrokeColor("#001637");Da(xe,4);Fa(xe);xe.Na=1;Ea(xe,!0);Ga(xe,"rgba(0,35,75,0.49)",6);Ha(xe,"left");Ia(xe,"top");xe.Ca=0;xe.fa=0;var ye=new za("floaterNumberFontFace","Arial");E(ye,30);ye.fill=!0;ye.setFillColor("White");
ye.La=1;Ca(ye,!0);ye.setStrokeColor("#00106F");Da(ye,2);Fa(ye);ye.Na=1;Ea(ye,!1);Ga(ye,"rgba(0,4,57,0.51)",4);Ha(ye,"left");Ia(ye,"top");ye.Ca=0;ye.fa=0;var ze=new za("floaterNumberFontFace","Arial");E(ze,30);Aa(ze);ze.fill=!0;ze.setFillColor("#FF1E00");ze.La=1;Ca(ze,!0);ze.setStrokeColor("#3F0000");Da(ze,2);Fa(ze);ze.Na=1;Ea(ze,!1);Ga(ze,"rgba(57,0,0,0.49)",4);Ha(ze,"left");Ia(ze,"top");ze.Ca=0;ze.fa=0;new va("f_default","fonts/f_default.woff","fonts/f_default.ttf","fonts");
var S=new za("f_default","Arial");E(S,12);S.fill=!0;S.setFillColor("Black");S.La=1;Ca(S,!1);S.setStrokeColor("Black");Da(S,1);Fa(S);S.Na=1;Ea(S,!1);Ha(S,"left");Ia(S,"top");S.Ca=0;S.fa=0;new va("ff_opensans_extrabold","fonts/ff_opensans_extrabold.woff","fonts/ff_opensans_extrabold.ttf","fonts");new va("ff_dimbo_regular","fonts/ff_dimbo_regular.woff","fonts/ff_dimbo_regular.ttf","fonts");new va("f_themeDefault","fonts/f_themeDefault.woff","fonts/f_themeDefault.ttf","fonts");
var T=new za("f_themeDefault","Arial");E(T,12);T.fill=!0;T.setFillColor("Black");T.La=1;Ca(T,!1);T.setStrokeColor("White");Da(T,5);Fa(T);T.Na=1;Ea(T,!0);Ha(T,"left");Ia(T,"top");T.Ca=0;T.fa=0;new va("f_game_ui","fonts/f_game_ui.woff","fonts/f_game_ui.ttf","fonts");var V=new za("f_game_ui","Arial");E(V,12);V.fill=!0;V.setFillColor("Black");V.La=1;Ca(V,!1);V.setStrokeColor("Black");Da(V,1);Fa(V);V.Na=1;Ea(V,!1);Ha(V,"left");Ia(V,"top");V.Ca=0;V.fa=0;var Ae=new za("f_game_ui","Arial");E(Ae,32);
Ae.fill=!0;Ae.setFillColor("#502B4C");Ae.La=1;Ca(Ae,!1);Ae.setStrokeColor("Black");Da(Ae,1);Fa(Ae);Ae.Na=1;Ea(Ae,!1);Ha(Ae,"center");Ia(Ae,"middle");Ae.Ca=0;Ae.fa=0;var Be=new za("f_game_ui","Arial");E(Be,32);Be.fill=!0;Be.setFillColor("#93648f");Be.La=1;Ca(Be,!1);Be.setStrokeColor("Black");Da(Be,1);Fa(Be);Be.Na=1;Ea(Be,!1);Ha(Be,"center");Ia(Be,"middle");Be.Ca=0;Be.fa=0;var Ce=new za("f_game_ui","Arial");E(Ce,36);Ce.fill=!0;Ce.setFillColor("White");Ce.La=1;Ca(Ce,!1);Ce.setStrokeColor("Black");
Da(Ce,1);Fa(Ce);Ce.Na=1;Ea(Ce,!1);Ha(Ce,"center");Ia(Ce,"middle");Ce.Ca=0;Ce.fa=0;var De=new ob("audioSprite","audio/audioSprite.mp3","audio/audioSprite.ogg","audio"),Ee=new ob("musicSprite","audio/musicSprite.mp3","audio/musicSprite.ogg","audio");mc.iw=new hb("_002_Shoot_01",De,0,164,1,10,["game"]);mc.jw=new hb("_002_Shoot_02",De,2E3,166,1,10,["game"]);mc.kw=new hb("_002_Shoot_03",De,4E3,183,1,10,["game"]);nc.lw=new hb("_003_Hit_cushion_01",De,6E3,190,1,10,["game"]);
nc.mw=new hb("_003_Hit_cushion_02",De,8E3,154,1,10,["game"]);nc.nw=new hb("_003_Hit_cushion_03",De,1E4,163,1,10,["game"]);var Fe=new hb("a_click",De,12E3,74,1,10,["game"]),Ge=new hb("a_complete",De,14E3,1537,1,10,["game"]),He=new hb("a_levelStart",De,17E3,1002,1,10,["sfx"]);new hb("a_levelComplete",De,2E4,1002,1,10,["sfx"]);var Ie=new hb("a_mouseDown",De,23E3,471,1,10,["sfx"]);new hb("a_levelend_star_01",De,25E3,1161,1,10,["sfx"]);new hb("a_levelend_star_02",De,28E3,1070,1,10,["sfx"]);
new hb("a_levelend_star_03",De,31E3,1039,1,10,["sfx"]);new hb("a_levelend_fail",De,34E3,1572,1,10,["sfx"]);new hb("a_levelend_score_counter",De,37E3,54,1,10,["sfx"]);new hb("a_levelend_score_end",De,39E3,888,1,10,["sfx"]);new hb("a_medal",De,41E3,1225,1,10,["sfx"]);var Je=new hb("a_music",Ee,0,36571,.88,10,["game"]),W=W||{};W["nl-nl"]=W["nl-nl"]||{};W["nl-nl"].loadingScreenLoading="Laden...";W["nl-nl"].startScreenPlay="SPELEN";W["nl-nl"].levelMapScreenTotalScore="Totale score";
W["nl-nl"].levelEndScreenTitle_level="Level <VALUE>";W["nl-nl"].levelEndScreenTitle_difficulty="Goed Gedaan!";W["nl-nl"].levelEndScreenTitle_endless="Level <VALUE>";W["nl-nl"].levelEndScreenTotalScore="Totale score";W["nl-nl"].levelEndScreenSubTitle_levelFailed="Level niet gehaald";W["nl-nl"].levelEndScreenTimeLeft="Tijd over";W["nl-nl"].levelEndScreenTimeBonus="Tijdbonus";W["nl-nl"].levelEndScreenHighScore="High score";W["nl-nl"].optionsStartScreen="Hoofdmenu";W["nl-nl"].optionsQuit="Stop";
W["nl-nl"].optionsResume="Terug naar spel";W["nl-nl"].optionsTutorial="Speluitleg";W["nl-nl"].optionsHighScore="High scores";W["nl-nl"].optionsMoreGames="Meer Spellen";W["nl-nl"].optionsDifficulty_easy="Makkelijk";W["nl-nl"].optionsDifficulty_medium="Gemiddeld";W["nl-nl"].optionsDifficulty_hard="Moeilijk";W["nl-nl"].optionsMusic_on="Aan";W["nl-nl"].optionsMusic_off="Uit";W["nl-nl"].optionsSFX_on="Aan";W["nl-nl"].optionsSFX_off="Uit";W["nl-nl"]["optionsLang_en-us"]="Engels (US)";
W["nl-nl"]["optionsLang_en-gb"]="Engels (GB)";W["nl-nl"]["optionsLang_nl-nl"]="Nederlands";W["nl-nl"].gameEndScreenTitle="Gefeliciteerd!\nJe hebt gewonnen.";W["nl-nl"].gameEndScreenBtnText="Ga verder";W["nl-nl"].optionsTitle="Instellingen";W["nl-nl"].optionsQuitConfirmationText="Pas op!\n\nAls je nu stopt verlies je alle voortgang in dit level. Weet je zeker dat je wilt stoppen?";W["nl-nl"].optionsQuitConfirmBtn_No="Nee";W["nl-nl"].optionsQuitConfirmBtn_Yes="Ja, ik weet het zeker";
W["nl-nl"].levelMapScreenTitle="Kies een level";W["nl-nl"].optionsRestartConfirmationText="Pas op!\n\nAls je nu herstart verlies je alle voortgang in dit level. Weet je zeker dat je wilt herstarten?";W["nl-nl"].optionsRestart="Herstart";W["nl-nl"].optionsSFXBig_on="Geluid aan";W["nl-nl"].optionsSFXBig_off="Geluid uit";W["nl-nl"].optionsAbout_title="Over ons";W["nl-nl"].optionsAbout_text="CoolGames\nwww.coolgames.com\nCopyright \u00a9 2016";W["nl-nl"].optionsAbout_backBtn="Terug";
W["nl-nl"].optionsAbout_version="versie:";W["nl-nl"].optionsAbout="Over ons";W["nl-nl"].levelEndScreenMedal="VERBETERD!";W["nl-nl"].startScreenQuestionaire="Wat vind jij?";W["nl-nl"].levelMapScreenWorld_0="Kies een level";W["nl-nl"].startScreenByTinglyGames="door: CoolGames";W["nl-nl"]["optionsLang_de-de"]="Duits";W["nl-nl"]["optionsLang_tr-tr"]="Turks";W["nl-nl"].optionsAbout_header="Ontwikkeld door:";W["nl-nl"].levelEndScreenViewHighscoreBtn="Scores bekijken";
W["nl-nl"].levelEndScreenSubmitHighscoreBtn="Score verzenden";W["nl-nl"].challengeStartScreenTitle_challengee_friend="Je bent uitgedaagd door:";W["nl-nl"].challengeStartTextScore="Punten van <NAME>:";W["nl-nl"].challengeStartTextTime="Tijd van <NAME>:";W["nl-nl"].challengeStartScreenToWin="Te winnen aantal Fairplay munten:";W["nl-nl"].challengeEndScreenWinnings="Je hebt <AMOUNT> Fairplay munten gewonnen!";W["nl-nl"].challengeEndScreenOutcomeMessage_WON="Je hebt de uitdaging gewonnen!";
W["nl-nl"].challengeEndScreenOutcomeMessage_LOST="Je hebt de uitdaging verloren.";W["nl-nl"].challengeEndScreenOutcomeMessage_TIED="Jullie hebben gelijk gespeeld.";W["nl-nl"].challengeCancelConfirmText="Je staat op het punt de uitdaging te annuleren. Je inzet wordt teruggestort minus de uitdagingskosten. Weet je zeker dat je de uitdaging wilt annuleren? ";W["nl-nl"].challengeCancelConfirmBtn_yes="Ja";W["nl-nl"].challengeCancelConfirmBtn_no="Nee";W["nl-nl"].challengeEndScreensBtn_submit="Verstuur uitdaging";
W["nl-nl"].challengeEndScreenBtn_cancel="Annuleer uitdaging";W["nl-nl"].challengeEndScreenName_you="Jij";W["nl-nl"].challengeEndScreenChallengeSend_error="Er is een fout opgetreden bij het versturen van de uitdaging. Probeer het later nog een keer.";W["nl-nl"].challengeEndScreenChallengeSend_success="Je uitdaging is verstuurd!";W["nl-nl"].challengeCancelMessage_error="Er is een fout opgetreden bij het annuleren van de uitdaging. Probeer het later nog een keer.";
W["nl-nl"].challengeCancelMessage_success="De uitdaging is geannuleerd.";W["nl-nl"].challengeEndScreenScoreSend_error="Er is een fout opgetreden tijdens de communicatie met de server. Probeer het later nog een keer.";W["nl-nl"].challengeStartScreenTitle_challengee_stranger="Jouw tegenstander:";W["nl-nl"].challengeStartScreenTitle_challenger_friend="Jouw tegenstander:";W["nl-nl"].challengeStartScreenTitle_challenger_stranger="Je zet een uitdaging voor:";
W["nl-nl"].challengeStartTextTime_challenger="Speel het spel en zet een tijd neer.";W["nl-nl"].challengeStartTextScore_challenger="Speel het spel en zet een score neer.";W["nl-nl"].challengeForfeitConfirmText="Je staat op het punt de uitdaging op te geven. Weet je zeker dat je dit wilt doen?";W["nl-nl"].challengeForfeitConfirmBtn_yes="Ja";W["nl-nl"].challengeForfeitConfirmBtn_no="Nee";W["nl-nl"].challengeForfeitMessage_success="Je hebt de uitdaging opgegeven.";
W["nl-nl"].challengeForfeitMessage_error="Er is een fout opgetreden tijdens het opgeven van de uitdaging. Probeer het later nog een keer.";W["nl-nl"].optionsChallengeForfeit="Geef op";W["nl-nl"].optionsChallengeCancel="Stop";W["nl-nl"].challengeLoadingError_notValid="Sorry, deze uitdaging kan niet meer gespeeld worden.";W["nl-nl"].challengeLoadingError_notStarted="Kan de server niet bereiken. Probeer het later nog een keer.";W["nl-nl"].levelEndScreenHighScore_time="Beste tijd:";
W["nl-nl"].levelEndScreenTotalScore_time="Totale tijd:";W["nl-nl"]["optionsLang_fr-fr"]="Frans";W["nl-nl"]["optionsLang_ko-kr"]="Koreaans";W["nl-nl"]["optionsLang_ar-eg"]="Arabisch";W["nl-nl"]["optionsLang_es-es"]="Spaans";W["nl-nl"]["optionsLang_pt-br"]="Braziliaans-Portugees";W["nl-nl"]["optionsLang_ru-ru"]="Russisch";W["nl-nl"].optionsExit="Stoppen";W["nl-nl"].levelEndScreenTotalScore_number="Totale score:";W["nl-nl"].levelEndScreenHighScore_number="Topscore:";
W["nl-nl"].challengeEndScreenChallengeSend_submessage="<NAME> heeft 72 uur om de uitdaging aan te nemen of te weigeren. Als <NAME> je uitdaging weigert of niet accepteert binnen 72 uur worden je inzet en uitdagingskosten teruggestort.";W["nl-nl"].challengeEndScreenChallengeSend_submessage_stranger="Als niemand binnen 72 uur je uitdaging accepteert, worden je inzet en uitdagingskosten teruggestort.";W["nl-nl"].challengeForfeitMessage_winnings="<NAME> heeft <AMOUNT> Fairplay munten gewonnen!";
W["nl-nl"].optionsAbout_header_publisher="Published by:";W["nl-nl"]["optionsLang_jp-jp"]="Japans";W["en-us"]=W["en-us"]||{};W["en-us"].loadingScreenLoading="Loading...";W["en-us"].startScreenPlay="PLAY";W["en-us"].levelMapScreenTotalScore="Total score";W["en-us"].levelEndScreenTitle_level="Level <VALUE>";W["en-us"].levelEndScreenTitle_difficulty="Well done!";W["en-us"].levelEndScreenTitle_endless="Stage <VALUE>";W["en-us"].levelEndScreenTotalScore="Total score";
W["en-us"].levelEndScreenSubTitle_levelFailed="Level failed";W["en-us"].levelEndScreenTimeLeft="Time remaining";W["en-us"].levelEndScreenTimeBonus="Time bonus";W["en-us"].levelEndScreenHighScore="High score";W["en-us"].optionsStartScreen="Main menu";W["en-us"].optionsQuit="Quit";W["en-us"].optionsResume="Resume";W["en-us"].optionsTutorial="How to play";W["en-us"].optionsHighScore="High scores";W["en-us"].optionsMoreGames="More Games";W["en-us"].optionsDifficulty_easy="Easy";
W["en-us"].optionsDifficulty_medium="Medium";W["en-us"].optionsDifficulty_hard="Difficult";W["en-us"].optionsMusic_on="On";W["en-us"].optionsMusic_off="Off";W["en-us"].optionsSFX_on="On";W["en-us"].optionsSFX_off="Off";W["en-us"]["optionsLang_en-us"]="English (US)";W["en-us"]["optionsLang_en-gb"]="English (GB)";W["en-us"]["optionsLang_nl-nl"]="Dutch";W["en-us"].gameEndScreenTitle="Congratulations!\nYou have completed the game.";W["en-us"].gameEndScreenBtnText="Continue";W["en-us"].optionsTitle="Settings";
W["en-us"].optionsQuitConfirmationText="Attention!\n\nIf you quit now you will lose all progress made during this level. Are you sure you want to quit?";W["en-us"].optionsQuitConfirmBtn_No="No";W["en-us"].optionsQuitConfirmBtn_Yes="Yes, I'm sure";W["en-us"].levelMapScreenTitle="Select a level";W["en-us"].optionsRestartConfirmationText="Attention!\n\nIf you restart now you will lose all progress made during this level. Are you sure you want to restart?";W["en-us"].optionsRestart="Restart";
W["en-us"].optionsSFXBig_on="Sound on";W["en-us"].optionsSFXBig_off="Sound off";W["en-us"].optionsAbout_title="About";W["en-us"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";W["en-us"].optionsAbout_backBtn="Back";W["en-us"].optionsAbout_version="version:";W["en-us"].optionsAbout="About";W["en-us"].levelEndScreenMedal="IMPROVED!";W["en-us"].startScreenQuestionaire="What do you think?";W["en-us"].levelMapScreenWorld_0="Select a level";W["en-us"].startScreenByTinglyGames="by: CoolGames";
W["en-us"]["optionsLang_de-de"]="German";W["en-us"]["optionsLang_tr-tr"]="Turkish";W["en-us"].optionsAbout_header="Developed by:";W["en-us"].levelEndScreenViewHighscoreBtn="View scores";W["en-us"].levelEndScreenSubmitHighscoreBtn="Submit score";W["en-us"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";W["en-us"].challengeStartTextScore="<NAME>'s score:";W["en-us"].challengeStartTextTime="<NAME>'s time:";W["en-us"].challengeStartScreenToWin="Amount to win:";
W["en-us"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";W["en-us"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";W["en-us"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";W["en-us"].challengeEndScreenOutcomeMessage_TIED="You tied.";W["en-us"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
W["en-us"].challengeCancelConfirmBtn_yes="Yes";W["en-us"].challengeCancelConfirmBtn_no="No";W["en-us"].challengeEndScreensBtn_submit="Submit challenge";W["en-us"].challengeEndScreenBtn_cancel="Cancel challenge";W["en-us"].challengeEndScreenName_you="You";W["en-us"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";W["en-us"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
W["en-us"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";W["en-us"].challengeCancelMessage_success="Your challenge has been cancelled.";W["en-us"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";W["en-us"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";W["en-us"].challengeStartScreenTitle_challenger_friend="You are challenging:";
W["en-us"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";W["en-us"].challengeStartTextTime_challenger="Play the game and set a time.";W["en-us"].challengeStartTextScore_challenger="Play the game and set a score.";W["en-us"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";W["en-us"].challengeForfeitConfirmBtn_yes="Yes";W["en-us"].challengeForfeitConfirmBtn_no="No";W["en-us"].challengeForfeitMessage_success="You have forfeited the challenge.";
W["en-us"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";W["en-us"].optionsChallengeForfeit="Forfeit";W["en-us"].optionsChallengeCancel="Quit";W["en-us"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";W["en-us"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";W["en-us"].levelEndScreenHighScore_time="Best time:";W["en-us"].levelEndScreenTotalScore_time="Total time:";
W["en-us"]["optionsLang_fr-fr"]="French";W["en-us"]["optionsLang_ko-kr"]="Korean";W["en-us"]["optionsLang_ar-eg"]="Arabic";W["en-us"]["optionsLang_es-es"]="Spanish";W["en-us"]["optionsLang_pt-br"]="Brazilian-Portuguese";W["en-us"]["optionsLang_ru-ru"]="Russian";W["en-us"].optionsExit="Exit";W["en-us"].levelEndScreenTotalScore_number="Total score:";W["en-us"].levelEndScreenHighScore_number="High score:";W["en-us"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
W["en-us"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";W["en-us"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";W["en-us"].optionsAbout_header_publisher="Published by:";W["en-us"]["optionsLang_jp-jp"]="Japanese";W["en-gb"]=W["en-gb"]||{};W["en-gb"].loadingScreenLoading="Loading...";W["en-gb"].startScreenPlay="PLAY";
W["en-gb"].levelMapScreenTotalScore="Total score";W["en-gb"].levelEndScreenTitle_level="Level <VALUE>";W["en-gb"].levelEndScreenTitle_difficulty="Well done!";W["en-gb"].levelEndScreenTitle_endless="Stage <VALUE>";W["en-gb"].levelEndScreenTotalScore="Total score";W["en-gb"].levelEndScreenSubTitle_levelFailed="Level failed";W["en-gb"].levelEndScreenTimeLeft="Time remaining";W["en-gb"].levelEndScreenTimeBonus="Time bonus";W["en-gb"].levelEndScreenHighScore="High score";
W["en-gb"].optionsStartScreen="Main menu";W["en-gb"].optionsQuit="Quit";W["en-gb"].optionsResume="Resume";W["en-gb"].optionsTutorial="How to play";W["en-gb"].optionsHighScore="High scores";W["en-gb"].optionsMoreGames="More Games";W["en-gb"].optionsDifficulty_easy="Easy";W["en-gb"].optionsDifficulty_medium="Medium";W["en-gb"].optionsDifficulty_hard="Difficult";W["en-gb"].optionsMusic_on="On";W["en-gb"].optionsMusic_off="Off";W["en-gb"].optionsSFX_on="On";W["en-gb"].optionsSFX_off="Off";
W["en-gb"]["optionsLang_en-us"]="English (US)";W["en-gb"]["optionsLang_en-gb"]="English (GB)";W["en-gb"]["optionsLang_nl-nl"]="Dutch";W["en-gb"].gameEndScreenTitle="Congratulations!\nYou have completed the game.";W["en-gb"].gameEndScreenBtnText="Continue";W["en-gb"].optionsTitle="Settings";W["en-gb"].optionsQuitConfirmationText="Attention!\n\nIf you quit now you will lose all progress made during this level. Are you sure you want to quit?";W["en-gb"].optionsQuitConfirmBtn_No="No";
W["en-gb"].optionsQuitConfirmBtn_Yes="Yes, I'm sure";W["en-gb"].levelMapScreenTitle="Select a level";W["en-gb"].optionsRestartConfirmationText="Attention!\n\nIf you restart now you will lose all progress made during this level. Are you sure you want to restart?";W["en-gb"].optionsRestart="Restart";W["en-gb"].optionsSFXBig_on="Sound on";W["en-gb"].optionsSFXBig_off="Sound off";W["en-gb"].optionsAbout_title="About";W["en-gb"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";
W["en-gb"].optionsAbout_backBtn="Back";W["en-gb"].optionsAbout_version="version:";W["en-gb"].optionsAbout="About";W["en-gb"].levelEndScreenMedal="IMPROVED!";W["en-gb"].startScreenQuestionaire="What do you think?";W["en-gb"].levelMapScreenWorld_0="Select a level";W["en-gb"].startScreenByTinglyGames="by: CoolGames";W["en-gb"]["optionsLang_de-de"]="German";W["en-gb"]["optionsLang_tr-tr"]="Turkish";W["en-gb"].optionsAbout_header="Developed by:";W["en-gb"].levelEndScreenViewHighscoreBtn="View scores";
W["en-gb"].levelEndScreenSubmitHighscoreBtn="Submit score";W["en-gb"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";W["en-gb"].challengeStartTextScore="<NAME>'s score:";W["en-gb"].challengeStartTextTime="<NAME>'s time:";W["en-gb"].challengeStartScreenToWin="Amount to win:";W["en-gb"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";W["en-gb"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";
W["en-gb"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";W["en-gb"].challengeEndScreenOutcomeMessage_TIED="You tied.";W["en-gb"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";W["en-gb"].challengeCancelConfirmBtn_yes="Yes";W["en-gb"].challengeCancelConfirmBtn_no="No";W["en-gb"].challengeEndScreensBtn_submit="Submit challenge";
W["en-gb"].challengeEndScreenBtn_cancel="Cancel challenge";W["en-gb"].challengeEndScreenName_you="You";W["en-gb"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";W["en-gb"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";W["en-gb"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";W["en-gb"].challengeCancelMessage_success="Your challenge has been cancelled.";
W["en-gb"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";W["en-gb"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";W["en-gb"].challengeStartScreenTitle_challenger_friend="You are challenging:";W["en-gb"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";W["en-gb"].challengeStartTextTime_challenger="Play the game and set a time.";
W["en-gb"].challengeStartTextScore_challenger="Play the game and set a score.";W["en-gb"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you wish to proceed?";W["en-gb"].challengeForfeitConfirmBtn_yes="Yes";W["en-gb"].challengeForfeitConfirmBtn_no="No";W["en-gb"].challengeForfeitMessage_success="You have forfeited the challenge.";W["en-gb"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
W["en-gb"].optionsChallengeForfeit="Forfeit";W["en-gb"].optionsChallengeCancel="Quit";W["en-gb"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";W["en-gb"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";W["en-gb"].levelEndScreenHighScore_time="Best time:";W["en-gb"].levelEndScreenTotalScore_time="Total time:";W["en-gb"]["optionsLang_fr-fr"]="French";W["en-gb"]["optionsLang_ko-kr"]="Korean";W["en-gb"]["optionsLang_ar-eg"]="Arabic";
W["en-gb"]["optionsLang_es-es"]="Spanish";W["en-gb"]["optionsLang_pt-br"]="Brazilian-Portuguese";W["en-gb"]["optionsLang_ru-ru"]="Russian";W["en-gb"].optionsExit="Exit";W["en-gb"].levelEndScreenTotalScore_number="Total score:";W["en-gb"].levelEndScreenHighScore_number="High score:";W["en-gb"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
W["en-gb"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";W["en-gb"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";W["en-gb"].optionsAbout_header_publisher="Published by:";W["en-gb"]["optionsLang_jp-jp"]="Japanese";W["de-de"]=W["de-de"]||{};W["de-de"].loadingScreenLoading="Laden ...";W["de-de"].startScreenPlay="SPIELEN";
W["de-de"].levelMapScreenTotalScore="Gesamtpunkte";W["de-de"].levelEndScreenTitle_level="Level <VALUE>";W["de-de"].levelEndScreenTitle_difficulty="Sehr gut!";W["de-de"].levelEndScreenTitle_endless="Stufe <VALUE>";W["de-de"].levelEndScreenTotalScore="Gesamtpunkte";W["de-de"].levelEndScreenSubTitle_levelFailed="Level nicht geschafft";W["de-de"].levelEndScreenTimeLeft="Restzeit";W["de-de"].levelEndScreenTimeBonus="Zeitbonus";W["de-de"].levelEndScreenHighScore="Highscore";
W["de-de"].optionsStartScreen="Hauptmen\u00fc";W["de-de"].optionsQuit="Beenden";W["de-de"].optionsResume="Weiterspielen";W["de-de"].optionsTutorial="So wird gespielt";W["de-de"].optionsHighScore="Highscores";W["de-de"].optionsMoreGames="Weitere Spiele";W["de-de"].optionsDifficulty_easy="Einfach";W["de-de"].optionsDifficulty_medium="Mittel";W["de-de"].optionsDifficulty_hard="Schwer";W["de-de"].optionsMusic_on="EIN";W["de-de"].optionsMusic_off="AUS";W["de-de"].optionsSFX_on="EIN";
W["de-de"].optionsSFX_off="AUS";W["de-de"]["optionsLang_en-us"]="Englisch (US)";W["de-de"]["optionsLang_en-gb"]="Englisch (GB)";W["de-de"]["optionsLang_nl-nl"]="Holl\u00e4ndisch";W["de-de"].gameEndScreenTitle="Gl\u00fcckwunsch!\nDu hast das Spiel abgeschlossen.";W["de-de"].gameEndScreenBtnText="Weiter";W["de-de"].optionsTitle="Einstellungen";W["de-de"].optionsQuitConfirmationText="Achtung!\n\nWenn du jetzt aufh\u00f6rst, verlierst du alle in diesem Level gemachten Fortschritte. Willst du wirklich aufh\u00f6ren?";
W["de-de"].optionsQuitConfirmBtn_No="NEIN";W["de-de"].optionsQuitConfirmBtn_Yes="Ja, ich bin mir sicher";W["de-de"].levelMapScreenTitle="W\u00e4hle ein Level";W["de-de"].optionsRestartConfirmationText="Achtung!\n\nWenn du jetzt neu startest, verlierst du alle in diesem Level gemachten Fortschritte. Willst du wirklich neu starten?";W["de-de"].optionsRestart="Neustart";W["de-de"].optionsSFXBig_on="Sound EIN";W["de-de"].optionsSFXBig_off="Sound AUS";W["de-de"].optionsAbout_title="\u00dcber";
W["de-de"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";W["de-de"].optionsAbout_backBtn="Zur\u00fcck";W["de-de"].optionsAbout_version="Version:";W["de-de"].optionsAbout="\u00dcber";W["de-de"].levelEndScreenMedal="VERBESSERT!";W["de-de"].startScreenQuestionaire="Deine Meinung z\u00e4hlt!";W["de-de"].levelMapScreenWorld_0="W\u00e4hle ein Level";W["de-de"].startScreenByTinglyGames="von: CoolGames";W["de-de"]["optionsLang_de-de"]="Deutsch";W["de-de"]["optionsLang_tr-tr"]="T\u00fcrkisch";
W["de-de"].optionsAbout_header="Entwickelt von:";W["de-de"].levelEndScreenViewHighscoreBtn="Punktzahlen ansehen";W["de-de"].levelEndScreenSubmitHighscoreBtn="Punktzahl senden";W["de-de"].challengeStartScreenTitle_challengee_friend="Dein Gegner:";W["de-de"].challengeStartTextScore="Punktzahl von <NAME>:";W["de-de"].challengeStartTextTime="Zeit von <NAME>:";W["de-de"].challengeStartScreenToWin="Einsatz:";W["de-de"].challengeEndScreenWinnings="Du hast <AMOUNT> Fairm\u00fcnzen gewonnen!";
W["de-de"].challengeEndScreenOutcomeMessage_WON="Du hast die Partie gewonnen!";W["de-de"].challengeEndScreenOutcomeMessage_LOST="Leider hat Dein Gegner die Partie gewonnen.";W["de-de"].challengeEndScreenOutcomeMessage_TIED="Gleichstand!";W["de-de"].challengeCancelConfirmText="Willst Du Deine Wette wirklich zur\u00fcckziehen? Dein Wetteinsatz wird Dir zur\u00fcckgegeben minus die Einsatzgeb\u00fchr.";W["de-de"].challengeCancelConfirmBtn_yes="Ja";W["de-de"].challengeCancelConfirmBtn_no="Nein";
W["de-de"].challengeEndScreensBtn_submit="Herausfordern";W["de-de"].challengeEndScreenBtn_cancel="Zur\u00fcckziehen";W["de-de"].challengeEndScreenName_you="Du";W["de-de"].challengeEndScreenChallengeSend_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";W["de-de"].challengeEndScreenChallengeSend_success="Herausforderung verschickt!";W["de-de"].challengeCancelMessage_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";
W["de-de"].challengeCancelMessage_success="Du hast die Wette erfolgreich zur\u00fcckgezogen.";W["de-de"].challengeEndScreenScoreSend_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";W["de-de"].challengeStartScreenTitle_challengee_stranger="Dein Gegner wird:";W["de-de"].challengeStartScreenTitle_challenger_friend="Du hast den folgenden Spieler herausgefordert:";W["de-de"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
W["de-de"].challengeStartTextTime_challenger="Spiel um die niedrigste Zeit!";W["de-de"].challengeStartTextScore_challenger="Spiel um die hochste Punktzahl!";W["de-de"].challengeForfeitConfirmText="Willst du Die Partie wirklich aufgeben?";W["de-de"].challengeForfeitConfirmBtn_yes="Ja";W["de-de"].challengeForfeitConfirmBtn_no="Nein";W["de-de"].challengeForfeitMessage_success="You have forfeited the challenge.";W["de-de"].challengeForfeitMessage_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";
W["de-de"].optionsChallengeForfeit="Aufgeben";W["de-de"].optionsChallengeCancel="Zur\u00fcckziehen";W["de-de"].challengeLoadingError_notValid="Leider ist diese Partie nicht mehr aktuel.";W["de-de"].challengeLoadingError_notStarted="Leider ist ein Fehler\u00a0aufgetreten. Es konnte keiner Verbindung zum Server hergestellt werden. Versuche es bitte nochmal sp\u00e4ter.";W["de-de"].levelEndScreenHighScore_time="Bestzeit:";W["de-de"].levelEndScreenTotalScore_time="Gesamtzeit:";
W["de-de"]["optionsLang_fr-fr"]="Franz\u00f6sisch";W["de-de"]["optionsLang_ko-kr"]="Koreanisch";W["de-de"]["optionsLang_ar-eg"]="Arabisch";W["de-de"]["optionsLang_es-es"]="Spanisch";W["de-de"]["optionsLang_pt-br"]="Portugiesisch (Brasilien)";W["de-de"]["optionsLang_ru-ru"]="Russisch";W["de-de"].optionsExit="Verlassen";W["de-de"].levelEndScreenTotalScore_number="Gesamtpunktzahl:";W["de-de"].levelEndScreenHighScore_number="Highscore:";W["de-de"].challengeEndScreenChallengeSend_submessage="<NAME> hat 72 Stunden um die Wette anzunehmen oder abzulehnen. Sollte <NAME> nicht reagieren oder ablehnen werden Dir Dein Wetteinsatz und die Geb\u00fchr zur\u00fcckerstattet.";
W["de-de"].challengeEndScreenChallengeSend_submessage_stranger="Als niemanden Deine Herausforderung innerhalb von 72 Stunden annimmt, werden Dir Deinen Wetteinsatz Einsatzgeb\u00fchr zur\u00fcckerstattet.";W["de-de"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";W["de-de"].optionsAbout_header_publisher="Published by:";W["de-de"]["optionsLang_jp-jp"]="Japanese";W["fr-fr"]=W["fr-fr"]||{};W["fr-fr"].loadingScreenLoading="Chargement...";W["fr-fr"].startScreenPlay="JOUER";
W["fr-fr"].levelMapScreenTotalScore="Score total";W["fr-fr"].levelEndScreenTitle_level="Niveau <VALUE>";W["fr-fr"].levelEndScreenTitle_difficulty="Bien jou\u00e9 !";W["fr-fr"].levelEndScreenTitle_endless="Sc\u00e8ne <VALUE>";W["fr-fr"].levelEndScreenTotalScore="Score total";W["fr-fr"].levelEndScreenSubTitle_levelFailed="\u00c9chec du niveau";W["fr-fr"].levelEndScreenTimeLeft="Temps restant";W["fr-fr"].levelEndScreenTimeBonus="Bonus de temps";W["fr-fr"].levelEndScreenHighScore="Meilleur score";
W["fr-fr"].optionsStartScreen="Menu principal";W["fr-fr"].optionsQuit="Quitter";W["fr-fr"].optionsResume="Reprendre";W["fr-fr"].optionsTutorial="Comment jouer";W["fr-fr"].optionsHighScore="Meilleurs scores";W["fr-fr"].optionsMoreGames="Plus de jeux";W["fr-fr"].optionsDifficulty_easy="Facile";W["fr-fr"].optionsDifficulty_medium="Moyen";W["fr-fr"].optionsDifficulty_hard="Difficile";W["fr-fr"].optionsMusic_on="Avec";W["fr-fr"].optionsMusic_off="Sans";W["fr-fr"].optionsSFX_on="Avec";
W["fr-fr"].optionsSFX_off="Sans";W["fr-fr"]["optionsLang_en-us"]="Anglais (US)";W["fr-fr"]["optionsLang_en-gb"]="Anglais (UK)";W["fr-fr"]["optionsLang_nl-nl"]="N\u00e9erlandais";W["fr-fr"].gameEndScreenTitle="F\u00e9licitations !\nVous avez termin\u00e9 le jeu.";W["fr-fr"].gameEndScreenBtnText="Continuer";W["fr-fr"].optionsTitle="Param\u00e8tres";W["fr-fr"].optionsQuitConfirmationText="Attention !\n\nEn quittant maintenant, vous perdrez votre progression pour le niveau en cours. Quitter quand m\u00eame ?";
W["fr-fr"].optionsQuitConfirmBtn_No="Non";W["fr-fr"].optionsQuitConfirmBtn_Yes="Oui";W["fr-fr"].levelMapScreenTitle="Choisir un niveau";W["fr-fr"].optionsRestartConfirmationText="Attention !\n\nEn recommen\u00e7ant maintenant, vous perdrez votre progression pour le niveau en cours. Recommencer quand m\u00eame ?";W["fr-fr"].optionsRestart="Recommencer";W["fr-fr"].optionsSFXBig_on="Avec son";W["fr-fr"].optionsSFXBig_off="Sans son";W["fr-fr"].optionsAbout_title="\u00c0 propos";
W["fr-fr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";W["fr-fr"].optionsAbout_backBtn="Retour";W["fr-fr"].optionsAbout_version="Version :";W["fr-fr"].optionsAbout="\u00c0 propos";W["fr-fr"].levelEndScreenMedal="RECORD BATTU !";W["fr-fr"].startScreenQuestionaire="Un avis sur le jeu ?";W["fr-fr"].levelMapScreenWorld_0="Choisir un niveau";W["fr-fr"].startScreenByTinglyGames="Un jeu CoolGames";W["fr-fr"]["optionsLang_de-de"]="Allemand";W["fr-fr"]["optionsLang_tr-tr"]="Turc";
W["fr-fr"].optionsAbout_header="D\u00e9velopp\u00e9 par :";W["fr-fr"].levelEndScreenViewHighscoreBtn="Voir les scores";W["fr-fr"].levelEndScreenSubmitHighscoreBtn="Publier un score";W["fr-fr"].challengeStartScreenTitle_challengee_friend="Votre adversaire\u00a0:";W["fr-fr"].challengeStartTextScore="Son score :";W["fr-fr"].challengeStartTextTime="Son temps\u00a0:";W["fr-fr"].challengeStartScreenToWin="\u00c0 gagner\u00a0:";W["fr-fr"].challengeEndScreenWinnings="Vous avez gagn\u00e9 <AMOUNT> fairpoints.";
W["fr-fr"].challengeEndScreenOutcomeMessage_WON="Vainqueur\u00a0!";W["fr-fr"].challengeEndScreenOutcomeMessage_LOST="Zut\u00a0!";W["fr-fr"].challengeEndScreenOutcomeMessage_TIED="Ex-aequo\u00a0!";W["fr-fr"].challengeCancelConfirmText="Si vous annulez, on vous remboursera le montant du pari moins les frais de pari. Voulez-vous continuer\u00a0? ";W["fr-fr"].challengeCancelConfirmBtn_yes="Oui";W["fr-fr"].challengeCancelConfirmBtn_no="Non";W["fr-fr"].challengeEndScreensBtn_submit="Lancer le d\u00e9fi";
W["fr-fr"].challengeEndScreenBtn_cancel="Annuler le d\u00e9fi";W["fr-fr"].challengeEndScreenName_you="Moi";W["fr-fr"].challengeEndScreenChallengeSend_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";W["fr-fr"].challengeEndScreenChallengeSend_success="D\u00e9fi lanc\u00e9.";W["fr-fr"].challengeCancelMessage_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";W["fr-fr"].challengeCancelMessage_success="D\u00e9fi annul\u00e9.";
W["fr-fr"].challengeEndScreenScoreSend_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";W["fr-fr"].challengeStartScreenTitle_challengee_stranger="Votre adversaire\u00a0:";W["fr-fr"].challengeStartScreenTitle_challenger_friend="Votre adversaire\u00a0:";W["fr-fr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";W["fr-fr"].challengeStartTextTime_challenger="Finissez le plus vite possible !";W["fr-fr"].challengeStartTextScore_challenger="Essayez d\u2019atteindre le plus haut score !";
W["fr-fr"].challengeForfeitConfirmText="Voulez-vous vraiment abandonner la partie ?";W["fr-fr"].challengeForfeitConfirmBtn_yes="Oui";W["fr-fr"].challengeForfeitConfirmBtn_no="Non";W["fr-fr"].challengeForfeitMessage_success="Vous avez abandonn\u00e9.";W["fr-fr"].challengeForfeitMessage_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";W["fr-fr"].optionsChallengeForfeit="Abandonner";W["fr-fr"].optionsChallengeCancel="Annuler";W["fr-fr"].challengeLoadingError_notValid="D\u00e9sol\u00e9, cette partie n'existe plus.";
W["fr-fr"].challengeLoadingError_notStarted="Une erreur de connexion est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";W["fr-fr"].levelEndScreenHighScore_time="Meilleur temps :";W["fr-fr"].levelEndScreenTotalScore_time="Temps total :";W["fr-fr"]["optionsLang_fr-fr"]="Fran\u00e7ais";W["fr-fr"]["optionsLang_ko-kr"]="Cor\u00e9en";W["fr-fr"]["optionsLang_ar-eg"]="Arabe";W["fr-fr"]["optionsLang_es-es"]="Espagnol";W["fr-fr"]["optionsLang_pt-br"]="Portugais - Br\u00e9silien";
W["fr-fr"]["optionsLang_ru-ru"]="Russe";W["fr-fr"].optionsExit="Quitter";W["fr-fr"].levelEndScreenTotalScore_number="Score total :";W["fr-fr"].levelEndScreenHighScore_number="Meilleur score :";W["fr-fr"].challengeEndScreenChallengeSend_submessage="<NAME> a 72 heures pour accepter votre d\u00e9fi. Si <NAME> refuse ou n\u2019accepte pas dans ce d\u00e9lai vous serez rembours\u00e9 le montant de votre pari et les frais de pari.";W["fr-fr"].challengeEndScreenChallengeSend_submessage_stranger="Si personne n\u2019accepte votre pari d\u2019ici 72 heures, on vous remboursera le montant du pari y compris les frais.";
W["fr-fr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";W["fr-fr"].optionsAbout_header_publisher="Published by:";W["fr-fr"]["optionsLang_jp-jp"]="Japanese";W["pt-br"]=W["pt-br"]||{};W["pt-br"].loadingScreenLoading="Carregando...";W["pt-br"].startScreenPlay="JOGAR";W["pt-br"].levelMapScreenTotalScore="Pontua\u00e7\u00e3o";W["pt-br"].levelEndScreenTitle_level="N\u00edvel <VALUE>";W["pt-br"].levelEndScreenTitle_difficulty="Muito bem!";
W["pt-br"].levelEndScreenTitle_endless="Fase <VALUE>";W["pt-br"].levelEndScreenTotalScore="Pontua\u00e7\u00e3o";W["pt-br"].levelEndScreenSubTitle_levelFailed="Tente novamente";W["pt-br"].levelEndScreenTimeLeft="Tempo restante";W["pt-br"].levelEndScreenTimeBonus="B\u00f4nus de tempo";W["pt-br"].levelEndScreenHighScore="Recorde";W["pt-br"].optionsStartScreen="Menu principal";W["pt-br"].optionsQuit="Sair";W["pt-br"].optionsResume="Continuar";W["pt-br"].optionsTutorial="Como jogar";
W["pt-br"].optionsHighScore="Recordes";W["pt-br"].optionsMoreGames="Mais jogos";W["pt-br"].optionsDifficulty_easy="F\u00e1cil";W["pt-br"].optionsDifficulty_medium="M\u00e9dio";W["pt-br"].optionsDifficulty_hard="Dif\u00edcil";W["pt-br"].optionsMusic_on="Sim";W["pt-br"].optionsMusic_off="N\u00e3o";W["pt-br"].optionsSFX_on="Sim";W["pt-br"].optionsSFX_off="N\u00e3o";W["pt-br"]["optionsLang_en-us"]="Ingl\u00eas (EUA)";W["pt-br"]["optionsLang_en-gb"]="Ingl\u00eas (GB)";W["pt-br"]["optionsLang_nl-nl"]="Holand\u00eas";
W["pt-br"].gameEndScreenTitle="Parab\u00e9ns!\nVoc\u00ea concluiu o jogo.";W["pt-br"].gameEndScreenBtnText="Continuar";W["pt-br"].optionsTitle="Configura\u00e7\u00f5es";W["pt-br"].optionsQuitConfirmationText="Aten\u00e7\u00e3o!\n\nSe voc\u00ea sair agora, perder\u00e1 todo progresso realizado neste n\u00edvel. Deseja mesmo sair?";W["pt-br"].optionsQuitConfirmBtn_No="N\u00e3o";W["pt-br"].optionsQuitConfirmBtn_Yes="Sim, tenho certeza.";W["pt-br"].levelMapScreenTitle="Selecione um n\u00edvel";
W["pt-br"].optionsRestartConfirmationText="Aten\u00e7\u00e3o!\n\nSe voc\u00ea reiniciar agora, perder\u00e1 todo progresso realizado neste n\u00edvel. Deseja mesmo reiniciar?";W["pt-br"].optionsRestart="Reiniciar";W["pt-br"].optionsSFXBig_on="Com som";W["pt-br"].optionsSFXBig_off="Sem som";W["pt-br"].optionsAbout_title="Sobre";W["pt-br"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";W["pt-br"].optionsAbout_backBtn="Voltar";W["pt-br"].optionsAbout_version="vers\u00e3o:";
W["pt-br"].optionsAbout="Sobre";W["pt-br"].levelEndScreenMedal="MELHOROU!";W["pt-br"].startScreenQuestionaire="O que voc\u00ea achou?";W["pt-br"].levelMapScreenWorld_0="Selecione um n\u00edvel";W["pt-br"].startScreenByTinglyGames="da: CoolGames";W["pt-br"]["optionsLang_de-de"]="Alem\u00e3o";W["pt-br"]["optionsLang_tr-tr"]="Turco";W["pt-br"].optionsAbout_header="Desenvolvido por:";W["pt-br"].levelEndScreenViewHighscoreBtn="Ver pontua\u00e7\u00f5es";W["pt-br"].levelEndScreenSubmitHighscoreBtn="Enviar recorde";
W["pt-br"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";W["pt-br"].challengeStartTextScore="<NAME>'s score:";W["pt-br"].challengeStartTextTime="<NAME>'s time:";W["pt-br"].challengeStartScreenToWin="Amount to win:";W["pt-br"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";W["pt-br"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";W["pt-br"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";
W["pt-br"].challengeEndScreenOutcomeMessage_TIED="You tied.";W["pt-br"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";W["pt-br"].challengeCancelConfirmBtn_yes="Yes";W["pt-br"].challengeCancelConfirmBtn_no="No";W["pt-br"].challengeEndScreensBtn_submit="Submit challenge";W["pt-br"].challengeEndScreenBtn_cancel="Cancel challenge";W["pt-br"].challengeEndScreenName_you="You";
W["pt-br"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";W["pt-br"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";W["pt-br"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";W["pt-br"].challengeCancelMessage_success="Your challenge has been cancelled.";W["pt-br"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";
W["pt-br"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";W["pt-br"].challengeStartScreenTitle_challenger_friend="You are challenging:";W["pt-br"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";W["pt-br"].challengeStartTextTime_challenger="Play the game and set a time.";W["pt-br"].challengeStartTextScore_challenger="Play the game and set a score.";W["pt-br"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";
W["pt-br"].challengeForfeitConfirmBtn_yes="Yes";W["pt-br"].challengeForfeitConfirmBtn_no="No";W["pt-br"].challengeForfeitMessage_success="You have forfeited the challenge.";W["pt-br"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";W["pt-br"].optionsChallengeForfeit="Desistir";W["pt-br"].optionsChallengeCancel="Sair do Jogo";W["pt-br"].challengeLoadingError_notValid="Desculpe, este desafio n\u00e3o \u00e9 mais v\u00e1lido.";
W["pt-br"].challengeLoadingError_notStarted="Imposs\u00edvel conectar ao servidor. Por favor, tente novamente mais tarde.";W["pt-br"].levelEndScreenHighScore_time="Tempo recorde:";W["pt-br"].levelEndScreenTotalScore_time="Tempo total:";W["pt-br"]["optionsLang_fr-fr"]="Franc\u00eas";W["pt-br"]["optionsLang_ko-kr"]="Coreano";W["pt-br"]["optionsLang_ar-eg"]="\u00c1rabe";W["pt-br"]["optionsLang_es-es"]="Espanhol";W["pt-br"]["optionsLang_pt-br"]="Portugu\u00eas do Brasil";
W["pt-br"]["optionsLang_ru-ru"]="Russo";W["pt-br"].optionsExit="Sa\u00edda";W["pt-br"].levelEndScreenTotalScore_number="Pontua\u00e7\u00e3o total:";W["pt-br"].levelEndScreenHighScore_number="Pontua\u00e7\u00e3o m\u00e1xima:";W["pt-br"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
W["pt-br"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";W["pt-br"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";W["pt-br"].optionsAbout_header_publisher="Published by:";W["pt-br"]["optionsLang_jp-jp"]="Japanese";W["es-es"]=W["es-es"]||{};W["es-es"].loadingScreenLoading="Cargando...";W["es-es"].startScreenPlay="JUGAR";
W["es-es"].levelMapScreenTotalScore="Punt. total";W["es-es"].levelEndScreenTitle_level="Nivel <VALUE>";W["es-es"].levelEndScreenTitle_difficulty="\u00a1Muy bien!";W["es-es"].levelEndScreenTitle_endless="Fase <VALUE>";W["es-es"].levelEndScreenTotalScore="Punt. total";W["es-es"].levelEndScreenSubTitle_levelFailed="Nivel fallido";W["es-es"].levelEndScreenTimeLeft="Tiempo restante";W["es-es"].levelEndScreenTimeBonus="Bonif. tiempo";W["es-es"].levelEndScreenHighScore="R\u00e9cord";
W["es-es"].optionsStartScreen="Men\u00fa principal";W["es-es"].optionsQuit="Salir";W["es-es"].optionsResume="Seguir";W["es-es"].optionsTutorial="C\u00f3mo jugar";W["es-es"].optionsHighScore="R\u00e9cords";W["es-es"].optionsMoreGames="M\u00e1s juegos";W["es-es"].optionsDifficulty_easy="F\u00e1cil";W["es-es"].optionsDifficulty_medium="Normal";W["es-es"].optionsDifficulty_hard="Dif\u00edcil";W["es-es"].optionsMusic_on="S\u00ed";W["es-es"].optionsMusic_off="No";W["es-es"].optionsSFX_on="S\u00ed";
W["es-es"].optionsSFX_off="No";W["es-es"]["optionsLang_en-us"]="Ingl\u00e9s (EE.UU.)";W["es-es"]["optionsLang_en-gb"]="Ingl\u00e9s (GB)";W["es-es"]["optionsLang_nl-nl"]="Neerland\u00e9s";W["es-es"].gameEndScreenTitle="\u00a1Enhorabuena!\nHas terminado el juego.";W["es-es"].gameEndScreenBtnText="Continuar";W["es-es"].optionsTitle="Ajustes";W["es-es"].optionsQuitConfirmationText="\u00a1Aviso!\n\nSi sales ahora, perder\u00e1s el progreso que hayas realizado en el nivel. \u00bfSeguro que quieres salir?";
W["es-es"].optionsQuitConfirmBtn_No="No";W["es-es"].optionsQuitConfirmBtn_Yes="S\u00ed, seguro";W["es-es"].levelMapScreenTitle="Elige un nivel";W["es-es"].optionsRestartConfirmationText="\u00a1Aviso!\n\nSi reinicias ahora, perder\u00e1s el progreso que hayas realizado en el nivel. \u00bfSeguro que quieres reiniciar?";W["es-es"].optionsRestart="Reiniciar";W["es-es"].optionsSFXBig_on="Sonido s\u00ed";W["es-es"].optionsSFXBig_off="Sonido no";W["es-es"].optionsAbout_title="Acerca de";
W["es-es"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";W["es-es"].optionsAbout_backBtn="Atr\u00e1s";W["es-es"].optionsAbout_version="versi\u00f3n:";W["es-es"].optionsAbout="Acerca de";W["es-es"].levelEndScreenMedal="\u00a1SUPERADO!";W["es-es"].startScreenQuestionaire="\u00bfQu\u00e9 te parece?";W["es-es"].levelMapScreenWorld_0="Elige un nivel";W["es-es"].startScreenByTinglyGames="de: CoolGames";W["es-es"]["optionsLang_de-de"]="Alem\u00e1n";W["es-es"]["optionsLang_tr-tr"]="Turco";
W["es-es"].optionsAbout_header="Desarrollado por:";W["es-es"].levelEndScreenViewHighscoreBtn="Ver puntuaciones";W["es-es"].levelEndScreenSubmitHighscoreBtn="Enviar puntuaci\u00f3n";W["es-es"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";W["es-es"].challengeStartTextScore="<NAME>'s score:";W["es-es"].challengeStartTextTime="<NAME>'s time:";W["es-es"].challengeStartScreenToWin="Amount to win:";W["es-es"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";
W["es-es"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";W["es-es"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";W["es-es"].challengeEndScreenOutcomeMessage_TIED="You tied.";W["es-es"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";W["es-es"].challengeCancelConfirmBtn_yes="Yes";W["es-es"].challengeCancelConfirmBtn_no="No";
W["es-es"].challengeEndScreensBtn_submit="Submit challenge";W["es-es"].challengeEndScreenBtn_cancel="Cancel challenge";W["es-es"].challengeEndScreenName_you="You";W["es-es"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";W["es-es"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";W["es-es"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
W["es-es"].challengeCancelMessage_success="Your challenge has been cancelled.";W["es-es"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";W["es-es"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";W["es-es"].challengeStartScreenTitle_challenger_friend="You are challenging:";W["es-es"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
W["es-es"].challengeStartTextTime_challenger="Play the game and set a time.";W["es-es"].challengeStartTextScore_challenger="Play the game and set a score.";W["es-es"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";W["es-es"].challengeForfeitConfirmBtn_yes="Yes";W["es-es"].challengeForfeitConfirmBtn_no="No";W["es-es"].challengeForfeitMessage_success="You have forfeited the challenge.";W["es-es"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
W["es-es"].optionsChallengeForfeit="Rendirse";W["es-es"].optionsChallengeCancel="Abandonar";W["es-es"].challengeLoadingError_notValid="Lo sentimos, este reto ya no es v\u00e1lido.";W["es-es"].challengeLoadingError_notStarted="Imposible conectar con el servidor. Int\u00e9ntalo m\u00e1s tarde.";W["es-es"].levelEndScreenHighScore_time="Mejor tiempo:";W["es-es"].levelEndScreenTotalScore_time="Tiempo total:";W["es-es"]["optionsLang_fr-fr"]="Franc\u00e9s";W["es-es"]["optionsLang_ko-kr"]="Coreano";
W["es-es"]["optionsLang_ar-eg"]="\u00c1rabe";W["es-es"]["optionsLang_es-es"]="Espa\u00f1ol";W["es-es"]["optionsLang_pt-br"]="Portugu\u00e9s brasile\u00f1o";W["es-es"]["optionsLang_ru-ru"]="Ruso";W["es-es"].optionsExit="Salir";W["es-es"].levelEndScreenTotalScore_number="Puntos totales:";W["es-es"].levelEndScreenHighScore_number="Mejor puntuaci\u00f3n:";W["es-es"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
W["es-es"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";W["es-es"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";W["es-es"].optionsAbout_header_publisher="Published by:";W["es-es"]["optionsLang_jp-jp"]="Japanese";W["tr-tr"]=W["tr-tr"]||{};W["tr-tr"].loadingScreenLoading="Y\u00fckleniyor...";W["tr-tr"].startScreenPlay="OYNA";
W["tr-tr"].levelMapScreenTotalScore="Toplam skor";W["tr-tr"].levelEndScreenTitle_level="Seviye <VALUE>";W["tr-tr"].levelEndScreenTitle_difficulty="Bravo!";W["tr-tr"].levelEndScreenTitle_endless="B\u00f6l\u00fcm <VALUE>";W["tr-tr"].levelEndScreenTotalScore="Toplam skor";W["tr-tr"].levelEndScreenSubTitle_levelFailed="Seviye ba\u015far\u0131s\u0131z";W["tr-tr"].levelEndScreenTimeLeft="Kalan S\u00fcre";W["tr-tr"].levelEndScreenTimeBonus="S\u00fcre Bonusu";W["tr-tr"].levelEndScreenHighScore="Y\u00fcksek skor";
W["tr-tr"].optionsStartScreen="Ana men\u00fc";W["tr-tr"].optionsQuit="\u00c7\u0131k";W["tr-tr"].optionsResume="Devam et";W["tr-tr"].optionsTutorial="Nas\u0131l oynan\u0131r";W["tr-tr"].optionsHighScore="Y\u00fcksek skorlar";W["tr-tr"].optionsMoreGames="Daha Fazla Oyun";W["tr-tr"].optionsDifficulty_easy="Kolay";W["tr-tr"].optionsDifficulty_medium="Orta";W["tr-tr"].optionsDifficulty_hard="Zorluk";W["tr-tr"].optionsMusic_on="A\u00e7\u0131k";W["tr-tr"].optionsMusic_off="Kapal\u0131";
W["tr-tr"].optionsSFX_on="A\u00e7\u0131k";W["tr-tr"].optionsSFX_off="Kapal\u0131";W["tr-tr"]["optionsLang_en-us"]="\u0130ngilizce (US)";W["tr-tr"]["optionsLang_en-gb"]="\u0130ngilizce (GB)";W["tr-tr"]["optionsLang_nl-nl"]="Hollandaca";W["tr-tr"].gameEndScreenTitle="Tebrikler!\nOyunu tamamlad\u0131n.";W["tr-tr"].gameEndScreenBtnText="Devam";W["tr-tr"].optionsTitle="Ayarlar";W["tr-tr"].optionsQuitConfirmationText="Dikkat!\n\u015eimdi \u00e7\u0131karsan bu seviyede yap\u0131lan t\u00fcm ilerleme kaybedilecek. \u00c7\u0131kmak istedi\u011finizden emin misiniz?";
W["tr-tr"].optionsQuitConfirmBtn_No="Hay\u0131r";W["tr-tr"].optionsQuitConfirmBtn_Yes="Evet, eminim";W["tr-tr"].levelMapScreenTitle="Bir seviye se\u00e7";W["tr-tr"].optionsRestartConfirmationText="Dikkat!\n\u015eimdi tekrar ba\u015flarsan bu seviyede yap\u0131lan t\u00fcm ilerleme kaybedilecek. Ba\u015ftan ba\u015flamak istedi\u011finden emin misin?";W["tr-tr"].optionsRestart="Tekrar ba\u015flat";W["tr-tr"].optionsSFXBig_on="Ses a\u00e7\u0131k";W["tr-tr"].optionsSFXBig_off="Ses kapal\u0131";
W["tr-tr"].optionsAbout_title="Hakk\u0131nda";W["tr-tr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";W["tr-tr"].optionsAbout_backBtn="Geri";W["tr-tr"].optionsAbout_version="s\u00fcr\u00fcm:";W["tr-tr"].optionsAbout="Hakk\u0131nda";W["tr-tr"].levelEndScreenMedal="\u0130Y\u0130LE\u015eT\u0130!";W["tr-tr"].startScreenQuestionaire="Ne dersin?";W["tr-tr"].levelMapScreenWorld_0="Bir seviye se\u00e7";W["tr-tr"].startScreenByTinglyGames="taraf\u0131ndan: CoolGames";
W["tr-tr"]["optionsLang_de-de"]="Almanca";W["tr-tr"]["optionsLang_tr-tr"]="T\u00fcrk\u00e7e";W["tr-tr"].optionsAbout_header="Haz\u0131rlayan:";W["tr-tr"].levelEndScreenViewHighscoreBtn="Puanlar\u0131 g\u00f6ster:";W["tr-tr"].levelEndScreenSubmitHighscoreBtn="Puan g\u00f6nder";W["tr-tr"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";W["tr-tr"].challengeStartTextScore="<NAME>'s score:";W["tr-tr"].challengeStartTextTime="<NAME>'s time:";
W["tr-tr"].challengeStartScreenToWin="Amount to win:";W["tr-tr"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";W["tr-tr"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";W["tr-tr"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";W["tr-tr"].challengeEndScreenOutcomeMessage_TIED="You tied.";W["tr-tr"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
W["tr-tr"].challengeCancelConfirmBtn_yes="Yes";W["tr-tr"].challengeCancelConfirmBtn_no="No";W["tr-tr"].challengeEndScreensBtn_submit="Submit challenge";W["tr-tr"].challengeEndScreenBtn_cancel="Cancel challenge";W["tr-tr"].challengeEndScreenName_you="You";W["tr-tr"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";W["tr-tr"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
W["tr-tr"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";W["tr-tr"].challengeCancelMessage_success="Your challenge has been cancelled.";W["tr-tr"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";W["tr-tr"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";W["tr-tr"].challengeStartScreenTitle_challenger_friend="You are challenging:";
W["tr-tr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";W["tr-tr"].challengeStartTextTime_challenger="Play the game and set a time.";W["tr-tr"].challengeStartTextScore_challenger="Play the game and set a score.";W["tr-tr"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";W["tr-tr"].challengeForfeitConfirmBtn_yes="Yes";W["tr-tr"].challengeForfeitConfirmBtn_no="No";W["tr-tr"].challengeForfeitMessage_success="You have forfeited the challenge.";
W["tr-tr"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";W["tr-tr"].optionsChallengeForfeit="Vazge\u00e7";W["tr-tr"].optionsChallengeCancel="\u00c7\u0131k\u0131\u015f";W["tr-tr"].challengeLoadingError_notValid="\u00dczg\u00fcn\u00fcz, bu zorluk art\u0131k ge\u00e7erli de\u011fil.";W["tr-tr"].challengeLoadingError_notStarted="Sunucuya ba\u011flan\u0131lam\u0131yor. L\u00fctfen daha sonra tekrar deneyin.";
W["tr-tr"].levelEndScreenHighScore_time="En \u0130yi Zaman:";W["tr-tr"].levelEndScreenTotalScore_time="Toplam Zaman:";W["tr-tr"]["optionsLang_fr-fr"]="Frans\u0131zca";W["tr-tr"]["optionsLang_ko-kr"]="Korece";W["tr-tr"]["optionsLang_ar-eg"]="Arap\u00e7a";W["tr-tr"]["optionsLang_es-es"]="\u0130spanyolca";W["tr-tr"]["optionsLang_pt-br"]="Brezilya Portekizcesi";W["tr-tr"]["optionsLang_ru-ru"]="Rus\u00e7a";W["tr-tr"].optionsExit="\u00c7\u0131k\u0131\u015f";W["tr-tr"].levelEndScreenTotalScore_number="Toplam Puan:";
W["tr-tr"].levelEndScreenHighScore_number="Y\u00fcksek Puan:";W["tr-tr"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";W["tr-tr"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";
W["tr-tr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";W["tr-tr"].optionsAbout_header_publisher="Published by:";W["tr-tr"]["optionsLang_jp-jp"]="Japanese";W["ru-ru"]=W["ru-ru"]||{};W["ru-ru"].loadingScreenLoading="\u0417\u0430\u0433\u0440\u0443\u0437\u043a\u0430...";W["ru-ru"].startScreenPlay="\u0418\u0413\u0420\u0410\u0422\u042c";W["ru-ru"].levelMapScreenTotalScore="\u041e\u0431\u0449\u0438\u0439 \u0441\u0447\u0435\u0442";W["ru-ru"].levelEndScreenTitle_level="\u0423\u0440\u043e\u0432\u0435\u043d\u044c <VALUE>";
W["ru-ru"].levelEndScreenTitle_difficulty="\u0425\u043e\u0440\u043e\u0448\u0438\u0439 \u0440\u0435\u0437\u0443\u043b\u044c\u0442\u0430\u0442!";W["ru-ru"].levelEndScreenTitle_endless="\u042d\u0442\u0430\u043f <VALUE>";W["ru-ru"].levelEndScreenTotalScore="\u041e\u0431\u0449\u0438\u0439 \u0441\u0447\u0435\u0442";W["ru-ru"].levelEndScreenSubTitle_levelFailed="\u0423\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u043f\u0440\u043e\u0439\u0434\u0435\u043d";W["ru-ru"].levelEndScreenTimeLeft="\u041e\u0441\u0442\u0430\u0432\u0448\u0435\u0435\u0441\u044f \u0432\u0440\u0435\u043c\u044f";
W["ru-ru"].levelEndScreenTimeBonus="\u0414\u043e\u043f\u043e\u043b\u043d\u0438\u0442\u0435\u043b\u044c\u043d\u043e\u0435 \u0432\u0440\u0435\u043c\u044f";W["ru-ru"].levelEndScreenHighScore="\u0420\u0435\u043a\u043e\u0440\u0434";W["ru-ru"].optionsStartScreen="\u0413\u043b\u0430\u0432\u043d\u043e\u0435 \u043c\u0435\u043d\u044e";W["ru-ru"].optionsQuit="\u0412\u044b\u0439\u0442\u0438";W["ru-ru"].optionsResume="\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u044c";W["ru-ru"].optionsTutorial="\u041a\u0430\u043a \u0438\u0433\u0440\u0430\u0442\u044c";
W["ru-ru"].optionsHighScore="\u0420\u0435\u043a\u043e\u0440\u0434\u044b";W["ru-ru"].optionsMoreGames="\u0411\u043e\u043b\u044c\u0448\u0435 \u0438\u0433\u0440";W["ru-ru"].optionsDifficulty_easy="\u041b\u0435\u0433\u043a\u0438\u0439";W["ru-ru"].optionsDifficulty_medium="\u0421\u0440\u0435\u0434\u043d\u0438\u0439";W["ru-ru"].optionsDifficulty_hard="\u0421\u043b\u043e\u0436\u043d\u044b\u0439";W["ru-ru"].optionsMusic_on="\u0412\u043a\u043b.";W["ru-ru"].optionsMusic_off="\u0412\u044b\u043a\u043b.";
W["ru-ru"].optionsSFX_on="\u0412\u043a\u043b.";W["ru-ru"].optionsSFX_off="\u0412\u044b\u043a\u043b.";W["ru-ru"]["optionsLang_en-us"]="\u0410\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 (\u0421\u0428\u0410)";W["ru-ru"]["optionsLang_en-gb"]="\u0410\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 (\u0412\u0411)";W["ru-ru"]["optionsLang_nl-nl"]="\u041d\u0438\u0434\u0435\u0440\u043b\u0430\u043d\u0434\u0441\u043a\u0438\u0439";W["ru-ru"].gameEndScreenTitle="\u041f\u043e\u0437\u0434\u0440\u0430\u0432\u043b\u044f\u0435\u043c!\n\u0412\u044b \u043f\u0440\u043e\u0448\u043b\u0438 \u0438\u0433\u0440\u0443.";
W["ru-ru"].gameEndScreenBtnText="\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u044c";W["ru-ru"].optionsTitle="\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438";W["ru-ru"].optionsQuitConfirmationText="\u0412\u043d\u0438\u043c\u0430\u043d\u0438\u0435!\n\n\u0415\u0441\u043b\u0438 \u0432\u044b \u0432\u044b\u0439\u0434\u0435\u0442\u0435 \u0441\u0435\u0439\u0447\u0430\u0441, \u0443\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u0431\u0443\u0434\u0435\u0442 \u0437\u0430\u0441\u0447\u0438\u0442\u0430\u043d. \u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0432\u044b\u0439\u0442\u0438?";
W["ru-ru"].optionsQuitConfirmBtn_No="\u041d\u0435\u0442";W["ru-ru"].optionsQuitConfirmBtn_Yes="\u0414\u0430, \u0432\u044b\u0439\u0442\u0438";W["ru-ru"].levelMapScreenTitle="\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0440\u043e\u0432\u0435\u043d\u044c";W["ru-ru"].optionsRestartConfirmationText="\u0412\u043d\u0438\u043c\u0430\u043d\u0438\u0435!\n\n\u0415\u0441\u043b\u0438 \u0432\u044b \u0441\u0435\u0439\u0447\u0430\u0441 \u043d\u0430\u0447\u043d\u0435\u0442\u0435 \u0438\u0433\u0440\u0443 \u0437\u0430\u043d\u043e\u0432\u043e, \u0443\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u0431\u0443\u0434\u0435\u0442 \u0437\u0430\u0441\u0447\u0438\u0442\u0430\u043d. \u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u043d\u0430\u0447\u0430\u0442\u044c \u0437\u0430\u043d\u043e\u0432\u043e?";
W["ru-ru"].optionsRestart="\u0417\u0430\u043d\u043e\u0432\u043e";W["ru-ru"].optionsSFXBig_on="\u0417\u0432\u0443\u043a \u0432\u043a\u043b.";W["ru-ru"].optionsSFXBig_off="\u0417\u0432\u0443\u043a \u0432\u044b\u043a\u043b.";W["ru-ru"].optionsAbout_title="\u041e \u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0435";W["ru-ru"].optionsAbout_text="\u00a9 CoolGames\nwww.coolgames.com\n2016";W["ru-ru"].optionsAbout_backBtn="\u041d\u0430\u0437\u0430\u0434";W["ru-ru"].optionsAbout_version="\u0412\u0435\u0440\u0441\u0438\u044f:";
W["ru-ru"].optionsAbout="\u041e \u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0435";W["ru-ru"].levelEndScreenMedal="\u041d\u041e\u0412\u042b\u0419 \u0420\u0415\u041a\u041e\u0420\u0414!";W["ru-ru"].startScreenQuestionaire="\u041a\u0430\u043a \u0432\u0430\u043c \u0438\u0433\u0440\u0430?";W["ru-ru"].levelMapScreenWorld_0="\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0440\u043e\u0432\u0435\u043d\u044c";W["ru-ru"].startScreenByTinglyGames="\u0420\u0430\u0437\u0440\u0430\u0431\u043e\u0442\u0447\u0438\u043a\u0438: CoolGames";
W["ru-ru"]["optionsLang_de-de"]="\u041d\u0435\u043c\u0435\u0446\u043a\u0438\u0439";W["ru-ru"]["optionsLang_tr-tr"]="\u0422\u0443\u0440\u0435\u0446\u043a\u0438\u0439";W["ru-ru"].optionsAbout_header="Developed by:";W["ru-ru"].levelEndScreenViewHighscoreBtn="View scores";W["ru-ru"].levelEndScreenSubmitHighscoreBtn="Submit score";W["ru-ru"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";W["ru-ru"].challengeStartTextScore="<NAME>'s score:";
W["ru-ru"].challengeStartTextTime="<NAME>'s time:";W["ru-ru"].challengeStartScreenToWin="Amount to win:";W["ru-ru"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";W["ru-ru"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";W["ru-ru"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";W["ru-ru"].challengeEndScreenOutcomeMessage_TIED="You tied.";W["ru-ru"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
W["ru-ru"].challengeCancelConfirmBtn_yes="Yes";W["ru-ru"].challengeCancelConfirmBtn_no="No";W["ru-ru"].challengeEndScreensBtn_submit="Submit challenge";W["ru-ru"].challengeEndScreenBtn_cancel="Cancel challenge";W["ru-ru"].challengeEndScreenName_you="You";W["ru-ru"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";W["ru-ru"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
W["ru-ru"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";W["ru-ru"].challengeCancelMessage_success="Your challenge has been cancelled.";W["ru-ru"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";W["ru-ru"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";W["ru-ru"].challengeStartScreenTitle_challenger_friend="You are challenging:";
W["ru-ru"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";W["ru-ru"].challengeStartTextTime_challenger="Play the game and set a time.";W["ru-ru"].challengeStartTextScore_challenger="Play the game and set a score.";W["ru-ru"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";W["ru-ru"].challengeForfeitConfirmBtn_yes="Yes";W["ru-ru"].challengeForfeitConfirmBtn_no="No";W["ru-ru"].challengeForfeitMessage_success="You have forfeited the challenge.";
W["ru-ru"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";W["ru-ru"].optionsChallengeForfeit="Forfeit";W["ru-ru"].optionsChallengeCancel="Quit";W["ru-ru"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";W["ru-ru"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";W["ru-ru"].levelEndScreenHighScore_time="Best time:";W["ru-ru"].levelEndScreenTotalScore_time="Total time:";
W["ru-ru"]["optionsLang_fr-fr"]="\u0424\u0440\u0430\u043d\u0446\u0443\u0437\u0441\u043a\u0438\u0439";W["ru-ru"]["optionsLang_ko-kr"]="\u041a\u043e\u0440\u0435\u0439\u0441\u043a\u0438\u0439";W["ru-ru"]["optionsLang_ar-eg"]="\u0410\u0440\u0430\u0431\u0441\u043a\u0438\u0439";W["ru-ru"]["optionsLang_es-es"]="\u0418\u0441\u043f\u0430\u043d\u0441\u043a\u0438\u0439";W["ru-ru"]["optionsLang_pt-br"]="\u0411\u0440\u0430\u0437\u0438\u043b\u044c\u0441\u043a\u0438\u0439 \u043f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u044c\u0441\u043a\u0438\u0439";
W["ru-ru"]["optionsLang_ru-ru"]="\u0420\u0443\u0441\u0441\u043a\u0438\u0439";W["ru-ru"].optionsExit="Exit";W["ru-ru"].levelEndScreenTotalScore_number="Total score:";W["ru-ru"].levelEndScreenHighScore_number="High score:";W["ru-ru"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
W["ru-ru"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";W["ru-ru"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";W["ru-ru"].optionsAbout_header_publisher="Published by:";W["ru-ru"]["optionsLang_jp-jp"]="Japanese";W["ar-eg"]=W["ar-eg"]||{};W["ar-eg"].loadingScreenLoading="\u064a\u062a\u0645 \u0627\u0644\u0622\u0646 \u0627\u0644\u062a\u062d\u0645\u064a\u0644...";
W["ar-eg"].startScreenPlay="\u062a\u0634\u063a\u064a\u0644";W["ar-eg"].levelMapScreenTotalScore="\u0627\u0644\u0646\u062a\u064a\u062c\u0629 \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a\u0629";W["ar-eg"].levelEndScreenTitle_level="\u0627\u0644\u0645\u0633\u062a\u0648\u0649 <VALUE>";W["ar-eg"].levelEndScreenTitle_difficulty="\u0623\u062d\u0633\u0646\u062a!";W["ar-eg"].levelEndScreenTitle_endless="\u0627\u0644\u0645\u0631\u062d\u0644\u0629 <VALUE>";W["ar-eg"].levelEndScreenTotalScore="\u0627\u0644\u0646\u062a\u064a\u062c\u0629 \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a\u0629";
W["ar-eg"].levelEndScreenSubTitle_levelFailed="\u0644\u0642\u062f \u0641\u0634\u0644\u062a \u0641\u064a \u0627\u062c\u062a\u064a\u0627\u0632 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649";W["ar-eg"].levelEndScreenTimeLeft="\u0627\u0644\u0648\u0642\u062a \u0627\u0644\u0645\u062a\u0628\u0642\u064a";W["ar-eg"].levelEndScreenTimeBonus="\u0645\u0643\u0627\u0641\u0623\u0629 \u0627\u0644\u0648\u0642\u062a";W["ar-eg"].levelEndScreenHighScore="\u0623\u0639\u0644\u0649 \u0646\u062a\u064a\u062c\u0629";
W["ar-eg"].optionsStartScreen="\u0627\u0644\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629";W["ar-eg"].optionsQuit="\u0627\u0644\u062e\u0631\u0648\u062c \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629";W["ar-eg"].optionsResume="\u0627\u0633\u062a\u0626\u0646\u0627\u0641";W["ar-eg"].optionsTutorial="\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u0644\u0639\u0628";W["ar-eg"].optionsHighScore="\u0623\u0639\u0644\u0649 \u0627\u0644\u0646\u062a\u0627\u0626\u062c";
W["ar-eg"].optionsMoreGames="\u0627\u0644\u0645\u0632\u064a\u062f \u0645\u0646 \u0627\u0644\u0623\u0644\u0639\u0627\u0628";W["ar-eg"].optionsDifficulty_easy="\u0633\u0647\u0644";W["ar-eg"].optionsDifficulty_medium="\u0645\u062a\u0648\u0633\u0637";W["ar-eg"].optionsDifficulty_hard="\u0635\u0639\u0628";W["ar-eg"].optionsMusic_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0645\u0648\u0633\u064a\u0642\u0649";W["ar-eg"].optionsMusic_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0645\u0648\u0633\u064a\u0642\u0649";
W["ar-eg"].optionsSFX_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0645\u0624\u062b\u0631\u0627\u062a \u0627\u0644\u0635\u0648\u062a\u064a\u0629";W["ar-eg"].optionsSFX_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0645\u0624\u062b\u0631\u0627\u062a \u0627\u0644\u0635\u0648\u062a\u064a\u0629";W["ar-eg"]["optionsLang_en-us"]="\u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 (\u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a \u0627\u0644\u0645\u062a\u062d\u062f\u0629)";
W["ar-eg"]["optionsLang_en-gb"]="\u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 (\u0627\u0644\u0645\u0645\u0644\u0643\u0629 \u0627\u0644\u0645\u062a\u062d\u062f\u0629)";W["ar-eg"]["optionsLang_nl-nl"]="\u0627\u0644\u0647\u0648\u0644\u0646\u062f\u064a\u0629";W["ar-eg"].gameEndScreenTitle="\u062a\u0647\u0627\u0646\u064a\u0646\u0627!\n\u0644\u0642\u062f \u0623\u0643\u0645\u0644\u062a \u0627\u0644\u0644\u0639\u0628\u0629.";W["ar-eg"].gameEndScreenBtnText="\u0645\u062a\u0627\u0628\u0639\u0629";
W["ar-eg"].optionsTitle="\u0627\u0644\u0625\u0639\u062f\u0627\u062f\u0627\u062a";W["ar-eg"].optionsQuitConfirmationText="\u0627\u0646\u062a\u0628\u0647!n\n\u0625\u0630\u0627 \u062e\u0631\u062c\u062a \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629 \u0627\u0644\u0622\u0646\u060c \u0641\u0633\u062a\u0641\u0642\u062f \u0643\u0644 \u0627\u0644\u062a\u0642\u062f\u0645 \u0627\u0644\u0630\u064a \u0623\u062d\u0631\u0632\u062a\u0647 \u062e\u0644\u0627\u0644 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649. \u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0627\u0644\u062e\u0631\u0648\u062c \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629\u061f";
W["ar-eg"].optionsQuitConfirmBtn_No="\u0644\u0627";W["ar-eg"].optionsQuitConfirmBtn_Yes="\u0646\u0639\u0645\u060c \u0645\u062a\u0623\u0643\u062f";W["ar-eg"].levelMapScreenTitle="\u062a\u062d\u062f\u064a\u062f \u0645\u0633\u062a\u0648\u0649";W["ar-eg"].optionsRestartConfirmationText="\u0627\u0646\u062a\u0628\u0647!\n\n\u0625\u0630\u0627 \u0642\u0645\u062a \u0628\u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0622\u0646\u060c \u0641\u0633\u062a\u0641\u0642\u062f \u0643\u0644 \u0627\u0644\u062a\u0642\u062f\u0645 \u0627\u0644\u0630\u064a \u0623\u062d\u0631\u0632\u062a\u0647 \u062e\u0644\u0627\u0644 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649. \u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644\u061f";
W["ar-eg"].optionsRestart="\u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644";W["ar-eg"].optionsSFXBig_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0635\u0648\u062a";W["ar-eg"].optionsSFXBig_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0635\u0648\u062a";W["ar-eg"].optionsAbout_title="\u062d\u0648\u0644";W["ar-eg"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";W["ar-eg"].optionsAbout_backBtn="\u0627\u0644\u0633\u0627\u0628\u0642";
W["ar-eg"].optionsAbout_version="\u0627\u0644\u0625\u0635\u062f\u0627\u0631:";W["ar-eg"].optionsAbout="\u062d\u0648\u0644";W["ar-eg"].levelEndScreenMedal="\u0644\u0642\u062f \u062a\u062d\u0633\u0651\u0646\u062a!";W["ar-eg"].startScreenQuestionaire="\u0645\u0627 \u0631\u0623\u064a\u0643\u061f";W["ar-eg"].levelMapScreenWorld_0="\u062a\u062d\u062f\u064a\u062f \u0645\u0633\u062a\u0648\u0649";W["ar-eg"].startScreenByTinglyGames="\u0628\u0648\u0627\u0633\u0637\u0629: CoolGames";
W["ar-eg"]["optionsLang_de-de"]="\u0627\u0644\u0623\u0644\u0645\u0627\u0646\u064a\u0629";W["ar-eg"]["optionsLang_tr-tr"]="\u0627\u0644\u062a\u0631\u0643\u064a\u0629";W["ar-eg"].optionsAbout_header="Developed by:";W["ar-eg"].levelEndScreenViewHighscoreBtn="View scores";W["ar-eg"].levelEndScreenSubmitHighscoreBtn="Submit score";W["ar-eg"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";W["ar-eg"].challengeStartTextScore="<NAME>'s score:";
W["ar-eg"].challengeStartTextTime="<NAME>'s time:";W["ar-eg"].challengeStartScreenToWin="Amount to win:";W["ar-eg"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";W["ar-eg"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";W["ar-eg"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";W["ar-eg"].challengeEndScreenOutcomeMessage_TIED="You tied.";W["ar-eg"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
W["ar-eg"].challengeCancelConfirmBtn_yes="Yes";W["ar-eg"].challengeCancelConfirmBtn_no="No";W["ar-eg"].challengeEndScreensBtn_submit="Submit challenge";W["ar-eg"].challengeEndScreenBtn_cancel="Cancel challenge";W["ar-eg"].challengeEndScreenName_you="You";W["ar-eg"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";W["ar-eg"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
W["ar-eg"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";W["ar-eg"].challengeCancelMessage_success="Your challenge has been cancelled.";W["ar-eg"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";W["ar-eg"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";W["ar-eg"].challengeStartScreenTitle_challenger_friend="You are challenging:";
W["ar-eg"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";W["ar-eg"].challengeStartTextTime_challenger="Play the game and set a time.";W["ar-eg"].challengeStartTextScore_challenger="Play the game and set a score.";W["ar-eg"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";W["ar-eg"].challengeForfeitConfirmBtn_yes="Yes";W["ar-eg"].challengeForfeitConfirmBtn_no="No";W["ar-eg"].challengeForfeitMessage_success="You have forfeited the challenge.";
W["ar-eg"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";W["ar-eg"].optionsChallengeForfeit="Forfeit";W["ar-eg"].optionsChallengeCancel="Quit";W["ar-eg"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";W["ar-eg"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";W["ar-eg"].levelEndScreenHighScore_time="Best time:";W["ar-eg"].levelEndScreenTotalScore_time="Total time:";
W["ar-eg"]["optionsLang_fr-fr"]="\u0627\u0644\u0641\u0631\u0646\u0633\u064a\u0629";W["ar-eg"]["optionsLang_ko-kr"]="\u0627\u0644\u0643\u0648\u0631\u064a\u0629";W["ar-eg"]["optionsLang_ar-eg"]="\u0627\u0644\u0639\u0631\u0628\u064a\u0629";W["ar-eg"]["optionsLang_es-es"]="\u0627\u0644\u0625\u0633\u0628\u0627\u0646\u064a\u0629";W["ar-eg"]["optionsLang_pt-br"]="\u0627\u0644\u0628\u0631\u0627\u0632\u064a\u0644\u064a\u0629 - \u0627\u0644\u0628\u0631\u062a\u063a\u0627\u0644\u064a\u0629";
W["ar-eg"]["optionsLang_ru-ru"]="\u0627\u0644\u0631\u0648\u0633\u064a\u0629";W["ar-eg"].optionsExit="Exit";W["ar-eg"].levelEndScreenTotalScore_number="Total score:";W["ar-eg"].levelEndScreenHighScore_number="High score:";W["ar-eg"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
W["ar-eg"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";W["ar-eg"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";W["ar-eg"].optionsAbout_header_publisher="Published by:";W["ar-eg"]["optionsLang_jp-jp"]="Japanese";W["ko-kr"]=W["ko-kr"]||{};W["ko-kr"].loadingScreenLoading="\ubd88\ub7ec\uc624\uae30 \uc911...";W["ko-kr"].startScreenPlay="PLAY";
W["ko-kr"].levelMapScreenTotalScore="\ucd1d \uc810\uc218";W["ko-kr"].levelEndScreenTitle_level="\ub808\ubca8 <VALUE>";W["ko-kr"].levelEndScreenTitle_difficulty="\uc798 \ud588\uc5b4\uc694!";W["ko-kr"].levelEndScreenTitle_endless="\uc2a4\ud14c\uc774\uc9c0 <VALUE>";W["ko-kr"].levelEndScreenTotalScore="\ucd1d \uc810\uc218";W["ko-kr"].levelEndScreenSubTitle_levelFailed="\ub808\ubca8 \uc2e4\ud328";W["ko-kr"].levelEndScreenTimeLeft="\ub0a8\uc740 \uc2dc\uac04";W["ko-kr"].levelEndScreenTimeBonus="\uc2dc\uac04 \ubcf4\ub108\uc2a4";
W["ko-kr"].levelEndScreenHighScore="\ucd5c\uace0 \uc810\uc218";W["ko-kr"].optionsStartScreen="\uba54\uc778 \uba54\ub274";W["ko-kr"].optionsQuit="\uc885\ub8cc";W["ko-kr"].optionsResume="\uacc4\uc18d";W["ko-kr"].optionsTutorial="\uac8c\uc784 \ubc29\ubc95";W["ko-kr"].optionsHighScore="\ucd5c\uace0 \uc810\uc218";W["ko-kr"].optionsMoreGames="\ub354 \ub9ce\uc740 \uac8c\uc784";W["ko-kr"].optionsDifficulty_easy="\uac04\ub2e8";W["ko-kr"].optionsDifficulty_medium="\uc911";
W["ko-kr"].optionsDifficulty_hard="\uc0c1";W["ko-kr"].optionsMusic_on="\ucf1c\uae30";W["ko-kr"].optionsMusic_off="\ub044\uae30";W["ko-kr"].optionsSFX_on="\ucf1c\uae30";W["ko-kr"].optionsSFX_off="\ub044\uae30";W["ko-kr"]["optionsLang_en-us"]="\uc601\uc5b4(US)";W["ko-kr"]["optionsLang_en-gb"]="\uc601\uc5b4(GB)";W["ko-kr"]["optionsLang_nl-nl"]="\ub124\ub35c\ub780\ub4dc\uc5b4";W["ko-kr"].gameEndScreenTitle="\ucd95\ud558\ud569\ub2c8\ub2e4!\n\uac8c\uc784\uc744 \uc644\ub8cc\ud588\uc2b5\ub2c8\ub2e4.";
W["ko-kr"].gameEndScreenBtnText="\uacc4\uc18d";W["ko-kr"].optionsTitle="\uc124\uc815";W["ko-kr"].optionsQuitConfirmationText="\uc8fc\uc758!\n\n\uc9c0\uae08 \uc885\ub8cc\ud558\uba74 \uc774 \ub808\ubca8\uc758 \ubaa8\ub4e0 \uc9c4\ud589 \ub0b4\uc6a9\uc744 \uc783\uac8c\ub429\ub2c8\ub2e4. \uc815\ub9d0 \uc885\ub8cc\ud558\uc2dc\uaca0\uc2b5\ub2c8\uae4c?";W["ko-kr"].optionsQuitConfirmBtn_No="\uc544\ub2c8\uc624";W["ko-kr"].optionsQuitConfirmBtn_Yes="\ub124, \ud655\uc2e4\ud569\ub2c8\ub2e4";
W["ko-kr"].levelMapScreenTitle="\ub808\ubca8 \uc120\ud0dd";W["ko-kr"].optionsRestartConfirmationText="\uc8fc\uc758!\n\n\uc9c0\uae08 \ub2e4\uc2dc \uc2dc\uc791\ud558\uba74 \uc774 \ub808\ubca8\uc758 \ubaa8\ub4e0 \uc9c4\ud589 \ub0b4\uc6a9\uc744 \uc783\uac8c\ub429\ub2c8\ub2e4. \uc815\ub9d0 \ub2e4\uc2dc \uc2dc\uc791\ud558\uc2dc\uaca0\uc2b5\ub2c8\uae4c?";W["ko-kr"].optionsRestart="\ub2e4\uc2dc \uc2dc\uc791";W["ko-kr"].optionsSFXBig_on="\uc74c\ud5a5 \ucf1c\uae30";W["ko-kr"].optionsSFXBig_off="\uc74c\ud5a5 \ub044\uae30";
W["ko-kr"].optionsAbout_title="\uad00\ub828 \uc815\ubcf4";W["ko-kr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";W["ko-kr"].optionsAbout_backBtn="\ub4a4\ub85c";W["ko-kr"].optionsAbout_version="\ubc84\uc804:";W["ko-kr"].optionsAbout="\uad00\ub828 \uc815\ubcf4";W["ko-kr"].levelEndScreenMedal="\ud5a5\uc0c1\ud588\uad70\uc694!";W["ko-kr"].startScreenQuestionaire="\uc5b4\ub5bb\uac8c \uc0dd\uac01\ud558\uc138\uc694?";W["ko-kr"].levelMapScreenWorld_0="\ub808\ubca8 \uc120\ud0dd";
W["ko-kr"].startScreenByTinglyGames="\uc81c\uc791: CoolGames";W["ko-kr"]["optionsLang_de-de"]="\ub3c5\uc77c\uc5b4";W["ko-kr"]["optionsLang_tr-tr"]="\ud130\ud0a4\uc5b4";W["ko-kr"].optionsAbout_header="Developed by:";W["ko-kr"].levelEndScreenViewHighscoreBtn="View scores";W["ko-kr"].levelEndScreenSubmitHighscoreBtn="Submit score";W["ko-kr"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";W["ko-kr"].challengeStartTextScore="<NAME>'s score:";
W["ko-kr"].challengeStartTextTime="<NAME>'s time:";W["ko-kr"].challengeStartScreenToWin="Amount to win:";W["ko-kr"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";W["ko-kr"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";W["ko-kr"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";W["ko-kr"].challengeEndScreenOutcomeMessage_TIED="You tied.";W["ko-kr"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
W["ko-kr"].challengeCancelConfirmBtn_yes="Yes";W["ko-kr"].challengeCancelConfirmBtn_no="No";W["ko-kr"].challengeEndScreensBtn_submit="Submit challenge";W["ko-kr"].challengeEndScreenBtn_cancel="Cancel challenge";W["ko-kr"].challengeEndScreenName_you="You";W["ko-kr"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";W["ko-kr"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
W["ko-kr"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";W["ko-kr"].challengeCancelMessage_success="Your challenge has been cancelled.";W["ko-kr"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";W["ko-kr"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";W["ko-kr"].challengeStartScreenTitle_challenger_friend="You are challenging:";
W["ko-kr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";W["ko-kr"].challengeStartTextTime_challenger="Play the game and set a time.";W["ko-kr"].challengeStartTextScore_challenger="Play the game and set a score.";W["ko-kr"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";W["ko-kr"].challengeForfeitConfirmBtn_yes="Yes";W["ko-kr"].challengeForfeitConfirmBtn_no="No";W["ko-kr"].challengeForfeitMessage_success="You have forfeited the challenge.";
W["ko-kr"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";W["ko-kr"].optionsChallengeForfeit="Forfeit";W["ko-kr"].optionsChallengeCancel="Quit";W["ko-kr"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";W["ko-kr"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";W["ko-kr"].levelEndScreenHighScore_time="Best time:";W["ko-kr"].levelEndScreenTotalScore_time="Total time:";
W["ko-kr"]["optionsLang_fr-fr"]="\ud504\ub791\uc2a4\uc5b4";W["ko-kr"]["optionsLang_ko-kr"]="\ud55c\uad6d\uc5b4";W["ko-kr"]["optionsLang_ar-eg"]="\uc544\ub77c\ube44\uc544\uc5b4";W["ko-kr"]["optionsLang_es-es"]="\uc2a4\ud398\uc778\uc5b4";W["ko-kr"]["optionsLang_pt-br"]="\ud3ec\ub974\ud22c\uac08\uc5b4(\ube0c\ub77c\uc9c8)";W["ko-kr"]["optionsLang_ru-ru"]="\ub7ec\uc2dc\uc544\uc5b4";W["ko-kr"].optionsExit="Exit";W["ko-kr"].levelEndScreenTotalScore_number="Total score:";
W["ko-kr"].levelEndScreenHighScore_number="High score:";W["ko-kr"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";W["ko-kr"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";
W["ko-kr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";W["ko-kr"].optionsAbout_header_publisher="Published by:";W["ko-kr"]["optionsLang_jp-jp"]="Japanese";W["jp-jp"]=W["jp-jp"]||{};W["jp-jp"].loadingScreenLoading="\u30ed\u30fc\u30c9\u4e2d\u2026";W["jp-jp"].startScreenPlay="\u30d7\u30ec\u30a4";W["jp-jp"].levelMapScreenTotalScore="\u30c8\u30fc\u30bf\u30eb\u30b9\u30b3\u30a2";W["jp-jp"].levelEndScreenTitle_level="\u30ec\u30d9\u30eb <VALUE>";
W["jp-jp"].levelEndScreenTitle_difficulty="\u3084\u3063\u305f\u306d\uff01";W["jp-jp"].levelEndScreenTitle_endless="\u30b9\u30c6\u30fc\u30b8 <VALUE>";W["jp-jp"].levelEndScreenTotalScore="\u30c8\u30fc\u30bf\u30eb\u30b9\u30b3\u30a2";W["jp-jp"].levelEndScreenSubTitle_levelFailed="\u30b2\u30fc\u30e0\u30aa\u30fc\u30d0\u30fc";W["jp-jp"].levelEndScreenTimeLeft="\u6b8b\u308a\u6642\u9593";W["jp-jp"].levelEndScreenTimeBonus="\u30bf\u30a4\u30e0\u30dc\u30fc\u30ca\u30b9";W["jp-jp"].levelEndScreenHighScore="\u30cf\u30a4\u30b9\u30b3\u30a2";
W["jp-jp"].optionsStartScreen="\u30e1\u30a4\u30f3\u30e1\u30cb\u30e5\u30fc";W["jp-jp"].optionsQuit="\u3084\u3081\u308b";W["jp-jp"].optionsResume="\u518d\u958b";W["jp-jp"].optionsTutorial="\u3042\u305d\u3073\u65b9";W["jp-jp"].optionsHighScore="\u30cf\u30a4\u30b9\u30b3\u30a2";W["jp-jp"].optionsMoreGames="\u4ed6\u306e\u30b2\u30fc\u30e0";W["jp-jp"].optionsDifficulty_easy="\u521d\u7d1a";W["jp-jp"].optionsDifficulty_medium="\u4e2d\u7d1a";W["jp-jp"].optionsDifficulty_hard="\u4e0a\u7d1a";
W["jp-jp"].optionsMusic_on="\u30aa\u30f3";W["jp-jp"].optionsMusic_off="\u30aa\u30d5";W["jp-jp"].optionsSFX_on="\u30aa\u30f3";W["jp-jp"].optionsSFX_off="\u30aa\u30d5";W["jp-jp"]["optionsLang_en-us"]="\u82f1\u8a9e\uff08\u7c73\u56fd\uff09";W["jp-jp"]["optionsLang_en-gb"]="\u82f1\u8a9e\uff08\u82f1\u56fd\uff09";W["jp-jp"]["optionsLang_nl-nl"]="\u30aa\u30e9\u30f3\u30c0\u8a9e";W["jp-jp"].gameEndScreenTitle="\u304a\u3081\u3067\u3068\u3046\uff01\n\u3059\u3079\u3066\u306e\u30ec\u30d9\u30eb\u3092\u30af\u30ea\u30a2\u3057\u307e\u3057\u305f\u3002";
W["jp-jp"].gameEndScreenBtnText="\u7d9a\u3051\u308b";W["jp-jp"].optionsTitle="\u8a2d\u5b9a";W["jp-jp"].optionsQuitConfirmationText="\u6ce8\u610f\uff01\n\n\u3053\u3053\u3067\u3084\u3081\u308b\u3068\n\u8a18\u9332\u304c\u30ea\u30bb\u30c3\u30c8\u3055\u308c\u307e\u3059\u304c\n\u3088\u308d\u3057\u3044\u3067\u3059\u304b\uff1f";W["jp-jp"].optionsQuitConfirmBtn_No="\u3044\u3044\u3048\u3001\u7d9a\u3051\u307e\u3059\u3002";W["jp-jp"].optionsQuitConfirmBtn_Yes="\u306f\u3044\u3001\u3084\u3081\u307e\u3059\u3002";
W["jp-jp"].levelMapScreenTitle="\u30ec\u30d9\u30eb\u9078\u629e";W["jp-jp"].optionsRestartConfirmationText="\u6ce8\u610f\uff01\n\n\u3053\u3053\u3067\u518d\u30b9\u30bf\u30fc\u30c8\u3059\u308b\u3068\n\u8a18\u9332\u304c\u30ea\u30bb\u30c3\u30c8\u3055\u308c\u307e\u3059\u304c\n\u3088\u308d\u3057\u3044\u3067\u3059\u304b\uff1f";W["jp-jp"].optionsRestart="\u518d\u30b9\u30bf\u30fc\u30c8";W["jp-jp"].optionsSFXBig_on="\u30b5\u30a6\u30f3\u30c9 \u30aa\u30f3";W["jp-jp"].optionsSFXBig_off="\u30b5\u30a6\u30f3\u30c9 \u30aa\u30d5";
W["jp-jp"].optionsAbout_title="About";W["jp-jp"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";W["jp-jp"].optionsAbout_backBtn="\u3082\u3069\u308b";W["jp-jp"].optionsAbout_version="version";W["jp-jp"].optionsAbout="About";W["jp-jp"].levelEndScreenMedal="\u8a18\u9332\u66f4\u65b0\uff01";W["jp-jp"].startScreenQuestionaire="\u3053\u306e\u30b2\u30fc\u30e0\u3078\u306e\u611f\u60f3";W["jp-jp"].levelMapScreenWorld_0="\u30ec\u30d9\u30eb\u9078\u629e";W["jp-jp"].startScreenByTinglyGames="by: CoolGames";
W["jp-jp"]["optionsLang_de-de"]="\u30c9\u30a4\u30c4\u8a9e";W["jp-jp"]["optionsLang_tr-tr"]="\u30c8\u30eb\u30b3\u8a9e";W["jp-jp"].optionsAbout_header="Developed by";W["jp-jp"].levelEndScreenViewHighscoreBtn="\u30b9\u30b3\u30a2\u3092\u307f\u308b";W["jp-jp"].levelEndScreenSubmitHighscoreBtn="\u30b9\u30b3\u30a2\u9001\u4fe1";W["jp-jp"].challengeStartScreenTitle_challengee_friend="\u304b\u3089\u6311\u6226\u3092\u53d7\u3051\u307e\u3057\u305f";W["jp-jp"].challengeStartTextScore="<NAME>\u306e\u30b9\u30b3\u30a2";
W["jp-jp"].challengeStartTextTime="<NAME>\u306e\u6642\u9593";W["jp-jp"].challengeStartScreenToWin="\u30dd\u30a4\u30f3\u30c8\u6570";W["jp-jp"].challengeEndScreenWinnings="<AMOUNT>\u30dd\u30a4\u30f3\u30c8\u7372\u5f97";W["jp-jp"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";W["jp-jp"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";W["jp-jp"].challengeEndScreenOutcomeMessage_TIED="\u540c\u70b9";W["jp-jp"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
W["jp-jp"].challengeCancelConfirmBtn_yes="Yes";W["jp-jp"].challengeCancelConfirmBtn_no="No";W["jp-jp"].challengeEndScreensBtn_submit="\u3042";W["jp-jp"].challengeEndScreenBtn_cancel="Cancel challenge";W["jp-jp"].challengeEndScreenName_you="You";W["jp-jp"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";W["jp-jp"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";W["jp-jp"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
W["jp-jp"].challengeCancelMessage_success="Your challenge has been cancelled.";W["jp-jp"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";W["jp-jp"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";W["jp-jp"].challengeStartScreenTitle_challenger_friend="You are challenging:";W["jp-jp"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
W["jp-jp"].challengeStartTextTime_challenger="Play the game and set a time.";W["jp-jp"].challengeStartTextScore_challenger="Play the game and set a score.";W["jp-jp"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";W["jp-jp"].challengeForfeitConfirmBtn_yes="Yes";W["jp-jp"].challengeForfeitConfirmBtn_no="No";W["jp-jp"].challengeForfeitMessage_success="You have forfeited the challenge.";W["jp-jp"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
W["jp-jp"].optionsChallengeForfeit="Forfeit";W["jp-jp"].optionsChallengeCancel="Quit";W["jp-jp"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";W["jp-jp"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";W["jp-jp"].levelEndScreenHighScore_time="Best time:";W["jp-jp"].levelEndScreenTotalScore_time="Total time:";W["jp-jp"]["optionsLang_fr-fr"]="French";W["jp-jp"]["optionsLang_ko-kr"]="Korean";W["jp-jp"]["optionsLang_ar-eg"]="Arabic";
W["jp-jp"]["optionsLang_es-es"]="Spanish";W["jp-jp"]["optionsLang_pt-br"]="Brazilian-Portuguese";W["jp-jp"]["optionsLang_ru-ru"]="Russian";W["jp-jp"].optionsExit="Exit";W["jp-jp"].levelEndScreenTotalScore_number="Total score:";W["jp-jp"].levelEndScreenHighScore_number="High score:";W["jp-jp"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
W["jp-jp"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";W["jp-jp"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";W["jp-jp"].optionsAbout_header_publisher="Published by:";W["jp-jp"]["optionsLang_jp-jp"]="\u65e5\u672c\u8a9e";W=W||{};W["nl-nl"]=W["nl-nl"]||{};W["nl-nl"].game_ui_SCORE="SCORE";W["nl-nl"].game_ui_STAGE="LEVEL";
W["nl-nl"].game_ui_LIVES="LEVENS";W["nl-nl"].game_ui_TIME="TIJD";W["nl-nl"].game_ui_HIGHSCORE="HIGH SCORE";W["nl-nl"].game_ui_LEVEL="LEVEL";W["nl-nl"].game_ui_time_left="Resterende tijd";W["nl-nl"].game_ui_TIME_TO_BEAT="DOELTIJD";W["nl-nl"].game_ui_SCORE_TO_BEAT="DOELSCORE";W["nl-nl"].game_ui_HIGHSCORE_break="HIGH\nSCORE";W["en-us"]=W["en-us"]||{};W["en-us"].game_ui_SCORE="SCORE";W["en-us"].game_ui_STAGE="STAGE";W["en-us"].game_ui_LIVES="LIVES";W["en-us"].game_ui_TIME="TIME";
W["en-us"].game_ui_HIGHSCORE="HIGH SCORE";W["en-us"].game_ui_LEVEL="LEVEL";W["en-us"].game_ui_time_left="Time left";W["en-us"].game_ui_TIME_TO_BEAT="TIME TO BEAT";W["en-us"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";W["en-us"].game_ui_HIGHSCORE_break="HIGH\nSCORE";W["en-gb"]=W["en-gb"]||{};W["en-gb"].game_ui_SCORE="SCORE";W["en-gb"].game_ui_STAGE="STAGE";W["en-gb"].game_ui_LIVES="LIVES";W["en-gb"].game_ui_TIME="TIME";W["en-gb"].game_ui_HIGHSCORE="HIGH SCORE";W["en-gb"].game_ui_LEVEL="LEVEL";
W["en-gb"].game_ui_time_left="Time left";W["en-gb"].game_ui_TIME_TO_BEAT="TIME TO BEAT";W["en-gb"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";W["en-gb"].game_ui_HIGHSCORE_break="HIGH\nSCORE";W["de-de"]=W["de-de"]||{};W["de-de"].game_ui_SCORE="PUNKTE";W["de-de"].game_ui_STAGE="STUFE";W["de-de"].game_ui_LIVES="LEBEN";W["de-de"].game_ui_TIME="ZEIT";W["de-de"].game_ui_HIGHSCORE="HIGHSCORE";W["de-de"].game_ui_LEVEL="LEVEL";W["de-de"].game_ui_time_left="Restzeit";W["de-de"].game_ui_TIME_TO_BEAT="ZEITVORGABE";
W["de-de"].game_ui_SCORE_TO_BEAT="Zu schlagende Punktzahl";W["de-de"].game_ui_HIGHSCORE_break="HIGHSCORE";W["fr-fr"]=W["fr-fr"]||{};W["fr-fr"].game_ui_SCORE="SCORE";W["fr-fr"].game_ui_STAGE="SC\u00c8NE";W["fr-fr"].game_ui_LIVES="VIES";W["fr-fr"].game_ui_TIME="TEMPS";W["fr-fr"].game_ui_HIGHSCORE="MEILLEUR SCORE";W["fr-fr"].game_ui_LEVEL="NIVEAU";W["fr-fr"].game_ui_time_left="Temps restant";W["fr-fr"].game_ui_TIME_TO_BEAT="TEMPS \u00c0 BATTRE";W["fr-fr"].game_ui_SCORE_TO_BEAT="SCORE \u00c0 BATTRE";
W["fr-fr"].game_ui_HIGHSCORE_break="MEILLEUR\nSCORE";W["pt-br"]=W["pt-br"]||{};W["pt-br"].game_ui_SCORE="PONTOS";W["pt-br"].game_ui_STAGE="FASE";W["pt-br"].game_ui_LIVES="VIDAS";W["pt-br"].game_ui_TIME="TEMPO";W["pt-br"].game_ui_HIGHSCORE="RECORDE";W["pt-br"].game_ui_LEVEL="N\u00cdVEL";W["pt-br"].game_ui_time_left="Tempo restante";W["pt-br"].game_ui_TIME_TO_BEAT="HORA DE ARRASAR";W["pt-br"].game_ui_SCORE_TO_BEAT="RECORDE A SER SUPERADO";W["pt-br"].game_ui_HIGHSCORE_break="RECORDE";
W["es-es"]=W["es-es"]||{};W["es-es"].game_ui_SCORE="PUNTOS";W["es-es"].game_ui_STAGE="FASE";W["es-es"].game_ui_LIVES="VIDAS";W["es-es"].game_ui_TIME="TIEMPO";W["es-es"].game_ui_HIGHSCORE="R\u00c9CORD";W["es-es"].game_ui_LEVEL="NIVEL";W["es-es"].game_ui_time_left="Tiempo restante";W["es-es"].game_ui_TIME_TO_BEAT="TIEMPO OBJETIVO";W["es-es"].game_ui_SCORE_TO_BEAT="PUNTUACI\u00d3N OBJETIVO";W["es-es"].game_ui_HIGHSCORE_break="R\u00c9CORD";W["tr-tr"]=W["tr-tr"]||{};W["tr-tr"].game_ui_SCORE="SKOR";
W["tr-tr"].game_ui_STAGE="B\u00d6L\u00dcM";W["tr-tr"].game_ui_LIVES="HAYATLAR";W["tr-tr"].game_ui_TIME="S\u00dcRE";W["tr-tr"].game_ui_HIGHSCORE="Y\u00dcKSEK SKOR";W["tr-tr"].game_ui_LEVEL="SEV\u0130YE";W["tr-tr"].game_ui_time_left="Kalan zaman";W["tr-tr"].game_ui_TIME_TO_BEAT="B\u0130T\u0130RME ZAMANI";W["tr-tr"].game_ui_SCORE_TO_BEAT="B\u0130T\u0130RME PUANI";W["tr-tr"].game_ui_HIGHSCORE_break="Y\u00dcKSEK\nSKOR";W["ru-ru"]=W["ru-ru"]||{};W["ru-ru"].game_ui_SCORE="\u0420\u0415\u0417\u0423\u041b\u042c\u0422\u0410\u0422";
W["ru-ru"].game_ui_STAGE="\u042d\u0422\u0410\u041f";W["ru-ru"].game_ui_LIVES="\u0416\u0418\u0417\u041d\u0418";W["ru-ru"].game_ui_TIME="\u0412\u0420\u0415\u041c\u042f";W["ru-ru"].game_ui_HIGHSCORE="\u0420\u0415\u041a\u041e\u0420\u0414";W["ru-ru"].game_ui_LEVEL="\u0423\u0420\u041e\u0412\u0415\u041d\u042c";W["ru-ru"].game_ui_time_left="Time left";W["ru-ru"].game_ui_TIME_TO_BEAT="TIME TO BEAT";W["ru-ru"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";W["ru-ru"].game_ui_HIGHSCORE_break="\u0420\u0415\u041a\u041e\u0420\u0414";
W["ar-eg"]=W["ar-eg"]||{};W["ar-eg"].game_ui_SCORE="\u0627\u0644\u0646\u062a\u064a\u062c\u0629";W["ar-eg"].game_ui_STAGE="\u0645\u0631\u062d\u0644\u0629";W["ar-eg"].game_ui_LIVES="\u0639\u062f\u062f \u0627\u0644\u0645\u062d\u0627\u0648\u0644\u0627\u062a";W["ar-eg"].game_ui_TIME="\u0627\u0644\u0648\u0642\u062a";W["ar-eg"].game_ui_HIGHSCORE="\u0623\u0639\u0644\u0649 \u0646\u062a\u064a\u062c\u0629";W["ar-eg"].game_ui_LEVEL="\u0645\u0633\u062a\u0648\u0649";W["ar-eg"].game_ui_time_left="Time left";
W["ar-eg"].game_ui_TIME_TO_BEAT="TIME TO BEAT";W["ar-eg"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";W["ar-eg"].game_ui_HIGHSCORE_break="\u0623\u0639\u0644\u0649 \u0646\u062a\u064a\u062c\u0629";W["ko-kr"]=W["ko-kr"]||{};W["ko-kr"].game_ui_SCORE="\uc810\uc218";W["ko-kr"].game_ui_STAGE="\uc2a4\ud14c\uc774\uc9c0";W["ko-kr"].game_ui_LIVES="\uae30\ud68c";W["ko-kr"].game_ui_TIME="\uc2dc\uac04";W["ko-kr"].game_ui_HIGHSCORE="\ucd5c\uace0 \uc810\uc218";W["ko-kr"].game_ui_LEVEL="\ub808\ubca8";
W["ko-kr"].game_ui_time_left="Time left";W["ko-kr"].game_ui_TIME_TO_BEAT="TIME TO BEAT";W["ko-kr"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";W["ko-kr"].game_ui_HIGHSCORE_break="\ucd5c\uace0 \uc810\uc218";W["jp-jp"]=W["jp-jp"]||{};W["jp-jp"].game_ui_SCORE="\u30b9\u30b3\u30a2";W["jp-jp"].game_ui_STAGE="\u30b9\u30c6\u30fc\u30b8";W["jp-jp"].game_ui_LIVES="\u30e9\u30a4\u30d5";W["jp-jp"].game_ui_TIME="\u30bf\u30a4\u30e0";W["jp-jp"].game_ui_HIGHSCORE="\u30cf\u30a4\u30b9\u30b3\u30a2";
W["jp-jp"].game_ui_LEVEL="\u30ec\u30d9\u30eb";W["jp-jp"].game_ui_time_left="\u6b8b\u308a\u6642\u9593";W["jp-jp"].game_ui_TIME_TO_BEAT="\u30af\u30ea\u30a2\u307e\u3067\u3042\u3068";W["jp-jp"].game_ui_SCORE_TO_BEAT="\u30af\u30ea\u30a2\u307e\u3067\u3042\u3068";W["jp-jp"].game_ui_HIGHSCORE_break="\u30cf\u30a4\n\u30b9\u30b3\u30a2";var Ke={};
function Le(){Ke={Cd:{uj:"en-us",Ai:"en-us en-gb nl-nl de-de fr-fr pt-br es-es tr-tr ru-ru ar-eg ko-kr jp-jp".split(" ")},sd:{jc:J(1040),Jo:J(960),zb:J(640),zf:J(640),He:J(0),Fj:J(-80),Ge:0,minHeight:J(780),nl:{id:"canvasBackground",depth:50},Ec:{id:"canvasGame",depth:100,top:J(200,"round"),left:J(40,"round"),width:J(560,"round"),height:J(560,"round")},hc:{id:"canvasGameUI",depth:150,top:0,left:0,height:J(120,"round")},Ee:{id:"canvasMain",depth:200}},ol:{jc:J(640),Jo:J(640),zb:J(1152),zf:J(1152),
He:J(0),Fj:J(0),Ge:0,minHeight:J(640),minWidth:J(850),nl:{id:"canvasBackground",depth:50},Ec:{id:"canvasGame",depth:100,top:J(40,"round"),left:J(296,"round"),width:J(560,"round"),height:J(560,"round")},hc:{id:"canvasGameUI",depth:150,top:0,left:J(151),width:J(140)},Ee:{id:"canvasMain",depth:200}},gb:{bigPlay:{type:"text",p:ud,Y:J(38),Da:J(99),font:{align:"center",g:"middle",fontSize:L({big:46,small:30}),fillColor:"#01198a",J:{j:!0,color:"#7bfdff",offsetX:0,offsetY:2,blur:0}},Cb:2,Yb:J(30),fontSize:L({big:46,
small:30})},difficulty_toggle:{type:"toggleText",p:Kd,Y:J(106),Da:J(40),font:{align:"center",g:"middle",fontSize:L({big:40,small:20}),fillColor:"#018a17",J:{j:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},O:[{id:"0",p:Mc,H:"optionsDifficulty_easy"},{id:"1",p:Lc,H:"optionsDifficulty_medium"},{id:"2",p:Kc,H:"optionsDifficulty_hard"}],ig:J(30),jg:J(12),ff:J(10),Cb:2,Yb:J(30),fontSize:L({big:40,small:20})},music_toggle:{type:"toggle",p:Kd,Y:J(106),Da:J(40),font:{align:"center",g:"middle",fontSize:L({big:40,
small:20}),fillColor:"#018a17",J:{j:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},O:[{id:"on",p:Gd,H:"optionsMusic_on"},{id:"off",p:Fd,H:"optionsMusic_off"}],ig:J(30),jg:J(12),ff:0,Cb:2,Yb:J(30)},sfx_toggle:{type:"toggle",p:Kd,Y:J(106),Da:J(40),font:{align:"center",g:"middle",fontSize:L({big:40,small:20}),fillColor:"#018a17",J:{j:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},O:[{id:"on",p:Ed,H:"optionsSFX_on"},{id:"off",p:Dd,H:"optionsSFX_off"}],ig:J(30),jg:J(12),ff:0,Cb:2,Yb:J(30)},music_big_toggle:{type:"toggleText",
p:Kd,Y:J(106),Da:J(40),font:{align:"center",g:"middle",fontSize:L({big:40,small:20}),fillColor:"#018a17",J:{j:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},O:[{id:"on",p:"undefined"!==typeof hd?hd:void 0,H:"optionsMusic_on"},{id:"off",p:"undefined"!==typeof gd?gd:void 0,H:"optionsMusic_off"}],ig:J(28,"round"),jg:J(10),ff:J(10),Cb:2,Yb:J(30),fontSize:L({big:40,small:20})},sfx_big_toggle:{type:"toggleText",p:Kd,Y:J(106),Da:J(40),font:{align:"center",g:"middle",fontSize:L({big:40,small:20}),fillColor:"#018a17",
J:{j:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},O:[{id:"on",p:"undefined"!==typeof ed?ed:void 0,H:"optionsSFXBig_on"},{id:"off",p:"undefined"!==typeof fd?fd:void 0,H:"optionsSFXBig_off"}],ig:J(33,"round"),jg:J(12),ff:J(10),Cb:2,Yb:J(30),fontSize:L({big:40,small:20})},language_toggle:{type:"toggleText",p:Kd,Y:J(106),Da:J(40),font:{align:"center",g:"middle",fontSize:L({big:40,small:20}),fillColor:"#018a17",J:{j:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},O:[{id:"en-us",p:Nc,H:"optionsLang_en-us"},
{id:"en-gb",p:Oc,H:"optionsLang_en-gb"},{id:"nl-nl",p:Pc,H:"optionsLang_nl-nl"},{id:"de-de",p:Rc,H:"optionsLang_de-de"},{id:"fr-fr",p:Sc,H:"optionsLang_fr-fr"},{id:"pt-br",p:Tc,H:"optionsLang_pt-br"},{id:"es-es",p:Uc,H:"optionsLang_es-es"},{id:"ru-ru",p:Wc,H:"optionsLang_ru-ru"},{id:"ar-eg",p:Xc,H:"optionsLang_ar-eg"},{id:"ko-kr",p:Yc,H:"optionsLang_ko-kr"},{id:"tr-tr",p:Qc,H:"optionsLang_tr-tr"},{id:"jp-jp",p:Vc,H:"optionsLang_jp-jp"}],ig:J(40),jg:J(20),ff:J(10),Cb:2,Yb:J(30),fontSize:L({big:40,
small:20})},default_text:{type:"text",p:Bd,Y:J(40),Da:J(40),font:{align:"center",g:"middle",fontSize:L({big:40,small:20}),fillColor:"#018a17",J:{j:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},Cb:2,Yb:J(30),fontSize:L({big:40,small:20})},default_image:{type:"image",p:Bd,Y:J(40),Da:J(40),Yb:J(6)},options:{type:"image",p:zd}},Hi:{bigPlay:{type:"text",p:ud,Y:J(40),Da:J(76),font:{align:"center",g:"middle",fontSize:L({big:40,small:20}),fillColor:"#01198a",J:{j:!0,color:"#7bfdff",offsetX:0,offsetY:2,
blur:0}},Cb:2,Yb:J(30),fontSize:L({big:40,small:20})}},Xg:{green:{font:{align:"center",g:"middle",fillColor:"#018a17",J:{j:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}}},blue:{font:{align:"center",g:"middle",fillColor:"#01198a",J:{j:!0,color:"#7bfdff",offsetX:0,offsetY:2,blur:0}}},bluegreen:{font:{align:"center",g:"middle",fillColor:"#004f89",J:{j:!0,color:"#7bffca",offsetX:0,offsetY:2,blur:0}}},orange:{font:{align:"center",g:"middle",fillColor:"#9a1900",J:{j:!0,color:"#ffb986",offsetX:0,offsetY:2,
blur:0}}},orangeyellow:{font:{align:"center",g:"middle",fillColor:"#8d2501",J:{j:!0,color:"#ffbe60",offsetX:0,offsetY:2,blur:0}}},pink:{font:{align:"center",g:"middle",fillColor:"#c6258f",J:{j:!0,color:"#ffbde9",offsetX:0,offsetY:2,blur:0}}},white:{font:{align:"center",g:"middle",fillColor:"#ffffff"}},pastel_pink:{font:{align:"center",g:"middle",fillColor:"#83574f"}},whiteWithRedBorder:{font:{align:"center",g:"middle",fillColor:"#ffffff",J:{j:!0,color:"#4c0200",offsetX:0,offsetY:2,blur:0}}},whiteWithBlueBorder:{font:{align:"center",
g:"middle",fillColor:"#ffffff",J:{j:!0,color:"#002534",offsetX:0,offsetY:2,blur:0}}}},buttons:{default_color:"green"},Ja:{Rv:20},Lc:{backgroundImage:"undefined"!==typeof jd?jd:void 0,lu:0,ls:500,Dj:5E3,cu:5E3,Iq:-1,Ov:12,Nv:100,Pd:J(78),zn:{align:"center"},kk:J(560),Lf:J(400),Mf:{align:"center"},Te:J(680),ie:J(16),zm:J(18),Gh:J(8),Xp:J(8),Yp:J(9),Zp:J(9),bi:{align:"center",fillColor:"#3B0057",fontSize:J(24)},er:{align:"center"},yn:J(620),jk:J(500),Hh:"center",Ve:J(500),Jh:J(60),kb:{align:"center"},
Wb:{align:"bottom",offset:J(20)},Fm:J(806),Dm:500,Tt:J(20)},Bm:{Hh:"right",kk:J(280),Te:J(430),Ve:J(340),kb:{align:"right",offset:J(32)},Wb:J(560),Fm:J(560)},Yh:{el:J(860),backgroundImage:void 0!==typeof jd?jd:void 0,dt:700,fq:1800,gu:700,Ju:2600,Ff:void 0!==typeof jd?Rd:void 0,Jc:700,qh:{align:"center"},gj:{align:"center"},rh:void 0!==typeof Rd?-Rd.height:0,Ef:{align:"top",offset:J(20)},Vl:1,gp:1,Wl:1,hp:1,Ul:1,fp:1,ht:ac,it:ic,ft:ac,gt:ac,et:ac,Iu:{align:"center"},Rh:J(656),Xe:J(300),Pj:700,Hu:700,
Mo:J(368),jh:J(796),ih:J(440),Lo:700,Jm:J(36),Ej:J(750),fu:500,Hh:"center",Ve:J(500),Jh:J(60),kb:{align:"center"},Wb:{align:"bottom",offset:J(20)},Fm:J(806),Dm:500,Tt:J(20)},gk:{el:J(0),Rh:J(456),Xe:J(320),Mo:{align:"center"},jh:J(346),ih:J(460),Jm:{align:"left",offset:J(32)},Ej:J(528),Hh:"right",Ve:J(340),kb:{align:"right",offset:J(32)},Wb:J(560),Fm:J(560)},ad:{Au:{align:"center",offset:J(-230)},Um:{align:"top",offset:J(576)},zu:"options",Pc:{g:"bottom"},hg:{align:"center"},$b:{align:"top",offset:J(35,
"round")},Qd:J(232),jf:J(98),fw:{align:"center",offset:J(-206)},Ck:{align:"top",offset:J(30)},ew:{align:"center",offset:J(206)},Bk:{align:"top",offset:J(30)},type:"grid",wu:3,vy:3,xu:5,wy:4,Oo:!0,Ms:!0,cm:J(78),lp:{align:"top",offset:J(140)},np:{align:"top",offset:J(140)},mp:J(20),ot:J(18),pt:J(18),Kp:{lj:{fontSize:L({big:60,small:30}),fillColor:"#3F4F5E",align:"center",g:"middle",J:{j:!0,color:"#D0D8EA",offsetX:0,offsetY:J(6),blur:0}}},Dt:{lj:{fontSize:L({big:32,small:16}),fillColor:"#3F4F5E",align:"center",
g:"middle",J:{j:!0,color:"#D0D8EA",offsetX:0,offsetY:J(2),blur:0}}},Sp:J(438),Tp:J(438),Lp:{align:"center"},Mp:{align:"center"},aq:{align:"center"},Cm:{align:"center",offset:J(-22)},Pp:{align:"center"},vm:{align:"center",offset:J(-10)},Kq:{align:"center",offset:J(216)},sn:{align:"top",offset:J(574)},Jq:{fontSize:L({big:24,small:12}),fillColor:"#3F4F5E",align:"center"},Lq:J(10),pq:{fontSize:L({big:24,small:12}),fillColor:"#3F4F5E",align:"center"},qq:{align:"center"},an:{align:"top",offset:J(588)},
Mu:J(160),Lu:J(40),backgroundImage:"undefined"!==typeof pd?pd:void 0,Jv:J(10),Kv:200,Iv:J(200),Cx:J(600),pu:800,ou:500},Np:{Ck:{align:"top",offset:J(20)},Bk:{align:"top",offset:J(20)},$b:{align:"top",offset:J(25,"round")},cm:J(234),lp:{align:"top",offset:J(110)},np:{align:"top",offset:J(110)},sn:{align:"top",offset:J(536)},an:{align:"top",offset:J(550)},Um:{align:"top",offset:J(538)}},Bj:{tc:"undefined"!==typeof re?re:void 0,kq:{align:"center"},lq:"undefined"!==typeof re?-re.height:void 0,Lj:[{type:"y",
la:0,duration:800,end:{align:"center",offset:J(-142)},Ra:ic,Bb:He}],Xm:[{type:"y",la:0,duration:600,end:"undefined"!==typeof re?-re.height:void 0,Ra:hc,uo:!0}],ko:{align:"center",g:"middle"},lo:{align:"center"},mo:0,Sg:J(500),Wk:J(80),rp:{align:"center",g:"middle"},wt:{align:"center"},tp:0,sj:J(560),sp:J(80),nq:3500},wm:{Lj:[{type:"y",la:0,duration:800,end:{align:"center"},Ra:ic,Bb:He}]},Gw:{tc:"undefined"!==typeof s_overlay_challenge_start?s_overlay_challenge_start:void 0,kq:{align:"center"},lq:J(56),
Mj:0,Nj:0,Pc:{align:"center",g:"top"},Qd:J(500),jf:J(100),hg:{align:"center"},$b:J(90),fy:{align:"center",g:"middle"},ky:J(500),jy:J(80),oy:{align:"center"},We:J(250),hz:{align:"center",g:"top"},jz:J(500),iz:J(40),kz:{align:"center"},lz:J(348),gz:{align:"center",g:"top"},nz:J(500),mz:J(50),pz:{align:"center"},qz:J(388),xA:{align:"center",g:"top"},zA:J(500),yA:J(40),CA:{align:"center"},DA:J(442),AA:0,BA:0,wA:{align:"center",g:"top"},FA:J(500),EA:J(50),GA:{align:"center"},HA:J(482),vA:J(10),tA:0,uA:0,
io:800,bs:ic,cs:600,ds:hc,nq:3500},Fw:{rw:500,io:800,sy:1500,ty:500,oz:2500,tz:500,rz:3200,sz:800,$x:4200,ay:300,zw:4500,By:{align:"center"},Cy:J(-800),yy:{align:"center"},zy:J(52),Mj:0,Nj:0,Ws:.8,Xs:"#000000",Km:{align:"center",g:"middle"},by:J(360),Xx:J(120),Yx:J(4),Zx:J(4),cy:{align:"center"},dy:J(340),cA:{align:"center"},dA:J(600),bA:J(500),aA:J(120),$z:{align:"center",g:"middle"},IA:{align:"center",g:"middle"},MA:J(360),JA:J(60),KA:J(4),LA:J(4),NA:{align:"center"},OA:J(480),jA:J(460),gA:{align:"center"},
hA:J(400),Aw:{align:"center"},Bw:J(500),qy:{align:"center",g:"middle"},ry:J(75,"round"),py:J(48),uy:J(120),ny:J(214,"round"),gy:J(40),hy:J(4),iy:J(4),ly:0,my:0,Ww:{align:"center",g:"middle"},Zw:J(220),Yw:J(180),Xw:J(80),Uw:J(4),Vw:J(4)},rc:{Ay:{ul:"undefined"!==typeof s_overlay_difficulty?s_overlay_difficulty:void 0,cx:"undefined"!==typeof s_overlay_endless?s_overlay_endless:void 0,Bx:"undefined"!==typeof nd?nd:void 0,Ax:"undefined"!==typeof od?od:void 0},kA:500,io:800,bs:ic,cs:800,ds:dc,cd:{align:"center"},
Xb:0,Pc:{align:"center",g:"middle",fontSize:L({big:26,small:13})},hg:{align:"center"},$b:J(58),Qd:J(500),jf:J(100),Ev:{align:"center",g:"middle",fontSize:L({big:56,small:28})},fA:{align:"center"},Fv:J(236),Ps:{align:"center",g:"top",fontSize:L({big:24,small:12})},$w:{align:"center"},So:J(144),Os:{align:"center",g:"top",fontSize:L({big:56,small:28})},ax:{align:"center"},To:J(176),Ss:J(200),Rs:J(60),Cv:{align:"center",g:"top",fontSize:L({big:24,small:12})},Wz:{align:"center"},Tq:J(286),Xz:J(0),gx:!1,
Dv:J(14),Vz:J(10),Bv:{align:"center",g:"top",fontSize:L({big:24,small:12})},Tz:J(10),Uz:J(4),Zz:J(200),Yz:J(50),sw:{align:"center",offset:J(12)},js:J(549),hx:{align:"center",offset:J(162)},$s:J(489),dh:{align:"center",offset:J(250)},xf:J(10),bh:J(90),ah:J(90),Ez:{align:"center",offset:J(-177,"round")},Fz:J(120),Gz:{align:"center"},Hz:J(96),Iz:{align:"center",offset:J(179,"round")},Jz:J(120),Kz:200,Lz:500,Nz:800,Rz:0,Qz:0,Pz:300,Mz:200,Oz:300,Ws:.8,ib:800,Xs:"#000000",du:J(508),eu:J(394),Jx:J(96),
Kx:J(74),Lx:3,Fx:400,Ex:2500,Mx:0,Nx:J(100),Ox:1.5,Vx:{align:"center"},Wx:J(76),Ux:J(180),Tx:J(36),Sx:{align:"center",g:"middle",fontSize:L({big:22,small:12}),w:"ff_opensans_extrabold",fillColor:"#1d347f",J:{j:!0,color:"#68cbfa",offsetY:J(2)}},Hx:500,Gx:500,Ix:J(-30),Qx:500,Px:0,Rx:4E3,mA:600,nA:1500,ww:500,xw:750,sx:{align:"center"},tx:J(290),rx:J(350),ey:1E3,type:{level:{cl:"level",cf:!0,qn:!0,An:"title_level",Uq:"totalScore",Zk:"retry",Ml:"next"},failed:{cl:"failed",cf:!1,qn:!1,An:"title_level",
eA:"subtitle_failed",Zk:"exit",Ml:"retry"},endless:{cl:"endless",cf:!1,qn:!0,An:"title_endless",Qs:"totalScore",Uq:"highScore",Zk:"exit",Ml:"retry"},difficulty:{cl:"difficulty",cf:!1,qn:!0,An:"title_difficulty",Qs:"timeLeft",Uq:["totalScore","timeBonus"],Zk:"exit",Ml:"retry"}}},zx:{xf:J(0),$b:J(30),So:J(114),To:J(146),Tq:J(266),js:J(488),$s:J(428),du:{align:"center",offset:J(220)},eu:J(260)},Ah:{backgroundImage:"undefined"!==typeof pe?pe:void 0},options:{backgroundImage:kd,cd:{align:"center"},Xb:0,
Pc:{},hg:{align:"center"},$b:J(58),Qd:J(500),jf:J(100),Ji:J(460,"round"),Ii:{align:"center"},vf:{align:"center",offset:J(36)},Uc:J(10,"round"),dh:J(510),xf:J(10),bh:J(130),ah:J(90),buttons:{startScreen:["tutorial",["music","sfx"],"language","moreGames","about"],levelMapScreen:["startScreen",["music","sfx"],"language","moreGames","about"],inGame:["resume","tutorial",["music","sfx"],"moreGames","quit"]},Pf:800,Qf:ic,Nh:600,Oh:dc,Ho:{align:"center"},Ri:J(260),Qi:J(460),Pi:J(300),Fo:{align:"center"},
Oi:J(460),Eo:{align:"center"},Ni:J(560,"round"),fh:J(460,"round"),Xj:{},Qc:"undefined"!==typeof ld?ld:void 0,qk:{align:"center"},Rd:J(84,"round"),wk:{align:"center",g:"top"},xk:J(480),Dn:J(46),sr:{align:"center"},yk:J(110,"round"),qr:{align:"center"},uk:J(160,"round"),rr:{align:"center"},vk:J(446,"round"),tk:{g:"middle",align:"center",fontSize:L({big:36,small:18})},mg:J(480),Cn:J(160),pr:{align:"center",offset:J(-80,"round")},sk:J(556,"round"),or:{align:"center",offset:J(80,"round")},rk:J(556,"round"),
Xn:{align:"center",g:"top",fillColor:"#3C0058",fontSize:L({big:26,small:13}),fa:J(6)},Zn:J(480),Yn:J(50),$n:{align:"center"},vi:J(106,"round"),ao:{align:"center",g:"top",fillColor:"#3C0058",fontSize:L({big:26,small:13}),fa:J(6)},wi:J(480),Qg:J(110),Uk:{align:"center"},sf:J(396,"round"),Tk:{align:"center"},Pg:J(140),Sk:{align:"center"},Ng:J(500),Og:J(480),Vk:{align:"center",g:"top",fillColor:"#808080",fontSize:L({big:12,small:8})},eo:{align:"center"},yi:J(610),co:J(440),bo:J(20),tf:J(200),xi:J(200),
Cr:J(80),Dr:J(140),Br:J(10)},Bu:{$b:J(12),vf:{align:"center",offset:J(16)},Ri:J(200),Pi:J(300),Oi:J(400),Ni:J(500,"round"),Rd:J(60,"round"),yk:J(80,"round"),uk:J(134,"round"),vk:J(410,"round"),sk:J(500,"round"),rk:J(500,"round"),vi:J(86,"round"),Pg:J(126),sf:J(392,"round"),Ng:J(490),yi:J(590)},gq:{backgroundImage:"undefined"!==typeof s_overlay_challenge_options?s_overlay_challenge_options:kd,cd:{align:"center"},Xb:J(120),Pc:{},hg:{align:"center"},$b:J(200),Ji:J(460,"round"),Ii:{align:"center"},vf:{align:"center",
offset:J(140)},Uc:J(10,"round"),dh:J(510),xf:J(10),bh:J(130),ah:J(90),buttons:{startScreen:["tutorial",["music","sfx"],"language","about"],inGame_challengee:["resume","tutorial",["music","sfx"],"forfeitChallenge"],inGame_challenger:["resume","tutorial",["music","sfx"],"cancelChallenge"]},Pf:800,Qf:ic,Nh:600,Oh:dc,Xj:{},Xy:{align:"center"},Yy:J(360),Wy:J(460),Vy:J(300),Ry:"default_text",Sy:{align:"center"},Ty:J(630),Oy:"default_text",Py:{align:"center"},Qy:J(730,"round"),Uy:J(460,"round"),Go:{},Ho:{align:"center"},
Ri:J(200),Qi:J(460),Pi:J(250),Fo:{align:"center"},Oi:J(520),Eo:{align:"center"},Ni:J(620,"round"),fh:J(460,"round"),Km:{},ju:{align:"center"},ku:J(200),Lm:J(460),iu:J(300),Qc:"undefined"!==typeof ld?ld:void 0,qk:{align:"center"},Rd:J(0,"round"),wk:{align:"center",g:"top"},xk:J(480),Dn:J(50),sr:{align:"center"},yk:J(20,"round"),qr:{align:"center"},uk:J(70,"round"),rr:{align:"center"},vk:J(356,"round"),tk:{g:"middle",align:"center",fontSize:L({big:36,small:18})},mg:J(480),Cn:J(150),pr:J(224,"round"),
sk:J(636,"round"),or:J(350,"round"),rk:J(636,"round"),Xn:{align:"center",g:"top",fillColor:"#3C0058",fontSize:L({big:26,small:13}),fa:J(6)},Zn:J(480),Yn:J(50),$n:{align:"center"},vi:J(26,"round"),ao:{align:"center",g:"top",fillColor:"#3C0058",fontSize:L({big:26,small:13}),fa:J(6)},wi:J(480),Qg:J(110),Uk:{align:"center"},sf:J(316,"round"),Tk:{align:"center"},Pg:J(60),Sk:{align:"center"},Ng:J(420),Og:J(480),Vk:{align:"center",g:"top",fillColor:"#808080",fontSize:L({big:12,small:8})},eo:{align:"center"},
yi:J(530),co:J(440),bo:J(20),tf:J(200),xi:J(200),Cr:J(80),Dr:J(100),Br:J(10)},ae:{backgroundImage:"undefined"!==typeof s_overlay_dialog?s_overlay_dialog:kd,cd:{align:"center"},Xb:J(120),Ji:J(460,"round"),Ii:{align:"center"},vf:{align:"bottom",offset:J(20)},Uc:J(10,"round"),dh:J(510),xf:J(10),bh:J(130),ah:J(90),Pf:800,Qf:ic,Nh:600,Oh:dc,bn:{},Uu:{align:"center"},sq:{align:"center",offset:J(40)},Wj:J(460),Vj:J(300),un:{},Su:{align:"center"},Tu:{align:"center",offset:J(160)},Ru:J(460),Qu:J(200)},dj:{backgroundImage:"undefined"!==
typeof md?md:void 0,er:{align:"center"},yn:J(152),jk:J(560),Mv:J(560),font:{align:"center",g:"middle",fontSize:L({big:52,small:26}),fillColor:"#FFFFFF"},ss:{align:"center"},Fi:J(600),gl:J(460),fl:"default_text"},ej:{Fi:J(520)}}}
var Me={Ou:"boostermedia",Vv:!1,Xh:{Rt:!1,vl:"8784d238b5a81ab432d0bf303850ed8a 9f5ffc7a10e0bad054458b089947ce2f 0c73b027c77dd2c1ee6cd996c2c83efc 03a60a509d53952c91fc9865fbd492ef 0e26dbc8d26a0880786e55e3e950a320 7e77fcbd9a8ec327db79b6c753a5eef1 5ff97ceeea117a01f512adc7ece5ade7 54f5ededff723ca5c52bc75764ceb738 526ceb1f05b2418711e1eb59058e0b09 ae11a4449bebb3561a078bac793dc74b f51482fb5ecee35fd139f89728a7a616".split(" ")},Cd:{uj:"en-us",Ai:["en-us"]}},W=W||{};W["nl-nl"]=W["nl-nl"]||{};
W["nl-nl"].TutorialTitle_6="Nono Cross";W["nl-nl"].TutorialTitle_5="Nono Cross";W["nl-nl"].TutorialTitle_4="Nono Cross";W["nl-nl"].TutorialTitle_3="Nono Cross";W["nl-nl"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";W["nl-nl"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["nl-nl"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";
W["nl-nl"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["nl-nl"].levelStartText="LEVEL <VALUE> START";W["nl-nl"].TutorialTitle_0="Nono Cross";W["nl-nl"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";W["nl-nl"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["nl-nl"].TutorialText_2="Around the level you will find clues on which cells to fill";
W["nl-nl"].TutorialTitle_1="Nono Cross";W["nl-nl"].TutorialTitle_2="Nono Cross";W["nl-nl"].restartConfirmation="Are you sure you want to restart this level?";W["nl-nl"].restartCancelBtnText="Cancel";W["nl-nl"].restartConfirmBtnText="Confirm";W["nl-nl"].desc_rubber_ducky="Rubber Ducky";W["nl-nl"].desc_butterfly="Butterfly";W["nl-nl"].desc_bell="Bell";W["nl-nl"].desc_telephone="Telephone";W["nl-nl"].desc_tomato="Tomato";W["nl-nl"].desc_key="Key";W["nl-nl"]["desc_gold fish"]="Gold Fish";
W["nl-nl"].desc_coffee_cup="Coffee Cup";W["nl-nl"].desc_cherry="Cherry";W["nl-nl"].desc_puzzle_piece="Puzzle Piece";W["nl-nl"].desc_camel="Camel";W["nl-nl"].desc_guinea_pig="Guinea Pig";W["nl-nl"].desc_car="Car";W["nl-nl"].desc_smile="Smile";W["nl-nl"].desc_weight_lifting="Weight Lifting";W["nl-nl"].desc_lollipop="Lollipop";W["nl-nl"].desc_bus="Bus";W["nl-nl"].desc_chair="Chair";W["nl-nl"].desc_frog="Frog";W["nl-nl"].desc_boat="Boat";W["nl-nl"].desc_flowers="Flowers";W["nl-nl"].desc_music_note="Music Note";
W["nl-nl"].desc_tractor="Tractor";W["nl-nl"].desc_cow="Cow";W["nl-nl"].desc_snail="Snail";W["nl-nl"].desc_pear="Pear";W["nl-nl"].desc_tree="Tree";W["nl-nl"].desc_snake="Snake";W["nl-nl"].desc_duck="Duck";W["nl-nl"].desc_strawberry="Strawberry";W["nl-nl"].desc_squirrel="Squirrel";W["nl-nl"].desc_plane="Plane";W["nl-nl"].desc_dog="Dog";W["nl-nl"].desc_city="City";W["nl-nl"].desc_mountains="Mountains";W["nl-nl"].desc_baseball="Baseball";W["nl-nl"].desc_sunflowers="Sunflowers";
W["nl-nl"].desc_umbrella="Umbrella";W["nl-nl"].desc_arrow="Arrow";W["nl-nl"].desc_cactus="Cactus";W["nl-nl"].desc_cowboy_hat="Cowboy Hat";W["nl-nl"].desc_robin="Robin";W["nl-nl"].desc_chicken="Chicken";W["nl-nl"].desc_kettle="Kettle";W["nl-nl"].desc_faucet="Faucet";W["nl-nl"].desc_turnip="Turnip";W["nl-nl"].desc_sword="Sword";W["nl-nl"].desc_the_moon="The Moon";W["nl-nl"].desc_banana="Banana";W["nl-nl"].desc_cat="Cat";W["nl-nl"].desc_shovel="Shovel";W["nl-nl"].desc_cellphone="Cellphone";
W["nl-nl"].desc_carrot="Carrot";W["nl-nl"]["desc_?"]="?";W["nl-nl"].desc_sapling="Sapling";W["nl-nl"].desc_lion="Lion";W["nl-nl"].desc_sunset="Sunset";W["nl-nl"].desc_hippo="Hippo";W["nl-nl"].desc_apple="Apple";W["nl-nl"].desc_corn="Corn";W["nl-nl"].desc_bunny="Bunny";W["nl-nl"].desc_star="Star";W["nl-nl"].desc_panda="Panda";W["nl-nl"].desc_heart="Heart";W["nl-nl"].desc_deer="Deer";W["nl-nl"].desc_computer="Computer";W["nl-nl"].desc_house="House";W["nl-nl"].desc_elephant="Elephant";
W["nl-nl"].desc_dolphin="Dolphin";W["nl-nl"].desc_unnamed="Unnamed";W["nl-nl"].desc_bee="Bee";W["nl-nl"].desc_koi_pond="Koi Pond";W["nl-nl"].desc_the_park="The Park";W["nl-nl"].desc_pearl="Pearl";W["nl-nl"].desc_tea_bag="Tea Bag";W["nl-nl"].TutorialText_7="Each puzzle only has one solution, so don't guess.";W["nl-nl"].TutorialTitle_7="Nono Cross";W["nl-nl"].desc_coffee_bean="Coffee Bean";W["nl-nl"].desc_frowney="Frowney";W["nl-nl"].desc_smiley="Smiley";W["nl-nl"].desc_koala="Koala";
W["nl-nl"].desc_saturn="Saturn";W["nl-nl"].desc_necklace="Necklace";W["nl-nl"].desc_shrub="Shrub";W["nl-nl"].desc_headphones="Headphones";W["nl-nl"].desc_blue_tee="Blue Tee";W["nl-nl"].desc_earring="Earring";W["nl-nl"].desc_lipstick="Lipstick";W["nl-nl"].desc_tv="TV";W["nl-nl"].desc_hamburger="Hamburger";W["nl-nl"].desc_egg="Egg";W["nl-nl"].desc_the_sun="The Sun";W["nl-nl"].desc_candle="Candle";W["nl-nl"].desc_flashlight="Flashlight";W["nl-nl"].desc_a_well="A Well";W["nl-nl"].desc_wave="Wave";
W["nl-nl"].desc_ponytail="Ponytail";W["nl-nl"].desc_icecream="Ice Cream";W["nl-nl"].desc_pickle_jar="Pickle Jar";W["nl-nl"].desc_stove="Stove";W["nl-nl"].desc_grapes="Grapes";W["nl-nl"].desc_mouse="Mouse";W["nl-nl"].desc_loin="Loin";W["nl-nl"].ui_level_text="Level";W["nl-nl"].desc_rose="rose";W["nl-nl"].desc_alpaca="alpaca";W["nl-nl"].desc_desert="desert";W["nl-nl"].desc_sheep="sheep";W["nl-nl"].desc_alarm_clock="alarm clock";W["nl-nl"].desc_fish_bowl="fish bowl";W["nl-nl"].desc_paint_brush="paint brush";
W["nl-nl"].desc_melon_slice="melon slice";W["nl-nl"].desc_toadstool="toadstool";W["nl-nl"].desc_choco_cake="choco cake";W["nl-nl"].desc_swan="swan";W["nl-nl"].desc_bicycle="bicycle";W["nl-nl"].desc_buttered_toast="buttered toast";W["nl-nl"].desc_purse="purse";W["nl-nl"].desc_bed="bed";W["nl-nl"].desc_tadpole="tadpole";W["nl-nl"].desc_picture_book="picture book";W["nl-nl"].desc_bear="bear";W["nl-nl"].desc_traffic_light="traffic light";W["nl-nl"].desc_campfire="campfire";W["nl-nl"].desc_drinks="drinks";
W["nl-nl"].desc_leaf="leaf";W["nl-nl"]["desc_dragonfly "]="dragonfly ";W["nl-nl"].desc_volcano="volcano";W["nl-nl"].desc_coral="coral";W["nl-nl"].desc_bracelet="bracelet";W["nl-nl"]["desc_backpack "]="backpack ";W["nl-nl"].desc_orca="orca";W["nl-nl"].desc_soup_pan="soup pan";W["nl-nl"].desc_tent="tent";W["nl-nl"].desc_choco_cookie="choco cookie";W["nl-nl"].desc_magic_hat="magic hat";W["nl-nl"]["desc_hand mirror"]="hand mirror";W["nl-nl"].desc_waterfall="waterfall";W["nl-nl"].desc_treasure_chest="treasure chest";
W["nl-nl"].desc_chimney="chimney";W["nl-nl"]["desc_salt_&_pepper"]="salt & pepper";W["nl-nl"].desc_glasses="glasses";W["nl-nl"].desc_lamp="lamp";W["nl-nl"].desc_horse="horse";W["nl-nl"].desc_golf="golf";W["nl-nl"].desc_pizza="pizza";W["nl-nl"].desc_rain="rain";W["nl-nl"].desc_toaster="toaster";W["nl-nl"].desc_cheese="cheese";W["nl-nl"].desc_goat="goat";W["nl-nl"].desc_ice_skate="ice skate";W["nl-nl"].desc_microphone="microphone";W["nl-nl"].desc_watering_can="watering can";
W["nl-nl"].desc_space_shuttle="space shuttle";W["nl-nl"].desc_door="door";W["nl-nl"].desc_bubblegum="bubblegum";W["nl-nl"].desc_shooting_star="shooting star";W["nl-nl"].desc_winter="winter";W["nl-nl"].desc_spring="spring";W["nl-nl"].desc_summer="summer";W["nl-nl"].desc_autumn="autumn";W["nl-nl"].desc_sprinkled_donut="sprinkled donut";W["nl-nl"].desc_santa="santa";W["nl-nl"].desc_hedgehog="hedgehog";W["nl-nl"].desc_clouds="clouds";W["nl-nl"].desc_boot="boot";W["nl-nl"].desc_scissors="scissors";
W["nl-nl"].desc_chocolate_bar="chocolate bar";W["nl-nl"].desc_magnifier="magnifier";W["nl-nl"].desc_clothes_hanger="clothes hanger";W["nl-nl"].desc_bowtie="bowtie";W["nl-nl"].desc_flying_kite="flying kite";W["nl-nl"].desc_beard="beard";W["nl-nl"].desc_fountain="fountain";W["nl-nl"].desc_crocodile="crocodile";W["nl-nl"].desc_peas="peas";W["nl-nl"].desc_tutu="tutu";W["nl-nl"].desc_tornado="tornado";W["nl-nl"].desc_balloon="balloon";W["nl-nl"].desc_spades="spades";W["nl-nl"].desc_paper_boat="paper boat";
W["nl-nl"].desc_pencil="pencil";W["nl-nl"].desc_phonograph="phonograph";W["nl-nl"].desc_sea_shore="sea shore";W["nl-nl"].desc_pelican="pelican";W["nl-nl"].desc_seagull="seagull";W["nl-nl"].desc_crab="crab";W["nl-nl"].desc_diamonds="diamonds";W["nl-nl"].desc_woods="woods";W["nl-nl"].desc_camera="camera";W["nl-nl"].desc_fishing_pole="fishing pole";W["nl-nl"].desc_river_bed="river bed";W["nl-nl"].desc_pants="pants";W["nl-nl"].desc_rocket="rocket";W["nl-nl"].desc_ambulance="ambulance";
W["nl-nl"].desc_lighthouse="lighthouse";W["nl-nl"].desc_nail_polish="nail polish";W["nl-nl"].desc_clubs="clubs";W["nl-nl"].desc_boiled_egg="boiled egg";W["nl-nl"].desc_lantern="lantern";W["nl-nl"].desc_thumbs_up="thumbs up";W["nl-nl"].desc_rainbow="rainbow";W["en-us"]=W["en-us"]||{};W["en-us"].TutorialTitle_6="Nono Cross";W["en-us"].TutorialTitle_5="Nono Cross";W["en-us"].TutorialTitle_4="Nono Cross";W["en-us"].TutorialTitle_3="Nono Cross";W["en-us"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";
W["en-us"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["en-us"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";W["en-us"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["en-us"].levelStartText="LEVEL <VALUE> START";W["en-us"].TutorialTitle_0="Nono Cross";W["en-us"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";
W["en-us"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["en-us"].TutorialText_2="Around the level you will find clues on which cells to fill";W["en-us"].TutorialTitle_1="Nono Cross";W["en-us"].TutorialTitle_2="Nono Cross";W["en-us"].restartConfirmation="Are you sure you want to restart this level?";W["en-us"].restartCancelBtnText="Cancel";W["en-us"].restartConfirmBtnText="Confirm";W["en-us"].desc_rubber_ducky="Rubber Ducky";
W["en-us"].desc_butterfly="Butterfly";W["en-us"].desc_bell="Bell";W["en-us"].desc_telephone="Telephone";W["en-us"].desc_tomato="Tomato";W["en-us"].desc_key="Key";W["en-us"]["desc_gold fish"]="Gold Fish";W["en-us"].desc_coffee_cup="Coffee Cup";W["en-us"].desc_cherry="Cherry";W["en-us"].desc_puzzle_piece="Puzzle Piece";W["en-us"].desc_camel="Camel";W["en-us"].desc_guinea_pig="Guinea Pig";W["en-us"].desc_car="Car";W["en-us"].desc_smile="Smile";W["en-us"].desc_weight_lifting="Weight Lifting";
W["en-us"].desc_lollipop="Lollipop";W["en-us"].desc_bus="Bus";W["en-us"].desc_chair="Chair";W["en-us"].desc_frog="Frog";W["en-us"].desc_boat="Boat";W["en-us"].desc_flowers="Flowers";W["en-us"].desc_music_note="Music Note";W["en-us"].desc_tractor="Tractor";W["en-us"].desc_cow="Cow";W["en-us"].desc_snail="Snail";W["en-us"].desc_pear="Pear";W["en-us"].desc_tree="Tree";W["en-us"].desc_snake="Snake";W["en-us"].desc_duck="Duck";W["en-us"].desc_strawberry="Strawberry";W["en-us"].desc_squirrel="Squirrel";
W["en-us"].desc_plane="Plane";W["en-us"].desc_dog="Dog";W["en-us"].desc_city="City";W["en-us"].desc_mountains="Mountains";W["en-us"].desc_baseball="Baseball";W["en-us"].desc_sunflowers="Sunflowers";W["en-us"].desc_umbrella="Umbrella";W["en-us"].desc_arrow="Arrow";W["en-us"].desc_cactus="Cactus";W["en-us"].desc_cowboy_hat="Cowboy Hat";W["en-us"].desc_robin="Robin";W["en-us"].desc_chicken="Chicken";W["en-us"].desc_kettle="Kettle";W["en-us"].desc_faucet="Faucet";W["en-us"].desc_turnip="Turnip";
W["en-us"].desc_sword="Sword";W["en-us"].desc_the_moon="The Moon";W["en-us"].desc_banana="Banana";W["en-us"].desc_cat="Cat";W["en-us"].desc_shovel="Shovel";W["en-us"].desc_cellphone="Cellphone";W["en-us"].desc_carrot="Carrot";W["en-us"]["desc_?"]="?";W["en-us"].desc_sapling="Sapling";W["en-us"].desc_lion="Lion";W["en-us"].desc_sunset="Sunset";W["en-us"].desc_hippo="Hippo";W["en-us"].desc_apple="Apple";W["en-us"].desc_corn="Corn";W["en-us"].desc_bunny="Bunny";W["en-us"].desc_star="Star";
W["en-us"].desc_panda="Panda";W["en-us"].desc_heart="Heart";W["en-us"].desc_deer="Deer";W["en-us"].desc_computer="Computer";W["en-us"].desc_house="House";W["en-us"].desc_elephant="Elephant";W["en-us"].desc_dolphin="Dolphin";W["en-us"].desc_unnamed="Unnamed";W["en-us"].desc_bee="Bee";W["en-us"].desc_koi_pond="Koi Pond";W["en-us"].desc_the_park="The Park";W["en-us"].desc_pearl="Pearl";W["en-us"].desc_tea_bag="Tea Bag";W["en-us"].TutorialText_7="Each puzzle only has one solution, so don't guess.";
W["en-us"].TutorialTitle_7="Nono Cross";W["en-us"].desc_coffee_bean="Coffee Bean";W["en-us"].desc_frowney="Frowney";W["en-us"].desc_smiley="Smiley";W["en-us"].desc_koala="Koala";W["en-us"].desc_saturn="Saturn";W["en-us"].desc_necklace="Necklace";W["en-us"].desc_shrub="Shrub";W["en-us"].desc_headphones="Headphones";W["en-us"].desc_blue_tee="Blue Tee";W["en-us"].desc_earring="Earring";W["en-us"].desc_lipstick="Lipstick";W["en-us"].desc_tv="TV";W["en-us"].desc_hamburger="Hamburger";
W["en-us"].desc_egg="Egg";W["en-us"].desc_the_sun="The Sun";W["en-us"].desc_candle="Candle";W["en-us"].desc_flashlight="Flashlight";W["en-us"].desc_a_well="A Well";W["en-us"].desc_wave="Wave";W["en-us"].desc_ponytail="Ponytail";W["en-us"].desc_icecream="Ice Cream";W["en-us"].desc_pickle_jar="Pickle Jar";W["en-us"].desc_stove="Stove";W["en-us"].desc_grapes="Grapes";W["en-us"].desc_mouse="Mouse";W["en-us"].desc_loin="Loin";W["en-us"].ui_level_text="Level";W["en-us"].desc_rose="rose";
W["en-us"].desc_alpaca="alpaca";W["en-us"].desc_desert="desert";W["en-us"].desc_sheep="sheep";W["en-us"].desc_alarm_clock="alarm clock";W["en-us"].desc_fish_bowl="fish bowl";W["en-us"].desc_paint_brush="paint brush";W["en-us"].desc_melon_slice="melon slice";W["en-us"].desc_toadstool="toadstool";W["en-us"].desc_choco_cake="choco cake";W["en-us"].desc_swan="swan";W["en-us"].desc_bicycle="bicycle";W["en-us"].desc_buttered_toast="buttered toast";W["en-us"].desc_purse="purse";W["en-us"].desc_bed="bed";
W["en-us"].desc_tadpole="tadpole";W["en-us"].desc_picture_book="picture book";W["en-us"].desc_bear="bear";W["en-us"].desc_traffic_light="traffic light";W["en-us"].desc_campfire="campfire";W["en-us"].desc_drinks="drinks";W["en-us"].desc_leaf="leaf";W["en-us"]["desc_dragonfly "]="dragonfly ";W["en-us"].desc_volcano="volcano";W["en-us"].desc_coral="coral";W["en-us"].desc_bracelet="bracelet";W["en-us"]["desc_backpack "]="backpack ";W["en-us"].desc_orca="orca";W["en-us"].desc_soup_pan="soup pan";
W["en-us"].desc_tent="tent";W["en-us"].desc_choco_cookie="choco cookie";W["en-us"].desc_magic_hat="magic hat";W["en-us"]["desc_hand mirror"]="hand mirror";W["en-us"].desc_waterfall="waterfall";W["en-us"].desc_treasure_chest="treasure chest";W["en-us"].desc_chimney="chimney";W["en-us"]["desc_salt_&_pepper"]="salt & pepper";W["en-us"].desc_glasses="glasses";W["en-us"].desc_lamp="lamp";W["en-us"].desc_horse="horse";W["en-us"].desc_golf="golf";W["en-us"].desc_pizza="pizza";W["en-us"].desc_rain="rain";
W["en-us"].desc_toaster="toaster";W["en-us"].desc_cheese="cheese";W["en-us"].desc_goat="goat";W["en-us"].desc_ice_skate="ice skate";W["en-us"].desc_microphone="microphone";W["en-us"].desc_watering_can="watering can";W["en-us"].desc_space_shuttle="space shuttle";W["en-us"].desc_door="door";W["en-us"].desc_bubblegum="bubblegum";W["en-us"].desc_shooting_star="shooting star";W["en-us"].desc_winter="winter";W["en-us"].desc_spring="spring";W["en-us"].desc_summer="summer";W["en-us"].desc_autumn="autumn";
W["en-us"].desc_sprinkled_donut="sprinkled donut";W["en-us"].desc_santa="santa";W["en-us"].desc_hedgehog="hedgehog";W["en-us"].desc_clouds="clouds";W["en-us"].desc_boot="boot";W["en-us"].desc_scissors="scissors";W["en-us"].desc_chocolate_bar="chocolate bar";W["en-us"].desc_magnifier="magnifier";W["en-us"].desc_clothes_hanger="clothes hanger";W["en-us"].desc_bowtie="bowtie";W["en-us"].desc_flying_kite="flying kite";W["en-us"].desc_beard="beard";W["en-us"].desc_fountain="fountain";
W["en-us"].desc_crocodile="crocodile";W["en-us"].desc_peas="peas";W["en-us"].desc_tutu="tutu";W["en-us"].desc_tornado="tornado";W["en-us"].desc_balloon="balloon";W["en-us"].desc_spades="spades";W["en-us"].desc_paper_boat="paper boat";W["en-us"].desc_pencil="pencil";W["en-us"].desc_phonograph="phonograph";W["en-us"].desc_sea_shore="sea shore";W["en-us"].desc_pelican="pelican";W["en-us"].desc_seagull="seagull";W["en-us"].desc_crab="crab";W["en-us"].desc_diamonds="diamonds";W["en-us"].desc_woods="woods";
W["en-us"].desc_camera="camera";W["en-us"].desc_fishing_pole="fishing pole";W["en-us"].desc_river_bed="river bed";W["en-us"].desc_pants="pants";W["en-us"].desc_rocket="rocket";W["en-us"].desc_ambulance="ambulance";W["en-us"].desc_lighthouse="lighthouse";W["en-us"].desc_nail_polish="nail polish";W["en-us"].desc_clubs="clubs";W["en-us"].desc_boiled_egg="boiled egg";W["en-us"].desc_lantern="lantern";W["en-us"].desc_thumbs_up="thumbs up";W["en-us"].desc_rainbow="rainbow";W["en-gb"]=W["en-gb"]||{};
W["en-gb"].TutorialTitle_6="Nono Cross";W["en-gb"].TutorialTitle_5="Nono Cross";W["en-gb"].TutorialTitle_4="Nono Cross";W["en-gb"].TutorialTitle_3="Nono Cross";W["en-gb"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";W["en-gb"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["en-gb"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";
W["en-gb"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["en-gb"].levelStartText="LEVEL <VALUE> START";W["en-gb"].TutorialTitle_0="Nono Cross";W["en-gb"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";W["en-gb"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["en-gb"].TutorialText_2="Around the level you will find clues on which cells to fill";
W["en-gb"].TutorialTitle_1="Nono Cross";W["en-gb"].TutorialTitle_2="Nono Cross";W["en-gb"].restartConfirmation="Are you sure you want to restart this level?";W["en-gb"].restartCancelBtnText="Cancel";W["en-gb"].restartConfirmBtnText="Confirm";W["en-gb"].desc_rubber_ducky="Rubber Ducky";W["en-gb"].desc_butterfly="Butterfly";W["en-gb"].desc_bell="Bell";W["en-gb"].desc_telephone="Telephone";W["en-gb"].desc_tomato="Tomato";W["en-gb"].desc_key="Key";W["en-gb"]["desc_gold fish"]="Gold Fish";
W["en-gb"].desc_coffee_cup="Coffee Cup";W["en-gb"].desc_cherry="Cherry";W["en-gb"].desc_puzzle_piece="Puzzle Piece";W["en-gb"].desc_camel="Camel";W["en-gb"].desc_guinea_pig="Guinea Pig";W["en-gb"].desc_car="Car";W["en-gb"].desc_smile="Smile";W["en-gb"].desc_weight_lifting="Weight Lifting";W["en-gb"].desc_lollipop="Lollipop";W["en-gb"].desc_bus="Bus";W["en-gb"].desc_chair="Chair";W["en-gb"].desc_frog="Frog";W["en-gb"].desc_boat="Boat";W["en-gb"].desc_flowers="Flowers";W["en-gb"].desc_music_note="Music Note";
W["en-gb"].desc_tractor="Tractor";W["en-gb"].desc_cow="Cow";W["en-gb"].desc_snail="Snail";W["en-gb"].desc_pear="Pear";W["en-gb"].desc_tree="Tree";W["en-gb"].desc_snake="Snake";W["en-gb"].desc_duck="Duck";W["en-gb"].desc_strawberry="Strawberry";W["en-gb"].desc_squirrel="Squirrel";W["en-gb"].desc_plane="Plane";W["en-gb"].desc_dog="Dog";W["en-gb"].desc_city="City";W["en-gb"].desc_mountains="Mountains";W["en-gb"].desc_baseball="Baseball";W["en-gb"].desc_sunflowers="Sunflowers";
W["en-gb"].desc_umbrella="Umbrella";W["en-gb"].desc_arrow="Arrow";W["en-gb"].desc_cactus="Cactus";W["en-gb"].desc_cowboy_hat="Cowboy Hat";W["en-gb"].desc_robin="Robin";W["en-gb"].desc_chicken="Chicken";W["en-gb"].desc_kettle="Kettle";W["en-gb"].desc_faucet="Faucet";W["en-gb"].desc_turnip="Turnip";W["en-gb"].desc_sword="Sword";W["en-gb"].desc_the_moon="The Moon";W["en-gb"].desc_banana="Banana";W["en-gb"].desc_cat="Cat";W["en-gb"].desc_shovel="Shovel";W["en-gb"].desc_cellphone="Cellphone";
W["en-gb"].desc_carrot="Carrot";W["en-gb"]["desc_?"]="?";W["en-gb"].desc_sapling="Sapling";W["en-gb"].desc_lion="Lion";W["en-gb"].desc_sunset="Sunset";W["en-gb"].desc_hippo="Hippo";W["en-gb"].desc_apple="Apple";W["en-gb"].desc_corn="Corn";W["en-gb"].desc_bunny="Bunny";W["en-gb"].desc_star="Star";W["en-gb"].desc_panda="Panda";W["en-gb"].desc_heart="Heart";W["en-gb"].desc_deer="Deer";W["en-gb"].desc_computer="Computer";W["en-gb"].desc_house="House";W["en-gb"].desc_elephant="Elephant";
W["en-gb"].desc_dolphin="Dolphin";W["en-gb"].desc_unnamed="Unnamed";W["en-gb"].desc_bee="Bee";W["en-gb"].desc_koi_pond="Koi Pond";W["en-gb"].desc_the_park="The Park";W["en-gb"].desc_pearl="Pearl";W["en-gb"].desc_tea_bag="Tea Bag";W["en-gb"].TutorialText_7="Each puzzle only has one solution, so don't guess.";W["en-gb"].TutorialTitle_7="Nono Cross";W["en-gb"].desc_coffee_bean="Coffee Bean";W["en-gb"].desc_frowney="Frowney";W["en-gb"].desc_smiley="Smiley";W["en-gb"].desc_koala="Koala";
W["en-gb"].desc_saturn="Saturn";W["en-gb"].desc_necklace="Necklace";W["en-gb"].desc_shrub="Shrub";W["en-gb"].desc_headphones="Headphones";W["en-gb"].desc_blue_tee="Blue Tee";W["en-gb"].desc_earring="Earring";W["en-gb"].desc_lipstick="Lipstick";W["en-gb"].desc_tv="TV";W["en-gb"].desc_hamburger="Hamburger";W["en-gb"].desc_egg="Egg";W["en-gb"].desc_the_sun="The Sun";W["en-gb"].desc_candle="Candle";W["en-gb"].desc_flashlight="Flashlight";W["en-gb"].desc_a_well="A Well";W["en-gb"].desc_wave="Wave";
W["en-gb"].desc_ponytail="Ponytail";W["en-gb"].desc_icecream="Ice Cream";W["en-gb"].desc_pickle_jar="Pickle Jar";W["en-gb"].desc_stove="Stove";W["en-gb"].desc_grapes="Grapes";W["en-gb"].desc_mouse="Mouse";W["en-gb"].desc_loin="Loin";W["en-gb"].ui_level_text="Level";W["en-gb"].desc_rose="rose";W["en-gb"].desc_alpaca="alpaca";W["en-gb"].desc_desert="desert";W["en-gb"].desc_sheep="sheep";W["en-gb"].desc_alarm_clock="alarm clock";W["en-gb"].desc_fish_bowl="fish bowl";W["en-gb"].desc_paint_brush="paint brush";
W["en-gb"].desc_melon_slice="melon slice";W["en-gb"].desc_toadstool="toadstool";W["en-gb"].desc_choco_cake="choco cake";W["en-gb"].desc_swan="swan";W["en-gb"].desc_bicycle="bicycle";W["en-gb"].desc_buttered_toast="buttered toast";W["en-gb"].desc_purse="purse";W["en-gb"].desc_bed="bed";W["en-gb"].desc_tadpole="tadpole";W["en-gb"].desc_picture_book="picture book";W["en-gb"].desc_bear="bear";W["en-gb"].desc_traffic_light="traffic light";W["en-gb"].desc_campfire="campfire";W["en-gb"].desc_drinks="drinks";
W["en-gb"].desc_leaf="leaf";W["en-gb"]["desc_dragonfly "]="dragonfly ";W["en-gb"].desc_volcano="volcano";W["en-gb"].desc_coral="coral";W["en-gb"].desc_bracelet="bracelet";W["en-gb"]["desc_backpack "]="backpack ";W["en-gb"].desc_orca="orca";W["en-gb"].desc_soup_pan="soup pan";W["en-gb"].desc_tent="tent";W["en-gb"].desc_choco_cookie="choco cookie";W["en-gb"].desc_magic_hat="magic hat";W["en-gb"]["desc_hand mirror"]="hand mirror";W["en-gb"].desc_waterfall="waterfall";W["en-gb"].desc_treasure_chest="treasure chest";
W["en-gb"].desc_chimney="chimney";W["en-gb"]["desc_salt_&_pepper"]="salt & pepper";W["en-gb"].desc_glasses="glasses";W["en-gb"].desc_lamp="lamp";W["en-gb"].desc_horse="horse";W["en-gb"].desc_golf="golf";W["en-gb"].desc_pizza="pizza";W["en-gb"].desc_rain="rain";W["en-gb"].desc_toaster="toaster";W["en-gb"].desc_cheese="cheese";W["en-gb"].desc_goat="goat";W["en-gb"].desc_ice_skate="ice skate";W["en-gb"].desc_microphone="microphone";W["en-gb"].desc_watering_can="watering can";
W["en-gb"].desc_space_shuttle="space shuttle";W["en-gb"].desc_door="door";W["en-gb"].desc_bubblegum="bubblegum";W["en-gb"].desc_shooting_star="shooting star";W["en-gb"].desc_winter="winter";W["en-gb"].desc_spring="spring";W["en-gb"].desc_summer="summer";W["en-gb"].desc_autumn="autumn";W["en-gb"].desc_sprinkled_donut="sprinkled donut";W["en-gb"].desc_santa="santa";W["en-gb"].desc_hedgehog="hedgehog";W["en-gb"].desc_clouds="clouds";W["en-gb"].desc_boot="boot";W["en-gb"].desc_scissors="scissors";
W["en-gb"].desc_chocolate_bar="chocolate bar";W["en-gb"].desc_magnifier="magnifier";W["en-gb"].desc_clothes_hanger="clothes hanger";W["en-gb"].desc_bowtie="bowtie";W["en-gb"].desc_flying_kite="flying kite";W["en-gb"].desc_beard="beard";W["en-gb"].desc_fountain="fountain";W["en-gb"].desc_crocodile="crocodile";W["en-gb"].desc_peas="peas";W["en-gb"].desc_tutu="tutu";W["en-gb"].desc_tornado="tornado";W["en-gb"].desc_balloon="balloon";W["en-gb"].desc_spades="spades";W["en-gb"].desc_paper_boat="paper boat";
W["en-gb"].desc_pencil="pencil";W["en-gb"].desc_phonograph="phonograph";W["en-gb"].desc_sea_shore="sea shore";W["en-gb"].desc_pelican="pelican";W["en-gb"].desc_seagull="seagull";W["en-gb"].desc_crab="crab";W["en-gb"].desc_diamonds="diamonds";W["en-gb"].desc_woods="woods";W["en-gb"].desc_camera="camera";W["en-gb"].desc_fishing_pole="fishing pole";W["en-gb"].desc_river_bed="river bed";W["en-gb"].desc_pants="pants";W["en-gb"].desc_rocket="rocket";W["en-gb"].desc_ambulance="ambulance";
W["en-gb"].desc_lighthouse="lighthouse";W["en-gb"].desc_nail_polish="nail polish";W["en-gb"].desc_clubs="clubs";W["en-gb"].desc_boiled_egg="boiled egg";W["en-gb"].desc_lantern="lantern";W["en-gb"].desc_thumbs_up="thumbs up";W["en-gb"].desc_rainbow="rainbow";W["de-de"]=W["de-de"]||{};W["de-de"].TutorialTitle_6="Nono Cross";W["de-de"].TutorialTitle_5="Nono Cross";W["de-de"].TutorialTitle_4="Nono Cross";W["de-de"].TutorialTitle_3="Nono Cross";W["de-de"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";
W["de-de"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["de-de"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";W["de-de"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["de-de"].levelStartText="LEVEL <VALUE> START";W["de-de"].TutorialTitle_0="Nono Cross";W["de-de"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";
W["de-de"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["de-de"].TutorialText_2="Around the level you will find clues on which cells to fill";W["de-de"].TutorialTitle_1="Nono Cross";W["de-de"].TutorialTitle_2="Nono Cross";W["de-de"].restartConfirmation="Are you sure you want to restart this level?";W["de-de"].restartCancelBtnText="Cancel";W["de-de"].restartConfirmBtnText="Confirm";W["de-de"].desc_rubber_ducky="Rubber Ducky";
W["de-de"].desc_butterfly="Butterfly";W["de-de"].desc_bell="Bell";W["de-de"].desc_telephone="Telephone";W["de-de"].desc_tomato="Tomato";W["de-de"].desc_key="Key";W["de-de"]["desc_gold fish"]="Gold Fish";W["de-de"].desc_coffee_cup="Coffee Cup";W["de-de"].desc_cherry="Cherry";W["de-de"].desc_puzzle_piece="Puzzle Piece";W["de-de"].desc_camel="Camel";W["de-de"].desc_guinea_pig="Guinea Pig";W["de-de"].desc_car="Car";W["de-de"].desc_smile="Smile";W["de-de"].desc_weight_lifting="Weight Lifting";
W["de-de"].desc_lollipop="Lollipop";W["de-de"].desc_bus="Bus";W["de-de"].desc_chair="Chair";W["de-de"].desc_frog="Frog";W["de-de"].desc_boat="Boat";W["de-de"].desc_flowers="Flowers";W["de-de"].desc_music_note="Music Note";W["de-de"].desc_tractor="Tractor";W["de-de"].desc_cow="Cow";W["de-de"].desc_snail="Snail";W["de-de"].desc_pear="Pear";W["de-de"].desc_tree="Tree";W["de-de"].desc_snake="Snake";W["de-de"].desc_duck="Duck";W["de-de"].desc_strawberry="Strawberry";W["de-de"].desc_squirrel="Squirrel";
W["de-de"].desc_plane="Plane";W["de-de"].desc_dog="Dog";W["de-de"].desc_city="City";W["de-de"].desc_mountains="Mountains";W["de-de"].desc_baseball="Baseball";W["de-de"].desc_sunflowers="Sunflowers";W["de-de"].desc_umbrella="Umbrella";W["de-de"].desc_arrow="Arrow";W["de-de"].desc_cactus="Cactus";W["de-de"].desc_cowboy_hat="Cowboy Hat";W["de-de"].desc_robin="Robin";W["de-de"].desc_chicken="Chicken";W["de-de"].desc_kettle="Kettle";W["de-de"].desc_faucet="Faucet";W["de-de"].desc_turnip="Turnip";
W["de-de"].desc_sword="Sword";W["de-de"].desc_the_moon="The Moon";W["de-de"].desc_banana="Banana";W["de-de"].desc_cat="Cat";W["de-de"].desc_shovel="Shovel";W["de-de"].desc_cellphone="Cellphone";W["de-de"].desc_carrot="Carrot";W["de-de"]["desc_?"]="?";W["de-de"].desc_sapling="Sapling";W["de-de"].desc_lion="Lion";W["de-de"].desc_sunset="Sunset";W["de-de"].desc_hippo="Hippo";W["de-de"].desc_apple="Apple";W["de-de"].desc_corn="Corn";W["de-de"].desc_bunny="Bunny";W["de-de"].desc_star="Star";
W["de-de"].desc_panda="Panda";W["de-de"].desc_heart="Heart";W["de-de"].desc_deer="Deer";W["de-de"].desc_computer="Computer";W["de-de"].desc_house="House";W["de-de"].desc_elephant="Elephant";W["de-de"].desc_dolphin="Dolphin";W["de-de"].desc_unnamed="Unnamed";W["de-de"].desc_bee="Bee";W["de-de"].desc_koi_pond="Koi Pond";W["de-de"].desc_the_park="The Park";W["de-de"].desc_pearl="Pearl";W["de-de"].desc_tea_bag="Tea Bag";W["de-de"].TutorialText_7="Each puzzle only has one solution, so don't guess.";
W["de-de"].TutorialTitle_7="Nono Cross";W["de-de"].desc_coffee_bean="Coffee Bean";W["de-de"].desc_frowney="Frowney";W["de-de"].desc_smiley="Smiley";W["de-de"].desc_koala="Koala";W["de-de"].desc_saturn="Saturn";W["de-de"].desc_necklace="Necklace";W["de-de"].desc_shrub="Shrub";W["de-de"].desc_headphones="Headphones";W["de-de"].desc_blue_tee="Blue Tee";W["de-de"].desc_earring="Earring";W["de-de"].desc_lipstick="Lipstick";W["de-de"].desc_tv="TV";W["de-de"].desc_hamburger="Hamburger";
W["de-de"].desc_egg="Egg";W["de-de"].desc_the_sun="The Sun";W["de-de"].desc_candle="Candle";W["de-de"].desc_flashlight="Flashlight";W["de-de"].desc_a_well="A Well";W["de-de"].desc_wave="Wave";W["de-de"].desc_ponytail="Ponytail";W["de-de"].desc_icecream="Ice Cream";W["de-de"].desc_pickle_jar="Pickle Jar";W["de-de"].desc_stove="Stove";W["de-de"].desc_grapes="Grapes";W["de-de"].desc_mouse="Mouse";W["de-de"].desc_loin="Loin";W["de-de"].ui_level_text="Level";W["de-de"].desc_rose="rose";
W["de-de"].desc_alpaca="alpaca";W["de-de"].desc_desert="desert";W["de-de"].desc_sheep="sheep";W["de-de"].desc_alarm_clock="alarm clock";W["de-de"].desc_fish_bowl="fish bowl";W["de-de"].desc_paint_brush="paint brush";W["de-de"].desc_melon_slice="melon slice";W["de-de"].desc_toadstool="toadstool";W["de-de"].desc_choco_cake="choco cake";W["de-de"].desc_swan="swan";W["de-de"].desc_bicycle="bicycle";W["de-de"].desc_buttered_toast="buttered toast";W["de-de"].desc_purse="purse";W["de-de"].desc_bed="bed";
W["de-de"].desc_tadpole="tadpole";W["de-de"].desc_picture_book="picture book";W["de-de"].desc_bear="bear";W["de-de"].desc_traffic_light="traffic light";W["de-de"].desc_campfire="campfire";W["de-de"].desc_drinks="drinks";W["de-de"].desc_leaf="leaf";W["de-de"]["desc_dragonfly "]="dragonfly ";W["de-de"].desc_volcano="volcano";W["de-de"].desc_coral="coral";W["de-de"].desc_bracelet="bracelet";W["de-de"]["desc_backpack "]="backpack ";W["de-de"].desc_orca="orca";W["de-de"].desc_soup_pan="soup pan";
W["de-de"].desc_tent="tent";W["de-de"].desc_choco_cookie="choco cookie";W["de-de"].desc_magic_hat="magic hat";W["de-de"]["desc_hand mirror"]="hand mirror";W["de-de"].desc_waterfall="waterfall";W["de-de"].desc_treasure_chest="treasure chest";W["de-de"].desc_chimney="chimney";W["de-de"]["desc_salt_&_pepper"]="salt & pepper";W["de-de"].desc_glasses="glasses";W["de-de"].desc_lamp="lamp";W["de-de"].desc_horse="horse";W["de-de"].desc_golf="golf";W["de-de"].desc_pizza="pizza";W["de-de"].desc_rain="rain";
W["de-de"].desc_toaster="toaster";W["de-de"].desc_cheese="cheese";W["de-de"].desc_goat="goat";W["de-de"].desc_ice_skate="ice skate";W["de-de"].desc_microphone="microphone";W["de-de"].desc_watering_can="watering can";W["de-de"].desc_space_shuttle="space shuttle";W["de-de"].desc_door="door";W["de-de"].desc_bubblegum="bubblegum";W["de-de"].desc_shooting_star="shooting star";W["de-de"].desc_winter="winter";W["de-de"].desc_spring="spring";W["de-de"].desc_summer="summer";W["de-de"].desc_autumn="autumn";
W["de-de"].desc_sprinkled_donut="sprinkled donut";W["de-de"].desc_santa="santa";W["de-de"].desc_hedgehog="hedgehog";W["de-de"].desc_clouds="clouds";W["de-de"].desc_boot="boot";W["de-de"].desc_scissors="scissors";W["de-de"].desc_chocolate_bar="chocolate bar";W["de-de"].desc_magnifier="magnifier";W["de-de"].desc_clothes_hanger="clothes hanger";W["de-de"].desc_bowtie="bowtie";W["de-de"].desc_flying_kite="flying kite";W["de-de"].desc_beard="beard";W["de-de"].desc_fountain="fountain";
W["de-de"].desc_crocodile="crocodile";W["de-de"].desc_peas="peas";W["de-de"].desc_tutu="tutu";W["de-de"].desc_tornado="tornado";W["de-de"].desc_balloon="balloon";W["de-de"].desc_spades="spades";W["de-de"].desc_paper_boat="paper boat";W["de-de"].desc_pencil="pencil";W["de-de"].desc_phonograph="phonograph";W["de-de"].desc_sea_shore="sea shore";W["de-de"].desc_pelican="pelican";W["de-de"].desc_seagull="seagull";W["de-de"].desc_crab="crab";W["de-de"].desc_diamonds="diamonds";W["de-de"].desc_woods="woods";
W["de-de"].desc_camera="camera";W["de-de"].desc_fishing_pole="fishing pole";W["de-de"].desc_river_bed="river bed";W["de-de"].desc_pants="pants";W["de-de"].desc_rocket="rocket";W["de-de"].desc_ambulance="ambulance";W["de-de"].desc_lighthouse="lighthouse";W["de-de"].desc_nail_polish="nail polish";W["de-de"].desc_clubs="clubs";W["de-de"].desc_boiled_egg="boiled egg";W["de-de"].desc_lantern="lantern";W["de-de"].desc_thumbs_up="thumbs up";W["de-de"].desc_rainbow="rainbow";W["fr-fr"]=W["fr-fr"]||{};
W["fr-fr"].TutorialTitle_6="Nono Cross";W["fr-fr"].TutorialTitle_5="Nono Cross";W["fr-fr"].TutorialTitle_4="Nono Cross";W["fr-fr"].TutorialTitle_3="Nono Cross";W["fr-fr"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";W["fr-fr"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["fr-fr"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";
W["fr-fr"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["fr-fr"].levelStartText="LEVEL <VALUE> START";W["fr-fr"].TutorialTitle_0="Nono Cross";W["fr-fr"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";W["fr-fr"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["fr-fr"].TutorialText_2="Around the level you will find clues on which cells to fill";
W["fr-fr"].TutorialTitle_1="Nono Cross";W["fr-fr"].TutorialTitle_2="Nono Cross";W["fr-fr"].restartConfirmation="Are you sure you want to restart this level?";W["fr-fr"].restartCancelBtnText="Cancel";W["fr-fr"].restartConfirmBtnText="Confirm";W["fr-fr"].desc_rubber_ducky="Rubber Ducky";W["fr-fr"].desc_butterfly="Butterfly";W["fr-fr"].desc_bell="Bell";W["fr-fr"].desc_telephone="Telephone";W["fr-fr"].desc_tomato="Tomato";W["fr-fr"].desc_key="Key";W["fr-fr"]["desc_gold fish"]="Gold Fish";
W["fr-fr"].desc_coffee_cup="Coffee Cup";W["fr-fr"].desc_cherry="Cherry";W["fr-fr"].desc_puzzle_piece="Puzzle Piece";W["fr-fr"].desc_camel="Camel";W["fr-fr"].desc_guinea_pig="Guinea Pig";W["fr-fr"].desc_car="Car";W["fr-fr"].desc_smile="Smile";W["fr-fr"].desc_weight_lifting="Weight Lifting";W["fr-fr"].desc_lollipop="Lollipop";W["fr-fr"].desc_bus="Bus";W["fr-fr"].desc_chair="Chair";W["fr-fr"].desc_frog="Frog";W["fr-fr"].desc_boat="Boat";W["fr-fr"].desc_flowers="Flowers";W["fr-fr"].desc_music_note="Music Note";
W["fr-fr"].desc_tractor="Tractor";W["fr-fr"].desc_cow="Cow";W["fr-fr"].desc_snail="Snail";W["fr-fr"].desc_pear="Pear";W["fr-fr"].desc_tree="Tree";W["fr-fr"].desc_snake="Snake";W["fr-fr"].desc_duck="Duck";W["fr-fr"].desc_strawberry="Strawberry";W["fr-fr"].desc_squirrel="Squirrel";W["fr-fr"].desc_plane="Plane";W["fr-fr"].desc_dog="Dog";W["fr-fr"].desc_city="City";W["fr-fr"].desc_mountains="Mountains";W["fr-fr"].desc_baseball="Baseball";W["fr-fr"].desc_sunflowers="Sunflowers";
W["fr-fr"].desc_umbrella="Umbrella";W["fr-fr"].desc_arrow="Arrow";W["fr-fr"].desc_cactus="Cactus";W["fr-fr"].desc_cowboy_hat="Cowboy Hat";W["fr-fr"].desc_robin="Robin";W["fr-fr"].desc_chicken="Chicken";W["fr-fr"].desc_kettle="Kettle";W["fr-fr"].desc_faucet="Faucet";W["fr-fr"].desc_turnip="Turnip";W["fr-fr"].desc_sword="Sword";W["fr-fr"].desc_the_moon="The Moon";W["fr-fr"].desc_banana="Banana";W["fr-fr"].desc_cat="Cat";W["fr-fr"].desc_shovel="Shovel";W["fr-fr"].desc_cellphone="Cellphone";
W["fr-fr"].desc_carrot="Carrot";W["fr-fr"]["desc_?"]="?";W["fr-fr"].desc_sapling="Sapling";W["fr-fr"].desc_lion="Lion";W["fr-fr"].desc_sunset="Sunset";W["fr-fr"].desc_hippo="Hippo";W["fr-fr"].desc_apple="Apple";W["fr-fr"].desc_corn="Corn";W["fr-fr"].desc_bunny="Bunny";W["fr-fr"].desc_star="Star";W["fr-fr"].desc_panda="Panda";W["fr-fr"].desc_heart="Heart";W["fr-fr"].desc_deer="Deer";W["fr-fr"].desc_computer="Computer";W["fr-fr"].desc_house="House";W["fr-fr"].desc_elephant="Elephant";
W["fr-fr"].desc_dolphin="Dolphin";W["fr-fr"].desc_unnamed="Unnamed";W["fr-fr"].desc_bee="Bee";W["fr-fr"].desc_koi_pond="Koi Pond";W["fr-fr"].desc_the_park="The Park";W["fr-fr"].desc_pearl="Pearl";W["fr-fr"].desc_tea_bag="Tea Bag";W["fr-fr"].TutorialText_7="Each puzzle only has one solution, so don't guess.";W["fr-fr"].TutorialTitle_7="Nono Cross";W["fr-fr"].desc_coffee_bean="Coffee Bean";W["fr-fr"].desc_frowney="Frowney";W["fr-fr"].desc_smiley="Smiley";W["fr-fr"].desc_koala="Koala";
W["fr-fr"].desc_saturn="Saturn";W["fr-fr"].desc_necklace="Necklace";W["fr-fr"].desc_shrub="Shrub";W["fr-fr"].desc_headphones="Headphones";W["fr-fr"].desc_blue_tee="Blue Tee";W["fr-fr"].desc_earring="Earring";W["fr-fr"].desc_lipstick="Lipstick";W["fr-fr"].desc_tv="TV";W["fr-fr"].desc_hamburger="Hamburger";W["fr-fr"].desc_egg="Egg";W["fr-fr"].desc_the_sun="The Sun";W["fr-fr"].desc_candle="Candle";W["fr-fr"].desc_flashlight="Flashlight";W["fr-fr"].desc_a_well="A Well";W["fr-fr"].desc_wave="Wave";
W["fr-fr"].desc_ponytail="Ponytail";W["fr-fr"].desc_icecream="Ice Cream";W["fr-fr"].desc_pickle_jar="Pickle Jar";W["fr-fr"].desc_stove="Stove";W["fr-fr"].desc_grapes="Grapes";W["fr-fr"].desc_mouse="Mouse";W["fr-fr"].desc_loin="Loin";W["fr-fr"].ui_level_text="Level";W["fr-fr"].desc_rose="rose";W["fr-fr"].desc_alpaca="alpaca";W["fr-fr"].desc_desert="desert";W["fr-fr"].desc_sheep="sheep";W["fr-fr"].desc_alarm_clock="alarm clock";W["fr-fr"].desc_fish_bowl="fish bowl";W["fr-fr"].desc_paint_brush="paint brush";
W["fr-fr"].desc_melon_slice="melon slice";W["fr-fr"].desc_toadstool="toadstool";W["fr-fr"].desc_choco_cake="choco cake";W["fr-fr"].desc_swan="swan";W["fr-fr"].desc_bicycle="bicycle";W["fr-fr"].desc_buttered_toast="buttered toast";W["fr-fr"].desc_purse="purse";W["fr-fr"].desc_bed="bed";W["fr-fr"].desc_tadpole="tadpole";W["fr-fr"].desc_picture_book="picture book";W["fr-fr"].desc_bear="bear";W["fr-fr"].desc_traffic_light="traffic light";W["fr-fr"].desc_campfire="campfire";W["fr-fr"].desc_drinks="drinks";
W["fr-fr"].desc_leaf="leaf";W["fr-fr"]["desc_dragonfly "]="dragonfly ";W["fr-fr"].desc_volcano="volcano";W["fr-fr"].desc_coral="coral";W["fr-fr"].desc_bracelet="bracelet";W["fr-fr"]["desc_backpack "]="backpack ";W["fr-fr"].desc_orca="orca";W["fr-fr"].desc_soup_pan="soup pan";W["fr-fr"].desc_tent="tent";W["fr-fr"].desc_choco_cookie="choco cookie";W["fr-fr"].desc_magic_hat="magic hat";W["fr-fr"]["desc_hand mirror"]="hand mirror";W["fr-fr"].desc_waterfall="waterfall";W["fr-fr"].desc_treasure_chest="treasure chest";
W["fr-fr"].desc_chimney="chimney";W["fr-fr"]["desc_salt_&_pepper"]="salt & pepper";W["fr-fr"].desc_glasses="glasses";W["fr-fr"].desc_lamp="lamp";W["fr-fr"].desc_horse="horse";W["fr-fr"].desc_golf="golf";W["fr-fr"].desc_pizza="pizza";W["fr-fr"].desc_rain="rain";W["fr-fr"].desc_toaster="toaster";W["fr-fr"].desc_cheese="cheese";W["fr-fr"].desc_goat="goat";W["fr-fr"].desc_ice_skate="ice skate";W["fr-fr"].desc_microphone="microphone";W["fr-fr"].desc_watering_can="watering can";
W["fr-fr"].desc_space_shuttle="space shuttle";W["fr-fr"].desc_door="door";W["fr-fr"].desc_bubblegum="bubblegum";W["fr-fr"].desc_shooting_star="shooting star";W["fr-fr"].desc_winter="winter";W["fr-fr"].desc_spring="spring";W["fr-fr"].desc_summer="summer";W["fr-fr"].desc_autumn="autumn";W["fr-fr"].desc_sprinkled_donut="sprinkled donut";W["fr-fr"].desc_santa="santa";W["fr-fr"].desc_hedgehog="hedgehog";W["fr-fr"].desc_clouds="clouds";W["fr-fr"].desc_boot="boot";W["fr-fr"].desc_scissors="scissors";
W["fr-fr"].desc_chocolate_bar="chocolate bar";W["fr-fr"].desc_magnifier="magnifier";W["fr-fr"].desc_clothes_hanger="clothes hanger";W["fr-fr"].desc_bowtie="bowtie";W["fr-fr"].desc_flying_kite="flying kite";W["fr-fr"].desc_beard="beard";W["fr-fr"].desc_fountain="fountain";W["fr-fr"].desc_crocodile="crocodile";W["fr-fr"].desc_peas="peas";W["fr-fr"].desc_tutu="tutu";W["fr-fr"].desc_tornado="tornado";W["fr-fr"].desc_balloon="balloon";W["fr-fr"].desc_spades="spades";W["fr-fr"].desc_paper_boat="paper boat";
W["fr-fr"].desc_pencil="pencil";W["fr-fr"].desc_phonograph="phonograph";W["fr-fr"].desc_sea_shore="sea shore";W["fr-fr"].desc_pelican="pelican";W["fr-fr"].desc_seagull="seagull";W["fr-fr"].desc_crab="crab";W["fr-fr"].desc_diamonds="diamonds";W["fr-fr"].desc_woods="woods";W["fr-fr"].desc_camera="camera";W["fr-fr"].desc_fishing_pole="fishing pole";W["fr-fr"].desc_river_bed="river bed";W["fr-fr"].desc_pants="pants";W["fr-fr"].desc_rocket="rocket";W["fr-fr"].desc_ambulance="ambulance";
W["fr-fr"].desc_lighthouse="lighthouse";W["fr-fr"].desc_nail_polish="nail polish";W["fr-fr"].desc_clubs="clubs";W["fr-fr"].desc_boiled_egg="boiled egg";W["fr-fr"].desc_lantern="lantern";W["fr-fr"].desc_thumbs_up="thumbs up";W["fr-fr"].desc_rainbow="rainbow";W["pt-pt"]=W["pt-pt"]||{};W["pt-pt"].TutorialTitle_6="Nono Cross";W["pt-pt"].TutorialTitle_5="Nono Cross";W["pt-pt"].TutorialTitle_4="Nono Cross";W["pt-pt"].TutorialTitle_3="Nono Cross";W["pt-pt"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";
W["pt-pt"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["pt-pt"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";W["pt-pt"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["pt-pt"].levelStartText="LEVEL <VALUE> START";W["pt-pt"].TutorialTitle_0="Nono Cross";W["pt-pt"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";
W["pt-pt"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["pt-pt"].TutorialText_2="Around the level you will find clues on which cells to fill";W["pt-pt"].TutorialTitle_1="Nono Cross";W["pt-pt"].TutorialTitle_2="Nono Cross";W["pt-pt"].restartConfirmation="Are you sure you want to restart this level?";W["pt-pt"].restartCancelBtnText="Cancel";W["pt-pt"].restartConfirmBtnText="Confirm";W["pt-pt"].desc_rubber_ducky="Rubber Ducky";
W["pt-pt"].desc_butterfly="Butterfly";W["pt-pt"].desc_bell="Bell";W["pt-pt"].desc_telephone="Telephone";W["pt-pt"].desc_tomato="Tomato";W["pt-pt"].desc_key="Key";W["pt-pt"]["desc_gold fish"]="Gold Fish";W["pt-pt"].desc_coffee_cup="Coffee Cup";W["pt-pt"].desc_cherry="Cherry";W["pt-pt"].desc_puzzle_piece="Puzzle Piece";W["pt-pt"].desc_camel="Camel";W["pt-pt"].desc_guinea_pig="Guinea Pig";W["pt-pt"].desc_car="Car";W["pt-pt"].desc_smile="Smile";W["pt-pt"].desc_weight_lifting="Weight Lifting";
W["pt-pt"].desc_lollipop="Lollipop";W["pt-pt"].desc_bus="Bus";W["pt-pt"].desc_chair="Chair";W["pt-pt"].desc_frog="Frog";W["pt-pt"].desc_boat="Boat";W["pt-pt"].desc_flowers="Flowers";W["pt-pt"].desc_music_note="Music Note";W["pt-pt"].desc_tractor="Tractor";W["pt-pt"].desc_cow="Cow";W["pt-pt"].desc_snail="Snail";W["pt-pt"].desc_pear="Pear";W["pt-pt"].desc_tree="Tree";W["pt-pt"].desc_snake="Snake";W["pt-pt"].desc_duck="Duck";W["pt-pt"].desc_strawberry="Strawberry";W["pt-pt"].desc_squirrel="Squirrel";
W["pt-pt"].desc_plane="Plane";W["pt-pt"].desc_dog="Dog";W["pt-pt"].desc_city="City";W["pt-pt"].desc_mountains="Mountains";W["pt-pt"].desc_baseball="Baseball";W["pt-pt"].desc_sunflowers="Sunflowers";W["pt-pt"].desc_umbrella="Umbrella";W["pt-pt"].desc_arrow="Arrow";W["pt-pt"].desc_cactus="Cactus";W["pt-pt"].desc_cowboy_hat="Cowboy Hat";W["pt-pt"].desc_robin="Robin";W["pt-pt"].desc_chicken="Chicken";W["pt-pt"].desc_kettle="Kettle";W["pt-pt"].desc_faucet="Faucet";W["pt-pt"].desc_turnip="Turnip";
W["pt-pt"].desc_sword="Sword";W["pt-pt"].desc_the_moon="The Moon";W["pt-pt"].desc_banana="Banana";W["pt-pt"].desc_cat="Cat";W["pt-pt"].desc_shovel="Shovel";W["pt-pt"].desc_cellphone="Cellphone";W["pt-pt"].desc_carrot="Carrot";W["pt-pt"]["desc_?"]="?";W["pt-pt"].desc_sapling="Sapling";W["pt-pt"].desc_lion="Lion";W["pt-pt"].desc_sunset="Sunset";W["pt-pt"].desc_hippo="Hippo";W["pt-pt"].desc_apple="Apple";W["pt-pt"].desc_corn="Corn";W["pt-pt"].desc_bunny="Bunny";W["pt-pt"].desc_star="Star";
W["pt-pt"].desc_panda="Panda";W["pt-pt"].desc_heart="Heart";W["pt-pt"].desc_deer="Deer";W["pt-pt"].desc_computer="Computer";W["pt-pt"].desc_house="House";W["pt-pt"].desc_elephant="Elephant";W["pt-pt"].desc_dolphin="Dolphin";W["pt-pt"].desc_unnamed="Unnamed";W["pt-pt"].desc_bee="Bee";W["pt-pt"].desc_koi_pond="Koi Pond";W["pt-pt"].desc_the_park="The Park";W["pt-pt"].desc_pearl="Pearl";W["pt-pt"].desc_tea_bag="Tea Bag";W["pt-pt"].TutorialText_7="Each puzzle only has one solution, so don't guess.";
W["pt-pt"].TutorialTitle_7="Nono Cross";W["pt-pt"].desc_coffee_bean="Coffee Bean";W["pt-pt"].desc_frowney="Frowney";W["pt-pt"].desc_smiley="Smiley";W["pt-pt"].desc_koala="Koala";W["pt-pt"].desc_saturn="Saturn";W["pt-pt"].desc_necklace="Necklace";W["pt-pt"].desc_shrub="Shrub";W["pt-pt"].desc_headphones="Headphones";W["pt-pt"].desc_blue_tee="Blue Tee";W["pt-pt"].desc_earring="Earring";W["pt-pt"].desc_lipstick="Lipstick";W["pt-pt"].desc_tv="TV";W["pt-pt"].desc_hamburger="Hamburger";
W["pt-pt"].desc_egg="Egg";W["pt-pt"].desc_the_sun="The Sun";W["pt-pt"].desc_candle="Candle";W["pt-pt"].desc_flashlight="Flashlight";W["pt-pt"].desc_a_well="A Well";W["pt-pt"].desc_wave="Wave";W["pt-pt"].desc_ponytail="Ponytail";W["pt-pt"].desc_icecream="Ice Cream";W["pt-pt"].desc_pickle_jar="Pickle Jar";W["pt-pt"].desc_stove="Stove";W["pt-pt"].desc_grapes="Grapes";W["pt-pt"].desc_mouse="Mouse";W["pt-pt"].desc_loin="Loin";W["pt-pt"].ui_level_text="Level";W["pt-pt"].desc_rose="rose";
W["pt-pt"].desc_alpaca="alpaca";W["pt-pt"].desc_desert="desert";W["pt-pt"].desc_sheep="sheep";W["pt-pt"].desc_alarm_clock="alarm clock";W["pt-pt"].desc_fish_bowl="fish bowl";W["pt-pt"].desc_paint_brush="paint brush";W["pt-pt"].desc_melon_slice="melon slice";W["pt-pt"].desc_toadstool="toadstool";W["pt-pt"].desc_choco_cake="choco cake";W["pt-pt"].desc_swan="swan";W["pt-pt"].desc_bicycle="bicycle";W["pt-pt"].desc_buttered_toast="buttered toast";W["pt-pt"].desc_purse="purse";W["pt-pt"].desc_bed="bed";
W["pt-pt"].desc_tadpole="tadpole";W["pt-pt"].desc_picture_book="picture book";W["pt-pt"].desc_bear="bear";W["pt-pt"].desc_traffic_light="traffic light";W["pt-pt"].desc_campfire="campfire";W["pt-pt"].desc_drinks="drinks";W["pt-pt"].desc_leaf="leaf";W["pt-pt"]["desc_dragonfly "]="dragonfly ";W["pt-pt"].desc_volcano="volcano";W["pt-pt"].desc_coral="coral";W["pt-pt"].desc_bracelet="bracelet";W["pt-pt"]["desc_backpack "]="backpack ";W["pt-pt"].desc_orca="orca";W["pt-pt"].desc_soup_pan="soup pan";
W["pt-pt"].desc_tent="tent";W["pt-pt"].desc_choco_cookie="choco cookie";W["pt-pt"].desc_magic_hat="magic hat";W["pt-pt"]["desc_hand mirror"]="hand mirror";W["pt-pt"].desc_waterfall="waterfall";W["pt-pt"].desc_treasure_chest="treasure chest";W["pt-pt"].desc_chimney="chimney";W["pt-pt"]["desc_salt_&_pepper"]="salt & pepper";W["pt-pt"].desc_glasses="glasses";W["pt-pt"].desc_lamp="lamp";W["pt-pt"].desc_horse="horse";W["pt-pt"].desc_golf="golf";W["pt-pt"].desc_pizza="pizza";W["pt-pt"].desc_rain="rain";
W["pt-pt"].desc_toaster="toaster";W["pt-pt"].desc_cheese="cheese";W["pt-pt"].desc_goat="goat";W["pt-pt"].desc_ice_skate="ice skate";W["pt-pt"].desc_microphone="microphone";W["pt-pt"].desc_watering_can="watering can";W["pt-pt"].desc_space_shuttle="space shuttle";W["pt-pt"].desc_door="door";W["pt-pt"].desc_bubblegum="bubblegum";W["pt-pt"].desc_shooting_star="shooting star";W["pt-pt"].desc_winter="winter";W["pt-pt"].desc_spring="spring";W["pt-pt"].desc_summer="summer";W["pt-pt"].desc_autumn="autumn";
W["pt-pt"].desc_sprinkled_donut="sprinkled donut";W["pt-pt"].desc_santa="santa";W["pt-pt"].desc_hedgehog="hedgehog";W["pt-pt"].desc_clouds="clouds";W["pt-pt"].desc_boot="boot";W["pt-pt"].desc_scissors="scissors";W["pt-pt"].desc_chocolate_bar="chocolate bar";W["pt-pt"].desc_magnifier="magnifier";W["pt-pt"].desc_clothes_hanger="clothes hanger";W["pt-pt"].desc_bowtie="bowtie";W["pt-pt"].desc_flying_kite="flying kite";W["pt-pt"].desc_beard="beard";W["pt-pt"].desc_fountain="fountain";
W["pt-pt"].desc_crocodile="crocodile";W["pt-pt"].desc_peas="peas";W["pt-pt"].desc_tutu="tutu";W["pt-pt"].desc_tornado="tornado";W["pt-pt"].desc_balloon="balloon";W["pt-pt"].desc_spades="spades";W["pt-pt"].desc_paper_boat="paper boat";W["pt-pt"].desc_pencil="pencil";W["pt-pt"].desc_phonograph="phonograph";W["pt-pt"].desc_sea_shore="sea shore";W["pt-pt"].desc_pelican="pelican";W["pt-pt"].desc_seagull="seagull";W["pt-pt"].desc_crab="crab";W["pt-pt"].desc_diamonds="diamonds";W["pt-pt"].desc_woods="woods";
W["pt-pt"].desc_camera="camera";W["pt-pt"].desc_fishing_pole="fishing pole";W["pt-pt"].desc_river_bed="river bed";W["pt-pt"].desc_pants="pants";W["pt-pt"].desc_rocket="rocket";W["pt-pt"].desc_ambulance="ambulance";W["pt-pt"].desc_lighthouse="lighthouse";W["pt-pt"].desc_nail_polish="nail polish";W["pt-pt"].desc_clubs="clubs";W["pt-pt"].desc_boiled_egg="boiled egg";W["pt-pt"].desc_lantern="lantern";W["pt-pt"].desc_thumbs_up="thumbs up";W["pt-pt"].desc_rainbow="rainbow";W["pt-br"]=W["pt-br"]||{};
W["pt-br"].TutorialTitle_6="Nono Cross";W["pt-br"].TutorialTitle_5="Nono Cross";W["pt-br"].TutorialTitle_4="Nono Cross";W["pt-br"].TutorialTitle_3="Nono Cross";W["pt-br"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";W["pt-br"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["pt-br"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";
W["pt-br"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["pt-br"].levelStartText="LEVEL <VALUE> START";W["pt-br"].TutorialTitle_0="Nono Cross";W["pt-br"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";W["pt-br"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["pt-br"].TutorialText_2="Around the level you will find clues on which cells to fill";
W["pt-br"].TutorialTitle_1="Nono Cross";W["pt-br"].TutorialTitle_2="Nono Cross";W["pt-br"].restartConfirmation="Are you sure you want to restart this level?";W["pt-br"].restartCancelBtnText="Cancel";W["pt-br"].restartConfirmBtnText="Confirm";W["pt-br"].desc_rubber_ducky="Rubber Ducky";W["pt-br"].desc_butterfly="Butterfly";W["pt-br"].desc_bell="Bell";W["pt-br"].desc_telephone="Telephone";W["pt-br"].desc_tomato="Tomato";W["pt-br"].desc_key="Key";W["pt-br"]["desc_gold fish"]="Gold Fish";
W["pt-br"].desc_coffee_cup="Coffee Cup";W["pt-br"].desc_cherry="Cherry";W["pt-br"].desc_puzzle_piece="Puzzle Piece";W["pt-br"].desc_camel="Camel";W["pt-br"].desc_guinea_pig="Guinea Pig";W["pt-br"].desc_car="Car";W["pt-br"].desc_smile="Smile";W["pt-br"].desc_weight_lifting="Weight Lifting";W["pt-br"].desc_lollipop="Lollipop";W["pt-br"].desc_bus="Bus";W["pt-br"].desc_chair="Chair";W["pt-br"].desc_frog="Frog";W["pt-br"].desc_boat="Boat";W["pt-br"].desc_flowers="Flowers";W["pt-br"].desc_music_note="Music Note";
W["pt-br"].desc_tractor="Tractor";W["pt-br"].desc_cow="Cow";W["pt-br"].desc_snail="Snail";W["pt-br"].desc_pear="Pear";W["pt-br"].desc_tree="Tree";W["pt-br"].desc_snake="Snake";W["pt-br"].desc_duck="Duck";W["pt-br"].desc_strawberry="Strawberry";W["pt-br"].desc_squirrel="Squirrel";W["pt-br"].desc_plane="Plane";W["pt-br"].desc_dog="Dog";W["pt-br"].desc_city="City";W["pt-br"].desc_mountains="Mountains";W["pt-br"].desc_baseball="Baseball";W["pt-br"].desc_sunflowers="Sunflowers";
W["pt-br"].desc_umbrella="Umbrella";W["pt-br"].desc_arrow="Arrow";W["pt-br"].desc_cactus="Cactus";W["pt-br"].desc_cowboy_hat="Cowboy Hat";W["pt-br"].desc_robin="Robin";W["pt-br"].desc_chicken="Chicken";W["pt-br"].desc_kettle="Kettle";W["pt-br"].desc_faucet="Faucet";W["pt-br"].desc_turnip="Turnip";W["pt-br"].desc_sword="Sword";W["pt-br"].desc_the_moon="The Moon";W["pt-br"].desc_banana="Banana";W["pt-br"].desc_cat="Cat";W["pt-br"].desc_shovel="Shovel";W["pt-br"].desc_cellphone="Cellphone";
W["pt-br"].desc_carrot="Carrot";W["pt-br"]["desc_?"]="?";W["pt-br"].desc_sapling="Sapling";W["pt-br"].desc_lion="Lion";W["pt-br"].desc_sunset="Sunset";W["pt-br"].desc_hippo="Hippo";W["pt-br"].desc_apple="Apple";W["pt-br"].desc_corn="Corn";W["pt-br"].desc_bunny="Bunny";W["pt-br"].desc_star="Star";W["pt-br"].desc_panda="Panda";W["pt-br"].desc_heart="Heart";W["pt-br"].desc_deer="Deer";W["pt-br"].desc_computer="Computer";W["pt-br"].desc_house="House";W["pt-br"].desc_elephant="Elephant";
W["pt-br"].desc_dolphin="Dolphin";W["pt-br"].desc_unnamed="Unnamed";W["pt-br"].desc_bee="Bee";W["pt-br"].desc_koi_pond="Koi Pond";W["pt-br"].desc_the_park="The Park";W["pt-br"].desc_pearl="Pearl";W["pt-br"].desc_tea_bag="Tea Bag";W["pt-br"].TutorialText_7="Each puzzle only has one solution, so don't guess.";W["pt-br"].TutorialTitle_7="Nono Cross";W["pt-br"].desc_coffee_bean="Coffee Bean";W["pt-br"].desc_frowney="Frowney";W["pt-br"].desc_smiley="Smiley";W["pt-br"].desc_koala="Koala";
W["pt-br"].desc_saturn="Saturn";W["pt-br"].desc_necklace="Necklace";W["pt-br"].desc_shrub="Shrub";W["pt-br"].desc_headphones="Headphones";W["pt-br"].desc_blue_tee="Blue Tee";W["pt-br"].desc_earring="Earring";W["pt-br"].desc_lipstick="Lipstick";W["pt-br"].desc_tv="TV";W["pt-br"].desc_hamburger="Hamburger";W["pt-br"].desc_egg="Egg";W["pt-br"].desc_the_sun="The Sun";W["pt-br"].desc_candle="Candle";W["pt-br"].desc_flashlight="Flashlight";W["pt-br"].desc_a_well="A Well";W["pt-br"].desc_wave="Wave";
W["pt-br"].desc_ponytail="Ponytail";W["pt-br"].desc_icecream="Ice Cream";W["pt-br"].desc_pickle_jar="Pickle Jar";W["pt-br"].desc_stove="Stove";W["pt-br"].desc_grapes="Grapes";W["pt-br"].desc_mouse="Mouse";W["pt-br"].desc_loin="Loin";W["pt-br"].ui_level_text="Level";W["pt-br"].desc_rose="rose";W["pt-br"].desc_alpaca="alpaca";W["pt-br"].desc_desert="desert";W["pt-br"].desc_sheep="sheep";W["pt-br"].desc_alarm_clock="alarm clock";W["pt-br"].desc_fish_bowl="fish bowl";W["pt-br"].desc_paint_brush="paint brush";
W["pt-br"].desc_melon_slice="melon slice";W["pt-br"].desc_toadstool="toadstool";W["pt-br"].desc_choco_cake="choco cake";W["pt-br"].desc_swan="swan";W["pt-br"].desc_bicycle="bicycle";W["pt-br"].desc_buttered_toast="buttered toast";W["pt-br"].desc_purse="purse";W["pt-br"].desc_bed="bed";W["pt-br"].desc_tadpole="tadpole";W["pt-br"].desc_picture_book="picture book";W["pt-br"].desc_bear="bear";W["pt-br"].desc_traffic_light="traffic light";W["pt-br"].desc_campfire="campfire";W["pt-br"].desc_drinks="drinks";
W["pt-br"].desc_leaf="leaf";W["pt-br"]["desc_dragonfly "]="dragonfly ";W["pt-br"].desc_volcano="volcano";W["pt-br"].desc_coral="coral";W["pt-br"].desc_bracelet="bracelet";W["pt-br"]["desc_backpack "]="backpack ";W["pt-br"].desc_orca="orca";W["pt-br"].desc_soup_pan="soup pan";W["pt-br"].desc_tent="tent";W["pt-br"].desc_choco_cookie="choco cookie";W["pt-br"].desc_magic_hat="magic hat";W["pt-br"]["desc_hand mirror"]="hand mirror";W["pt-br"].desc_waterfall="waterfall";W["pt-br"].desc_treasure_chest="treasure chest";
W["pt-br"].desc_chimney="chimney";W["pt-br"]["desc_salt_&_pepper"]="salt & pepper";W["pt-br"].desc_glasses="glasses";W["pt-br"].desc_lamp="lamp";W["pt-br"].desc_horse="horse";W["pt-br"].desc_golf="golf";W["pt-br"].desc_pizza="pizza";W["pt-br"].desc_rain="rain";W["pt-br"].desc_toaster="toaster";W["pt-br"].desc_cheese="cheese";W["pt-br"].desc_goat="goat";W["pt-br"].desc_ice_skate="ice skate";W["pt-br"].desc_microphone="microphone";W["pt-br"].desc_watering_can="watering can";
W["pt-br"].desc_space_shuttle="space shuttle";W["pt-br"].desc_door="door";W["pt-br"].desc_bubblegum="bubblegum";W["pt-br"].desc_shooting_star="shooting star";W["pt-br"].desc_winter="winter";W["pt-br"].desc_spring="spring";W["pt-br"].desc_summer="summer";W["pt-br"].desc_autumn="autumn";W["pt-br"].desc_sprinkled_donut="sprinkled donut";W["pt-br"].desc_santa="santa";W["pt-br"].desc_hedgehog="hedgehog";W["pt-br"].desc_clouds="clouds";W["pt-br"].desc_boot="boot";W["pt-br"].desc_scissors="scissors";
W["pt-br"].desc_chocolate_bar="chocolate bar";W["pt-br"].desc_magnifier="magnifier";W["pt-br"].desc_clothes_hanger="clothes hanger";W["pt-br"].desc_bowtie="bowtie";W["pt-br"].desc_flying_kite="flying kite";W["pt-br"].desc_beard="beard";W["pt-br"].desc_fountain="fountain";W["pt-br"].desc_crocodile="crocodile";W["pt-br"].desc_peas="peas";W["pt-br"].desc_tutu="tutu";W["pt-br"].desc_tornado="tornado";W["pt-br"].desc_balloon="balloon";W["pt-br"].desc_spades="spades";W["pt-br"].desc_paper_boat="paper boat";
W["pt-br"].desc_pencil="pencil";W["pt-br"].desc_phonograph="phonograph";W["pt-br"].desc_sea_shore="sea shore";W["pt-br"].desc_pelican="pelican";W["pt-br"].desc_seagull="seagull";W["pt-br"].desc_crab="crab";W["pt-br"].desc_diamonds="diamonds";W["pt-br"].desc_woods="woods";W["pt-br"].desc_camera="camera";W["pt-br"].desc_fishing_pole="fishing pole";W["pt-br"].desc_river_bed="river bed";W["pt-br"].desc_pants="pants";W["pt-br"].desc_rocket="rocket";W["pt-br"].desc_ambulance="ambulance";
W["pt-br"].desc_lighthouse="lighthouse";W["pt-br"].desc_nail_polish="nail polish";W["pt-br"].desc_clubs="clubs";W["pt-br"].desc_boiled_egg="boiled egg";W["pt-br"].desc_lantern="lantern";W["pt-br"].desc_thumbs_up="thumbs up";W["pt-br"].desc_rainbow="rainbow";W["es-es"]=W["es-es"]||{};W["es-es"].TutorialTitle_6="Nono Cross";W["es-es"].TutorialTitle_5="Nono Cross";W["es-es"].TutorialTitle_4="Nono Cross";W["es-es"].TutorialTitle_3="Nono Cross";W["es-es"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";
W["es-es"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["es-es"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";W["es-es"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["es-es"].levelStartText="LEVEL <VALUE> START";W["es-es"].TutorialTitle_0="Nono Cross";W["es-es"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";
W["es-es"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["es-es"].TutorialText_2="Around the level you will find clues on which cells to fill";W["es-es"].TutorialTitle_1="Nono Cross";W["es-es"].TutorialTitle_2="Nono Cross";W["es-es"].restartConfirmation="Are you sure you want to restart this level?";W["es-es"].restartCancelBtnText="Cancel";W["es-es"].restartConfirmBtnText="Confirm";W["es-es"].desc_rubber_ducky="Rubber Ducky";
W["es-es"].desc_butterfly="Butterfly";W["es-es"].desc_bell="Bell";W["es-es"].desc_telephone="Telephone";W["es-es"].desc_tomato="Tomato";W["es-es"].desc_key="Key";W["es-es"]["desc_gold fish"]="Gold Fish";W["es-es"].desc_coffee_cup="Coffee Cup";W["es-es"].desc_cherry="Cherry";W["es-es"].desc_puzzle_piece="Puzzle Piece";W["es-es"].desc_camel="Camel";W["es-es"].desc_guinea_pig="Guinea Pig";W["es-es"].desc_car="Car";W["es-es"].desc_smile="Smile";W["es-es"].desc_weight_lifting="Weight Lifting";
W["es-es"].desc_lollipop="Lollipop";W["es-es"].desc_bus="Bus";W["es-es"].desc_chair="Chair";W["es-es"].desc_frog="Frog";W["es-es"].desc_boat="Boat";W["es-es"].desc_flowers="Flowers";W["es-es"].desc_music_note="Music Note";W["es-es"].desc_tractor="Tractor";W["es-es"].desc_cow="Cow";W["es-es"].desc_snail="Snail";W["es-es"].desc_pear="Pear";W["es-es"].desc_tree="Tree";W["es-es"].desc_snake="Snake";W["es-es"].desc_duck="Duck";W["es-es"].desc_strawberry="Strawberry";W["es-es"].desc_squirrel="Squirrel";
W["es-es"].desc_plane="Plane";W["es-es"].desc_dog="Dog";W["es-es"].desc_city="City";W["es-es"].desc_mountains="Mountains";W["es-es"].desc_baseball="Baseball";W["es-es"].desc_sunflowers="Sunflowers";W["es-es"].desc_umbrella="Umbrella";W["es-es"].desc_arrow="Arrow";W["es-es"].desc_cactus="Cactus";W["es-es"].desc_cowboy_hat="Cowboy Hat";W["es-es"].desc_robin="Robin";W["es-es"].desc_chicken="Chicken";W["es-es"].desc_kettle="Kettle";W["es-es"].desc_faucet="Faucet";W["es-es"].desc_turnip="Turnip";
W["es-es"].desc_sword="Sword";W["es-es"].desc_the_moon="The Moon";W["es-es"].desc_banana="Banana";W["es-es"].desc_cat="Cat";W["es-es"].desc_shovel="Shovel";W["es-es"].desc_cellphone="Cellphone";W["es-es"].desc_carrot="Carrot";W["es-es"]["desc_?"]="?";W["es-es"].desc_sapling="Sapling";W["es-es"].desc_lion="Lion";W["es-es"].desc_sunset="Sunset";W["es-es"].desc_hippo="Hippo";W["es-es"].desc_apple="Apple";W["es-es"].desc_corn="Corn";W["es-es"].desc_bunny="Bunny";W["es-es"].desc_star="Star";
W["es-es"].desc_panda="Panda";W["es-es"].desc_heart="Heart";W["es-es"].desc_deer="Deer";W["es-es"].desc_computer="Computer";W["es-es"].desc_house="House";W["es-es"].desc_elephant="Elephant";W["es-es"].desc_dolphin="Dolphin";W["es-es"].desc_unnamed="Unnamed";W["es-es"].desc_bee="Bee";W["es-es"].desc_koi_pond="Koi Pond";W["es-es"].desc_the_park="The Park";W["es-es"].desc_pearl="Pearl";W["es-es"].desc_tea_bag="Tea Bag";W["es-es"].TutorialText_7="Each puzzle only has one solution, so don't guess.";
W["es-es"].TutorialTitle_7="Nono Cross";W["es-es"].desc_coffee_bean="Coffee Bean";W["es-es"].desc_frowney="Frowney";W["es-es"].desc_smiley="Smiley";W["es-es"].desc_koala="Koala";W["es-es"].desc_saturn="Saturn";W["es-es"].desc_necklace="Necklace";W["es-es"].desc_shrub="Shrub";W["es-es"].desc_headphones="Headphones";W["es-es"].desc_blue_tee="Blue Tee";W["es-es"].desc_earring="Earring";W["es-es"].desc_lipstick="Lipstick";W["es-es"].desc_tv="TV";W["es-es"].desc_hamburger="Hamburger";
W["es-es"].desc_egg="Egg";W["es-es"].desc_the_sun="The Sun";W["es-es"].desc_candle="Candle";W["es-es"].desc_flashlight="Flashlight";W["es-es"].desc_a_well="A Well";W["es-es"].desc_wave="Wave";W["es-es"].desc_ponytail="Ponytail";W["es-es"].desc_icecream="Ice Cream";W["es-es"].desc_pickle_jar="Pickle Jar";W["es-es"].desc_stove="Stove";W["es-es"].desc_grapes="Grapes";W["es-es"].desc_mouse="Mouse";W["es-es"].desc_loin="Loin";W["es-es"].ui_level_text="Level";W["es-es"].desc_rose="rose";
W["es-es"].desc_alpaca="alpaca";W["es-es"].desc_desert="desert";W["es-es"].desc_sheep="sheep";W["es-es"].desc_alarm_clock="alarm clock";W["es-es"].desc_fish_bowl="fish bowl";W["es-es"].desc_paint_brush="paint brush";W["es-es"].desc_melon_slice="melon slice";W["es-es"].desc_toadstool="toadstool";W["es-es"].desc_choco_cake="choco cake";W["es-es"].desc_swan="swan";W["es-es"].desc_bicycle="bicycle";W["es-es"].desc_buttered_toast="buttered toast";W["es-es"].desc_purse="purse";W["es-es"].desc_bed="bed";
W["es-es"].desc_tadpole="tadpole";W["es-es"].desc_picture_book="picture book";W["es-es"].desc_bear="bear";W["es-es"].desc_traffic_light="traffic light";W["es-es"].desc_campfire="campfire";W["es-es"].desc_drinks="drinks";W["es-es"].desc_leaf="leaf";W["es-es"]["desc_dragonfly "]="dragonfly ";W["es-es"].desc_volcano="volcano";W["es-es"].desc_coral="coral";W["es-es"].desc_bracelet="bracelet";W["es-es"]["desc_backpack "]="backpack ";W["es-es"].desc_orca="orca";W["es-es"].desc_soup_pan="soup pan";
W["es-es"].desc_tent="tent";W["es-es"].desc_choco_cookie="choco cookie";W["es-es"].desc_magic_hat="magic hat";W["es-es"]["desc_hand mirror"]="hand mirror";W["es-es"].desc_waterfall="waterfall";W["es-es"].desc_treasure_chest="treasure chest";W["es-es"].desc_chimney="chimney";W["es-es"]["desc_salt_&_pepper"]="salt & pepper";W["es-es"].desc_glasses="glasses";W["es-es"].desc_lamp="lamp";W["es-es"].desc_horse="horse";W["es-es"].desc_golf="golf";W["es-es"].desc_pizza="pizza";W["es-es"].desc_rain="rain";
W["es-es"].desc_toaster="toaster";W["es-es"].desc_cheese="cheese";W["es-es"].desc_goat="goat";W["es-es"].desc_ice_skate="ice skate";W["es-es"].desc_microphone="microphone";W["es-es"].desc_watering_can="watering can";W["es-es"].desc_space_shuttle="space shuttle";W["es-es"].desc_door="door";W["es-es"].desc_bubblegum="bubblegum";W["es-es"].desc_shooting_star="shooting star";W["es-es"].desc_winter="winter";W["es-es"].desc_spring="spring";W["es-es"].desc_summer="summer";W["es-es"].desc_autumn="autumn";
W["es-es"].desc_sprinkled_donut="sprinkled donut";W["es-es"].desc_santa="santa";W["es-es"].desc_hedgehog="hedgehog";W["es-es"].desc_clouds="clouds";W["es-es"].desc_boot="boot";W["es-es"].desc_scissors="scissors";W["es-es"].desc_chocolate_bar="chocolate bar";W["es-es"].desc_magnifier="magnifier";W["es-es"].desc_clothes_hanger="clothes hanger";W["es-es"].desc_bowtie="bowtie";W["es-es"].desc_flying_kite="flying kite";W["es-es"].desc_beard="beard";W["es-es"].desc_fountain="fountain";
W["es-es"].desc_crocodile="crocodile";W["es-es"].desc_peas="peas";W["es-es"].desc_tutu="tutu";W["es-es"].desc_tornado="tornado";W["es-es"].desc_balloon="balloon";W["es-es"].desc_spades="spades";W["es-es"].desc_paper_boat="paper boat";W["es-es"].desc_pencil="pencil";W["es-es"].desc_phonograph="phonograph";W["es-es"].desc_sea_shore="sea shore";W["es-es"].desc_pelican="pelican";W["es-es"].desc_seagull="seagull";W["es-es"].desc_crab="crab";W["es-es"].desc_diamonds="diamonds";W["es-es"].desc_woods="woods";
W["es-es"].desc_camera="camera";W["es-es"].desc_fishing_pole="fishing pole";W["es-es"].desc_river_bed="river bed";W["es-es"].desc_pants="pants";W["es-es"].desc_rocket="rocket";W["es-es"].desc_ambulance="ambulance";W["es-es"].desc_lighthouse="lighthouse";W["es-es"].desc_nail_polish="nail polish";W["es-es"].desc_clubs="clubs";W["es-es"].desc_boiled_egg="boiled egg";W["es-es"].desc_lantern="lantern";W["es-es"].desc_thumbs_up="thumbs up";W["es-es"].desc_rainbow="rainbow";W["tr-tr"]=W["tr-tr"]||{};
W["tr-tr"].TutorialTitle_6="Nono Cross";W["tr-tr"].TutorialTitle_5="Nono Cross";W["tr-tr"].TutorialTitle_4="Nono Cross";W["tr-tr"].TutorialTitle_3="Nono Cross";W["tr-tr"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";W["tr-tr"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["tr-tr"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";
W["tr-tr"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["tr-tr"].levelStartText="LEVEL <VALUE> START";W["tr-tr"].TutorialTitle_0="Nono Cross";W["tr-tr"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";W["tr-tr"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["tr-tr"].TutorialText_2="Around the level you will find clues on which cells to fill";
W["tr-tr"].TutorialTitle_1="Nono Cross";W["tr-tr"].TutorialTitle_2="Nono Cross";W["tr-tr"].restartConfirmation="Are you sure you want to restart this level?";W["tr-tr"].restartCancelBtnText="Cancel";W["tr-tr"].restartConfirmBtnText="Confirm";W["tr-tr"].desc_rubber_ducky="Rubber Ducky";W["tr-tr"].desc_butterfly="Butterfly";W["tr-tr"].desc_bell="Bell";W["tr-tr"].desc_telephone="Telephone";W["tr-tr"].desc_tomato="Tomato";W["tr-tr"].desc_key="Key";W["tr-tr"]["desc_gold fish"]="Gold Fish";
W["tr-tr"].desc_coffee_cup="Coffee Cup";W["tr-tr"].desc_cherry="Cherry";W["tr-tr"].desc_puzzle_piece="Puzzle Piece";W["tr-tr"].desc_camel="Camel";W["tr-tr"].desc_guinea_pig="Guinea Pig";W["tr-tr"].desc_car="Car";W["tr-tr"].desc_smile="Smile";W["tr-tr"].desc_weight_lifting="Weight Lifting";W["tr-tr"].desc_lollipop="Lollipop";W["tr-tr"].desc_bus="Bus";W["tr-tr"].desc_chair="Chair";W["tr-tr"].desc_frog="Frog";W["tr-tr"].desc_boat="Boat";W["tr-tr"].desc_flowers="Flowers";W["tr-tr"].desc_music_note="Music Note";
W["tr-tr"].desc_tractor="Tractor";W["tr-tr"].desc_cow="Cow";W["tr-tr"].desc_snail="Snail";W["tr-tr"].desc_pear="Pear";W["tr-tr"].desc_tree="Tree";W["tr-tr"].desc_snake="Snake";W["tr-tr"].desc_duck="Duck";W["tr-tr"].desc_strawberry="Strawberry";W["tr-tr"].desc_squirrel="Squirrel";W["tr-tr"].desc_plane="Plane";W["tr-tr"].desc_dog="Dog";W["tr-tr"].desc_city="City";W["tr-tr"].desc_mountains="Mountains";W["tr-tr"].desc_baseball="Baseball";W["tr-tr"].desc_sunflowers="Sunflowers";
W["tr-tr"].desc_umbrella="Umbrella";W["tr-tr"].desc_arrow="Arrow";W["tr-tr"].desc_cactus="Cactus";W["tr-tr"].desc_cowboy_hat="Cowboy Hat";W["tr-tr"].desc_robin="Robin";W["tr-tr"].desc_chicken="Chicken";W["tr-tr"].desc_kettle="Kettle";W["tr-tr"].desc_faucet="Faucet";W["tr-tr"].desc_turnip="Turnip";W["tr-tr"].desc_sword="Sword";W["tr-tr"].desc_the_moon="The Moon";W["tr-tr"].desc_banana="Banana";W["tr-tr"].desc_cat="Cat";W["tr-tr"].desc_shovel="Shovel";W["tr-tr"].desc_cellphone="Cellphone";
W["tr-tr"].desc_carrot="Carrot";W["tr-tr"]["desc_?"]="?";W["tr-tr"].desc_sapling="Sapling";W["tr-tr"].desc_lion="Lion";W["tr-tr"].desc_sunset="Sunset";W["tr-tr"].desc_hippo="Hippo";W["tr-tr"].desc_apple="Apple";W["tr-tr"].desc_corn="Corn";W["tr-tr"].desc_bunny="Bunny";W["tr-tr"].desc_star="Star";W["tr-tr"].desc_panda="Panda";W["tr-tr"].desc_heart="Heart";W["tr-tr"].desc_deer="Deer";W["tr-tr"].desc_computer="Computer";W["tr-tr"].desc_house="House";W["tr-tr"].desc_elephant="Elephant";
W["tr-tr"].desc_dolphin="Dolphin";W["tr-tr"].desc_unnamed="Unnamed";W["tr-tr"].desc_bee="Bee";W["tr-tr"].desc_koi_pond="Koi Pond";W["tr-tr"].desc_the_park="The Park";W["tr-tr"].desc_pearl="Pearl";W["tr-tr"].desc_tea_bag="Tea Bag";W["tr-tr"].TutorialText_7="Each puzzle only has one solution, so don't guess.";W["tr-tr"].TutorialTitle_7="Nono Cross";W["tr-tr"].desc_coffee_bean="Coffee Bean";W["tr-tr"].desc_frowney="Frowney";W["tr-tr"].desc_smiley="Smiley";W["tr-tr"].desc_koala="Koala";
W["tr-tr"].desc_saturn="Saturn";W["tr-tr"].desc_necklace="Necklace";W["tr-tr"].desc_shrub="Shrub";W["tr-tr"].desc_headphones="Headphones";W["tr-tr"].desc_blue_tee="Blue Tee";W["tr-tr"].desc_earring="Earring";W["tr-tr"].desc_lipstick="Lipstick";W["tr-tr"].desc_tv="TV";W["tr-tr"].desc_hamburger="Hamburger";W["tr-tr"].desc_egg="Egg";W["tr-tr"].desc_the_sun="The Sun";W["tr-tr"].desc_candle="Candle";W["tr-tr"].desc_flashlight="Flashlight";W["tr-tr"].desc_a_well="A Well";W["tr-tr"].desc_wave="Wave";
W["tr-tr"].desc_ponytail="Ponytail";W["tr-tr"].desc_icecream="Ice Cream";W["tr-tr"].desc_pickle_jar="Pickle Jar";W["tr-tr"].desc_stove="Stove";W["tr-tr"].desc_grapes="Grapes";W["tr-tr"].desc_mouse="Mouse";W["tr-tr"].desc_loin="Loin";W["tr-tr"].ui_level_text="Level";W["tr-tr"].desc_rose="rose";W["tr-tr"].desc_alpaca="alpaca";W["tr-tr"].desc_desert="desert";W["tr-tr"].desc_sheep="sheep";W["tr-tr"].desc_alarm_clock="alarm clock";W["tr-tr"].desc_fish_bowl="fish bowl";W["tr-tr"].desc_paint_brush="paint brush";
W["tr-tr"].desc_melon_slice="melon slice";W["tr-tr"].desc_toadstool="toadstool";W["tr-tr"].desc_choco_cake="choco cake";W["tr-tr"].desc_swan="swan";W["tr-tr"].desc_bicycle="bicycle";W["tr-tr"].desc_buttered_toast="buttered toast";W["tr-tr"].desc_purse="purse";W["tr-tr"].desc_bed="bed";W["tr-tr"].desc_tadpole="tadpole";W["tr-tr"].desc_picture_book="picture book";W["tr-tr"].desc_bear="bear";W["tr-tr"].desc_traffic_light="traffic light";W["tr-tr"].desc_campfire="campfire";W["tr-tr"].desc_drinks="drinks";
W["tr-tr"].desc_leaf="leaf";W["tr-tr"]["desc_dragonfly "]="dragonfly ";W["tr-tr"].desc_volcano="volcano";W["tr-tr"].desc_coral="coral";W["tr-tr"].desc_bracelet="bracelet";W["tr-tr"]["desc_backpack "]="backpack ";W["tr-tr"].desc_orca="orca";W["tr-tr"].desc_soup_pan="soup pan";W["tr-tr"].desc_tent="tent";W["tr-tr"].desc_choco_cookie="choco cookie";W["tr-tr"].desc_magic_hat="magic hat";W["tr-tr"]["desc_hand mirror"]="hand mirror";W["tr-tr"].desc_waterfall="waterfall";W["tr-tr"].desc_treasure_chest="treasure chest";
W["tr-tr"].desc_chimney="chimney";W["tr-tr"]["desc_salt_&_pepper"]="salt & pepper";W["tr-tr"].desc_glasses="glasses";W["tr-tr"].desc_lamp="lamp";W["tr-tr"].desc_horse="horse";W["tr-tr"].desc_golf="golf";W["tr-tr"].desc_pizza="pizza";W["tr-tr"].desc_rain="rain";W["tr-tr"].desc_toaster="toaster";W["tr-tr"].desc_cheese="cheese";W["tr-tr"].desc_goat="goat";W["tr-tr"].desc_ice_skate="ice skate";W["tr-tr"].desc_microphone="microphone";W["tr-tr"].desc_watering_can="watering can";
W["tr-tr"].desc_space_shuttle="space shuttle";W["tr-tr"].desc_door="door";W["tr-tr"].desc_bubblegum="bubblegum";W["tr-tr"].desc_shooting_star="shooting star";W["tr-tr"].desc_winter="winter";W["tr-tr"].desc_spring="spring";W["tr-tr"].desc_summer="summer";W["tr-tr"].desc_autumn="autumn";W["tr-tr"].desc_sprinkled_donut="sprinkled donut";W["tr-tr"].desc_santa="santa";W["tr-tr"].desc_hedgehog="hedgehog";W["tr-tr"].desc_clouds="clouds";W["tr-tr"].desc_boot="boot";W["tr-tr"].desc_scissors="scissors";
W["tr-tr"].desc_chocolate_bar="chocolate bar";W["tr-tr"].desc_magnifier="magnifier";W["tr-tr"].desc_clothes_hanger="clothes hanger";W["tr-tr"].desc_bowtie="bowtie";W["tr-tr"].desc_flying_kite="flying kite";W["tr-tr"].desc_beard="beard";W["tr-tr"].desc_fountain="fountain";W["tr-tr"].desc_crocodile="crocodile";W["tr-tr"].desc_peas="peas";W["tr-tr"].desc_tutu="tutu";W["tr-tr"].desc_tornado="tornado";W["tr-tr"].desc_balloon="balloon";W["tr-tr"].desc_spades="spades";W["tr-tr"].desc_paper_boat="paper boat";
W["tr-tr"].desc_pencil="pencil";W["tr-tr"].desc_phonograph="phonograph";W["tr-tr"].desc_sea_shore="sea shore";W["tr-tr"].desc_pelican="pelican";W["tr-tr"].desc_seagull="seagull";W["tr-tr"].desc_crab="crab";W["tr-tr"].desc_diamonds="diamonds";W["tr-tr"].desc_woods="woods";W["tr-tr"].desc_camera="camera";W["tr-tr"].desc_fishing_pole="fishing pole";W["tr-tr"].desc_river_bed="river bed";W["tr-tr"].desc_pants="pants";W["tr-tr"].desc_rocket="rocket";W["tr-tr"].desc_ambulance="ambulance";
W["tr-tr"].desc_lighthouse="lighthouse";W["tr-tr"].desc_nail_polish="nail polish";W["tr-tr"].desc_clubs="clubs";W["tr-tr"].desc_boiled_egg="boiled egg";W["tr-tr"].desc_lantern="lantern";W["tr-tr"].desc_thumbs_up="thumbs up";W["tr-tr"].desc_rainbow="rainbow";W["ru-ru"]=W["ru-ru"]||{};W["ru-ru"].TutorialTitle_6="Nono Cross";W["ru-ru"].TutorialTitle_5="Nono Cross";W["ru-ru"].TutorialTitle_4="Nono Cross";W["ru-ru"].TutorialTitle_3="Nono Cross";W["ru-ru"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";
W["ru-ru"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["ru-ru"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";W["ru-ru"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["ru-ru"].levelStartText="LEVEL <VALUE> START";W["ru-ru"].TutorialTitle_0="Nono Cross";W["ru-ru"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";
W["ru-ru"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["ru-ru"].TutorialText_2="Around the level you will find clues on which cells to fill";W["ru-ru"].TutorialTitle_1="Nono Cross";W["ru-ru"].TutorialTitle_2="Nono Cross";W["ru-ru"].restartConfirmation="Are you sure you want to restart this level?";W["ru-ru"].restartCancelBtnText="Cancel";W["ru-ru"].restartConfirmBtnText="Confirm";W["ru-ru"].desc_rubber_ducky="Rubber Ducky";
W["ru-ru"].desc_butterfly="Butterfly";W["ru-ru"].desc_bell="Bell";W["ru-ru"].desc_telephone="Telephone";W["ru-ru"].desc_tomato="Tomato";W["ru-ru"].desc_key="Key";W["ru-ru"]["desc_gold fish"]="Gold Fish";W["ru-ru"].desc_coffee_cup="Coffee Cup";W["ru-ru"].desc_cherry="Cherry";W["ru-ru"].desc_puzzle_piece="Puzzle Piece";W["ru-ru"].desc_camel="Camel";W["ru-ru"].desc_guinea_pig="Guinea Pig";W["ru-ru"].desc_car="Car";W["ru-ru"].desc_smile="Smile";W["ru-ru"].desc_weight_lifting="Weight Lifting";
W["ru-ru"].desc_lollipop="Lollipop";W["ru-ru"].desc_bus="Bus";W["ru-ru"].desc_chair="Chair";W["ru-ru"].desc_frog="Frog";W["ru-ru"].desc_boat="Boat";W["ru-ru"].desc_flowers="Flowers";W["ru-ru"].desc_music_note="Music Note";W["ru-ru"].desc_tractor="Tractor";W["ru-ru"].desc_cow="Cow";W["ru-ru"].desc_snail="Snail";W["ru-ru"].desc_pear="Pear";W["ru-ru"].desc_tree="Tree";W["ru-ru"].desc_snake="Snake";W["ru-ru"].desc_duck="Duck";W["ru-ru"].desc_strawberry="Strawberry";W["ru-ru"].desc_squirrel="Squirrel";
W["ru-ru"].desc_plane="Plane";W["ru-ru"].desc_dog="Dog";W["ru-ru"].desc_city="City";W["ru-ru"].desc_mountains="Mountains";W["ru-ru"].desc_baseball="Baseball";W["ru-ru"].desc_sunflowers="Sunflowers";W["ru-ru"].desc_umbrella="Umbrella";W["ru-ru"].desc_arrow="Arrow";W["ru-ru"].desc_cactus="Cactus";W["ru-ru"].desc_cowboy_hat="Cowboy Hat";W["ru-ru"].desc_robin="Robin";W["ru-ru"].desc_chicken="Chicken";W["ru-ru"].desc_kettle="Kettle";W["ru-ru"].desc_faucet="Faucet";W["ru-ru"].desc_turnip="Turnip";
W["ru-ru"].desc_sword="Sword";W["ru-ru"].desc_the_moon="The Moon";W["ru-ru"].desc_banana="Banana";W["ru-ru"].desc_cat="Cat";W["ru-ru"].desc_shovel="Shovel";W["ru-ru"].desc_cellphone="Cellphone";W["ru-ru"].desc_carrot="Carrot";W["ru-ru"]["desc_?"]="?";W["ru-ru"].desc_sapling="Sapling";W["ru-ru"].desc_lion="Lion";W["ru-ru"].desc_sunset="Sunset";W["ru-ru"].desc_hippo="Hippo";W["ru-ru"].desc_apple="Apple";W["ru-ru"].desc_corn="Corn";W["ru-ru"].desc_bunny="Bunny";W["ru-ru"].desc_star="Star";
W["ru-ru"].desc_panda="Panda";W["ru-ru"].desc_heart="Heart";W["ru-ru"].desc_deer="Deer";W["ru-ru"].desc_computer="Computer";W["ru-ru"].desc_house="House";W["ru-ru"].desc_elephant="Elephant";W["ru-ru"].desc_dolphin="Dolphin";W["ru-ru"].desc_unnamed="Unnamed";W["ru-ru"].desc_bee="Bee";W["ru-ru"].desc_koi_pond="Koi Pond";W["ru-ru"].desc_the_park="The Park";W["ru-ru"].desc_pearl="Pearl";W["ru-ru"].desc_tea_bag="Tea Bag";W["ru-ru"].TutorialText_7="Each puzzle only has one solution, so don't guess.";
W["ru-ru"].TutorialTitle_7="Nono Cross";W["ru-ru"].desc_coffee_bean="Coffee Bean";W["ru-ru"].desc_frowney="Frowney";W["ru-ru"].desc_smiley="Smiley";W["ru-ru"].desc_koala="Koala";W["ru-ru"].desc_saturn="Saturn";W["ru-ru"].desc_necklace="Necklace";W["ru-ru"].desc_shrub="Shrub";W["ru-ru"].desc_headphones="Headphones";W["ru-ru"].desc_blue_tee="Blue Tee";W["ru-ru"].desc_earring="Earring";W["ru-ru"].desc_lipstick="Lipstick";W["ru-ru"].desc_tv="TV";W["ru-ru"].desc_hamburger="Hamburger";
W["ru-ru"].desc_egg="Egg";W["ru-ru"].desc_the_sun="The Sun";W["ru-ru"].desc_candle="Candle";W["ru-ru"].desc_flashlight="Flashlight";W["ru-ru"].desc_a_well="A Well";W["ru-ru"].desc_wave="Wave";W["ru-ru"].desc_ponytail="Ponytail";W["ru-ru"].desc_icecream="Ice Cream";W["ru-ru"].desc_pickle_jar="Pickle Jar";W["ru-ru"].desc_stove="Stove";W["ru-ru"].desc_grapes="Grapes";W["ru-ru"].desc_mouse="Mouse";W["ru-ru"].desc_loin="Loin";W["ru-ru"].ui_level_text="Level";W["ru-ru"].desc_rose="rose";
W["ru-ru"].desc_alpaca="alpaca";W["ru-ru"].desc_desert="desert";W["ru-ru"].desc_sheep="sheep";W["ru-ru"].desc_alarm_clock="alarm clock";W["ru-ru"].desc_fish_bowl="fish bowl";W["ru-ru"].desc_paint_brush="paint brush";W["ru-ru"].desc_melon_slice="melon slice";W["ru-ru"].desc_toadstool="toadstool";W["ru-ru"].desc_choco_cake="choco cake";W["ru-ru"].desc_swan="swan";W["ru-ru"].desc_bicycle="bicycle";W["ru-ru"].desc_buttered_toast="buttered toast";W["ru-ru"].desc_purse="purse";W["ru-ru"].desc_bed="bed";
W["ru-ru"].desc_tadpole="tadpole";W["ru-ru"].desc_picture_book="picture book";W["ru-ru"].desc_bear="bear";W["ru-ru"].desc_traffic_light="traffic light";W["ru-ru"].desc_campfire="campfire";W["ru-ru"].desc_drinks="drinks";W["ru-ru"].desc_leaf="leaf";W["ru-ru"]["desc_dragonfly "]="dragonfly ";W["ru-ru"].desc_volcano="volcano";W["ru-ru"].desc_coral="coral";W["ru-ru"].desc_bracelet="bracelet";W["ru-ru"]["desc_backpack "]="backpack ";W["ru-ru"].desc_orca="orca";W["ru-ru"].desc_soup_pan="soup pan";
W["ru-ru"].desc_tent="tent";W["ru-ru"].desc_choco_cookie="choco cookie";W["ru-ru"].desc_magic_hat="magic hat";W["ru-ru"]["desc_hand mirror"]="hand mirror";W["ru-ru"].desc_waterfall="waterfall";W["ru-ru"].desc_treasure_chest="treasure chest";W["ru-ru"].desc_chimney="chimney";W["ru-ru"]["desc_salt_&_pepper"]="salt & pepper";W["ru-ru"].desc_glasses="glasses";W["ru-ru"].desc_lamp="lamp";W["ru-ru"].desc_horse="horse";W["ru-ru"].desc_golf="golf";W["ru-ru"].desc_pizza="pizza";W["ru-ru"].desc_rain="rain";
W["ru-ru"].desc_toaster="toaster";W["ru-ru"].desc_cheese="cheese";W["ru-ru"].desc_goat="goat";W["ru-ru"].desc_ice_skate="ice skate";W["ru-ru"].desc_microphone="microphone";W["ru-ru"].desc_watering_can="watering can";W["ru-ru"].desc_space_shuttle="space shuttle";W["ru-ru"].desc_door="door";W["ru-ru"].desc_bubblegum="bubblegum";W["ru-ru"].desc_shooting_star="shooting star";W["ru-ru"].desc_winter="winter";W["ru-ru"].desc_spring="spring";W["ru-ru"].desc_summer="summer";W["ru-ru"].desc_autumn="autumn";
W["ru-ru"].desc_sprinkled_donut="sprinkled donut";W["ru-ru"].desc_santa="santa";W["ru-ru"].desc_hedgehog="hedgehog";W["ru-ru"].desc_clouds="clouds";W["ru-ru"].desc_boot="boot";W["ru-ru"].desc_scissors="scissors";W["ru-ru"].desc_chocolate_bar="chocolate bar";W["ru-ru"].desc_magnifier="magnifier";W["ru-ru"].desc_clothes_hanger="clothes hanger";W["ru-ru"].desc_bowtie="bowtie";W["ru-ru"].desc_flying_kite="flying kite";W["ru-ru"].desc_beard="beard";W["ru-ru"].desc_fountain="fountain";
W["ru-ru"].desc_crocodile="crocodile";W["ru-ru"].desc_peas="peas";W["ru-ru"].desc_tutu="tutu";W["ru-ru"].desc_tornado="tornado";W["ru-ru"].desc_balloon="balloon";W["ru-ru"].desc_spades="spades";W["ru-ru"].desc_paper_boat="paper boat";W["ru-ru"].desc_pencil="pencil";W["ru-ru"].desc_phonograph="phonograph";W["ru-ru"].desc_sea_shore="sea shore";W["ru-ru"].desc_pelican="pelican";W["ru-ru"].desc_seagull="seagull";W["ru-ru"].desc_crab="crab";W["ru-ru"].desc_diamonds="diamonds";W["ru-ru"].desc_woods="woods";
W["ru-ru"].desc_camera="camera";W["ru-ru"].desc_fishing_pole="fishing pole";W["ru-ru"].desc_river_bed="river bed";W["ru-ru"].desc_pants="pants";W["ru-ru"].desc_rocket="rocket";W["ru-ru"].desc_ambulance="ambulance";W["ru-ru"].desc_lighthouse="lighthouse";W["ru-ru"].desc_nail_polish="nail polish";W["ru-ru"].desc_clubs="clubs";W["ru-ru"].desc_boiled_egg="boiled egg";W["ru-ru"].desc_lantern="lantern";W["ru-ru"].desc_thumbs_up="thumbs up";W["ru-ru"].desc_rainbow="rainbow";W["ar-eg"]=W["ar-eg"]||{};
W["ar-eg"].TutorialTitle_6="Nono Cross";W["ar-eg"].TutorialTitle_5="Nono Cross";W["ar-eg"].TutorialTitle_4="Nono Cross";W["ar-eg"].TutorialTitle_3="Nono Cross";W["ar-eg"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";W["ar-eg"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["ar-eg"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";
W["ar-eg"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["ar-eg"].levelStartText="LEVEL <VALUE> START";W["ar-eg"].TutorialTitle_0="Nono Cross";W["ar-eg"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";W["ar-eg"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["ar-eg"].TutorialText_2="Around the level you will find clues on which cells to fill";
W["ar-eg"].TutorialTitle_1="Nono Cross";W["ar-eg"].TutorialTitle_2="Nono Cross";W["ar-eg"].restartConfirmation="Are you sure you want to restart this level?";W["ar-eg"].restartCancelBtnText="Cancel";W["ar-eg"].restartConfirmBtnText="Confirm";W["ar-eg"].desc_rubber_ducky="Rubber Ducky";W["ar-eg"].desc_butterfly="Butterfly";W["ar-eg"].desc_bell="Bell";W["ar-eg"].desc_telephone="Telephone";W["ar-eg"].desc_tomato="Tomato";W["ar-eg"].desc_key="Key";W["ar-eg"]["desc_gold fish"]="Gold Fish";
W["ar-eg"].desc_coffee_cup="Coffee Cup";W["ar-eg"].desc_cherry="Cherry";W["ar-eg"].desc_puzzle_piece="Puzzle Piece";W["ar-eg"].desc_camel="Camel";W["ar-eg"].desc_guinea_pig="Guinea Pig";W["ar-eg"].desc_car="Car";W["ar-eg"].desc_smile="Smile";W["ar-eg"].desc_weight_lifting="Weight Lifting";W["ar-eg"].desc_lollipop="Lollipop";W["ar-eg"].desc_bus="Bus";W["ar-eg"].desc_chair="Chair";W["ar-eg"].desc_frog="Frog";W["ar-eg"].desc_boat="Boat";W["ar-eg"].desc_flowers="Flowers";W["ar-eg"].desc_music_note="Music Note";
W["ar-eg"].desc_tractor="Tractor";W["ar-eg"].desc_cow="Cow";W["ar-eg"].desc_snail="Snail";W["ar-eg"].desc_pear="Pear";W["ar-eg"].desc_tree="Tree";W["ar-eg"].desc_snake="Snake";W["ar-eg"].desc_duck="Duck";W["ar-eg"].desc_strawberry="Strawberry";W["ar-eg"].desc_squirrel="Squirrel";W["ar-eg"].desc_plane="Plane";W["ar-eg"].desc_dog="Dog";W["ar-eg"].desc_city="City";W["ar-eg"].desc_mountains="Mountains";W["ar-eg"].desc_baseball="Baseball";W["ar-eg"].desc_sunflowers="Sunflowers";
W["ar-eg"].desc_umbrella="Umbrella";W["ar-eg"].desc_arrow="Arrow";W["ar-eg"].desc_cactus="Cactus";W["ar-eg"].desc_cowboy_hat="Cowboy Hat";W["ar-eg"].desc_robin="Robin";W["ar-eg"].desc_chicken="Chicken";W["ar-eg"].desc_kettle="Kettle";W["ar-eg"].desc_faucet="Faucet";W["ar-eg"].desc_turnip="Turnip";W["ar-eg"].desc_sword="Sword";W["ar-eg"].desc_the_moon="The Moon";W["ar-eg"].desc_banana="Banana";W["ar-eg"].desc_cat="Cat";W["ar-eg"].desc_shovel="Shovel";W["ar-eg"].desc_cellphone="Cellphone";
W["ar-eg"].desc_carrot="Carrot";W["ar-eg"]["desc_?"]="?";W["ar-eg"].desc_sapling="Sapling";W["ar-eg"].desc_lion="Lion";W["ar-eg"].desc_sunset="Sunset";W["ar-eg"].desc_hippo="Hippo";W["ar-eg"].desc_apple="Apple";W["ar-eg"].desc_corn="Corn";W["ar-eg"].desc_bunny="Bunny";W["ar-eg"].desc_star="Star";W["ar-eg"].desc_panda="Panda";W["ar-eg"].desc_heart="Heart";W["ar-eg"].desc_deer="Deer";W["ar-eg"].desc_computer="Computer";W["ar-eg"].desc_house="House";W["ar-eg"].desc_elephant="Elephant";
W["ar-eg"].desc_dolphin="Dolphin";W["ar-eg"].desc_unnamed="Unnamed";W["ar-eg"].desc_bee="Bee";W["ar-eg"].desc_koi_pond="Koi Pond";W["ar-eg"].desc_the_park="The Park";W["ar-eg"].desc_pearl="Pearl";W["ar-eg"].desc_tea_bag="Tea Bag";W["ar-eg"].TutorialText_7="Each puzzle only has one solution, so don't guess.";W["ar-eg"].TutorialTitle_7="Nono Cross";W["ar-eg"].desc_coffee_bean="Coffee Bean";W["ar-eg"].desc_frowney="Frowney";W["ar-eg"].desc_smiley="Smiley";W["ar-eg"].desc_koala="Koala";
W["ar-eg"].desc_saturn="Saturn";W["ar-eg"].desc_necklace="Necklace";W["ar-eg"].desc_shrub="Shrub";W["ar-eg"].desc_headphones="Headphones";W["ar-eg"].desc_blue_tee="Blue Tee";W["ar-eg"].desc_earring="Earring";W["ar-eg"].desc_lipstick="Lipstick";W["ar-eg"].desc_tv="TV";W["ar-eg"].desc_hamburger="Hamburger";W["ar-eg"].desc_egg="Egg";W["ar-eg"].desc_the_sun="The Sun";W["ar-eg"].desc_candle="Candle";W["ar-eg"].desc_flashlight="Flashlight";W["ar-eg"].desc_a_well="A Well";W["ar-eg"].desc_wave="Wave";
W["ar-eg"].desc_ponytail="Ponytail";W["ar-eg"].desc_icecream="Ice Cream";W["ar-eg"].desc_pickle_jar="Pickle Jar";W["ar-eg"].desc_stove="Stove";W["ar-eg"].desc_grapes="Grapes";W["ar-eg"].desc_mouse="Mouse";W["ar-eg"].desc_loin="Loin";W["ar-eg"].ui_level_text="Level";W["ar-eg"].desc_rose="rose";W["ar-eg"].desc_alpaca="alpaca";W["ar-eg"].desc_desert="desert";W["ar-eg"].desc_sheep="sheep";W["ar-eg"].desc_alarm_clock="alarm clock";W["ar-eg"].desc_fish_bowl="fish bowl";W["ar-eg"].desc_paint_brush="paint brush";
W["ar-eg"].desc_melon_slice="melon slice";W["ar-eg"].desc_toadstool="toadstool";W["ar-eg"].desc_choco_cake="choco cake";W["ar-eg"].desc_swan="swan";W["ar-eg"].desc_bicycle="bicycle";W["ar-eg"].desc_buttered_toast="buttered toast";W["ar-eg"].desc_purse="purse";W["ar-eg"].desc_bed="bed";W["ar-eg"].desc_tadpole="tadpole";W["ar-eg"].desc_picture_book="picture book";W["ar-eg"].desc_bear="bear";W["ar-eg"].desc_traffic_light="traffic light";W["ar-eg"].desc_campfire="campfire";W["ar-eg"].desc_drinks="drinks";
W["ar-eg"].desc_leaf="leaf";W["ar-eg"]["desc_dragonfly "]="dragonfly ";W["ar-eg"].desc_volcano="volcano";W["ar-eg"].desc_coral="coral";W["ar-eg"].desc_bracelet="bracelet";W["ar-eg"]["desc_backpack "]="backpack ";W["ar-eg"].desc_orca="orca";W["ar-eg"].desc_soup_pan="soup pan";W["ar-eg"].desc_tent="tent";W["ar-eg"].desc_choco_cookie="choco cookie";W["ar-eg"].desc_magic_hat="magic hat";W["ar-eg"]["desc_hand mirror"]="hand mirror";W["ar-eg"].desc_waterfall="waterfall";W["ar-eg"].desc_treasure_chest="treasure chest";
W["ar-eg"].desc_chimney="chimney";W["ar-eg"]["desc_salt_&_pepper"]="salt & pepper";W["ar-eg"].desc_glasses="glasses";W["ar-eg"].desc_lamp="lamp";W["ar-eg"].desc_horse="horse";W["ar-eg"].desc_golf="golf";W["ar-eg"].desc_pizza="pizza";W["ar-eg"].desc_rain="rain";W["ar-eg"].desc_toaster="toaster";W["ar-eg"].desc_cheese="cheese";W["ar-eg"].desc_goat="goat";W["ar-eg"].desc_ice_skate="ice skate";W["ar-eg"].desc_microphone="microphone";W["ar-eg"].desc_watering_can="watering can";
W["ar-eg"].desc_space_shuttle="space shuttle";W["ar-eg"].desc_door="door";W["ar-eg"].desc_bubblegum="bubblegum";W["ar-eg"].desc_shooting_star="shooting star";W["ar-eg"].desc_winter="winter";W["ar-eg"].desc_spring="spring";W["ar-eg"].desc_summer="summer";W["ar-eg"].desc_autumn="autumn";W["ar-eg"].desc_sprinkled_donut="sprinkled donut";W["ar-eg"].desc_santa="santa";W["ar-eg"].desc_hedgehog="hedgehog";W["ar-eg"].desc_clouds="clouds";W["ar-eg"].desc_boot="boot";W["ar-eg"].desc_scissors="scissors";
W["ar-eg"].desc_chocolate_bar="chocolate bar";W["ar-eg"].desc_magnifier="magnifier";W["ar-eg"].desc_clothes_hanger="clothes hanger";W["ar-eg"].desc_bowtie="bowtie";W["ar-eg"].desc_flying_kite="flying kite";W["ar-eg"].desc_beard="beard";W["ar-eg"].desc_fountain="fountain";W["ar-eg"].desc_crocodile="crocodile";W["ar-eg"].desc_peas="peas";W["ar-eg"].desc_tutu="tutu";W["ar-eg"].desc_tornado="tornado";W["ar-eg"].desc_balloon="balloon";W["ar-eg"].desc_spades="spades";W["ar-eg"].desc_paper_boat="paper boat";
W["ar-eg"].desc_pencil="pencil";W["ar-eg"].desc_phonograph="phonograph";W["ar-eg"].desc_sea_shore="sea shore";W["ar-eg"].desc_pelican="pelican";W["ar-eg"].desc_seagull="seagull";W["ar-eg"].desc_crab="crab";W["ar-eg"].desc_diamonds="diamonds";W["ar-eg"].desc_woods="woods";W["ar-eg"].desc_camera="camera";W["ar-eg"].desc_fishing_pole="fishing pole";W["ar-eg"].desc_river_bed="river bed";W["ar-eg"].desc_pants="pants";W["ar-eg"].desc_rocket="rocket";W["ar-eg"].desc_ambulance="ambulance";
W["ar-eg"].desc_lighthouse="lighthouse";W["ar-eg"].desc_nail_polish="nail polish";W["ar-eg"].desc_clubs="clubs";W["ar-eg"].desc_boiled_egg="boiled egg";W["ar-eg"].desc_lantern="lantern";W["ar-eg"].desc_thumbs_up="thumbs up";W["ar-eg"].desc_rainbow="rainbow";W["ko-kr"]=W["ko-kr"]||{};W["ko-kr"].TutorialTitle_6="Nono Cross";W["ko-kr"].TutorialTitle_5="Nono Cross";W["ko-kr"].TutorialTitle_4="Nono Cross";W["ko-kr"].TutorialTitle_3="Nono Cross";W["ko-kr"].TutorialText_6="You can then select a cross to fill in the remainder of that row or column. This will help you solve the puzzle.";
W["ko-kr"].TutorialText_5="A clue will turn grey once you have filled in the cells.";W["ko-kr"].TutorialText_4="Multiple numbers will mean multiple groups that have at least one cell between them.";W["ko-kr"].TutorialText_3="The number on a row or column tells you how many cells should be filled in. Those cells are always next to each other.";W["ko-kr"].levelStartText="LEVEL <VALUE> START";W["ko-kr"].TutorialTitle_0="Nono Cross";W["ko-kr"].TutorialText_0="Your goal is to reveal the hidden picture in each level.";
W["ko-kr"].TutorialText_1="#touch{Click to fill the cells in the level.}{Tap to fill the cells in the level.}";W["ko-kr"].TutorialText_2="Around the level you will find clues on which cells to fill";W["ko-kr"].TutorialTitle_1="Nono Cross";W["ko-kr"].TutorialTitle_2="Nono Cross";W["ko-kr"].restartConfirmation="Are you sure you want to restart this level?";W["ko-kr"].restartCancelBtnText="Cancel";W["ko-kr"].restartConfirmBtnText="Confirm";W["ko-kr"].desc_rubber_ducky="Rubber Ducky";
W["ko-kr"].desc_butterfly="Butterfly";W["ko-kr"].desc_bell="Bell";W["ko-kr"].desc_telephone="Telephone";W["ko-kr"].desc_tomato="Tomato";W["ko-kr"].desc_key="Key";W["ko-kr"]["desc_gold fish"]="Gold Fish";W["ko-kr"].desc_coffee_cup="Coffee Cup";W["ko-kr"].desc_cherry="Cherry";W["ko-kr"].desc_puzzle_piece="Puzzle Piece";W["ko-kr"].desc_camel="Camel";W["ko-kr"].desc_guinea_pig="Guinea Pig";W["ko-kr"].desc_car="Car";W["ko-kr"].desc_smile="Smile";W["ko-kr"].desc_weight_lifting="Weight Lifting";
W["ko-kr"].desc_lollipop="Lollipop";W["ko-kr"].desc_bus="Bus";W["ko-kr"].desc_chair="Chair";W["ko-kr"].desc_frog="Frog";W["ko-kr"].desc_boat="Boat";W["ko-kr"].desc_flowers="Flowers";W["ko-kr"].desc_music_note="Music Note";W["ko-kr"].desc_tractor="Tractor";W["ko-kr"].desc_cow="Cow";W["ko-kr"].desc_snail="Snail";W["ko-kr"].desc_pear="Pear";W["ko-kr"].desc_tree="Tree";W["ko-kr"].desc_snake="Snake";W["ko-kr"].desc_duck="Duck";W["ko-kr"].desc_strawberry="Strawberry";W["ko-kr"].desc_squirrel="Squirrel";
W["ko-kr"].desc_plane="Plane";W["ko-kr"].desc_dog="Dog";W["ko-kr"].desc_city="City";W["ko-kr"].desc_mountains="Mountains";W["ko-kr"].desc_baseball="Baseball";W["ko-kr"].desc_sunflowers="Sunflowers";W["ko-kr"].desc_umbrella="Umbrella";W["ko-kr"].desc_arrow="Arrow";W["ko-kr"].desc_cactus="Cactus";W["ko-kr"].desc_cowboy_hat="Cowboy Hat";W["ko-kr"].desc_robin="Robin";W["ko-kr"].desc_chicken="Chicken";W["ko-kr"].desc_kettle="Kettle";W["ko-kr"].desc_faucet="Faucet";W["ko-kr"].desc_turnip="Turnip";
W["ko-kr"].desc_sword="Sword";W["ko-kr"].desc_the_moon="The Moon";W["ko-kr"].desc_banana="Banana";W["ko-kr"].desc_cat="Cat";W["ko-kr"].desc_shovel="Shovel";W["ko-kr"].desc_cellphone="Cellphone";W["ko-kr"].desc_carrot="Carrot";W["ko-kr"]["desc_?"]="?";W["ko-kr"].desc_sapling="Sapling";W["ko-kr"].desc_lion="Lion";W["ko-kr"].desc_sunset="Sunset";W["ko-kr"].desc_hippo="Hippo";W["ko-kr"].desc_apple="Apple";W["ko-kr"].desc_corn="Corn";W["ko-kr"].desc_bunny="Bunny";W["ko-kr"].desc_star="Star";
W["ko-kr"].desc_panda="Panda";W["ko-kr"].desc_heart="Heart";W["ko-kr"].desc_deer="Deer";W["ko-kr"].desc_computer="Computer";W["ko-kr"].desc_house="House";W["ko-kr"].desc_elephant="Elephant";W["ko-kr"].desc_dolphin="Dolphin";W["ko-kr"].desc_unnamed="Unnamed";W["ko-kr"].desc_bee="Bee";W["ko-kr"].desc_koi_pond="Koi Pond";W["ko-kr"].desc_the_park="The Park";W["ko-kr"].desc_pearl="Pearl";W["ko-kr"].desc_tea_bag="Tea Bag";W["ko-kr"].TutorialText_7="Each puzzle only has one solution, so don't guess.";
W["ko-kr"].TutorialTitle_7="Nono Cross";W["ko-kr"].desc_coffee_bean="Coffee Bean";W["ko-kr"].desc_frowney="Frowney";W["ko-kr"].desc_smiley="Smiley";W["ko-kr"].desc_koala="Koala";W["ko-kr"].desc_saturn="Saturn";W["ko-kr"].desc_necklace="Necklace";W["ko-kr"].desc_shrub="Shrub";W["ko-kr"].desc_headphones="Headphones";W["ko-kr"].desc_blue_tee="Blue Tee";W["ko-kr"].desc_earring="Earring";W["ko-kr"].desc_lipstick="Lipstick";W["ko-kr"].desc_tv="TV";W["ko-kr"].desc_hamburger="Hamburger";
W["ko-kr"].desc_egg="Egg";W["ko-kr"].desc_the_sun="The Sun";W["ko-kr"].desc_candle="Candle";W["ko-kr"].desc_flashlight="Flashlight";W["ko-kr"].desc_a_well="A Well";W["ko-kr"].desc_wave="Wave";W["ko-kr"].desc_ponytail="Ponytail";W["ko-kr"].desc_icecream="Ice Cream";W["ko-kr"].desc_pickle_jar="Pickle Jar";W["ko-kr"].desc_stove="Stove";W["ko-kr"].desc_grapes="Grapes";W["ko-kr"].desc_mouse="Mouse";W["ko-kr"].desc_loin="Loin";W["ko-kr"].ui_level_text="Level";W["ko-kr"].desc_rose="rose";
W["ko-kr"].desc_alpaca="alpaca";W["ko-kr"].desc_desert="desert";W["ko-kr"].desc_sheep="sheep";W["ko-kr"].desc_alarm_clock="alarm clock";W["ko-kr"].desc_fish_bowl="fish bowl";W["ko-kr"].desc_paint_brush="paint brush";W["ko-kr"].desc_melon_slice="melon slice";W["ko-kr"].desc_toadstool="toadstool";W["ko-kr"].desc_choco_cake="choco cake";W["ko-kr"].desc_swan="swan";W["ko-kr"].desc_bicycle="bicycle";W["ko-kr"].desc_buttered_toast="buttered toast";W["ko-kr"].desc_purse="purse";W["ko-kr"].desc_bed="bed";
W["ko-kr"].desc_tadpole="tadpole";W["ko-kr"].desc_picture_book="picture book";W["ko-kr"].desc_bear="bear";W["ko-kr"].desc_traffic_light="traffic light";W["ko-kr"].desc_campfire="campfire";W["ko-kr"].desc_drinks="drinks";W["ko-kr"].desc_leaf="leaf";W["ko-kr"]["desc_dragonfly "]="dragonfly ";W["ko-kr"].desc_volcano="volcano";W["ko-kr"].desc_coral="coral";W["ko-kr"].desc_bracelet="bracelet";W["ko-kr"]["desc_backpack "]="backpack ";W["ko-kr"].desc_orca="orca";W["ko-kr"].desc_soup_pan="soup pan";
W["ko-kr"].desc_tent="tent";W["ko-kr"].desc_choco_cookie="choco cookie";W["ko-kr"].desc_magic_hat="magic hat";W["ko-kr"]["desc_hand mirror"]="hand mirror";W["ko-kr"].desc_waterfall="waterfall";W["ko-kr"].desc_treasure_chest="treasure chest";W["ko-kr"].desc_chimney="chimney";W["ko-kr"]["desc_salt_&_pepper"]="salt & pepper";W["ko-kr"].desc_glasses="glasses";W["ko-kr"].desc_lamp="lamp";W["ko-kr"].desc_horse="horse";W["ko-kr"].desc_golf="golf";W["ko-kr"].desc_pizza="pizza";W["ko-kr"].desc_rain="rain";
W["ko-kr"].desc_toaster="toaster";W["ko-kr"].desc_cheese="cheese";W["ko-kr"].desc_goat="goat";W["ko-kr"].desc_ice_skate="ice skate";W["ko-kr"].desc_microphone="microphone";W["ko-kr"].desc_watering_can="watering can";W["ko-kr"].desc_space_shuttle="space shuttle";W["ko-kr"].desc_door="door";W["ko-kr"].desc_bubblegum="bubblegum";W["ko-kr"].desc_shooting_star="shooting star";W["ko-kr"].desc_winter="winter";W["ko-kr"].desc_spring="spring";W["ko-kr"].desc_summer="summer";W["ko-kr"].desc_autumn="autumn";
W["ko-kr"].desc_sprinkled_donut="sprinkled donut";W["ko-kr"].desc_santa="santa";W["ko-kr"].desc_hedgehog="hedgehog";W["ko-kr"].desc_clouds="clouds";W["ko-kr"].desc_boot="boot";W["ko-kr"].desc_scissors="scissors";W["ko-kr"].desc_chocolate_bar="chocolate bar";W["ko-kr"].desc_magnifier="magnifier";W["ko-kr"].desc_clothes_hanger="clothes hanger";W["ko-kr"].desc_bowtie="bowtie";W["ko-kr"].desc_flying_kite="flying kite";W["ko-kr"].desc_beard="beard";W["ko-kr"].desc_fountain="fountain";
W["ko-kr"].desc_crocodile="crocodile";W["ko-kr"].desc_peas="peas";W["ko-kr"].desc_tutu="tutu";W["ko-kr"].desc_tornado="tornado";W["ko-kr"].desc_balloon="balloon";W["ko-kr"].desc_spades="spades";W["ko-kr"].desc_paper_boat="paper boat";W["ko-kr"].desc_pencil="pencil";W["ko-kr"].desc_phonograph="phonograph";W["ko-kr"].desc_sea_shore="sea shore";W["ko-kr"].desc_pelican="pelican";W["ko-kr"].desc_seagull="seagull";W["ko-kr"].desc_crab="crab";W["ko-kr"].desc_diamonds="diamonds";W["ko-kr"].desc_woods="woods";
W["ko-kr"].desc_camera="camera";W["ko-kr"].desc_fishing_pole="fishing pole";W["ko-kr"].desc_river_bed="river bed";W["ko-kr"].desc_pants="pants";W["ko-kr"].desc_rocket="rocket";W["ko-kr"].desc_ambulance="ambulance";W["ko-kr"].desc_lighthouse="lighthouse";W["ko-kr"].desc_nail_polish="nail polish";W["ko-kr"].desc_clubs="clubs";W["ko-kr"].desc_boiled_egg="boiled egg";W["ko-kr"].desc_lantern="lantern";W["ko-kr"].desc_thumbs_up="thumbs up";W["ko-kr"].desc_rainbow="rainbow";W["jp-jp"]=W["jp-jp"]||{};
W["jp-jp"].TutorialTitle_6="\u30d4\u30af\u30c1\u30e3\u30fc\u30ed\u30b8\u30c3\u30af";W["jp-jp"].TutorialTitle_5="\u30d4\u30af\u30c1\u30e3\u30fc\u30ed\u30b8\u30c3\u30af";W["jp-jp"].TutorialTitle_4="\u30d4\u30af\u30c1\u30e3\u30fc\u30ed\u30b8\u30c3\u30af";W["jp-jp"].TutorialTitle_3="\u30d4\u30af\u30c1\u30e3\u30fc\u30ed\u30b8\u30c3\u30af";W["jp-jp"].TutorialText_6="\u30e1\u30e2\u304c\u308f\u308a\u306b\n\u30bb\u30eb\u306b\u00d7\u5370\u3092\u3064\u3051\u3066\u304a\u304f\u3068\n\u30d1\u30ba\u30eb\u3092\u89e3\u304f\u306e\u306b\u5f79\u7acb\u3061\u307e\u3059";
W["jp-jp"].TutorialText_5="\u6b63\u3057\u3044\u30bb\u30eb\u3092\u5857\u308a\u3064\u3076\u3059\u3068\n\u30d2\u30f3\u30c8\u306f\u30b0\u30ec\u30fc\u306b\u5909\u308f\u308a\u307e\u3059";W["jp-jp"].TutorialText_4="\u6570\u5b57\u304c2\u3064\u4ee5\u4e0a\u306e\u3068\u304d\u306f\n\u9593\u306b1\u30bb\u30eb\u7a7a\u3051\u3066\n\u8907\u6570\u30b0\u30eb\u30fc\u30d7\u3092\u4f5c\u308a\u307e\u3059";W["jp-jp"].TutorialText_3="\u30bb\u30eb\u3092\u3044\u304f\u3064\u5857\u308a\u3064\u3076\u3059\u304b\u306f\n\u5217/\u884c\u306e\u6a2a\u306e\u6570\u5b57\u3067\u66f8\u3044\u3066\u3042\u308a\u307e\u3059\n\u5857\u308a\u3064\u3076\u3059\u30bb\u30eb\u306f\n\u5fc5\u305a\u96a3\u308a\u5408\u3063\u305f\u72b6\u614b\u3067\u3059";
W["jp-jp"].levelStartText="\u30ec\u30d9\u30eb<VALUE>\u30b9\u30bf\u30fc\u30c8";W["jp-jp"].TutorialTitle_0="\u30d4\u30af\u30c1\u30e3\u30fc\u30ed\u30b8\u30c3\u30af";W["jp-jp"].TutorialText_0="\u5404\u30ec\u30d9\u30eb\u3067\u96a0\u3055\u308c\u305f\u7d75\u3092\u66b4\u3044\u3066\u3044\u304d\u307e\u3059";W["jp-jp"].TutorialText_1="#touch{\u30af\u30ea\u30c3\u30af\u3057\u3066\u30bb\u30eb\u3092\u5857\u308a\u3064\u3076\u3057\u3066\n\u5404\u30ec\u30d9\u30eb\u3092\u30af\u30ea\u30a2\u3057\u307e\u3059}{\u30bf\u30c3\u30d7\u3057\u3066\u30bb\u30eb\u3092\u5857\u308a\u3064\u3076\u3057\u3066\n\u5404\u30ec\u30d9\u30eb\u3092\u30af\u30ea\u30a2\u3057\u307e\u3059}";
W["jp-jp"].TutorialText_2="\u5404\u30ec\u30d9\u30eb\u306b\u3066\n\u5857\u308a\u3064\u3076\u3059\u30bb\u30eb\u306e\u30d2\u30f3\u30c8\u304c\n\u66f8\u3044\u3066\u3042\u308a\u307e\u3059";W["jp-jp"].TutorialTitle_1="\u30d4\u30af\u30c1\u30e3\u30fc\u30ed\u30b8\u30c3\u30af";W["jp-jp"].TutorialTitle_2="\u30d4\u30af\u30c1\u30e3\u30fc\u30ed\u30b8\u30c3\u30af";W["jp-jp"].restartConfirmation="\u3053\u3053\u3067\u518d\u30b9\u30bf\u30fc\u30c8\u3059\u308b\u3068\n\u8a18\u9332\u304c\u30ea\u30bb\u30c3\u30c8\u3055\u308c\u307e\u3059\u304c\n\u3088\u308d\u3057\u3044\u3067\u3059\u304b\uff1f";
W["jp-jp"].restartCancelBtnText="\u30ad\u30e3\u30f3\u30bb\u30eb";W["jp-jp"].restartConfirmBtnText="\u78ba\u8a8d";W["jp-jp"].desc_rubber_ducky="\u30aa\u30e2\u30c1\u30e3\u306e\u30a2\u30d2\u30eb";W["jp-jp"].desc_butterfly="\u30c1\u30e7\u30a6\u30c1\u30e7";W["jp-jp"].desc_bell="\u9234";W["jp-jp"].desc_telephone="\u96fb\u8a71";W["jp-jp"].desc_tomato="\u30c8\u30de\u30c8";W["jp-jp"].desc_key="\u30ab\u30ae";W["jp-jp"]["desc_gold fish"]="\u91d1\u9b5a";W["jp-jp"].desc_coffee_cup="\u30b3\u30fc\u30d2\u30fc\u30ab\u30c3\u30d7";
W["jp-jp"].desc_cherry="\u30c1\u30a7\u30ea\u30fc";W["jp-jp"].desc_puzzle_piece="\u30d1\u30ba\u30eb\u306e\u30d4\u30fc\u30b9";W["jp-jp"].desc_camel="\u697d\u3060";W["jp-jp"].desc_guinea_pig="\u30ae\u30cb\u30a2\u306e\u30d6\u30bf";W["jp-jp"].desc_car="\u8eca";W["jp-jp"].desc_smile="\u30b9\u30de\u30a4\u30eb";W["jp-jp"].desc_weight_lifting="\u30a6\u30a7\u30a4\u30c8\u30ea\u30d5\u30c6\u30a3\u30f3\u30b0";W["jp-jp"].desc_lollipop="\u30ed\u30ea\u30dd\u30c3\u30d7";W["jp-jp"].desc_bus="\u30d0\u30b9";
W["jp-jp"].desc_chair="\u30a4\u30b9";W["jp-jp"].desc_frog="\u30ab\u30a8\u30eb";W["jp-jp"].desc_boat="\u30dc\u30fc\u30c8";W["jp-jp"].desc_flowers="\u82b1";W["jp-jp"].desc_music_note="\u97f3\u7b26";W["jp-jp"].desc_tractor="\u30c8\u30e9\u30af\u30bf\u30fc";W["jp-jp"].desc_cow="\u725b";W["jp-jp"].desc_snail="\u30ab\u30bf\u30c4\u30e0\u30ea";W["jp-jp"].desc_pear="\u6d0b\u30ca\u30b7";W["jp-jp"].desc_tree="\u6728";W["jp-jp"].desc_snake="\u30d8\u30d3";W["jp-jp"].desc_duck="\u30a2\u30d2\u30eb";
W["jp-jp"].desc_strawberry="\u30a4\u30c1\u30b4";W["jp-jp"].desc_squirrel="\u30ea\u30b9";W["jp-jp"].desc_plane="\u98db\u884c\u6a5f";W["jp-jp"].desc_dog="\u72ac";W["jp-jp"].desc_city="\u8857";W["jp-jp"].desc_mountains="\u5c71";W["jp-jp"].desc_baseball="\u91ce\u7403";W["jp-jp"].desc_sunflowers="\u30d2\u30de\u30ef\u30ea";W["jp-jp"].desc_umbrella="\u5098";W["jp-jp"].desc_arrow="\u77e2";W["jp-jp"].desc_cactus="\u30b5\u30dc\u30c6\u30f3";W["jp-jp"].desc_cowboy_hat="\u30ab\u30a6\u30dc\u30fc\u30a4\u30cf\u30c3\u30c8";
W["jp-jp"].desc_robin="\u30b3\u30de\u30c9\u30ea";W["jp-jp"].desc_chicken="\u30c1\u30ad\u30f3";W["jp-jp"].desc_kettle="\u30e4\u30ab\u30f3";W["jp-jp"].desc_faucet="\u86c7\u53e3";W["jp-jp"].desc_turnip="\u30ab\u30d6";W["jp-jp"].desc_sword="\u5263";W["jp-jp"].desc_the_moon="\u6708";W["jp-jp"].desc_banana="\u30d0\u30ca\u30ca";W["jp-jp"].desc_cat="\u30cd\u30b3";W["jp-jp"].desc_shovel="\u30b7\u30e7\u30d9\u30eb";W["jp-jp"].desc_cellphone="\u643a\u5e2f\u96fb\u8a71";W["jp-jp"].desc_carrot="\u30cb\u30f3\u30b8\u30f3";
W["jp-jp"]["desc_?"]="\uff1f";W["jp-jp"].desc_sapling="\u82d7\u6728";W["jp-jp"].desc_lion="Lion";W["jp-jp"].desc_sunset="\u30b5\u30f3\u30bb\u30c3\u30c8";W["jp-jp"].desc_hippo="\u30ab\u30d0";W["jp-jp"].desc_apple="\u30ea\u30f3\u30b4";W["jp-jp"].desc_corn="\u30c8\u30a6\u30e2\u30ed\u30b3\u30b7";W["jp-jp"].desc_bunny="\u30a6\u30b5\u30ae";W["jp-jp"].desc_star="\u661f";W["jp-jp"].desc_panda="\u30d1\u30f3\u30c0";W["jp-jp"].desc_heart="\u30cf\u30fc\u30c8";W["jp-jp"].desc_deer="\u30b7\u30ab";
W["jp-jp"].desc_computer="\u30b3\u30f3\u30d4\u30e5\u30fc\u30bf";W["jp-jp"].desc_house="\u5bb6";W["jp-jp"].desc_elephant="\u30be\u30a6";W["jp-jp"].desc_dolphin="\u30a4\u30eb\u30ab";W["jp-jp"].desc_unnamed="\u540d\u7121\u3057";W["jp-jp"].desc_bee="\u30cf\u30c1";W["jp-jp"].desc_koi_pond="\u30b3\u30a4\u306e\u6c60";W["jp-jp"].desc_the_park="\u516c\u5712";W["jp-jp"].desc_pearl="\u771f\u73e0";W["jp-jp"].desc_tea_bag="\u30c6\u30a3\u30fc\u30d0\u30c3\u30af";W["jp-jp"].TutorialText_7="\u5404\u30d1\u30ba\u30eb\u306b\u7b54\u3048\u306f\u3072\u3068\u3064\u3060\u3051\n\u306a\u306e\u3067\u5f53\u3066\u305a\u3063\u307d\u3046\u306f\u304d\u304b\u306a\u3044\u3088";
W["jp-jp"].TutorialTitle_7="\u30d4\u30af\u30c1\u30e3\u30fc\u30ed\u30b8\u30c3\u30af";W["jp-jp"].desc_coffee_bean="\u30b3\u30fc\u30d2\u30fc\u8c46";W["jp-jp"].desc_frowney="\u3057\u304b\u3081\u3063\u9762";W["jp-jp"].desc_smiley="\u30b9\u30de\u30a4\u30ea\u30fc";W["jp-jp"].desc_koala="\u30b3\u30a2\u30e9";W["jp-jp"].desc_saturn="\u571f\u661f";W["jp-jp"].desc_necklace="\u30cd\u30c3\u30af\u30ec\u30b9";W["jp-jp"].desc_shrub="\u704c\u6728";W["jp-jp"].desc_headphones="\u30d8\u30c3\u30c9\u30d5\u30a9\u30f3";
W["jp-jp"].desc_blue_tee="\u30d6\u30eb\u30fc\u306eT\u30b7\u30e3\u30c4";W["jp-jp"].desc_earring="\u30a4\u30a2\u30ea\u30f3\u30b0";W["jp-jp"].desc_lipstick="\u30ea\u30c3\u30d7\u30b9\u30c6\u30a3\u30c3\u30af";W["jp-jp"].desc_tv="TV";W["jp-jp"].desc_hamburger="\u30cf\u30f3\u30d0\u30fc\u30ac\u30fc";W["jp-jp"].desc_egg="\u30bf\u30de\u30b4";W["jp-jp"].desc_the_sun="\u592a\u967d";W["jp-jp"].desc_candle="\u30ad\u30e3\u30f3\u30c9\u30eb";W["jp-jp"].desc_flashlight="\u30d5\u30e9\u30c3\u30b7\u30e5\u30e9\u30a4\u30c8";
W["jp-jp"].desc_a_well="\u4e95\u6238";W["jp-jp"].desc_wave="\u6ce2";W["jp-jp"].desc_ponytail="\u30dd\u30cb\u30fc\u30c6\u30fc\u30eb";W["jp-jp"].desc_icecream="\u30a2\u30a4\u30b9\u30af\u30ea\u30fc\u30e0";W["jp-jp"].desc_pickle_jar="\u30d4\u30af\u30eb\u30b9\u306e\u30b8\u30e3\u30fc";W["jp-jp"].desc_stove="\u30b9\u30c8\u30fc\u30d6";W["jp-jp"].desc_grapes="\u30b0\u30ec\u30fc\u30d7";W["jp-jp"].desc_mouse="\u30cd\u30ba\u30df";W["jp-jp"].desc_loin="\u8170";W["jp-jp"].ui_level_text="\u30ec\u30d9\u30eb";
W["jp-jp"].desc_rose="rose";W["jp-jp"].desc_alpaca="alpaca";W["jp-jp"].desc_desert="desert";W["jp-jp"].desc_sheep="sheep";W["jp-jp"].desc_alarm_clock="alarm clock";W["jp-jp"].desc_fish_bowl="fish bowl";W["jp-jp"].desc_paint_brush="paint brush";W["jp-jp"].desc_melon_slice="melon slice";W["jp-jp"].desc_toadstool="toadstool";W["jp-jp"].desc_choco_cake="choco cake";W["jp-jp"].desc_swan="swan";W["jp-jp"].desc_bicycle="bicycle";W["jp-jp"].desc_buttered_toast="buttered toast";W["jp-jp"].desc_purse="purse";
W["jp-jp"].desc_bed="bed";W["jp-jp"].desc_tadpole="tadpole";W["jp-jp"].desc_picture_book="picture book";W["jp-jp"].desc_bear="bear";W["jp-jp"].desc_traffic_light="traffic light";W["jp-jp"].desc_campfire="campfire";W["jp-jp"].desc_drinks="drinks";W["jp-jp"].desc_leaf="leaf";W["jp-jp"]["desc_dragonfly "]="dragonfly ";W["jp-jp"].desc_volcano="volcano";W["jp-jp"].desc_coral="coral";W["jp-jp"].desc_bracelet="bracelet";W["jp-jp"]["desc_backpack "]="backpack ";W["jp-jp"].desc_orca="orca";
W["jp-jp"].desc_soup_pan="soup pan";W["jp-jp"].desc_tent="tent";W["jp-jp"].desc_choco_cookie="choco cookie";W["jp-jp"].desc_magic_hat="magic hat";W["jp-jp"]["desc_hand mirror"]="hand mirror";W["jp-jp"].desc_waterfall="waterfall";W["jp-jp"].desc_treasure_chest="treasure chest";W["jp-jp"].desc_chimney="chimney";W["jp-jp"]["desc_salt_&_pepper"]="salt & pepper";W["jp-jp"].desc_glasses="glasses";W["jp-jp"].desc_lamp="lamp";W["jp-jp"].desc_horse="horse";W["jp-jp"].desc_golf="golf";
W["jp-jp"].desc_pizza="pizza";W["jp-jp"].desc_rain="rain";W["jp-jp"].desc_toaster="toaster";W["jp-jp"].desc_cheese="cheese";W["jp-jp"].desc_goat="goat";W["jp-jp"].desc_ice_skate="ice skate";W["jp-jp"].desc_microphone="microphone";W["jp-jp"].desc_watering_can="watering can";W["jp-jp"].desc_space_shuttle="space shuttle";W["jp-jp"].desc_door="door";W["jp-jp"].desc_bubblegum="bubblegum";W["jp-jp"].desc_shooting_star="shooting star";W["jp-jp"].desc_winter="winter";W["jp-jp"].desc_spring="spring";
W["jp-jp"].desc_summer="summer";W["jp-jp"].desc_autumn="autumn";W["jp-jp"].desc_sprinkled_donut="sprinkled donut";W["jp-jp"].desc_santa="santa";W["jp-jp"].desc_hedgehog="hedgehog";W["jp-jp"].desc_clouds="clouds";W["jp-jp"].desc_boot="boot";W["jp-jp"].desc_scissors="scissors";W["jp-jp"].desc_chocolate_bar="chocolate bar";W["jp-jp"].desc_magnifier="magnifier";W["jp-jp"].desc_clothes_hanger="clothes hanger";W["jp-jp"].desc_bowtie="bowtie";W["jp-jp"].desc_flying_kite="flying kite";
W["jp-jp"].desc_beard="beard";W["jp-jp"].desc_fountain="fountain";W["jp-jp"].desc_crocodile="crocodile";W["jp-jp"].desc_peas="peas";W["jp-jp"].desc_tutu="tutu";W["jp-jp"].desc_tornado="tornado";W["jp-jp"].desc_balloon="balloon";W["jp-jp"].desc_spades="spades";W["jp-jp"].desc_paper_boat="paper boat";W["jp-jp"].desc_pencil="pencil";W["jp-jp"].desc_phonograph="phonograph";W["jp-jp"].desc_sea_shore="sea shore";W["jp-jp"].desc_pelican="pelican";W["jp-jp"].desc_seagull="seagull";W["jp-jp"].desc_crab="crab";
W["jp-jp"].desc_diamonds="diamonds";W["jp-jp"].desc_woods="woods";W["jp-jp"].desc_camera="camera";W["jp-jp"].desc_fishing_pole="fishing pole";W["jp-jp"].desc_river_bed="river bed";W["jp-jp"].desc_pants="pants";W["jp-jp"].desc_rocket="rocket";W["jp-jp"].desc_ambulance="ambulance";W["jp-jp"].desc_lighthouse="lighthouse";W["jp-jp"].desc_nail_polish="nail polish";W["jp-jp"].desc_clubs="clubs";W["jp-jp"].desc_boiled_egg="boiled egg";W["jp-jp"].desc_lantern="lantern";W["jp-jp"].desc_thumbs_up="thumbs up";
W["jp-jp"].desc_rainbow="rainbow";var Ne=null;
function Oe(){Ne={buttons:{vw:{x:870,y:240},dx:{x:870,y:120}},ia:{size:50},Ke:{Af:"unlocked",ep:"picross",zd:"level",bf:!0},Sa:{cq:{x:150,y:150}},label:{height:150,yt:32,cw:32,width:150},Aj:{ym:9},Tf:{au:100,offset:{x:-20,y:-20}},pg:{bathduck5x5:{width:250,height:250,items:[{x:0,y:50,id:"color",kind:5},{x:50,y:0,id:"color",kind:17},{x:50,y:50,id:"color",kind:17},{x:100,y:50,id:"color",kind:17},{x:100,y:0,id:"color",kind:17},{x:50,y:100,id:"color",kind:17},{x:50,y:150,id:"color",kind:17},{x:100,y:150,
id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:100,y:100,id:"color",kind:8},{x:150,y:100,id:"color",kind:8},{x:0,y:200,id:"color",kind:19},{x:100,y:200,id:"color",kind:19},{x:50,y:200,id:"color",kind:20},{x:150,y:200,id:"color",kind:19},{x:200,y:200,id:"color",kind:20},{x:0,y:150,id:"color",kind:21},{x:0,y:100,id:"color",kind:21},{x:0,y:0,id:"color",kind:21},{x:150,y:0,id:"color",kind:21},{x:150,y:50,id:"color",kind:21},{x:200,y:0,id:"color",kind:21},{x:200,
y:50,id:"color",kind:21},{x:200,y:150,id:"color",kind:21},{x:0,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"}],name:{key:"rubber_ducky"}},butterfly5x5:{width:250,
height:250,items:[{x:100,y:50,id:"color",kind:9},{x:0,y:100,id:"color",kind:10},{x:100,y:200,id:"color",kind:10},{x:100,y:0,id:"color",kind:10},{x:200,y:100,id:"color",kind:10},{x:100,y:100,id:"color",kind:17},{x:100,y:150,id:"color",kind:17},{x:50,y:200,id:"color",kind:31},{x:50,y:150,id:"color",kind:31},{x:0,y:150,id:"color",kind:31},{x:0,y:200,id:"color",kind:31},{x:150,y:200,id:"color",kind:31},{x:150,y:150,id:"color",kind:31},{x:200,y:150,id:"color",kind:31},{x:200,y:200,id:"color",kind:31},
{x:50,y:100,id:"color",kind:35},{x:50,y:50,id:"color",kind:35},{x:0,y:50,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:150,y:100,id:"color",kind:35},{x:150,y:50,id:"color",kind:35},{x:150,y:0,id:"color",kind:35},{x:200,y:0,id:"color",kind:35},{x:200,y:50,id:"color",kind:35},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:0,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,
id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:50,id:"cell"}],name:{key:"butterfly"}},bell5x5:{width:250,height:250,items:[{x:100,y:200,id:"color",kind:8},{x:0,y:200,id:"color",kind:35},{x:50,y:200,id:"color",kind:35},{x:150,y:200,id:"color",kind:35},{x:200,y:200,id:"color",
kind:35},{x:200,y:100,id:"color",kind:35},{x:200,y:50,id:"color",kind:35},{x:200,y:0,id:"color",kind:35},{x:150,y:0,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:0,y:50,id:"color",kind:35},{x:0,y:100,id:"color",kind:35},{x:0,y:150,id:"color",kind:17},{x:50,y:150,id:"color",kind:17},{x:100,y:150,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:200,y:150,id:"color",kind:17},{x:150,y:100,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},{x:150,y:50,id:"color",
kind:17},{x:100,y:0,id:"color",kind:17},{x:50,y:50,id:"color",kind:17},{x:50,y:100,id:"color",kind:23},{x:100,y:50,id:"color",kind:23},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:150,id:"cell"}],name:{key:"bell"}},telephone5x5:{width:250,height:250,items:[{x:200,y:150,id:"color",kind:2},{x:150,y:150,id:"color",
kind:2},{x:50,y:150,id:"color",kind:2},{x:0,y:150,id:"color",kind:2},{x:50,y:100,id:"color",kind:2},{x:100,y:100,id:"color",kind:2},{x:150,y:100,id:"color",kind:2},{x:0,y:200,id:"color",kind:1},{x:50,y:200,id:"color",kind:1},{x:150,y:200,id:"color",kind:1},{x:200,y:200,id:"color",kind:1},{x:100,y:200,id:"color",kind:1},{x:100,y:50,id:"color",kind:1},{x:0,y:0,id:"color",kind:2},{x:50,y:0,id:"color",kind:2},{x:100,y:0,id:"color",kind:2},{x:150,y:0,id:"color",kind:2},{x:200,y:0,id:"color",kind:2},{x:0,
y:50,id:"color",kind:1},{x:200,y:50,id:"color",kind:1},{x:0,y:100,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:0,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:150,id:"cell"},{x:150,y:100,id:"cell"},
{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"}],name:{key:"telephone"}},tomato5x5:{width:250,height:250,items:[{x:50,y:200,id:"color",kind:26},{x:150,y:200,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:100,y:150,id:"color",kind:26},{x:150,y:150,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:0,y:100,id:"color",kind:26},{x:50,y:50,id:"color",kind:26},{x:200,y:50,id:"color",
kind:26},{x:100,y:100,id:"color",kind:26},{x:0,y:150,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:150,y:100,id:"color",kind:26},{x:100,y:200,id:"color",kind:26},{x:100,y:50,id:"color",kind:14},{x:100,y:0,id:"color",kind:13},{x:150,y:0,id:"color",kind:13},{x:150,y:50,id:"color",kind:13},{x:0,y:50,id:"color",kind:26},{x:50,y:100,id:"color",kind:23},{x:0,y:200,id:"color",kind:10},{x:0,y:0,id:"color",kind:10},{x:200,y:0,id:"color",kind:10},{x:200,y:200,id:"color",kind:10},{x:50,y:0,id:"color",
kind:26},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:100,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:0,id:"cell"}],name:{key:"tomato"}},key5x5:{width:250,height:250,items:[{x:100,y:0,id:"color",kind:17},{x:100,y:100,id:"color",
kind:17},{x:50,y:50,id:"color",kind:17},{x:150,y:50,id:"color",kind:17},{x:100,y:150,id:"color",kind:8},{x:50,y:200,id:"color",kind:17},{x:100,y:200,id:"color",kind:17},{x:0,y:200,id:"color",kind:18},{x:0,y:150,id:"color",kind:18},{x:50,y:150,id:"color",kind:18},{x:50,y:100,id:"color",kind:18},{x:0,y:100,id:"color",kind:18},{x:0,y:50,id:"color",kind:18},{x:0,y:0,id:"color",kind:18},{x:50,y:0,id:"color",kind:18},{x:100,y:50,id:"color",kind:18},{x:150,y:0,id:"color",kind:18},{x:200,y:0,id:"color",kind:18},
{x:200,y:50,id:"color",kind:18},{x:200,y:100,id:"color",kind:18},{x:150,y:100,id:"color",kind:18},{x:150,y:150,id:"color",kind:18},{x:200,y:150,id:"color",kind:18},{x:200,y:200,id:"color",kind:18},{x:150,y:200,id:"color",kind:18},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:50,id:"cell"}],name:{key:"key"}},fish5x5:{width:250,height:250,items:[{x:50,y:0,id:"color",kind:5},{x:100,y:50,id:"color",kind:5},
{x:0,y:50,id:"color",kind:5},{x:0,y:100,id:"color",kind:5},{x:50,y:100,id:"color",kind:5},{x:50,y:50,id:"color",kind:5},{x:100,y:100,id:"color",kind:5},{x:0,y:150,id:"color",kind:5},{x:50,y:150,id:"color",kind:5},{x:100,y:150,id:"color",kind:5},{x:50,y:200,id:"color",kind:5},{x:150,y:100,id:"color",kind:5},{x:200,y:100,id:"color",kind:5},{x:200,y:50,id:"color",kind:5},{x:200,y:150,id:"color",kind:5},{x:0,y:200,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:100,
y:200,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:50,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:200,
y:50,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:0,id:"cell"}],name:{key:"gold fish"}},coffeecup5x5:{width:250,height:250,items:[{x:0,y:100,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:50,y:100,id:"color",
kind:4},{x:50,y:150,id:"color",kind:3},{x:50,y:50,id:"color",kind:23},{x:100,y:0,id:"color",kind:23},{x:0,y:50,id:"color",kind:10},{x:0,y:0,id:"color",kind:10},{x:50,y:0,id:"color",kind:10},{x:100,y:50,id:"color",kind:10},{x:150,y:0,id:"color",kind:10},{x:150,y:50,id:"color",kind:10},{x:200,y:50,id:"color",kind:10},{x:200,y:0,id:"color",kind:10},{x:150,y:150,id:"color",kind:10},{x:200,y:200,id:"color",kind:10},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},
{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:150,y:200,id:"cell"}],name:{key:"coffee_cup"}},cherry5x5:{width:250,height:250,items:[{x:200,y:200,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:150,y:150,id:"color",kind:26},{x:150,y:200,id:"color",kind:26},{x:50,y:150,id:"color",kind:30},{x:50,y:100,id:"color",kind:30},{x:0,y:100,id:"color",kind:30},{x:0,y:150,id:"color",kind:30},{x:200,y:100,
id:"color",kind:10},{x:200,y:50,id:"color",kind:10},{x:150,y:0,id:"color",kind:10},{x:100,y:0,id:"color",kind:10},{x:100,y:50,id:"color",kind:11},{x:50,y:0,id:"color",kind:10},{x:100,y:200,id:"color",kind:8},{x:100,y:150,id:"color",kind:8},{x:50,y:200,id:"color",kind:8},{x:0,y:200,id:"color",kind:8},{x:0,y:50,id:"color",kind:8},{x:50,y:50,id:"color",kind:8},{x:0,y:0,id:"color",kind:8},{x:100,y:100,id:"color",kind:11},{x:150,y:100,id:"color",kind:8},{x:150,y:50,id:"color",kind:8},{x:200,y:0,id:"color",
kind:8},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:200,id:"cell"}],name:{key:"cherry"}},puzzlepiece5x5:{width:250,height:250,items:[{x:0,y:100,id:"color",kind:34},{x:50,y:100,id:"color",kind:34},{x:50,y:50,id:"color",
kind:34},{x:50,y:150,id:"color",kind:34},{x:50,y:200,id:"color",kind:34},{x:100,y:150,id:"color",kind:34},{x:150,y:150,id:"color",kind:34},{x:150,y:200,id:"color",kind:34},{x:100,y:100,id:"color",kind:34},{x:100,y:50,id:"color",kind:34},{x:100,y:0,id:"color",kind:34},{x:150,y:50,id:"color",kind:34},{x:0,y:200,id:"color",kind:26},{x:0,y:150,id:"color",kind:26},{x:0,y:50,id:"color",kind:26},{x:100,y:200,id:"color",kind:20},{x:150,y:100,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:200,y:50,
id:"color",kind:17},{x:200,y:150,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:0,y:0,id:"color",kind:2},{x:50,y:0,id:"color",kind:21},{x:150,y:0,id:"color",kind:21},{x:200,y:0,id:"color",kind:31},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:200,id:"cell"}],name:{key:"puzzle_piece"}},
camel5x5:{width:250,height:250,items:[{x:0,y:200,id:"color",kind:3},{x:0,y:150,id:"color",kind:3},{x:0,y:100,id:"color",kind:3},{x:0,y:50,id:"color",kind:3},{x:50,y:50,id:"color",kind:3},{x:50,y:100,id:"color",kind:3},{x:100,y:100,id:"color",kind:3},{x:150,y:100,id:"color",kind:3},{x:150,y:50,id:"color",kind:3},{x:150,y:0,id:"color",kind:3},{x:200,y:0,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:100,y:200,id:"color",kind:3},{x:50,y:150,id:"color",kind:7},{x:150,y:150,id:"color",kind:7},{x:200,
y:150,id:"color",kind:7},{x:200,y:100,id:"color",kind:7},{x:200,y:50,id:"color",kind:7},{x:100,y:50,id:"color",kind:7},{x:100,y:0,id:"color",kind:7},{x:50,y:0,id:"color",kind:7},{x:0,y:0,id:"color",kind:7},{x:50,y:200,id:"color",kind:17},{x:150,y:200,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},
{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"}],name:{key:"camel"}},mouse5x6:{width:300,height:250,items:[{x:0,y:150,id:"color",kind:24},{x:50,y:150,id:"color",kind:24},{x:150,y:150,id:"color",kind:24},{x:50,y:50,id:"color",kind:35},{x:200,y:150,id:"color",kind:35},{x:50,y:100,id:"color",kind:24},{x:150,y:100,id:"color",kind:24},{x:50,y:200,id:"color",kind:35},{x:150,y:200,id:"color",kind:35},{x:100,y:100,id:"color",kind:24},{x:100,y:150,id:"color",kind:24},
{x:0,y:200,id:"color",kind:17},{x:100,y:200,id:"color",kind:17},{x:0,y:100,id:"color",kind:17},{x:0,y:50,id:"color",kind:17},{x:0,y:0,id:"color",kind:17},{x:50,y:0,id:"color",kind:17},{x:100,y:0,id:"color",kind:17},{x:100,y:50,id:"color",kind:17},{x:150,y:50,id:"color",kind:17},{x:150,y:0,id:"color",kind:17},{x:200,y:50,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:250,y:200,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:250,y:150,id:"color",kind:35},{x:250,y:100,id:"color",kind:35},
{x:250,y:50,id:"color",kind:35},{x:250,y:0,id:"color",kind:35},{x:200,y:0,id:"color",kind:35},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:50,id:"cell"}],name:{key:"mouse"}},guineapig5x6:{width:300,
height:250,items:[{x:50,y:100,id:"color",kind:3},{x:200,y:100,id:"color",kind:3},{x:250,y:150,id:"color",kind:3},{x:150,y:100,id:"color",kind:4},{x:150,y:50,id:"color",kind:4},{x:200,y:50,id:"color",kind:4},{x:50,y:200,id:"color",kind:35},{x:150,y:200,id:"color",kind:35},{x:50,y:50,id:"color",kind:35},{x:0,y:150,id:"color",kind:23},{x:0,y:100,id:"color",kind:23},{x:50,y:150,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:100,y:100,id:"color",kind:23},{x:150,y:150,id:"color",kind:23},{x:200,
y:150,id:"color",kind:23},{x:250,y:100,id:"color",kind:23},{x:0,y:200,id:"color",kind:6},{x:100,y:200,id:"color",kind:6},{x:200,y:200,id:"color",kind:6},{x:250,y:200,id:"color",kind:6},{x:250,y:50,id:"color",kind:6},{x:200,y:0,id:"color",kind:6},{x:250,y:0,id:"color",kind:6},{x:150,y:0,id:"color",kind:6},{x:100,y:0,id:"color",kind:6},{x:100,y:50,id:"color",kind:6},{x:50,y:0,id:"color",kind:6},{x:0,y:0,id:"color",kind:6},{x:0,y:50,id:"color",kind:6},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:50,
y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:250,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:200,id:"cell"},{x:150,y:200,id:"cell"}],name:{key:"guinea_pig"}},car5x6:{width:300,height:250,items:[{x:0,y:150,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},
{x:100,y:100,id:"color",kind:26},{x:150,y:50,id:"color",kind:26},{x:150,y:100,id:"color",kind:26},{x:100,y:150,id:"color",kind:26},{x:150,y:150,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:250,y:150,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:50,y:200,id:"color",kind:28},{x:200,y:200,id:"color",kind:28},{x:0,y:100,id:"color",kind:17},{x:50,y:0,id:"color",kind:26},{x:150,y:0,id:"color",kind:26},{x:200,y:0,id:"color",kind:26},{x:100,y:0,id:"color",
kind:26},{x:100,y:50,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:250,y:200,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:0,id:"cell"},
{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:200,y:200,id:"cell"}],name:{key:"car"}},coffeebean6x5:{width:250,height:300,items:[{x:150,y:250,id:"color",kind:3},{x:0,y:200,id:"color",kind:3},{x:200,y:200,id:"color",kind:3},{x:200,y:150,id:"color",kind:3},{x:200,y:100,id:"color",kind:3},{x:0,y:100,id:"color",
kind:4},{x:50,y:100,id:"color",kind:4},{x:50,y:50,id:"color",kind:4},{x:50,y:0,id:"color",kind:4},{x:100,y:0,id:"color",kind:4},{x:150,y:0,id:"color",kind:4},{x:0,y:50,id:"color",kind:4},{x:150,y:50,id:"color",kind:4},{x:150,y:100,id:"color",kind:4},{x:200,y:50,id:"color",kind:4},{x:0,y:250,id:"color",kind:13},{x:200,y:250,id:"color",kind:13},{x:150,y:150,id:"color",kind:4},{x:150,y:200,id:"color",kind:4},{x:100,y:250,id:"color",kind:4},{x:50,y:200,id:"color",kind:4},{x:50,y:150,id:"color",kind:4},
{x:100,y:200,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:100,y:100,id:"color",kind:3},{x:100,y:50,id:"color",kind:3},{x:50,y:250,id:"color",kind:4},{x:0,y:150,id:"color",kind:3},{x:0,y:0,id:"color",kind:13},{x:200,y:0,id:"color",kind:13},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:0,
y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"}],name:{key:"coffee_bean"}},sad6x5:{width:250,height:300,items:[{x:50,y:250,id:"color",kind:17},{x:100,y:250,id:"color",kind:17},{x:150,y:250,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:0,y:200,id:"color",kind:17},{x:50,y:150,id:"color",kind:17},{x:100,y:150,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:0,y:150,id:"color",kind:17},
{x:0,y:100,id:"color",kind:17},{x:0,y:50,id:"color",kind:17},{x:0,y:0,id:"color",kind:17},{x:50,y:0,id:"color",kind:17},{x:100,y:0,id:"color",kind:17},{x:100,y:50,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},{x:150,y:0,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:200,y:50,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:200,y:150,id:"color",kind:17},{x:0,y:250,id:"color",kind:0},{x:50,y:200,id:"color",kind:0},{x:100,y:200,id:"color",kind:0},{x:150,y:200,id:"color",kind:0},
{x:200,y:250,id:"color",kind:0},{x:150,y:100,id:"color",kind:0},{x:150,y:50,id:"color",kind:0},{x:50,y:50,id:"color",kind:0},{x:50,y:100,id:"color",kind:0},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:200,y:250,id:"cell"}],name:{key:"frowney"}},smiley6x5:{width:250,height:300,items:[{x:50,y:50,id:"color",kind:0},{x:150,y:50,id:"color",kind:0},{x:0,y:200,id:"color",
kind:0},{x:50,y:250,id:"color",kind:0},{x:100,y:250,id:"color",kind:0},{x:150,y:250,id:"color",kind:0},{x:200,y:200,id:"color",kind:0},{x:50,y:100,id:"color",kind:0},{x:150,y:100,id:"color",kind:0},{x:0,y:250,id:"color",kind:17},{x:200,y:250,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:100,y:150,id:"color",kind:17},{x:50,y:150,id:"color",kind:17},{x:0,y:100,id:"color",kind:17},{x:0,y:50,id:"color",kind:17},{x:0,y:0,id:"color",kind:17},{x:100,y:0,id:"color",kind:17},{x:100,y:50,id:"color",
kind:17},{x:100,y:100,id:"color",kind:17},{x:50,y:0,id:"color",kind:17},{x:150,y:0,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:200,y:50,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:0,y:150,id:"color",kind:17},{x:50,y:200,id:"color",kind:17},{x:100,y:200,id:"color",kind:17},{x:150,y:200,id:"color",kind:17},{x:200,y:150,id:"color",kind:17},{x:50,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:0,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,
y:200,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:250,id:"cell"}],name:{key:"smiley"}},weights5x7:{width:350,height:250,items:[{x:100,y:100,id:"color",kind:7},{x:100,y:50,id:"color",kind:7},{x:150,y:50,id:"color",kind:7},{x:150,y:100,id:"color",kind:7},{x:200,y:50,id:"color",kind:7},{x:50,y:100,id:"color",kind:18},{x:0,y:100,id:"color",kind:18},{x:0,y:150,id:"color",kind:18},{x:0,y:50,id:"color",kind:18},{x:250,y:100,id:"color",kind:18},{x:300,y:100,id:"color",kind:18},{x:300,y:50,id:"color",kind:18},
{x:300,y:150,id:"color",kind:18},{x:150,y:150,id:"color",kind:6},{x:200,y:150,id:"color",kind:6},{x:200,y:100,id:"color",kind:18},{x:100,y:150,id:"color",kind:7},{x:150,y:200,id:"color",kind:7},{x:0,y:200,id:"color",kind:8},{x:50,y:200,id:"color",kind:8},{x:50,y:150,id:"color",kind:8},{x:100,y:200,id:"color",kind:8},{x:200,y:200,id:"color",kind:8},{x:250,y:150,id:"color",kind:8},{x:250,y:200,id:"color",kind:8},{x:300,y:200,id:"color",kind:8},{x:250,y:50,id:"color",kind:8},{x:250,y:0,id:"color",kind:8},
{x:300,y:0,id:"color",kind:8},{x:200,y:0,id:"color",kind:8},{x:150,y:0,id:"color",kind:8},{x:50,y:0,id:"color",kind:8},{x:50,y:50,id:"color",kind:8},{x:0,y:0,id:"color",kind:8},{x:100,y:0,id:"color",kind:8},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},
{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"}],name:{key:"weight_lifting"}},koala5x7:{width:350,height:250,items:[{x:150,y:200,id:"color",kind:3},{x:100,y:100,id:"color",kind:1},{x:200,y:100,id:"color",kind:1},{x:150,y:150,id:"color",kind:3},{x:50,y:100,id:"color",kind:24},{x:0,y:100,id:"color",kind:24},{x:0,y:50,id:"color",kind:24},{x:50,y:50,id:"color",kind:24},{x:50,y:0,id:"color",kind:24},{x:100,y:150,id:"color",kind:24},{x:100,y:200,id:"color",kind:24},{x:200,y:150,id:"color",
kind:24},{x:200,y:200,id:"color",kind:24},{x:50,y:150,id:"color",kind:24},{x:250,y:150,id:"color",kind:24},{x:250,y:100,id:"color",kind:24},{x:150,y:100,id:"color",kind:24},{x:100,y:50,id:"color",kind:24},{x:150,y:50,id:"color",kind:24},{x:200,y:50,id:"color",kind:24},{x:250,y:50,id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:300,y:50,id:"color",kind:24},{x:300,y:100,id:"color",kind:24},{x:300,y:0,id:"color",kind:24},{x:0,y:0,id:"color",kind:24},{x:0,y:200,id:"color",kind:10},{x:0,y:150,id:"color",
kind:10},{x:50,y:200,id:"color",kind:10},{x:100,y:0,id:"color",kind:10},{x:200,y:0,id:"color",kind:10},{x:150,y:0,id:"color",kind:10},{x:250,y:200,id:"color",kind:10},{x:300,y:200,id:"color",kind:10},{x:300,y:150,id:"color",kind:10},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:0,id:"cell"},
{x:50,y:0,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:250,y:0,id:"cell"}],name:{key:"koala"}},lollipop7x5:{width:250,height:350,items:[{x:100,y:150,id:"color",kind:22},{x:100,y:250,id:"color",kind:23},{x:100,y:300,id:"color",kind:23},{x:200,y:50,id:"color",kind:30},{x:150,y:100,id:"color",kind:29},{x:100,y:100,id:"color",kind:29},{x:50,y:100,id:"color",kind:30},{x:100,y:0,id:"color",kind:31},{x:150,y:0,id:"color",kind:31},{x:100,y:50,
id:"color",kind:31},{x:50,y:50,id:"color",kind:31},{x:150,y:50,id:"color",kind:31},{x:50,y:300,id:"color",kind:17},{x:50,y:250,id:"color",kind:17},{x:50,y:200,id:"color",kind:17},{x:50,y:150,id:"color",kind:17},{x:0,y:150,id:"color",kind:17},{x:0,y:100,id:"color",kind:17},{x:0,y:200,id:"color",kind:17},{x:0,y:250,id:"color",kind:17},{x:0,y:300,id:"color",kind:17},{x:150,y:300,id:"color",kind:17},{x:150,y:250,id:"color",kind:17},{x:150,y:200,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:200,
y:150,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:200,y:250,id:"color",kind:17},{x:200,y:300,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:0,y:0,id:"color",kind:17},{x:0,y:50,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:100,y:200,id:"color",kind:23},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:0,id:"cell"},{x:50,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:0,id:"cell"},{x:100,
y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:200,y:50,id:"cell"}],name:{key:"lollipop"}},saturn5x7:{width:350,height:250,items:[{x:50,y:100,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},{x:150,y:100,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:300,y:100,id:"color",kind:17},{x:100,y:150,id:"color",kind:8},{x:150,y:150,id:"color",kind:8},{x:200,y:150,id:"color",kind:8},{x:200,y:50,id:"color",kind:8},{x:150,y:50,id:"color",kind:8},{x:100,y:50,id:"color",kind:8},{x:0,y:50,id:"color",kind:1},
{x:50,y:0,id:"color",kind:1},{x:50,y:50,id:"color",kind:1},{x:100,y:0,id:"color",kind:1},{x:150,y:0,id:"color",kind:1},{x:200,y:0,id:"color",kind:1},{x:250,y:50,id:"color",kind:1},{x:250,y:200,id:"color",kind:1},{x:300,y:200,id:"color",kind:1},{x:0,y:100,id:"color",kind:17},{x:250,y:100,id:"color",kind:17},{x:200,y:200,id:"color",kind:1},{x:250,y:150,id:"color",kind:1},{x:300,y:150,id:"color",kind:1},{x:50,y:150,id:"color",kind:1},{x:0,y:200,id:"color",kind:2},{x:50,y:200,id:"color",kind:2},{x:0,
y:150,id:"color",kind:2},{x:100,y:200,id:"color",kind:2},{x:150,y:200,id:"color",kind:2},{x:0,y:0,id:"color",kind:2},{x:300,y:0,id:"color",kind:2},{x:300,y:50,id:"color",kind:2},{x:250,y:0,id:"color",kind:2},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:250,y:0,id:"cell"},
{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:0,id:"cell"}],name:{key:"saturn"}},necklace7x5:{width:250,height:350,items:[{x:100,y:300,id:"color",kind:20},{x:100,y:250,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:50,y:50,id:"color",
kind:7},{x:50,y:0,id:"color",kind:7},{x:100,y:0,id:"color",kind:7},{x:100,y:50,id:"color",kind:7},{x:150,y:0,id:"color",kind:7},{x:150,y:50,id:"color",kind:7},{x:150,y:100,id:"color",kind:7},{x:100,y:100,id:"color",kind:7},{x:50,y:100,id:"color",kind:7},{x:0,y:150,id:"color",kind:7},{x:100,y:150,id:"color",kind:7},{x:200,y:150,id:"color",kind:7},{x:200,y:100,id:"color",kind:22},{x:200,y:200,id:"color",kind:7},{x:150,y:250,id:"color",kind:7},{x:150,y:300,id:"color",kind:7},{x:50,y:300,id:"color",kind:7},
{x:50,y:250,id:"color",kind:7},{x:0,y:200,id:"color",kind:7},{x:100,y:200,id:"color",kind:7},{x:0,y:0,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:0,y:300,id:"color",kind:18},{x:200,y:300,id:"color",kind:18},{x:0,y:250,id:"color",kind:7},{x:200,y:250,id:"color",kind:7},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},
{x:200,y:0,id:"cell"},{x:0,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:0,y:300,id:"cell"},{x:200,y:300,id:"cell"}],name:{key:"necklace"}},bus5x7:{width:350,height:250,items:[{x:0,y:150,id:"color",kind:12},{x:100,y:50,id:"color",kind:12},{x:200,y:50,id:"color",kind:12},{x:300,y:50,id:"color",kind:12},{x:50,y:100,id:"color",kind:12},{x:50,y:150,id:"color",kind:12},{x:100,y:150,id:"color",kind:12},{x:100,y:100,id:"color",kind:12},{x:150,y:150,id:"color",kind:12},{x:200,y:150,id:"color",
kind:12},{x:250,y:150,id:"color",kind:12},{x:300,y:150,id:"color",kind:12},{x:50,y:50,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:50,y:200,id:"color",kind:28},{x:250,y:200,id:"color",kind:28},{x:0,y:50,id:"color",kind:22},{x:0,y:100,id:"color",kind:17},{x:0,y:200,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:300,y:200,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,y:0,id:"color",
kind:15},{x:100,y:0,id:"color",kind:15},{x:150,y:0,id:"color",kind:15},{x:200,y:0,id:"color",kind:15},{x:250,y:0,id:"color",kind:15},{x:300,y:0,id:"color",kind:15},{x:300,y:100,id:"color",kind:12},{x:250,y:100,id:"color",kind:12},{x:200,y:100,id:"color",kind:12},{x:150,y:100,id:"color",kind:12},{x:50,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},
{x:250,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:150,y:0,id:"cell"}],name:{key:"bus"}},chair6x6:{width:300,height:300,items:[{x:100,y:250,id:"color",kind:3},{x:100,y:200,id:"color",kind:3},{x:250,y:250,id:"color",kind:3},{x:250,
y:200,id:"color",kind:3},{x:250,y:150,id:"color",kind:3},{x:250,y:50,id:"color",kind:3},{x:250,y:0,id:"color",kind:3},{x:250,y:100,id:"color",kind:3},{x:200,y:150,id:"color",kind:4},{x:100,y:150,id:"color",kind:4},{x:150,y:150,id:"color",kind:4},{x:50,y:50,id:"color",kind:4},{x:0,y:50,id:"color",kind:4},{x:0,y:100,id:"color",kind:3},{x:0,y:150,id:"color",kind:3},{x:0,y:200,id:"color",kind:3},{x:0,y:250,id:"color",kind:3},{x:50,y:250,id:"color",kind:17},{x:50,y:200,id:"color",kind:17},{x:50,y:150,
id:"color",kind:17},{x:50,y:100,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},{x:100,y:50,id:"color",kind:17},{x:100,y:0,id:"color",kind:17},{x:50,y:0,id:"color",kind:17},{x:0,y:0,id:"color",kind:17},{x:150,y:0,id:"color",kind:17},{x:150,y:50,id:"color",kind:17},{x:150,y:100,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:200,y:50,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:200,y:250,id:"color",kind:17},{x:150,y:250,id:"color",kind:17},{x:150,
y:200,id:"color",kind:17},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:0,y:50,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"}],name:{key:"chair"}},frog6x6:{width:300,height:300,items:[{x:200,y:100,id:"color",kind:11},
{x:200,y:50,id:"color",kind:11},{x:150,y:150,id:"color",kind:11},{x:200,y:150,id:"color",kind:11},{x:250,y:250,id:"color",kind:11},{x:50,y:250,id:"color",kind:13},{x:100,y:250,id:"color",kind:13},{x:0,y:250,id:"color",kind:13},{x:0,y:200,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},
{x:250,y:200,id:"color",kind:11},{x:250,y:150,id:"color",kind:11},{x:250,y:100,id:"color",kind:11},{x:100,y:150,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:50,y:100,id:"color",kind:31},{x:150,y:250,id:"color",kind:10},{x:150,y:50,id:"color",kind:10},{x:200,y:0,id:"color",kind:10},{x:200,y:250,id:"color",kind:10},{x:200,y:200,id:"color",kind:10},{x:250,y:50,id:"color",kind:1},{x:0,y:100,id:"color",kind:1},{x:0,y:50,id:"color",
kind:22},{x:100,y:100,id:"color",kind:30},{x:150,y:100,id:"color",kind:30},{x:250,y:0,id:"color",kind:11},{x:200,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:0,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:250,id:"cell"},
{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:0,y:50,id:"cell"}],name:{key:"frog"}},boat6x6:{width:300,height:300,items:[{x:50,y:200,id:"color",kind:3},{x:100,y:200,id:"color",kind:3},{x:100,y:250,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:150,y:200,id:"color",kind:3},{x:200,y:200,id:"color",kind:3},{x:200,y:250,id:"color",kind:3},{x:250,y:200,id:"color",kind:3},{x:100,y:100,id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},
{x:100,y:50,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:200,y:0,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:0,y:200,id:"color",kind:3},{x:50,y:250,id:"color",kind:3},{x:150,y:150,id:"color",kind:2},{x:150,y:100,id:"color",kind:2},{x:150,y:50,id:"color",kind:2},{x:150,y:0,id:"color",kind:2},{x:0,y:250,id:"color",kind:19},{x:250,y:250,id:"color",kind:19},{x:0,y:150,id:"color",kind:20},
{x:50,y:150,id:"color",kind:20},{x:100,y:150,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:150,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:200,id:"cell"},
{x:0,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:50,y:100,id:"cell"}],name:{key:"boat"}},flower6x6:{width:300,height:300,items:[{x:50,y:50,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:100,y:200,id:"color",kind:17},{x:0,y:50,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},{x:50,y:0,id:"color",kind:26},{x:100,y:50,id:"color",kind:26},{x:150,y:100,id:"color",kind:31},{x:200,y:150,id:"color",kind:31},
{x:200,y:50,id:"color",kind:31},{x:250,y:100,id:"color",kind:31},{x:50,y:200,id:"color",kind:30},{x:100,y:150,id:"color",kind:30},{x:100,y:250,id:"color",kind:30},{x:150,y:200,id:"color",kind:30},{x:50,y:150,id:"color",kind:11},{x:50,y:250,id:"color",kind:11},{x:200,y:200,id:"color",kind:11},{x:200,y:250,id:"color",kind:11},{x:0,y:250,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:250,y:200,id:"color",
kind:20},{x:250,y:150,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:0,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:50,
y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"}],name:{key:"flowers"}},musicnote6x6:{width:300,height:300,items:[{x:0,y:250,id:"color",kind:1},{x:50,y:250,id:"color",kind:1},{x:100,y:200,id:"color",kind:1},{x:100,y:150,id:"color",kind:1},{x:100,y:100,id:"color",kind:1},{x:100,y:50,id:"color",kind:1},{x:150,y:0,id:"color",kind:1},{x:150,y:50,id:"color",kind:1},{x:250,y:50,id:"color",kind:1},{x:50,y:200,id:"color",kind:1},{x:0,y:200,id:"color",kind:2},{x:100,y:0,id:"color",kind:2},
{x:0,y:150,id:"color",kind:32},{x:0,y:100,id:"color",kind:32},{x:0,y:50,id:"color",kind:32},{x:0,y:0,id:"color",kind:32},{x:50,y:0,id:"color",kind:32},{x:50,y:50,id:"color",kind:32},{x:50,y:100,id:"color",kind:32},{x:50,y:150,id:"color",kind:32},{x:250,y:0,id:"color",kind:32},{x:250,y:150,id:"color",kind:32},{x:250,y:200,id:"color",kind:32},{x:250,y:250,id:"color",kind:32},{x:200,y:250,id:"color",kind:32},{x:200,y:150,id:"color",kind:32},{x:200,y:100,id:"color",kind:32},{x:200,y:200,id:"color",kind:32},
{x:100,y:250,id:"color",kind:1},{x:200,y:0,id:"color",kind:1},{x:200,y:50,id:"color",kind:1},{x:250,y:100,id:"color",kind:1},{x:150,y:100,id:"color",kind:32},{x:150,y:150,id:"color",kind:32},{x:150,y:200,id:"color",kind:32},{x:150,y:250,id:"color",kind:32},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:50,
id:"cell"},{x:250,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:250,y:100,id:"cell"}],name:{key:"music_note"}},tractor6x6:{width:300,height:300,items:[{x:200,y:50,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:150,y:150,id:"color",kind:26},{x:100,y:150,id:"color",kind:26},{x:100,y:200,id:"color",kind:26},{x:200,y:0,id:"color",kind:27},{x:150,y:100,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:0,y:200,id:"color",kind:26},{x:150,y:50,id:"color",
kind:5},{x:0,y:250,id:"color",kind:24},{x:0,y:50,id:"color",kind:24},{x:0,y:0,id:"color",kind:24},{x:50,y:0,id:"color",kind:24},{x:50,y:50,id:"color",kind:24},{x:100,y:50,id:"color",kind:24},{x:100,y:0,id:"color",kind:24},{x:150,y:0,id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:150,y:250,id:"color",kind:28},{x:150,y:200,id:"color",kind:28},{x:200,y:200,id:"color",kind:28},{x:200,y:250,id:"color",kind:28},{x:250,y:200,id:"color",kind:26},{x:250,y:150,id:"color",kind:26},{x:250,y:50,id:"color",
kind:26},{x:250,y:100,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:0,y:150,id:"color",kind:26},{x:50,y:100,id:"color",kind:5},{x:0,y:100,id:"color",kind:5},{x:50,y:250,id:"color",kind:28},{x:100,y:100,id:"color",kind:24},{x:200,y:100,id:"color",kind:24},{x:100,y:250,id:"color",kind:24},{x:250,y:250,id:"color",kind:24},{x:50,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,
id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"}],name:{key:"tractor"}},cow6x6:{width:300,height:300,items:[{x:50,y:200,id:"color",kind:11},{x:0,y:200,id:"color",kind:11},{x:0,y:250,id:"color",kind:11},{x:50,y:250,id:"color",kind:11},{x:100,y:250,id:"color",kind:11},{x:150,y:250,id:"color",
kind:11},{x:200,y:150,id:"color",kind:4},{x:250,y:150,id:"color",kind:4},{x:250,y:100,id:"color",kind:4},{x:250,y:200,id:"color",kind:4},{x:0,y:50,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:200,y:200,id:"color",kind:6},{x:200,y:250,id:"color",kind:6},{x:250,y:250,id:"color",kind:6},{x:50,y:50,id:"color",kind:7},{x:50,y:100,id:"color",
kind:7},{x:100,y:100,id:"color",kind:7},{x:150,y:100,id:"color",kind:7},{x:200,y:100,id:"color",kind:7},{x:200,y:50,id:"color",kind:7},{x:150,y:0,id:"color",kind:7},{x:100,y:0,id:"color",kind:7},{x:100,y:150,id:"color",kind:7},{x:150,y:150,id:"color",kind:7},{x:100,y:200,id:"color",kind:28},{x:150,y:200,id:"color",kind:28},{x:150,y:50,id:"color",kind:28},{x:100,y:50,id:"color",kind:28},{x:0,y:0,id:"color",kind:28},{x:250,y:0,id:"color",kind:28},{x:0,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,
id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"}],name:{key:"cow"}},
shrub6x6:{width:300,height:300,items:[{x:150,y:200,id:"color",kind:3},{x:50,y:150,id:"color",kind:13},{x:0,y:100,id:"color",kind:13},{x:50,y:50,id:"color",kind:13},{x:0,y:0,id:"color",kind:13},{x:50,y:0,id:"color",kind:13},{x:150,y:50,id:"color",kind:13},{x:200,y:50,id:"color",kind:13},{x:200,y:0,id:"color",kind:13},{x:250,y:50,id:"color",kind:13},{x:250,y:100,id:"color",kind:13},{x:150,y:100,id:"color",kind:13},{x:100,y:100,id:"color",kind:13},{x:100,y:50,id:"color",kind:13},{x:50,y:100,id:"color",
kind:13},{x:150,y:150,id:"color",kind:14},{x:200,y:100,id:"color",kind:14},{x:250,y:150,id:"color",kind:14},{x:200,y:200,id:"color",kind:14},{x:50,y:200,id:"color",kind:14},{x:0,y:150,id:"color",kind:14},{x:100,y:150,id:"color",kind:14},{x:200,y:150,id:"color",kind:13},{x:100,y:200,id:"color",kind:13},{x:100,y:250,id:"color",kind:4},{x:150,y:250,id:"color",kind:3},{x:0,y:250,id:"color",kind:24},{x:0,y:200,id:"color",kind:24},{x:50,y:250,id:"color",kind:24},{x:200,y:250,id:"color",kind:24},{x:250,
y:250,id:"color",kind:24},{x:250,y:200,id:"color",kind:24},{x:0,y:50,id:"color",kind:24},{x:150,y:0,id:"color",kind:14},{x:250,y:0,id:"color",kind:14},{x:100,y:0,id:"color",kind:24},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:0,id:"cell"},
{x:0,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:100,y:100,id:"cell"}],name:{key:"shrub"}},snail6x6:{width:300,height:300,items:[{x:200,y:200,id:"color",kind:4},{x:250,y:200,id:"color",kind:4},{x:150,y:200,id:"color",kind:4},{x:150,y:150,id:"color",kind:4},{x:150,y:100,id:"color",kind:4},{x:200,y:100,id:"color",kind:4},{x:100,y:200,id:"color",kind:6},{x:100,y:150,id:"color",kind:6},{x:100,y:100,id:"color",kind:6},{x:150,y:50,id:"color",kind:6},{x:200,y:50,id:"color",
kind:6},{x:250,y:100,id:"color",kind:6},{x:250,y:150,id:"color",kind:6},{x:200,y:150,id:"color",kind:6},{x:0,y:100,id:"color",kind:13},{x:50,y:150,id:"color",kind:13},{x:50,y:200,id:"color",kind:13},{x:50,y:250,id:"color",kind:13},{x:100,y:250,id:"color",kind:13},{x:150,y:250,id:"color",kind:13},{x:200,y:250,id:"color",kind:13},{x:250,y:250,id:"color",kind:13},{x:0,y:250,id:"color",kind:17},{x:0,y:200,id:"color",kind:17},{x:0,y:150,id:"color",kind:17},{x:50,y:100,id:"color",kind:17},{x:0,y:50,id:"color",
kind:17},{x:0,y:0,id:"color",kind:17},{x:50,y:0,id:"color",kind:17},{x:50,y:50,id:"color",kind:17},{x:100,y:50,id:"color",kind:17},{x:100,y:0,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:150,y:0,id:"color",kind:17},{x:250,y:0,id:"color",kind:17},{x:250,y:50,id:"color",kind:17},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,
y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:0,y:100,id:"cell"}],name:{key:"snail"}},pear6x6:{width:300,height:300,items:[{x:50,y:250,id:"color",kind:13},{x:0,y:200,id:"color",kind:13},{x:100,y:100,id:"color",kind:13},{x:200,y:100,id:"color",kind:13},{x:150,y:100,id:"color",kind:13},{x:200,y:50,id:"color",kind:13},{x:200,y:150,id:"color",kind:13},{x:200,y:200,id:"color",kind:13},{x:50,y:150,id:"color",kind:13},
{x:100,y:200,id:"color",kind:13},{x:50,y:200,id:"color",kind:13},{x:150,y:150,id:"color",kind:13},{x:150,y:250,id:"color",kind:13},{x:100,y:250,id:"color",kind:14},{x:150,y:200,id:"color",kind:14},{x:100,y:150,id:"color",kind:14},{x:150,y:50,id:"color",kind:14},{x:200,y:0,id:"color",kind:3},{x:0,y:150,id:"color",kind:13},{x:50,y:100,id:"color",kind:13},{x:0,y:250,id:"color",kind:8},{x:200,y:250,id:"color",kind:8},{x:250,y:250,id:"color",kind:8},{x:250,y:200,id:"color",kind:8},{x:250,y:150,id:"color",
kind:8},{x:150,y:0,id:"color",kind:8},{x:100,y:0,id:"color",kind:8},{x:50,y:0,id:"color",kind:8},{x:0,y:0,id:"color",kind:8},{x:0,y:50,id:"color",kind:8},{x:0,y:100,id:"color",kind:8},{x:50,y:50,id:"color",kind:8},{x:100,y:50,id:"color",kind:8},{x:250,y:50,id:"color",kind:13},{x:250,y:0,id:"color",kind:8},{x:250,y:100,id:"color",kind:14},{x:50,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:50,id:"cell"},
{x:150,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"}],name:{key:"pear"}},tree6x6:{width:300,height:300,items:[{x:200,y:100,id:"color",kind:13},{x:200,y:50,id:"color",kind:13},{x:0,y:200,id:"color",kind:13},{x:0,y:250,id:"color",kind:13},{x:50,y:250,id:"color",kind:13},{x:0,
y:100,id:"color",kind:21},{x:0,y:0,id:"color",kind:21},{x:0,y:150,id:"color",kind:21},{x:50,y:150,id:"color",kind:21},{x:50,y:200,id:"color",kind:21},{x:100,y:200,id:"color",kind:21},{x:250,y:200,id:"color",kind:21},{x:150,y:200,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:200,y:200,id:"color",kind:21},{x:150,y:0,id:"color",kind:13},{x:50,y:50,id:"color",kind:13},{x:100,y:100,id:"color",kind:13},{x:150,y:50,id:"color",kind:13},{x:200,y:0,id:"color",kind:13},{x:0,y:50,id:"color",kind:13},
{x:50,y:0,id:"color",kind:13},{x:100,y:0,id:"color",kind:13},{x:100,y:50,id:"color",kind:13},{x:250,y:0,id:"color",kind:13},{x:150,y:150,id:"color",kind:14},{x:200,y:150,id:"color",kind:14},{x:250,y:150,id:"color",kind:14},{x:250,y:100,id:"color",kind:14},{x:250,y:50,id:"color",kind:14},{x:50,y:100,id:"color",kind:14},{x:100,y:150,id:"color",kind:14},{x:150,y:100,id:"color",kind:13},{x:100,y:250,id:"color",kind:34},{x:200,y:250,id:"color",kind:34},{x:250,y:250,id:"color",kind:34},{x:150,y:250,id:"cell"},
{x:150,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:150,y:100,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:250,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:100,id:"cell"}],name:{key:"tree"}},snake6x6:{width:300,height:300,items:[{x:150,y:100,id:"color",kind:31},
{x:250,y:150,id:"color",kind:31},{x:250,y:50,id:"color",kind:31},{x:50,y:50,id:"color",kind:1},{x:200,y:100,id:"color",kind:31},{x:100,y:200,id:"color",kind:26},{x:150,y:200,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:200,y:200,id:"color",kind:26},{x:250,y:200,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:250,y:0,id:"color",kind:26},{x:200,y:0,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:150,y:0,id:"color",kind:26},{x:100,y:100,id:"color",kind:31},{x:100,y:150,id:"color",
kind:13},{x:150,y:150,id:"color",kind:13},{x:50,y:150,id:"color",kind:13},{x:0,y:200,id:"color",kind:14},{x:0,y:150,id:"color",kind:14},{x:0,y:100,id:"color",kind:14},{x:50,y:100,id:"color",kind:14},{x:0,y:50,id:"color",kind:14},{x:0,y:0,id:"color",kind:14},{x:50,y:0,id:"color",kind:14},{x:100,y:0,id:"color",kind:14},{x:100,y:50,id:"color",kind:14},{x:150,y:50,id:"color",kind:14},{x:50,y:200,id:"color",kind:14},{x:50,y:250,id:"color",kind:14},{x:0,y:250,id:"color",kind:14},{x:100,y:250,id:"color",
kind:14},{x:150,y:250,id:"color",kind:14},{x:200,y:250,id:"color",kind:14},{x:250,y:250,id:"color",kind:14},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:50,id:"cell"},{x:150,y:150,id:"cell"},{x:0,y:0,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},
{x:250,y:250,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:250,id:"cell"},{x:100,y:150,id:"cell"}],name:{key:"snake"}},duck6x6:{width:300,height:300,items:[{x:0,y:250,id:"color",kind:18},{x:250,y:250,id:"color",kind:18},{x:250,y:150,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:100,y:50,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},
{x:100,y:0,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:250,y:50,id:"color",kind:17},{x:200,y:50,id:"color",kind:17},{x:150,y:150,id:"color",kind:13},{x:100,y:150,id:"color",kind:13},{x:50,y:150,id:"color",kind:13},{x:0,y:150,id:"color",kind:13},{x:0,y:200,id:"color",kind:13},{x:150,y:100,id:"color",kind:13},{x:150,y:50,id:"color",kind:13},{x:200,y:0,id:"color",kind:14},{x:150,y:0,id:"color",kind:14},{x:200,y:150,id:"color",kind:14},
{x:200,y:200,id:"color",kind:14},{x:250,y:200,id:"color",kind:14},{x:200,y:250,id:"color",kind:15},{x:100,y:250,id:"color",kind:15},{x:50,y:250,id:"color",kind:15},{x:150,y:250,id:"color",kind:15},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:100,
y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:250,id:"cell"}],name:{key:"duck"}},headphones6x7:{width:350,height:300,items:[{x:0,y:150,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:300,y:100,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:50,y:250,id:"color",kind:18},{x:250,y:200,id:"color",kind:18},{x:250,y:250,id:"color",kind:18},{x:50,y:200,id:"color",kind:18},
{x:0,y:200,id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:100,y:200,id:"color",kind:16},{x:100,y:250,id:"color",kind:16},{x:200,y:200,id:"color",kind:16},{x:200,y:250,id:"color",kind:16},{x:0,y:250,id:"color",kind:35},{x:150,y:250,id:"color",kind:35},{x:150,y:200,id:"color",kind:35},{x:150,y:150,id:"color",kind:35},{x:100,y:150,id:"color",kind:35},{x:50,y:150,id:"color",kind:35},{x:100,y:100,
id:"color",kind:35},{x:100,y:50,id:"color",kind:35},{x:150,y:100,id:"color",kind:35},{x:150,y:50,id:"color",kind:35},{x:200,y:50,id:"color",kind:35},{x:200,y:100,id:"color",kind:35},{x:200,y:150,id:"color",kind:35},{x:250,y:150,id:"color",kind:35},{x:300,y:250,id:"color",kind:35},{x:300,y:0,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:0,y:100,id:"color",kind:23},{x:0,y:50,id:"color",kind:23},{x:50,y:50,id:"color",kind:23},{x:50,y:0,id:"color",kind:23},{x:100,y:0,id:"color",kind:23},{x:150,
y:0,id:"color",kind:23},{x:200,y:0,id:"color",kind:23},{x:250,y:0,id:"color",kind:23},{x:50,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:100,id:"cell"},
{x:0,y:50,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:100,id:"cell"},{x:300,y:100,id:"cell"}],name:{key:"headphones"}},strawberry7x6:{width:300,height:350,items:[{x:100,y:0,id:"color",kind:14},{x:150,y:0,id:"color",kind:14},{x:50,y:0,id:"color",kind:13},{x:200,y:0,id:"color",kind:13},{x:100,y:50,id:"color",kind:13},{x:0,y:250,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:250,y:300,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:250,
y:50,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:50,y:300,id:"color",kind:20},{x:50,y:50,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},{x:0,y:100,id:"color",kind:26},{x:0,y:150,id:"color",kind:26},{x:0,y:200,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:50,y:250,id:"color",kind:26},{x:100,y:300,id:"color",kind:26},{x:150,y:300,id:"color",kind:26},{x:150,y:250,id:"color",kind:26},{x:150,y:200,id:"color",kind:26},{x:100,
y:200,id:"color",kind:26},{x:100,y:150,id:"color",kind:26},{x:100,y:100,id:"color",kind:26},{x:150,y:150,id:"color",kind:26},{x:150,y:50,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:250,y:150,id:"color",kind:26},{x:250,y:200,id:"color",kind:26},{x:200,y:200,id:"color",kind:26},{x:200,y:250,id:"color",kind:26},{x:50,y:150,id:"color",kind:17},{x:100,y:250,id:"color",kind:17},{x:150,y:100,id:"color",kind:17},{x:200,y:150,id:"color",
kind:17},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:100,id:"cell"},{x:0,
y:100,id:"cell"},{x:50,y:50,id:"cell"}],name:{key:"strawberry"}},squirrel6x7:{width:400,height:300,items:[{x:0,y:50,id:"color",kind:3},{x:50,y:50,id:"color",kind:3},{x:50,y:0,id:"color",kind:3},{x:50,y:100,id:"color",kind:3},{x:50,y:150,id:"color",kind:3},{x:150,y:200,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:200,y:250,id:"color",kind:3},{x:300,y:200,id:"color",kind:3},{x:300,y:0,id:"color",kind:3},{x:300,y:150,id:"color",kind:3},{x:250,y:50,id:"color",kind:3},{x:250,y:100,id:"color",
kind:3},{x:250,y:150,id:"color",kind:3},{x:250,y:200,id:"color",kind:3},{x:250,y:250,id:"color",kind:3},{x:250,y:0,id:"color",kind:3},{x:50,y:200,id:"color",kind:4},{x:0,y:150,id:"color",kind:3},{x:100,y:250,id:"color",kind:4},{x:100,y:200,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:300,y:250,id:"color",kind:13},{x:100,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:350,y:200,id:"color",
kind:13},{x:350,y:250,id:"color",kind:13},{x:50,y:250,id:"color",kind:13},{x:0,y:250,id:"color",kind:13},{x:200,y:200,id:"color",kind:13},{x:150,y:150,id:"color",kind:13},{x:200,y:150,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:200,y:100,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:300,y:100,
id:"color",kind:4},{x:350,y:100,id:"color",kind:4},{x:350,y:50,id:"color",kind:4},{x:300,y:50,id:"color",kind:3},{x:50,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},
{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"}],name:{key:"squirrel"}},plane6x7:{width:350,height:300,items:[{x:300,y:100,id:"color",kind:26},{x:300,y:150,id:"color",kind:22},{x:250,y:150,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:150,y:200,id:"color",
kind:22},{x:100,y:150,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:150,y:50,id:"color",kind:25},{x:150,y:0,id:"color",kind:25},{x:50,y:100,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:100,y:50,id:"color",kind:25},{x:0,y:50,id:"color",kind:21},{x:50,y:50,id:"color",kind:21},{x:50,y:0,id:"color",kind:21},{x:100,y:0,id:"color",kind:21},{x:0,y:0,id:"color",kind:21},{x:0,y:200,id:"color",
kind:21},{x:0,y:250,id:"color",kind:21},{x:50,y:250,id:"color",kind:21},{x:50,y:200,id:"color",kind:21},{x:100,y:250,id:"color",kind:21},{x:200,y:250,id:"color",kind:21},{x:200,y:200,id:"color",kind:21},{x:250,y:200,id:"color",kind:21},{x:250,y:250,id:"color",kind:21},{x:300,y:250,id:"color",kind:21},{x:300,y:200,id:"color",kind:21},{x:250,y:50,id:"color",kind:21},{x:200,y:50,id:"color",kind:21},{x:250,y:100,id:"color",kind:21},{x:300,y:50,id:"color",kind:21},{x:300,y:0,id:"color",kind:21},{x:250,
y:0,id:"color",kind:21},{x:200,y:0,id:"color",kind:21},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:0,y:100,id:"cell"}],
name:{key:"plane"}},shirt7x6:{width:300,height:350,items:[{x:100,y:50,id:"color",kind:7},{x:150,y:0,id:"color",kind:7},{x:150,y:50,id:"color",kind:7},{x:100,y:0,id:"color",kind:7},{x:50,y:250,id:"color",kind:19},{x:100,y:250,id:"color",kind:19},{x:150,y:250,id:"color",kind:19},{x:200,y:250,id:"color",kind:19},{x:200,y:200,id:"color",kind:19},{x:150,y:200,id:"color",kind:19},{x:150,y:150,id:"color",kind:19},{x:100,y:150,id:"color",kind:19},{x:100,y:200,id:"color",kind:19},{x:50,y:150,id:"color",kind:19},
{x:50,y:200,id:"color",kind:19},{x:100,y:100,id:"color",kind:19},{x:150,y:100,id:"color",kind:19},{x:200,y:150,id:"color",kind:19},{x:200,y:100,id:"color",kind:19},{x:200,y:50,id:"color",kind:19},{x:50,y:100,id:"color",kind:19},{x:50,y:50,id:"color",kind:19},{x:0,y:100,id:"color",kind:18},{x:0,y:50,id:"color",kind:18},{x:250,y:50,id:"color",kind:18},{x:250,y:100,id:"color",kind:18},{x:50,y:300,id:"color",kind:3},{x:100,y:300,id:"color",kind:3},{x:150,y:300,id:"color",kind:3},{x:200,y:300,id:"color",
kind:3},{x:0,y:300,id:"color",kind:8},{x:0,y:250,id:"color",kind:8},{x:0,y:200,id:"color",kind:8},{x:0,y:150,id:"color",kind:8},{x:250,y:150,id:"color",kind:8},{x:250,y:200,id:"color",kind:8},{x:250,y:250,id:"color",kind:8},{x:250,y:300,id:"color",kind:8},{x:250,y:0,id:"color",kind:8},{x:200,y:0,id:"color",kind:8},{x:50,y:0,id:"color",kind:8},{x:0,y:0,id:"color",kind:8},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,
id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"}],name:{key:"blue_tee"}},space6x7:{width:350,height:300,items:[{x:0,y:100,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:50,y:50,id:"color",
kind:22},{x:50,y:0,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:100,y:50,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:200,y:250,id:"color",kind:12},{x:250,y:200,id:"color",kind:12},{x:300,y:200,id:"color",kind:11},{x:300,y:250,id:"color",kind:11},{x:250,y:250,id:"color",kind:11},{x:0,y:150,id:"color",kind:1},{x:0,y:200,id:"color",kind:1},{x:50,y:250,
id:"color",kind:1},{x:50,y:200,id:"color",kind:1},{x:100,y:200,id:"color",kind:1},{x:150,y:250,id:"color",kind:1},{x:150,y:200,id:"color",kind:1},{x:150,y:150,id:"color",kind:1},{x:200,y:150,id:"color",kind:1},{x:200,y:200,id:"color",kind:1},{x:250,y:150,id:"color",kind:1},{x:200,y:100,id:"color",kind:1},{x:250,y:100,id:"color",kind:1},{x:300,y:100,id:"color",kind:1},{x:300,y:150,id:"color",kind:1},{x:300,y:50,id:"color",kind:1},{x:300,y:0,id:"color",kind:1},{x:250,y:0,id:"color",kind:1},{x:200,y:50,
id:"color",kind:1},{x:200,y:0,id:"color",kind:1},{x:150,y:0,id:"color",kind:1},{x:0,y:0,id:"color",kind:1},{x:250,y:50,id:"color",kind:17},{x:100,y:250,id:"color",kind:1},{x:0,y:250,id:"color",kind:17},{x:0,y:250,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:200,
y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:250,id:"cell"}],name:{key:"the_moon"}},earring7x6:{width:300,height:350,items:[{x:100,y:150,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:100,y:300,id:"color",kind:20},{x:50,y:200,id:"color",kind:7},{x:150,y:200,id:"color",kind:7},{x:200,y:200,id:"color",kind:7},{x:200,y:150,id:"color",kind:7},
{x:250,y:150,id:"color",kind:7},{x:250,y:100,id:"color",kind:7},{x:200,y:100,id:"color",kind:7},{x:50,y:150,id:"color",kind:7},{x:50,y:100,id:"color",kind:7},{x:50,y:50,id:"color",kind:7},{x:100,y:50,id:"color",kind:7},{x:150,y:50,id:"color",kind:7},{x:200,y:50,id:"color",kind:7},{x:250,y:50,id:"color",kind:7},{x:250,y:0,id:"color",kind:7},{x:200,y:0,id:"color",kind:7},{x:0,y:100,id:"color",kind:7},{x:0,y:150,id:"color",kind:7},{x:50,y:0,id:"color",kind:6},{x:100,y:0,id:"color",kind:6},{x:150,y:0,
id:"color",kind:6},{x:50,y:300,id:"color",kind:6},{x:50,y:250,id:"color",kind:6},{x:150,y:250,id:"color",kind:6},{x:150,y:300,id:"color",kind:6},{x:200,y:300,id:"color",kind:6},{x:200,y:250,id:"color",kind:6},{x:0,y:200,id:"color",kind:7},{x:0,y:250,id:"color",kind:7},{x:0,y:300,id:"color",kind:7},{x:0,y:50,id:"color",kind:7},{x:0,y:0,id:"color",kind:7},{x:250,y:200,id:"color",kind:17},{x:250,y:250,id:"color",kind:17},{x:250,y:300,id:"color",kind:17},{x:100,y:250,id:"color",kind:20},{x:0,y:150,id:"cell"},
{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},
{x:0,y:300,id:"cell"}],name:{key:"earring"}},lipstick6x7:{width:350,height:300,items:[{x:50,y:50,id:"color",kind:29},{x:100,y:0,id:"color",kind:29},{x:200,y:0,id:"color",kind:29},{x:100,y:50,id:"color",kind:29},{x:150,y:50,id:"color",kind:29},{x:200,y:50,id:"color",kind:29},{x:250,y:50,id:"color",kind:29},{x:50,y:100,id:"color",kind:30},{x:100,y:100,id:"color",kind:30},{x:150,y:100,id:"color",kind:30},{x:200,y:100,id:"color",kind:30},{x:250,y:100,id:"color",kind:30},{x:100,y:150,id:"color",kind:30},
{x:150,y:150,id:"color",kind:30},{x:200,y:150,id:"color",kind:30},{x:200,y:200,id:"color",kind:29},{x:250,y:200,id:"color",kind:29},{x:200,y:250,id:"color",kind:1},{x:250,y:250,id:"color",kind:1},{x:0,y:0,id:"color",kind:7},{x:50,y:0,id:"color",kind:7},{x:0,y:50,id:"color",kind:7},{x:0,y:100,id:"color",kind:7},{x:0,y:150,id:"color",kind:7},{x:50,y:150,id:"color",kind:7},{x:50,y:200,id:"color",kind:7},{x:100,y:250,id:"color",kind:7},{x:100,y:200,id:"color",kind:7},{x:150,y:200,id:"color",kind:7},{x:150,
y:250,id:"color",kind:7},{x:300,y:200,id:"color",kind:7},{x:250,y:150,id:"color",kind:7},{x:300,y:150,id:"color",kind:7},{x:300,y:100,id:"color",kind:7},{x:300,y:50,id:"color",kind:7},{x:300,y:0,id:"color",kind:7},{x:250,y:0,id:"color",kind:7},{x:150,y:0,id:"color",kind:7},{x:0,y:200,id:"color",kind:7},{x:50,y:250,id:"color",kind:7},{x:0,y:250,id:"color",kind:6},{x:300,y:250,id:"color",kind:6},{x:0,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,
id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"}],name:{key:"lipstick"}},dog6x7:{width:350,height:300,items:[{x:100,y:200,id:"color",kind:4},{x:200,y:200,id:"color",kind:4},
{x:200,y:150,id:"color",kind:4},{x:150,y:100,id:"color",kind:4},{x:100,y:150,id:"color",kind:4},{x:100,y:50,id:"color",kind:4},{x:200,y:50,id:"color",kind:4},{x:150,y:50,id:"color",kind:4},{x:150,y:200,id:"color",kind:0},{x:150,y:250,id:"color",kind:26},{x:50,y:50,id:"color",kind:3},{x:50,y:100,id:"color",kind:3},{x:250,y:100,id:"color",kind:3},{x:250,y:50,id:"color",kind:3},{x:150,y:150,id:"color",kind:4},{x:100,y:100,id:"color",kind:1},{x:200,y:100,id:"color",kind:1},{x:100,y:250,id:"color",kind:3},
{x:200,y:250,id:"color",kind:3},{x:0,y:250,id:"color",kind:4},{x:300,y:250,id:"color",kind:4},{x:0,y:200,id:"color",kind:4},{x:300,y:200,id:"color",kind:4},{x:250,y:250,id:"color",kind:13},{x:250,y:200,id:"color",kind:13},{x:250,y:150,id:"color",kind:13},{x:300,y:150,id:"color",kind:13},{x:300,y:100,id:"color",kind:13},{x:300,y:50,id:"color",kind:13},{x:300,y:0,id:"color",kind:13},{x:250,y:0,id:"color",kind:13},{x:200,y:0,id:"color",kind:13},{x:150,y:0,id:"color",kind:13},{x:100,y:0,id:"color",kind:13},
{x:50,y:0,id:"color",kind:13},{x:0,y:0,id:"color",kind:13},{x:0,y:50,id:"color",kind:13},{x:0,y:100,id:"color",kind:13},{x:0,y:150,id:"color",kind:13},{x:50,y:150,id:"color",kind:13},{x:50,y:200,id:"color",kind:13},{x:50,y:250,id:"color",kind:13},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:50,id:"cell"},
{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:200,id:"cell"}],name:{key:"dog"}},city7x7:{width:350,height:350,items:[{x:0,y:0,id:"color",kind:28},{x:100,y:0,id:"color",kind:28},{x:50,y:0,id:"color",kind:28},{x:50,y:50,id:"color",kind:28},{x:100,y:100,id:"color",kind:28},{x:50,y:100,id:"color",kind:28},{x:0,y:100,id:"color",kind:28},{x:50,y:150,id:"color",
kind:28},{x:150,y:150,id:"color",kind:28},{x:150,y:100,id:"color",kind:28},{x:150,y:0,id:"color",kind:28},{x:150,y:50,id:"color",kind:28},{x:150,y:200,id:"color",kind:28},{x:150,y:250,id:"color",kind:28},{x:100,y:200,id:"color",kind:28},{x:100,y:300,id:"color",kind:28},{x:0,y:200,id:"color",kind:28},{x:50,y:200,id:"color",kind:28},{x:50,y:250,id:"color",kind:28},{x:0,y:300,id:"color",kind:28},{x:150,y:300,id:"color",kind:28},{x:250,y:300,id:"color",kind:1},{x:250,y:250,id:"color",kind:1},{x:250,y:200,
id:"color",kind:1},{x:250,y:150,id:"color",kind:1},{x:250,y:0,id:"color",kind:1},{x:300,y:150,id:"color",kind:1},{x:300,y:0,id:"color",kind:1},{x:0,y:50,id:"color",kind:17},{x:100,y:150,id:"color",kind:17},{x:100,y:250,id:"color",kind:17},{x:50,y:300,id:"color",kind:28},{x:200,y:0,id:"color",kind:1},{x:200,y:50,id:"color",kind:1},{x:200,y:150,id:"color",kind:1},{x:200,y:200,id:"color",kind:1},{x:200,y:250,id:"color",kind:1},{x:200,y:300,id:"color",kind:1},{x:250,y:50,id:"color",kind:2},{x:300,y:50,
id:"color",kind:2},{x:300,y:100,id:"color",kind:2},{x:300,y:300,id:"color",kind:27},{x:300,y:250,id:"color",kind:27},{x:300,y:200,id:"color",kind:27},{x:100,y:50,id:"color",kind:0},{x:0,y:150,id:"color",kind:0},{x:0,y:250,id:"color",kind:0},{x:250,y:100,id:"color",kind:2},{x:200,y:100,id:"color",kind:2},{x:300,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:150,
y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:0,y:0,id:"cell"},{x:0,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:150,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:50,id:"cell"},{x:100,y:50,id:"cell"}],name:{key:"city"}},mountains7x7:{width:350,height:350,items:[{x:50,y:200,id:"color",kind:27},{x:0,y:200,id:"color",kind:27},{x:100,y:100,id:"color",kind:27},{x:100,y:50,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:150,y:100,
id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:150,y:200,id:"color",kind:27},{x:150,y:150,id:"color",kind:27},{x:200,y:150,id:"color",kind:27},{x:200,y:200,id:"color",kind:27},{x:200,y:250,id:"color",kind:27},{x:250,y:200,id:"color",kind:27},{x:250,y:150,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:150,y:300,id:"color",kind:27},{x:200,y:300,id:"color",
kind:22},{x:250,y:250,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:300,y:250,id:"color",kind:27},{x:0,y:150,id:"color",kind:27},{x:0,y:100,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:50,y:100,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:200,y:0,id:"color",
kind:20},{x:300,y:0,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:300,y:100,id:"color",kind:20},{x:300,y:150,id:"color",kind:20},{x:100,y:250,id:"color",kind:27},{x:50,y:300,id:"color",kind:27},{x:0,y:250,id:"color",kind:27},{x:0,y:300,id:"color",kind:14},{x:100,y:300,id:"color",kind:14},{x:150,y:250,id:"color",kind:14},{x:0,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:100,
y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"}],name:{key:"mountains"}},baseball7x7:{width:350,height:350,items:[{x:50,y:250,id:"color",kind:26},{x:100,y:200,id:"color",kind:26},{x:100,y:150,id:"color",kind:26},{x:100,y:100,id:"color",kind:26},{x:50,
y:50,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:200,y:200,id:"color",kind:26},{x:250,y:250,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:50,y:100,id:"color",kind:23},{x:150,y:100,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:100,y:50,id:"color",kind:23},{x:100,y:0,id:"color",kind:23},{x:150,y:0,id:"color",kind:23},{x:200,y:0,id:"color",kind:23},{x:0,y:250,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:50,y:300,id:"color",kind:20},
{x:250,y:300,id:"color",kind:20},{x:300,y:300,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:100,y:300,id:"color",kind:22},{x:300,y:100,id:"color",kind:22},{x:200,y:50,id:"color",kind:23},{x:150,y:150,id:"color",kind:23},{x:150,y:200,id:"color",kind:23},{x:50,y:200,id:"color",kind:23},{x:50,y:150,id:"color",
kind:23},{x:0,y:100,id:"color",kind:23},{x:0,y:150,id:"color",kind:23},{x:0,y:200,id:"color",kind:23},{x:250,y:150,id:"color",kind:23},{x:250,y:100,id:"color",kind:23},{x:150,y:300,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:100,y:250,id:"color",kind:23},{x:150,y:250,id:"color",kind:23},{x:200,y:250,id:"color",kind:23},{x:250,y:200,id:"color",kind:23},{x:100,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:250,id:"cell"},
{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:300,id:"cell"}],name:{key:"baseball"}},tv7x7:{width:350,height:350,items:[{x:0,
y:0,id:"color",kind:0},{x:0,y:50,id:"color",kind:0},{x:0,y:100,id:"color",kind:0},{x:0,y:200,id:"color",kind:0},{x:50,y:200,id:"color",kind:0},{x:100,y:200,id:"color",kind:0},{x:150,y:200,id:"color",kind:0},{x:200,y:200,id:"color",kind:0},{x:250,y:200,id:"color",kind:0},{x:300,y:150,id:"color",kind:0},{x:300,y:100,id:"color",kind:0},{x:300,y:50,id:"color",kind:0},{x:300,y:0,id:"color",kind:0},{x:250,y:0,id:"color",kind:0},{x:200,y:0,id:"color",kind:0},{x:150,y:0,id:"color",kind:0},{x:100,y:0,id:"color",
kind:0},{x:50,y:0,id:"color",kind:0},{x:0,y:150,id:"color",kind:0},{x:300,y:200,id:"color",kind:0},{x:150,y:250,id:"color",kind:0},{x:50,y:300,id:"color",kind:0},{x:100,y:300,id:"color",kind:0},{x:150,y:300,id:"color",kind:0},{x:200,y:300,id:"color",kind:0},{x:250,y:300,id:"color",kind:0},{x:250,y:50,id:"color",kind:7},{x:250,y:100,id:"color",kind:13},{x:250,y:150,id:"color",kind:13},{x:50,y:150,id:"color",kind:6},{x:100,y:150,id:"color",kind:6},{x:50,y:100,id:"color",kind:4},{x:100,y:100,id:"color",
kind:4},{x:50,y:50,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:200,y:100,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:0,y:250,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},{x:0,y:300,id:"color",kind:3},{x:300,y:300,
id:"color",kind:3},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},
{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"}],name:{key:"tv"}},sunflower7x7:{width:350,height:350,items:[{x:0,y:100,id:"color",kind:3},{x:150,y:200,id:"color",kind:3},{x:200,y:150,id:"color",kind:3},{x:300,y:200,id:"color",kind:3},{x:100,y:150,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:100,y:0,id:"color",
kind:20},{x:50,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:50,y:200,id:"color",kind:3},{x:100,y:100,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:0,y:200,id:"color",kind:9},{x:50,y:150,id:"color",kind:9},{x:50,y:250,id:"color",kind:9},
{x:100,y:200,id:"color",kind:9},{x:200,y:200,id:"color",kind:9},{x:150,y:150,id:"color",kind:9},{x:200,y:100,id:"color",kind:9},{x:250,y:150,id:"color",kind:9},{x:300,y:100,id:"color",kind:9},{x:250,y:300,id:"color",kind:9},{x:100,y:300,id:"color",kind:14},{x:100,y:250,id:"color",kind:14},{x:250,y:250,id:"color",kind:14},{x:0,y:250,id:"color",kind:14},{x:50,y:300,id:"color",kind:13},{x:150,y:300,id:"color",kind:13},{x:200,y:300,id:"color",kind:13},{x:200,y:250,id:"color",kind:13},{x:300,y:300,id:"color",
kind:13},{x:0,y:150,id:"color",kind:17},{x:50,y:100,id:"color",kind:17},{x:0,y:50,id:"color",kind:17},{x:250,y:200,id:"color",kind:17},{x:300,y:250,id:"color",kind:17},{x:300,y:150,id:"color",kind:17},{x:150,y:250,id:"color",kind:17},{x:0,y:300,id:"color",kind:17},{x:50,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:250,id:"cell"},{x:200,
y:200,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:100,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:150,y:300,id:"cell"}],name:{key:"sunflowers"}},umbrella7x7:{width:350,height:350,items:[{x:300,y:100,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:150,y:100,id:"color",kind:26},{x:100,y:100,id:"color",
kind:26},{x:50,y:100,id:"color",kind:26},{x:0,y:100,id:"color",kind:26},{x:50,y:50,id:"color",kind:26},{x:100,y:50,id:"color",kind:26},{x:150,y:50,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:150,y:150,id:"color",kind:24},{x:150,y:200,id:"color",kind:24},{x:150,y:250,id:"color",kind:24},{x:150,y:300,id:"color",kind:28},{x:200,y:300,id:"color",kind:28},{x:0,y:150,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:100,y:150,
id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:100,y:300,id:"color",kind:22},{x:50,y:300,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:200,y:200,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:250,y:250,id:"color",
kind:22},{x:300,y:50,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:200,y:0,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:50,y:200,id:"color",kind:23},{x:50,y:250,id:"color",kind:23},{x:250,y:200,id:"color",kind:23},{x:250,y:150,id:"color",kind:23},{x:100,y:0,id:"color",kind:23},{x:0,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},
{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:100,y:0,id:"cell"}],name:{key:"umbrella"}},arrow7x7:{width:350,height:350,items:[{x:0,y:150,id:"color",
kind:1},{x:0,y:100,id:"color",kind:1},{x:50,y:100,id:"color",kind:1},{x:100,y:50,id:"color",kind:1},{x:100,y:150,id:"color",kind:1},{x:150,y:100,id:"color",kind:1},{x:0,y:50,id:"color",kind:1},{x:0,y:0,id:"color",kind:1},{x:200,y:150,id:"color",kind:1},{x:150,y:200,id:"color",kind:1},{x:200,y:250,id:"color",kind:1},{x:250,y:200,id:"color",kind:1},{x:250,y:300,id:"color",kind:1},{x:300,y:250,id:"color",kind:1},{x:0,y:300,id:"color",kind:22},{x:50,y:300,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},
{x:100,y:250,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:100,y:300,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:150,y:300,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:300,y:100,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:250,y:150,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:100,y:0,
id:"color",kind:1},{x:50,y:0,id:"color",kind:1},{x:150,y:0,id:"color",kind:1},{x:300,y:300,id:"color",kind:1},{x:50,y:200,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:200,y:0,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:100,y:100,id:"color",kind:16},{x:150,y:150,id:"color",kind:16},{x:200,y:200,id:"color",kind:16},{x:250,y:250,id:"color",kind:16},{x:50,y:50,
id:"color",kind:16},{x:0,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:300,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:150,y:150,id:"cell"}],
name:{key:"arrow"}},cactus7x7:{width:350,height:350,items:[{x:100,y:300,id:"color",kind:13},{x:100,y:250,id:"color",kind:13},{x:100,y:50,id:"color",kind:13},{x:100,y:100,id:"color",kind:13},{x:0,y:200,id:"color",kind:13},{x:200,y:100,id:"color",kind:13},{x:0,y:300,id:"color",kind:6},{x:0,y:250,id:"color",kind:6},{x:200,y:300,id:"color",kind:6},{x:150,y:250,id:"color",kind:6},{x:150,y:300,id:"color",kind:6},{x:250,y:250,id:"color",kind:6},{x:200,y:250,id:"color",kind:6},{x:250,y:300,id:"color",kind:6},
{x:300,y:300,id:"color",kind:6},{x:150,y:200,id:"color",kind:6},{x:300,y:200,id:"color",kind:6},{x:300,y:250,id:"color",kind:6},{x:0,y:100,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},
{x:300,y:0,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:300,y:100,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:250,y:200,id:"color",kind:20},{x:300,y:150,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:250,y:0,id:"color",kind:17},{x:50,y:300,id:"color",kind:14},{x:50,y:250,id:"color",kind:14},{x:100,y:200,id:"color",kind:14},{x:50,y:150,id:"color",kind:14},{x:50,y:100,id:"color",kind:14},{x:50,y:50,id:"color",kind:14},{x:100,y:150,id:"color",
kind:14},{x:50,y:200,id:"color",kind:13},{x:200,y:150,id:"color",kind:14},{x:150,y:150,id:"color",kind:14},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:0,id:"cell"},{x:50,y:300,id:"cell"}],
name:{key:"cactus"}},hat7x7:{width:350,height:350,items:[{x:0,y:150,id:"color",kind:4},{x:0,y:100,id:"color",kind:4},{x:50,y:150,id:"color",kind:4},{x:100,y:150,id:"color",kind:4},{x:150,y:150,id:"color",kind:4},{x:200,y:150,id:"color",kind:4},{x:250,y:150,id:"color",kind:3},{x:300,y:100,id:"color",kind:3},{x:300,y:150,id:"color",kind:3},{x:100,y:50,id:"color",kind:4},{x:100,y:0,id:"color",kind:4},{x:100,y:100,id:"color",kind:4},{x:200,y:100,id:"color",kind:3},{x:200,y:0,id:"color",kind:3},{x:150,
y:100,id:"color",kind:4},{x:200,y:50,id:"color",kind:3},{x:150,y:50,id:"color",kind:4},{x:0,y:300,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:50,y:300,id:"color",kind:22},{x:100,y:300,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:250,y:200,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},
{x:300,y:300,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:200,y:200,id:"color",kind:1},{x:200,y:250,id:"color",kind:1},{x:150,y:250,id:"color",kind:1},{x:150,y:300,id:"color",kind:1},
{x:100,y:250,id:"color",kind:1},{x:100,y:200,id:"color",kind:1},{x:150,y:200,id:"color",kind:1},{x:200,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:150,y:300,
id:"cell"}],name:{key:"cowboy_hat"}},bird7x7:{width:350,height:350,items:[{x:50,y:50,id:"color",kind:3},{x:100,y:50,id:"color",kind:3},{x:100,y:100,id:"color",kind:3},{x:50,y:100,id:"color",kind:3},{x:150,y:200,id:"color",kind:4},{x:150,y:100,id:"color",kind:3},{x:200,y:150,id:"color",kind:3},{x:200,y:200,id:"color",kind:3},{x:250,y:200,id:"color",kind:3},{x:300,y:200,id:"color",kind:3},{x:100,y:150,id:"color",kind:4},{x:50,y:150,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:100,y:200,id:"color",
kind:26},{x:100,y:250,id:"color",kind:26},{x:200,y:250,id:"color",kind:3},{x:150,y:150,id:"color",kind:3},{x:150,y:250,id:"color",kind:4},{x:100,y:300,id:"color",kind:11},{x:250,y:250,id:"color",kind:11},{x:200,y:300,id:"color",kind:11},{x:0,y:300,id:"color",kind:13},{x:250,y:150,id:"color",kind:13},{x:200,y:100,id:"color",kind:13},{x:250,y:50,id:"color",kind:13},{x:200,y:50,id:"color",kind:13},{x:150,y:0,id:"color",kind:13},{x:250,y:100,id:"color",kind:11},{x:250,y:0,id:"color",kind:11},{x:300,y:50,
id:"color",kind:11},{x:300,y:100,id:"color",kind:13},{x:300,y:0,id:"color",kind:11},{x:300,y:150,id:"color",kind:11},{x:250,y:300,id:"color",kind:13},{x:300,y:250,id:"color",kind:13},{x:300,y:300,id:"color",kind:11},{x:150,y:300,id:"color",kind:28},{x:0,y:100,id:"color",kind:0},{x:50,y:300,id:"color",kind:20},{x:50,y:250,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,
y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:50,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:150,y:300,id:"cell"},{x:250,
y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:150,y:0,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:100,id:"cell"}],name:{key:"robin"}},chicken7x7:{width:350,height:350,items:[{x:50,y:0,id:"color",kind:26},{x:100,y:0,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:100,y:50,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},
{x:100,y:200,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:200,y:200,id:"color",kind:22},{x:250,y:200,id:"color",kind:22},{x:250,y:150,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:300,y:100,id:"color",kind:22},{x:0,y:100,id:"color",kind:8},{x:150,y:300,id:"color",kind:8},{x:150,y:200,id:"color",kind:23},{x:150,y:150,id:"color",kind:23},{x:200,y:150,id:"color",kind:23},{x:50,y:100,id:"color",kind:23},{x:50,y:50,
id:"color",kind:23},{x:0,y:300,id:"color",kind:6},{x:50,y:300,id:"color",kind:6},{x:100,y:300,id:"color",kind:6},{x:200,y:300,id:"color",kind:6},{x:250,y:300,id:"color",kind:6},{x:300,y:300,id:"color",kind:6},{x:0,y:250,id:"color",kind:6},{x:300,y:250,id:"color",kind:6},{x:0,y:200,id:"color",kind:4},{x:0,y:150,id:"color",kind:4},{x:50,y:250,id:"color",kind:4},{x:0,y:50,id:"color",kind:4},{x:0,y:0,id:"color",kind:4},{x:150,y:0,id:"color",kind:4},{x:150,y:50,id:"color",kind:4},{x:150,y:100,id:"color",
kind:4},{x:200,y:100,id:"color",kind:4},{x:200,y:50,id:"color",kind:4},{x:200,y:0,id:"color",kind:4},{x:250,y:0,id:"color",kind:4},{x:250,y:50,id:"color",kind:4},{x:300,y:50,id:"color",kind:4},{x:300,y:0,id:"color",kind:4},{x:300,y:150,id:"color",kind:4},{x:300,y:200,id:"color",kind:4},{x:250,y:250,id:"color",kind:4},{x:150,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},
{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:250,id:"cell"}],name:{key:"chicken"}},teapot7x7:{width:350,height:350,items:[{x:100,
y:300,id:"color",kind:28},{x:150,y:300,id:"color",kind:28},{x:200,y:300,id:"color",kind:28},{x:150,y:250,id:"color",kind:27},{x:100,y:250,id:"color",kind:27},{x:200,y:250,id:"color",kind:27},{x:200,y:200,id:"color",kind:27},{x:150,y:200,id:"color",kind:27},{x:100,y:200,id:"color",kind:27},{x:100,y:150,id:"color",kind:27},{x:150,y:150,id:"color",kind:27},{x:200,y:150,id:"color",kind:27},{x:150,y:100,id:"color",kind:27},{x:100,y:100,id:"color",kind:27},{x:200,y:100,id:"color",kind:27},{x:100,y:50,id:"color",
kind:25},{x:150,y:50,id:"color",kind:25},{x:200,y:50,id:"color",kind:25},{x:150,y:0,id:"color",kind:0},{x:250,y:100,id:"color",kind:28},{x:300,y:100,id:"color",kind:28},{x:250,y:200,id:"color",kind:28},{x:0,y:100,id:"color",kind:27},{x:300,y:150,id:"color",kind:28},{x:300,y:200,id:"color",kind:28},{x:50,y:150,id:"color",kind:27},{x:50,y:100,id:"color",kind:27},{x:0,y:150,id:"color",kind:8},{x:0,y:200,id:"color",kind:8},{x:50,y:200,id:"color",kind:8},{x:50,y:250,id:"color",kind:8},{x:0,y:250,id:"color",
kind:8},{x:0,y:300,id:"color",kind:8},{x:50,y:300,id:"color",kind:8},{x:50,y:50,id:"color",kind:8},{x:0,y:50,id:"color",kind:8},{x:0,y:0,id:"color",kind:8},{x:50,y:0,id:"color",kind:8},{x:100,y:0,id:"color",kind:8},{x:200,y:0,id:"color",kind:8},{x:250,y:0,id:"color",kind:8},{x:300,y:0,id:"color",kind:8},{x:300,y:50,id:"color",kind:8},{x:250,y:50,id:"color",kind:8},{x:250,y:150,id:"color",kind:8},{x:250,y:250,id:"color",kind:8},{x:250,y:300,id:"color",kind:8},{x:300,y:300,id:"color",kind:8},{x:300,
y:250,id:"color",kind:8},{x:150,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:150,
y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:100,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:150,id:"cell"}],name:{key:"kettle"}},faucet7x7:{width:350,height:350,items:[{x:150,y:0,id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:200,y:100,id:"color",kind:24},{x:150,y:100,id:"color",kind:24},{x:150,y:150,id:"color",kind:24},{x:150,y:200,id:"color",kind:24},{x:200,y:200,id:"color",kind:24},{x:200,y:150,id:"color",kind:24},{x:200,y:300,id:"color",
kind:24},{x:200,y:250,id:"color",kind:25},{x:250,y:150,id:"color",kind:24},{x:250,y:100,id:"color",kind:24},{x:200,y:50,id:"color",kind:25},{x:50,y:150,id:"color",kind:24},{x:250,y:200,id:"color",kind:24},{x:50,y:200,id:"color",kind:24},{x:100,y:150,id:"color",kind:25},{x:50,y:250,id:"color",kind:21},{x:0,y:300,id:"color",kind:35},{x:0,y:250,id:"color",kind:35},{x:0,y:200,id:"color",kind:35},{x:0,y:150,id:"color",kind:35},{x:0,y:100,id:"color",kind:35},{x:0,y:50,id:"color",kind:35},{x:0,y:0,id:"color",
kind:35},{x:50,y:0,id:"color",kind:35},{x:50,y:50,id:"color",kind:35},{x:50,y:100,id:"color",kind:35},{x:100,y:100,id:"color",kind:35},{x:100,y:50,id:"color",kind:35},{x:100,y:0,id:"color",kind:35},{x:150,y:50,id:"color",kind:35},{x:250,y:50,id:"color",kind:35},{x:300,y:0,id:"color",kind:35},{x:300,y:50,id:"color",kind:35},{x:300,y:100,id:"color",kind:35},{x:300,y:150,id:"color",kind:35},{x:300,y:200,id:"color",kind:35},{x:300,y:250,id:"color",kind:35},{x:300,y:300,id:"color",kind:35},{x:250,y:300,
id:"color",kind:35},{x:250,y:250,id:"color",kind:35},{x:150,y:250,id:"color",kind:35},{x:150,y:300,id:"color",kind:35},{x:100,y:300,id:"color",kind:35},{x:100,y:250,id:"color",kind:35},{x:100,y:200,id:"color",kind:35},{x:50,y:300,id:"color",kind:35},{x:200,y:0,id:"color",kind:24},{x:200,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:300,
id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:250,y:150,id:"cell"}],name:{key:"faucet"}},hamburger7x7:{width:350,height:350,items:[{x:50,y:100,id:"color",kind:6},{x:100,y:100,id:"color",kind:6},{x:150,y:100,id:"color",kind:6},{x:200,y:100,id:"color",kind:6},{x:150,y:50,id:"color",kind:6},{x:100,y:50,id:"color",kind:6},{x:50,y:300,id:"color",kind:6},{x:100,y:300,id:"color",kind:6},{x:150,y:300,id:"color",kind:6},{x:200,y:300,id:"color",kind:6},
{x:150,y:250,id:"color",kind:3},{x:200,y:250,id:"color",kind:3},{x:250,y:250,id:"color",kind:3},{x:50,y:200,id:"color",kind:17},{x:100,y:200,id:"color",kind:17},{x:150,y:200,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:250,y:200,id:"color",kind:17},{x:0,y:150,id:"color",kind:13},{x:100,y:150,id:"color",kind:13},{x:150,y:150,id:"color",kind:14},{x:200,y:150,id:"color",kind:14},{x:250,y:150,id:"color",kind:13},{x:300,y:150,id:"color",kind:14},{x:50,y:150,id:"color",kind:14},{x:250,y:300,
id:"color",kind:4},{x:250,y:100,id:"color",kind:4},{x:200,y:50,id:"color",kind:4},{x:50,y:250,id:"color",kind:4},{x:100,y:250,id:"color",kind:3},{x:0,y:300,id:"color",kind:26},{x:0,y:250,id:"color",kind:26},{x:0,y:200,id:"color",kind:26},{x:0,y:100,id:"color",kind:26},{x:0,y:50,id:"color",kind:26},{x:0,y:0,id:"color",kind:26},{x:50,y:0,id:"color",kind:26},{x:50,y:50,id:"color",kind:26},{x:100,y:0,id:"color",kind:26},{x:150,y:0,id:"color",kind:26},{x:200,y:0,id:"color",kind:26},{x:250,y:0,id:"color",
kind:26},{x:250,y:50,id:"color",kind:26},{x:300,y:0,id:"color",kind:26},{x:300,y:50,id:"color",kind:26},{x:300,y:100,id:"color",kind:26},{x:300,y:200,id:"color",kind:26},{x:300,y:250,id:"color",kind:26},{x:300,y:300,id:"color",kind:26},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:150,
y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:300,y:150,id:"cell"}],name:{key:"hamburger"}},turnip7x7:{width:350,height:350,items:[{x:0,y:200,id:"color",kind:3},{x:50,y:200,id:"color",kind:3},{x:250,y:200,id:"color",kind:3},{x:300,y:200,id:"color",kind:3},{x:50,y:250,
id:"color",kind:3},{x:0,y:300,id:"color",kind:3},{x:100,y:300,id:"color",kind:3},{x:250,y:300,id:"color",kind:3},{x:300,y:250,id:"color",kind:3},{x:50,y:300,id:"color",kind:4},{x:0,y:250,id:"color",kind:4},{x:200,y:300,id:"color",kind:4},{x:250,y:250,id:"color",kind:4},{x:150,y:300,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:150,y:250,id:"color",kind:23},{x:100,y:250,id:"color",kind:23},{x:100,y:200,id:"color",kind:23},{x:150,y:200,id:"color",kind:23},{x:200,y:200,id:"color",kind:23},
{x:150,y:150,id:"color",kind:13},{x:100,y:100,id:"color",kind:13},{x:150,y:100,id:"color",kind:13},{x:100,y:50,id:"color",kind:13},{x:50,y:50,id:"color",kind:13},{x:200,y:100,id:"color",kind:14},{x:200,y:50,id:"color",kind:14},{x:250,y:50,id:"color",kind:14},{x:100,y:150,id:"color",kind:24},{x:50,y:150,id:"color",kind:24},{x:50,y:100,id:"color",kind:24},{x:0,y:150,id:"color",kind:24},{x:0,y:100,id:"color",kind:24},{x:0,y:50,id:"color",kind:24},{x:0,y:0,id:"color",kind:24},{x:50,y:0,id:"color",kind:24},
{x:100,y:0,id:"color",kind:24},{x:150,y:50,id:"color",kind:24},{x:150,y:0,id:"color",kind:24},{x:200,y:0,id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:300,y:0,id:"color",kind:24},{x:300,y:50,id:"color",kind:24},{x:250,y:100,id:"color",kind:24},{x:300,y:100,id:"color",kind:24},{x:300,y:150,id:"color",kind:24},{x:250,y:150,id:"color",kind:24},{x:200,y:150,id:"color",kind:24},{x:300,y:300,id:"color",kind:4},{x:100,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:200,id:"cell"},
{x:0,y:200,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:100,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:250,id:"cell"}],name:{key:"turnip"}},egg7x7:{width:350,height:350,items:[{x:150,y:150,id:"color",
kind:8},{x:200,y:150,id:"color",kind:8},{x:200,y:100,id:"color",kind:8},{x:150,y:300,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:0,y:200,id:"color",kind:28},{x:0,y:250,id:"color",kind:28},{x:0,y:300,id:"color",
kind:28},{x:300,y:300,id:"color",kind:28},{x:0,y:50,id:"color",kind:28},{x:0,y:0,id:"color",kind:28},{x:50,y:0,id:"color",kind:28},{x:300,y:0,id:"color",kind:28},{x:250,y:300,id:"color",kind:28},{x:50,y:300,id:"color",kind:28},{x:50,y:250,id:"color",kind:22},{x:100,y:300,id:"color",kind:23},{x:100,y:250,id:"color",kind:23},{x:100,y:200,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:50,y:150,id:"color",kind:23},{x:50,y:100,id:"color",kind:23},{x:100,y:100,id:"color",kind:23},{x:100,y:50,id:"color",
kind:23},{x:100,y:0,id:"color",kind:23},{x:150,y:0,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:200,y:50,id:"color",kind:23},{x:200,y:0,id:"color",kind:23},{x:250,y:50,id:"color",kind:23},{x:250,y:100,id:"color",kind:23},{x:300,y:100,id:"color",kind:23},{x:300,y:150,id:"color",kind:23},{x:250,y:150,id:"color",kind:23},{x:250,y:200,id:"color",kind:23},{x:200,y:200,id:"color",kind:23},{x:200,y:250,id:"color",kind:23},{x:150,y:250,id:"color",kind:23},{x:150,y:200,id:"color",kind:23},{x:150,
y:100,id:"color",kind:17},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:0,y:250,id:"cell"},
{x:0,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:0,id:"cell"},{x:300,y:150,id:"cell"}],name:{key:"egg"}},sun7x7:{width:350,height:350,items:[{x:100,y:250,id:"color",kind:8},{x:150,y:250,id:"color",kind:8},{x:200,y:200,id:"color",kind:8},{x:50,y:200,id:"color",kind:8},{x:50,y:150,id:"color",kind:8},{x:100,y:150,id:"color",kind:8},{x:150,y:100,id:"color",kind:8},{x:100,y:50,id:"color",kind:8},{x:250,y:150,id:"color",kind:8},{x:250,y:100,id:"color",kind:8},{x:100,y:200,id:"color",kind:17},{x:200,
y:250,id:"color",kind:17},{x:250,y:200,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},{x:50,y:100,id:"color",kind:17},{x:200,y:50,id:"color",kind:17},{x:150,y:50,id:"color",kind:8},{x:200,y:100,id:"color",kind:8},{x:200,y:150,id:"color",kind:8},{x:150,y:200,id:"color",kind:8},{x:0,y:250,id:"color",kind:1},{x:50,y:250,id:"color",kind:1},{x:50,y:300,id:"color",kind:1},{x:100,y:300,id:"color",kind:1},{x:150,y:300,id:"color",kind:1},{x:200,y:300,id:"color",kind:1},
{x:250,y:250,id:"color",kind:1},{x:300,y:250,id:"color",kind:1},{x:300,y:300,id:"color",kind:1},{x:300,y:200,id:"color",kind:1},{x:300,y:150,id:"color",kind:1},{x:300,y:100,id:"color",kind:1},{x:250,y:50,id:"color",kind:1},{x:100,y:0,id:"color",kind:1},{x:50,y:0,id:"color",kind:1},{x:0,y:0,id:"color",kind:1},{x:50,y:50,id:"color",kind:1},{x:0,y:50,id:"color",kind:1},{x:0,y:100,id:"color",kind:1},{x:0,y:200,id:"color",kind:1},{x:0,y:150,id:"color",kind:8},{x:0,y:300,id:"color",kind:17},{x:150,y:0,
id:"color",kind:1},{x:200,y:0,id:"color",kind:1},{x:300,y:50,id:"color",kind:8},{x:250,y:0,id:"color",kind:8},{x:300,y:0,id:"color",kind:1},{x:250,y:300,id:"color",kind:17},{x:0,y:300,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},
{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:300,id:"cell"}],name:{key:"the_sun"}},sword7x7:{width:350,height:350,items:[{x:0,y:250,id:"color",kind:24},{x:50,y:200,id:"color",kind:24},{x:100,y:150,id:"color",kind:24},{x:150,y:100,id:"color",kind:24},{x:200,y:100,id:"color",kind:27},{x:150,y:50,id:"color",kind:27},{x:50,y:300,id:"color",kind:22},{x:100,
y:250,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:250,y:150,id:"color",kind:27},{x:300,y:200,id:"color",kind:27},{x:100,y:0,id:"color",kind:27},{x:200,y:50,id:"color",kind:28},{x:250,y:100,id:"color",kind:28},{x:250,y:50,id:"color",kind:28},{x:250,y:0,id:"color",kind:28},{x:300,y:50,id:"color",kind:28},{x:300,y:0,id:"color",kind:27},
{x:0,y:200,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:300,y:100,id:"color",kind:20},{x:300,y:150,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},
{x:300,y:300,id:"color",kind:20},{x:250,y:300,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:250,y:200,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:200,y:250,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:100,y:300,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:0,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:150,
id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:150,id:"cell"}],name:{key:"sword"}},moon7x7:{width:350,height:350,items:[{x:150,y:50,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:250,y:0,id:"color",
kind:17},{x:300,y:0,id:"color",kind:17},{x:250,y:50,id:"color",kind:17},{x:300,y:100,id:"color",kind:17},{x:300,y:50,id:"color",kind:17},{x:300,y:150,id:"color",kind:17},{x:250,y:150,id:"color",kind:17},{x:300,y:200,id:"color",kind:17},{x:250,y:200,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:50,y:50,id:"color",kind:17},{x:0,y:150,id:"color",kind:17},{x:100,y:300,id:"color",kind:17},{x:0,y:0,id:"color",kind:1},{x:50,y:0,id:"color",kind:1},{x:100,y:0,id:"color",
kind:1},{x:0,y:50,id:"color",kind:1},{x:100,y:50,id:"color",kind:1},{x:50,y:100,id:"color",kind:1},{x:50,y:150,id:"color",kind:1},{x:100,y:200,id:"color",kind:1},{x:100,y:150,id:"color",kind:1},{x:100,y:100,id:"color",kind:1},{x:0,y:250,id:"color",kind:1},{x:250,y:250,id:"color",kind:1},{x:0,y:200,id:"color",kind:2},{x:50,y:200,id:"color",kind:2},{x:50,y:250,id:"color",kind:2},{x:100,y:250,id:"color",kind:2},{x:0,y:300,id:"color",kind:2},{x:50,y:300,id:"color",kind:2},{x:150,y:300,id:"color",kind:2},
{x:200,y:300,id:"color",kind:2},{x:0,y:100,id:"color",kind:2},{x:150,y:200,id:"color",kind:1},{x:150,y:0,id:"color",kind:1},{x:200,y:250,id:"color",kind:1},{x:300,y:250,id:"color",kind:1},{x:150,y:250,id:"color",kind:1},{x:300,y:300,id:"color",kind:1},{x:250,y:300,id:"color",kind:1},{x:150,y:100,id:"color",kind:1},{x:200,y:100,id:"color",kind:1},{x:200,y:150,id:"color",kind:1},{x:250,y:100,id:"color",kind:1},{x:200,y:50,id:"color",kind:1},{x:100,y:300,id:"cell"},{x:100,y:150,id:"cell"},{x:200,y:150,
id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:0,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:250,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:250,
id:"cell"},{x:300,y:300,id:"cell"}],name:{key:"the_moon"}},candle5x8:{width:250,height:400,items:[{x:100,y:300,id:"color",kind:22},{x:150,y:300,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:50,y:200,id:"color",kind:23},{x:100,y:200,id:"color",kind:23},{x:50,y:300,id:"color",kind:23},{x:50,y:250,id:"color",kind:23},{x:50,y:350,id:"color",kind:18},{x:100,y:350,id:"color",kind:18},{x:150,y:350,id:"color",kind:18},{x:200,y:300,
id:"color",kind:18},{x:0,y:300,id:"color",kind:18},{x:50,y:100,id:"color",kind:8},{x:50,y:50,id:"color",kind:8},{x:100,y:0,id:"color",kind:8},{x:150,y:50,id:"color",kind:8},{x:150,y:100,id:"color",kind:8},{x:100,y:50,id:"color",kind:17},{x:100,y:150,id:"color",kind:4},{x:100,y:100,id:"color",kind:17},{x:0,y:350,id:"color",kind:1},{x:200,y:350,id:"color",kind:1},{x:200,y:250,id:"color",kind:1},{x:200,y:200,id:"color",kind:1},{x:200,y:150,id:"color",kind:1},{x:150,y:150,id:"color",kind:1},{x:200,y:100,
id:"color",kind:1},{x:200,y:50,id:"color",kind:1},{x:150,y:0,id:"color",kind:1},{x:200,y:0,id:"color",kind:1},{x:50,y:0,id:"color",kind:1},{x:0,y:0,id:"color",kind:1},{x:0,y:50,id:"color",kind:1},{x:0,y:150,id:"color",kind:1},{x:50,y:150,id:"color",kind:1},{x:0,y:100,id:"color",kind:1},{x:0,y:200,id:"color",kind:1},{x:0,y:250,id:"color",kind:1},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},
{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"}],name:{key:"candle"}},banana5x8:{width:400,height:250,items:[{x:250,y:200,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:150,y:200,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},{x:0,y:100,id:"color",kind:17},{x:50,y:150,id:"color",kind:17},{x:150,y:150,
id:"color",kind:17},{x:200,y:150,id:"color",kind:17},{x:250,y:150,id:"color",kind:17},{x:300,y:200,id:"color",kind:17},{x:50,y:50,id:"color",kind:17},{x:50,y:100,id:"color",kind:17},{x:0,y:50,id:"color",kind:3},{x:0,y:0,id:"color",kind:4},{x:0,y:200,id:"color",kind:5},{x:50,y:200,id:"color",kind:5},{x:0,y:150,id:"color",kind:5},{x:100,y:0,id:"color",kind:5},{x:150,y:0,id:"color",kind:5},{x:100,y:50,id:"color",kind:5},{x:150,y:100,id:"color",kind:5},{x:200,y:100,id:"color",kind:5},{x:200,y:50,id:"color",
kind:5},{x:200,y:0,id:"color",kind:5},{x:250,y:0,id:"color",kind:5},{x:250,y:50,id:"color",kind:5},{x:250,y:100,id:"color",kind:5},{x:300,y:100,id:"color",kind:5},{x:300,y:0,id:"color",kind:5},{x:350,y:0,id:"color",kind:5},{x:350,y:200,id:"color",kind:5},{x:350,y:150,id:"color",kind:17},{x:50,y:0,id:"color",kind:4},{x:350,y:100,id:"color",kind:5},{x:300,y:150,id:"color",kind:17},{x:100,y:150,id:"color",kind:17},{x:100,y:200,id:"color",kind:17},{x:300,y:50,id:"color",kind:5},{x:350,y:50,id:"color",
kind:5},{x:150,y:50,id:"color",kind:5},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:50,y:50,id:"cell"},{x:300,y:200,id:"cell"},{x:50,y:0,id:"cell"},{x:0,y:0,id:"cell"}],name:{key:"banana"}},
cat5x8:{width:400,height:250,items:[{x:150,y:0,id:"color",kind:31},{x:50,y:50,id:"color",kind:31},{x:50,y:0,id:"color",kind:31},{x:0,y:0,id:"color",kind:31},{x:0,y:50,id:"color",kind:31},{x:100,y:0,id:"color",kind:31},{x:100,y:50,id:"color",kind:31},{x:100,y:100,id:"color",kind:31},{x:100,y:150,id:"color",kind:31},{x:50,y:150,id:"color",kind:31},{x:150,y:100,id:"color",kind:31},{x:200,y:100,id:"color",kind:31},{x:200,y:50,id:"color",kind:31},{x:150,y:50,id:"color",kind:31},{x:200,y:0,id:"color",kind:31},
{x:300,y:0,id:"color",kind:31},{x:350,y:150,id:"color",kind:31},{x:350,y:200,id:"color",kind:31},{x:50,y:100,id:"color",kind:28},{x:0,y:100,id:"color",kind:27},{x:0,y:150,id:"color",kind:27},{x:0,y:200,id:"color",kind:27},{x:50,y:200,id:"color",kind:27},{x:100,y:200,id:"color",kind:27},{x:150,y:200,id:"color",kind:27},{x:150,y:150,id:"color",kind:27},{x:200,y:150,id:"color",kind:27},{x:200,y:200,id:"color",kind:27},{x:250,y:200,id:"color",kind:27},{x:250,y:150,id:"color",kind:27},{x:300,y:150,id:"color",
kind:27},{x:300,y:200,id:"color",kind:27},{x:250,y:50,id:"color",kind:27},{x:300,y:50,id:"color",kind:27},{x:350,y:50,id:"color",kind:27},{x:350,y:100,id:"color",kind:27},{x:300,y:100,id:"color",kind:27},{x:250,y:100,id:"color",kind:27},{x:250,y:0,id:"color",kind:28},{x:350,y:0,id:"color",kind:28},{x:50,y:100,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},
{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:0,id:"cell"}],name:{key:"cat"}},shovel8x5:{width:250,height:400,items:[{x:100,y:100,id:"color",kind:27},{x:100,y:0,id:"color",kind:28},{x:50,y:0,id:"color",kind:28},{x:150,y:0,id:"color",kind:28},{x:100,y:150,
id:"color",kind:27},{x:100,y:200,id:"color",kind:27},{x:0,y:250,id:"color",kind:3},{x:0,y:300,id:"color",kind:3},{x:50,y:350,id:"color",kind:3},{x:200,y:350,id:"color",kind:3},{x:200,y:300,id:"color",kind:3},{x:0,y:350,id:"color",kind:4},{x:150,y:350,id:"color",kind:4},{x:200,y:250,id:"color",kind:4},{x:0,y:150,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:0,y:0,id:"color",
kind:20},{x:150,y:50,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:200,y:100,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:100,y:250,id:"color",kind:28},{x:100,y:50,id:"color",kind:28},{x:50,y:250,id:"color",kind:16},{x:50,y:300,id:"color",kind:16},{x:100,y:300,id:"color",kind:16},{x:100,y:350,id:"color",kind:16},{x:150,y:300,id:"color",kind:16},{x:150,y:250,id:"color",kind:16},{x:0,
y:200,id:"color",kind:13},{x:50,y:200,id:"color",kind:13},{x:150,y:200,id:"color",kind:13},{x:200,y:200,id:"color",kind:13},{x:50,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:50,y:250,id:"cell"}],name:{key:"shovel"}},flashlight5x8:{width:400,height:250,items:[{x:150,y:150,id:"color",kind:1},
{x:150,y:100,id:"color",kind:1},{x:150,y:50,id:"color",kind:1},{x:200,y:100,id:"color",kind:1},{x:300,y:100,id:"color",kind:1},{x:350,y:100,id:"color",kind:1},{x:100,y:150,id:"color",kind:17},{x:50,y:200,id:"color",kind:17},{x:0,y:200,id:"color",kind:17},{x:0,y:150,id:"color",kind:17},{x:0,y:100,id:"color",kind:17},{x:0,y:50,id:"color",kind:17},{x:0,y:0,id:"color",kind:17},{x:50,y:0,id:"color",kind:17},{x:50,y:50,id:"color",kind:17},{x:100,y:50,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},
{x:50,y:100,id:"color",kind:17},{x:50,y:150,id:"color",kind:17},{x:250,y:100,id:"color",kind:7},{x:250,y:150,id:"color",kind:7},{x:300,y:150,id:"color",kind:7},{x:350,y:150,id:"color",kind:7},{x:350,y:50,id:"color",kind:6},{x:350,y:0,id:"color",kind:6},{x:100,y:200,id:"color",kind:0},{x:150,y:200,id:"color",kind:0},{x:200,y:200,id:"color",kind:0},{x:200,y:150,id:"color",kind:0},{x:250,y:200,id:"color",kind:0},{x:300,y:200,id:"color",kind:0},{x:350,y:200,id:"color",kind:0},{x:200,y:50,id:"color",kind:0},
{x:200,y:0,id:"color",kind:0},{x:150,y:0,id:"color",kind:0},{x:100,y:0,id:"color",kind:0},{x:250,y:0,id:"color",kind:0},{x:300,y:0,id:"color",kind:0},{x:300,y:50,id:"color",kind:6},{x:250,y:50,id:"color",kind:7},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:0,id:"cell"},{x:100,
y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:0,y:0,id:"cell"}],name:{key:"flashlight"}},well8x5:{width:250,height:400,items:[{x:50,y:350,id:"color",kind:4},{x:100,y:350,id:"color",kind:4},{x:150,y:350,id:"color",kind:4},{x:0,y:250,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:200,y:250,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},
{x:0,y:300,id:"color",kind:20},{x:50,y:200,id:"color",kind:6},{x:150,y:200,id:"color",kind:6},{x:50,y:100,id:"color",kind:3},{x:150,y:100,id:"color",kind:3},{x:100,y:50,id:"color",kind:3},{x:100,y:100,id:"color",kind:3},{x:100,y:200,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},
{x:200,y:100,id:"color",kind:20},{x:100,y:300,id:"color",kind:4},{x:50,y:300,id:"color",kind:4},{x:150,y:300,id:"color",kind:4},{x:50,y:250,id:"color",kind:6},{x:150,y:250,id:"color",kind:6},{x:150,y:150,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:50,y:150,id:"color",kind:3},{x:200,y:150,id:"color",kind:3},{x:0,y:150,id:"color",kind:3},{x:100,y:250,id:"color",kind:20},{x:0,y:350,id:"color",kind:34},{x:200,y:350,id:"color",kind:34},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,
id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:150,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"}],name:{key:"a_well"}},cellphone8x5:{width:250,height:400,items:[{x:50,y:150,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:100,y:100,
id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:0,y:300,id:"color",kind:27},{x:0,y:250,id:"color",kind:27},{x:0,y:200,id:"color",kind:27},{x:0,y:150,id:"color",kind:27},{x:0,y:100,id:"color",kind:27},{x:50,y:350,id:"color",kind:27},{x:100,y:350,id:"color",kind:27},{x:150,y:350,id:"color",kind:27},{x:200,y:300,id:"color",kind:27},{x:200,y:250,id:"color",kind:27},{x:200,y:200,id:"color",kind:27},{x:200,y:150,id:"color",kind:27},{x:200,y:100,id:"color",kind:27},{x:100,y:50,id:"color",kind:27},
{x:50,y:50,id:"color",kind:27},{x:200,y:0,id:"color",kind:28},{x:150,y:150,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:150,y:50,id:"color",kind:27},{x:200,y:50,id:"color",kind:28},{x:50,y:200,id:"color",kind:28},{x:100,y:250,id:"color",kind:28},{x:150,y:300,id:"color",kind:28},{x:150,y:200,id:"color",kind:28},{x:50,y:300,id:"color",kind:28},{x:150,y:250,id:"color",kind:27},{x:100,y:300,id:"color",kind:27},{x:50,y:250,id:"color",kind:27},{x:100,y:200,id:"color",kind:27},{x:0,y:350,id:"color",
kind:16},{x:200,y:350,id:"color",kind:16},{x:0,y:50,id:"color",kind:16},{x:0,y:0,id:"color",kind:16},{x:50,y:0,id:"color",kind:16},{x:100,y:0,id:"color",kind:16},{x:150,y:0,id:"color",kind:16},{x:200,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:350,
id:"cell"},{x:50,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"}],name:{key:"cellphone"}},carrot8x5:{width:250,height:400,items:[{x:100,y:350,id:"color",kind:5},{x:100,y:300,id:"color",kind:5},{x:100,y:200,id:"color",kind:5},{x:100,y:100,id:"color",kind:5},{x:50,y:200,id:"color",kind:5},{x:50,y:150,id:"color",kind:5},{x:50,y:100,id:"color",kind:5},
{x:150,y:300,id:"color",kind:5},{x:150,y:250,id:"color",kind:5},{x:150,y:200,id:"color",kind:5},{x:150,y:150,id:"color",kind:5},{x:50,y:0,id:"color",kind:13},{x:150,y:0,id:"color",kind:13},{x:50,y:300,id:"color",kind:5},{x:50,y:250,id:"color",kind:8},{x:100,y:250,id:"color",kind:8},{x:100,y:150,id:"color",kind:8},{x:150,y:100,id:"color",kind:8},{x:100,y:50,id:"color",kind:14},{x:0,y:200,id:"color",kind:3},{x:200,y:200,id:"color",kind:3},{x:0,y:350,id:"color",kind:3},{x:150,y:350,id:"color",kind:3},
{x:200,y:350,id:"color",kind:3},{x:50,y:350,id:"color",kind:4},{x:0,y:250,id:"color",kind:3},{x:200,y:300,id:"color",kind:3},{x:0,y:300,id:"color",kind:4},{x:200,y:250,id:"color",kind:4},{x:0,y:150,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:200,y:100,id:"color",kind:20},{x:200,
y:150,id:"color",kind:20},{x:50,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:0,y:200,id:"cell"},{x:200,y:200,id:"cell"}],name:{key:"carrot"}},question8x6:{width:300,height:400,items:[{x:50,y:350,id:"color",
kind:18},{x:50,y:250,id:"color",kind:18},{x:100,y:200,id:"color",kind:18},{x:150,y:200,id:"color",kind:18},{x:150,y:50,id:"color",kind:18},{x:200,y:150,id:"color",kind:18},{x:200,y:100,id:"color",kind:18},{x:200,y:50,id:"color",kind:18},{x:150,y:0,id:"color",kind:18},{x:100,y:0,id:"color",kind:18},{x:50,y:0,id:"color",kind:18},{x:0,y:50,id:"color",kind:18},{x:100,y:350,id:"color",kind:16},{x:100,y:250,id:"color",kind:16},{x:200,y:200,id:"color",kind:16},{x:250,y:150,id:"color",kind:16},{x:250,y:100,
id:"color",kind:16},{x:250,y:50,id:"color",kind:16},{x:150,y:150,id:"color",kind:18},{x:50,y:200,id:"color",kind:18},{x:200,y:0,id:"color",kind:16},{x:50,y:50,id:"color",kind:16},{x:0,y:350,id:"color",kind:32},{x:0,y:300,id:"color",kind:32},{x:0,y:250,id:"color",kind:32},{x:0,y:200,id:"color",kind:32},{x:0,y:150,id:"color",kind:32},{x:0,y:100,id:"color",kind:32},{x:50,y:100,id:"color",kind:32},{x:50,y:150,id:"color",kind:32},{x:100,y:150,id:"color",kind:32},{x:100,y:100,id:"color",kind:32},{x:100,
y:50,id:"color",kind:32},{x:150,y:100,id:"color",kind:32},{x:0,y:0,id:"color",kind:32},{x:250,y:0,id:"color",kind:32},{x:250,y:200,id:"color",kind:32},{x:250,y:250,id:"color",kind:32},{x:200,y:250,id:"color",kind:32},{x:150,y:250,id:"color",kind:32},{x:150,y:300,id:"color",kind:32},{x:100,y:300,id:"color",kind:32},{x:50,y:300,id:"color",kind:32},{x:150,y:350,id:"color",kind:32},{x:200,y:350,id:"color",kind:32},{x:200,y:300,id:"color",kind:32},{x:250,y:300,id:"color",kind:32},{x:250,y:350,id:"color",
kind:32},{x:0,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:50,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:50,
y:50,id:"cell"}],name:{key:"?"}},sunset6x8:{width:400,height:300,items:[{x:0,y:200,id:"color",kind:19},{x:50,y:250,id:"color",kind:19},{x:50,y:200,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:250,y:200,id:"color",kind:19},{x:200,y:200,id:"color",kind:20},{x:350,y:250,id:"color",kind:19},{x:300,y:250,id:"color",kind:20},{x:50,y:150,id:"color",kind:17},{x:100,y:150,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:200,y:150,id:"color",kind:17},{x:150,y:100,id:"color",kind:17},{x:100,
y:100,id:"color",kind:17},{x:0,y:150,id:"color",kind:8},{x:0,y:100,id:"color",kind:8},{x:50,y:100,id:"color",kind:8},{x:50,y:50,id:"color",kind:8},{x:100,y:50,id:"color",kind:8},{x:150,y:50,id:"color",kind:8},{x:200,y:50,id:"color",kind:8},{x:200,y:100,id:"color",kind:8},{x:250,y:100,id:"color",kind:8},{x:300,y:50,id:"color",kind:8},{x:250,y:150,id:"color",kind:8},{x:300,y:150,id:"color",kind:8},{x:200,y:250,id:"color",kind:20},{x:300,y:200,id:"color",kind:19},{x:150,y:200,id:"color",kind:19},{x:250,
y:250,id:"color",kind:19},{x:0,y:250,id:"color",kind:19},{x:350,y:200,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:100,y:250,id:"color",kind:19},{x:250,y:50,id:"color",kind:5},{x:300,y:100,id:"color",kind:5},{x:350,y:50,id:"color",kind:5},{x:350,y:150,id:"color",kind:5},{x:0,y:50,id:"color",kind:5},{x:350,y:100,id:"color",kind:5},{x:50,y:0,id:"color",kind:5},{x:0,y:0,id:"color",kind:5},{x:150,y:0,id:"color",kind:5},{x:300,y:0,id:"color",kind:5},{x:350,y:0,id:"color",kind:5},{x:100,y:0,
id:"color",kind:8},{x:200,y:0,id:"color",kind:8},{x:250,y:0,id:"color",kind:8},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},
{x:250,y:50,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:250,y:200,id:"cell"}],name:{key:"sunset"}},wave8x6:{width:300,height:400,items:[{x:150,y:100,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:250,y:150,id:"color",kind:22},{x:150,y:150,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:200,y:150,id:"color",kind:23},{x:200,y:100,id:"color",kind:23},{x:100,
y:50,id:"color",kind:23},{x:50,y:100,id:"color",kind:23},{x:50,y:300,id:"color",kind:20},{x:50,y:250,id:"color",kind:20},{x:100,y:300,id:"color",kind:20},{x:100,y:350,id:"color",kind:20},{x:250,y:350,id:"color",kind:19},{x:50,y:350,id:"color",kind:19},{x:0,y:350,id:"color",kind:19},{x:100,y:250,id:"color",kind:18},{x:100,y:200,id:"color",kind:18},{x:0,y:150,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:0,y:300,id:"color",kind:19},{x:0,y:0,id:"color",kind:24},
{x:100,y:0,id:"color",kind:24},{x:150,y:0,id:"color",kind:24},{x:250,y:50,id:"color",kind:24},{x:200,y:50,id:"color",kind:24},{x:250,y:100,id:"color",kind:24},{x:250,y:200,id:"color",kind:24},{x:250,y:250,id:"color",kind:24},{x:200,y:250,id:"color",kind:24},{x:250,y:300,id:"color",kind:24},{x:0,y:50,id:"color",kind:23},{x:250,y:0,id:"color",kind:23},{x:150,y:300,id:"color",kind:18},{x:200,y:300,id:"color",kind:18},{x:0,y:250,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:200,y:350,id:"color",
kind:20},{x:50,y:150,id:"color",kind:18},{x:200,y:0,id:"color",kind:22},{x:150,y:200,id:"color",kind:24},{x:200,y:200,id:"color",kind:22},{x:50,y:0,id:"color",kind:23},{x:50,y:200,id:"color",kind:18},{x:150,y:350,id:"color",kind:20},{x:150,y:250,id:"color",kind:18},{x:250,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:0,
y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:350,id:"cell"},{x:150,y:250,id:"cell"}],name:{key:"wave"}},ponytail6x8:{width:400,height:300,items:[{x:0,y:200,id:"color",kind:4},{x:0,y:150,id:"color",
kind:4},{x:0,y:100,id:"color",kind:4},{x:50,y:100,id:"color",kind:4},{x:50,y:150,id:"color",kind:4},{x:50,y:200,id:"color",kind:4},{x:50,y:250,id:"color",kind:4},{x:100,y:250,id:"color",kind:4},{x:100,y:100,id:"color",kind:3},{x:100,y:50,id:"color",kind:3},{x:150,y:50,id:"color",kind:3},{x:150,y:100,id:"color",kind:3},{x:100,y:200,id:"color",kind:3},{x:150,y:150,id:"color",kind:3},{x:150,y:200,id:"color",kind:3},{x:100,y:150,id:"color",kind:4},{x:50,y:50,id:"color",kind:3},{x:200,y:100,id:"color",
kind:2},{x:250,y:100,id:"color",kind:3},{x:300,y:100,id:"color",kind:3},{x:300,y:150,id:"color",kind:3},{x:250,y:150,id:"color",kind:3},{x:300,y:200,id:"color",kind:3},{x:350,y:250,id:"color",kind:3},{x:250,y:200,id:"color",kind:3},{x:300,y:250,id:"color",kind:3},{x:0,y:250,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},
{x:250,y:50,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:200,y:250,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:50,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,
y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:250,id:"cell"}],name:{key:"ponytail"}},
sapling8x6:{width:300,height:400,items:[{x:150,y:200,id:"color",kind:3},{x:100,y:200,id:"color",kind:3},{x:100,y:250,id:"color",kind:3},{x:100,y:300,id:"color",kind:3},{x:150,y:300,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:50,y:200,id:"color",kind:3},{x:0,y:200,id:"color",kind:3},{x:200,y:200,id:"color",kind:3},{x:50,y:250,id:"color",kind:3},{x:50,y:300,id:"color",kind:3},{x:0,y:350,id:"color",kind:4},{x:200,y:350,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:150,y:350,id:"color",
kind:4},{x:100,y:350,id:"color",kind:4},{x:50,y:350,id:"color",kind:4},{x:0,y:300,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},
{x:250,y:150,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:250,y:200,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:100,y:150,id:"color",kind:14},{x:100,y:100,id:"color",kind:14},{x:100,y:50,id:"color",kind:14},{x:150,y:0,id:"color",kind:14},{x:200,y:50,id:"color",kind:14},{x:200,y:100,id:"color",kind:14},{x:250,y:300,id:"color",kind:13},{x:250,y:50,id:"color",kind:13},{x:200,y:0,id:"color",
kind:13},{x:50,y:100,id:"color",kind:13},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:0,y:350,id:"cell"},
{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"}],name:{key:"sapling"}},icescream8x6:{width:300,height:400,items:[{x:100,y:250,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:200,y:250,id:"color",kind:3},{x:150,y:200,id:"color",kind:3},{x:100,y:200,id:"color",kind:3},{x:200,y:200,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:150,y:150,id:"color",kind:3},{x:200,y:150,id:"color",kind:3},{x:200,y:100,id:"color",kind:3},{x:150,y:100,id:"color",kind:3},{x:100,y:100,id:"color",kind:3},{x:150,
y:50,id:"color",kind:3},{x:200,y:50,id:"color",kind:3},{x:50,y:250,id:"color",kind:4},{x:50,y:200,id:"color",kind:4},{x:50,y:150,id:"color",kind:4},{x:50,y:100,id:"color",kind:4},{x:50,y:50,id:"color",kind:4},{x:50,y:0,id:"color",kind:4},{x:100,y:0,id:"color",kind:4},{x:150,y:0,id:"color",kind:4},{x:100,y:50,id:"color",kind:4},{x:150,y:300,id:"color",kind:22},{x:100,y:300,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:50,y:300,id:"color",kind:23},{x:100,y:350,id:"color",kind:6},{x:150,y:350,
id:"color",kind:6},{x:50,y:350,id:"color",kind:24},{x:0,y:350,id:"color",kind:24},{x:0,y:300,id:"color",kind:24},{x:0,y:250,id:"color",kind:24},{x:0,y:50,id:"color",kind:24},{x:0,y:0,id:"color",kind:24},{x:200,y:0,id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:250,y:50,id:"color",kind:24},{x:250,y:100,id:"color",kind:24},{x:250,y:150,id:"color",kind:24},{x:250,y:200,id:"color",kind:24},{x:250,y:250,id:"color",kind:24},{x:250,y:300,id:"color",kind:24},{x:250,y:350,id:"color",kind:24},{x:200,
y:350,id:"color",kind:24},{x:0,y:200,id:"color",kind:31},{x:0,y:150,id:"color",kind:31},{x:0,y:100,id:"color",kind:31},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"},
{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:100,id:"cell"}],name:{key:"icecream"}},lion8x6:{width:300,height:400,items:[{x:100,y:50,id:"color",kind:17},{x:150,y:50,id:"color",kind:17},{x:150,y:100,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},{x:50,y:0,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:100,y:150,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:100,y:200,id:"color",kind:17},{x:150,y:200,
id:"color",kind:17},{x:100,y:250,id:"color",kind:4},{x:150,y:250,id:"color",kind:4},{x:0,y:50,id:"color",kind:5},{x:0,y:100,id:"color",kind:5},{x:100,y:0,id:"color",kind:5},{x:200,y:50,id:"color",kind:5},{x:250,y:50,id:"color",kind:5},{x:50,y:200,id:"color",kind:5},{x:0,y:200,id:"color",kind:5},{x:100,y:350,id:"color",kind:5},{x:150,y:350,id:"color",kind:5},{x:150,y:300,id:"color",kind:5},{x:200,y:300,id:"color",kind:5},{x:200,y:200,id:"color",kind:5},{x:250,y:200,id:"color",kind:5},{x:250,y:250,
id:"color",kind:5},{x:200,y:150,id:"color",kind:1},{x:50,y:150,id:"color",kind:1},{x:50,y:100,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:50,y:300,id:"color",kind:8},{x:200,y:250,id:"color",kind:8},{x:0,y:150,id:"color",kind:8},{x:250,y:150,id:"color",kind:8},{x:250,y:100,id:"color",kind:8},{x:50,y:50,id:"color",kind:8},{x:150,y:0,id:"color",kind:8},{x:100,y:300,id:"color",kind:8},{x:50,y:250,id:"color",kind:8},{x:0,y:300,id:"color",kind:17},{x:0,y:350,id:"color",kind:17},{x:50,y:350,
id:"color",kind:17},{x:200,y:350,id:"color",kind:17},{x:250,y:350,id:"color",kind:17},{x:250,y:300,id:"color",kind:17},{x:0,y:250,id:"color",kind:13},{x:0,y:0,id:"color",kind:13},{x:250,y:0,id:"color",kind:13},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:50,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:200,
id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"}],name:{key:"lion"}},hippo6x8:{width:400,height:300,items:[{x:200,y:250,id:"color",kind:27},{x:200,y:200,id:"color",kind:27},{x:150,y:150,id:"color",kind:27},{x:100,y:100,
id:"color",kind:27},{x:50,y:50,id:"color",kind:27},{x:100,y:0,id:"color",kind:27},{x:150,y:100,id:"color",kind:27},{x:200,y:100,id:"color",kind:27},{x:150,y:50,id:"color",kind:27},{x:300,y:100,id:"color",kind:27},{x:200,y:150,id:"color",kind:27},{x:250,y:100,id:"color",kind:27},{x:300,y:150,id:"color",kind:27},{x:350,y:150,id:"color",kind:27},{x:300,y:200,id:"color",kind:27},{x:250,y:200,id:"color",kind:27},{x:250,y:250,id:"color",kind:27},{x:50,y:100,id:"color",kind:22},{x:150,y:250,id:"color",kind:31},
{x:150,y:0,id:"color",kind:27},{x:250,y:150,id:"color",kind:1},{x:100,y:250,id:"color",kind:31},{x:50,y:250,id:"color",kind:22},{x:100,y:50,id:"color",kind:28},{x:300,y:250,id:"color",kind:28},{x:350,y:250,id:"color",kind:28},{x:350,y:200,id:"color",kind:28},{x:0,y:250,id:"color",kind:13},{x:0,y:200,id:"color",kind:13},{x:0,y:150,id:"color",kind:13},{x:0,y:100,id:"color",kind:13},{x:0,y:50,id:"color",kind:13},{x:0,y:0,id:"color",kind:13},{x:50,y:0,id:"color",kind:13},{x:50,y:150,id:"color",kind:13},
{x:50,y:200,id:"color",kind:13},{x:100,y:200,id:"color",kind:13},{x:100,y:150,id:"color",kind:13},{x:150,y:200,id:"color",kind:13},{x:200,y:50,id:"color",kind:13},{x:200,y:0,id:"color",kind:13},{x:250,y:0,id:"color",kind:13},{x:250,y:50,id:"color",kind:13},{x:300,y:50,id:"color",kind:13},{x:300,y:0,id:"color",kind:13},{x:350,y:0,id:"color",kind:13},{x:350,y:50,id:"color",kind:13},{x:350,y:100,id:"color",kind:13},{x:50,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},
{x:150,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"}],name:{key:"hippo"}},pickles8x6:{width:300,height:400,items:[{x:50,y:350,id:"color",kind:22},{x:100,y:350,id:"color",kind:22},{x:150,y:350,id:"color",
kind:22},{x:200,y:350,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:250,y:150,id:"color",kind:22},{x:250,y:200,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:50,y:0,id:"color",kind:15},{x:100,y:0,id:"color",kind:15},{x:150,y:0,id:"color",
kind:15},{x:200,y:0,id:"color",kind:15},{x:200,y:250,id:"color",kind:13},{x:200,y:200,id:"color",kind:13},{x:200,y:150,id:"color",kind:13},{x:150,y:150,id:"color",kind:14},{x:150,y:200,id:"color",kind:14},{x:150,y:100,id:"color",kind:14},{x:100,y:250,id:"color",kind:13},{x:100,y:200,id:"color",kind:13},{x:100,y:300,id:"color",kind:13},{x:50,y:200,id:"color",kind:14},{x:50,y:150,id:"color",kind:14},{x:50,y:100,id:"color",kind:14},{x:50,y:250,id:"color",kind:14},{x:50,y:300,id:"color",kind:33},{x:100,
y:150,id:"color",kind:33},{x:100,y:100,id:"color",kind:33},{x:150,y:250,id:"color",kind:33},{x:200,y:100,id:"color",kind:33},{x:200,y:300,id:"color",kind:33},{x:150,y:300,id:"color",kind:14},{x:0,y:350,id:"color",kind:26},{x:250,y:350,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:250,y:0,id:"color",kind:26},{x:0,y:0,id:"color",kind:26},{x:0,y:50,id:"color",kind:26},{x:100,y:50,id:"color",kind:33},{x:150,y:50,id:"color",kind:33},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,
id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:100,id:"cell"},{x:100,y:150,
id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"}],name:{key:"pickle_jar"}},apple6x8:{width:400,height:300,items:[{x:350,y:200,id:"color",kind:3},{x:300,y:150,id:"color",kind:3},{x:350,y:150,id:"color",kind:3},{x:300,y:100,id:"color",kind:3},{x:350,y:100,id:"color",kind:3},{x:300,y:50,id:"color",kind:3},{x:350,y:50,id:"color",kind:3},{x:250,y:50,id:"color",kind:3},{x:200,y:0,id:"color",kind:3},{x:300,y:0,id:"color",kind:3},{x:150,y:0,id:"color",kind:3},{x:100,y:0,id:"color",
kind:3},{x:50,y:0,id:"color",kind:3},{x:0,y:0,id:"color",kind:3},{x:250,y:0,id:"color",kind:3},{x:350,y:250,id:"color",kind:3},{x:100,y:50,id:"color",kind:2},{x:50,y:100,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:100,y:200,id:"color",kind:26},{x:150,y:150,id:"color",kind:26},{x:150,y:100,id:"color",kind:26},{x:100,y:100,id:"color",kind:26},{x:100,y:150,id:"color",kind:26},{x:0,y:250,id:"color",kind:20},{x:50,y:250,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},{x:100,y:250,id:"color",
kind:20},{x:150,y:250,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:200,y:250,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:250,y:200,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:0,y:200,id:"color",kind:13},{x:150,y:50,id:"color",kind:13},{x:200,y:100,id:"color",kind:13},{x:250,y:150,id:"color",kind:13},{x:300,y:200,id:"color",kind:13},{x:350,y:0,id:"color",kind:14},{x:200,y:50,id:"color",kind:14},{x:0,
y:50,id:"color",kind:14},{x:0,y:150,id:"color",kind:14},{x:50,y:50,id:"color",kind:14},{x:0,y:100,id:"color",kind:14},{x:250,y:100,id:"color",kind:14},{x:0,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,
y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:50,id:"cell"},{x:300,y:50,id:"cell"}],name:{key:"apple"}},corn8x7:{width:350,height:400,items:[{x:150,y:200,id:"color",kind:14},{x:150,y:250,id:"color",kind:14},{x:150,y:300,id:"color",kind:14},{x:200,y:350,id:"color",kind:13},{x:250,y:300,id:"color",kind:13},{x:100,y:350,id:"color",kind:13},{x:50,y:350,id:"color",kind:13},{x:50,y:250,id:"color",kind:13},{x:150,y:350,id:"color",kind:14},{x:200,y:300,
id:"color",kind:13},{x:250,y:250,id:"color",kind:13},{x:0,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:300,y:100,id:"color",kind:20},{x:300,y:150,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:250,
y:200,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:100,y:250,id:"color",kind:20},{x:200,y:250,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:300,y:200,id:"color",kind:20},{x:50,y:300,id:"color",kind:13},{x:100,y:100,id:"color",kind:8},{x:100,y:150,id:"color",kind:17},{x:200,y:150,id:"color",
kind:17},{x:150,y:100,id:"color",kind:17},{x:100,y:50,id:"color",kind:17},{x:200,y:50,id:"color",kind:17},{x:150,y:0,id:"color",kind:17},{x:150,y:50,id:"color",kind:8},{x:100,y:0,id:"color",kind:8},{x:150,y:150,id:"color",kind:8},{x:200,y:100,id:"color",kind:8},{x:200,y:0,id:"color",kind:8},{x:0,y:300,id:"color",kind:10},{x:0,y:350,id:"color",kind:10},{x:100,y:300,id:"color",kind:10},{x:250,y:350,id:"color",kind:10},{x:300,y:350,id:"color",kind:10},{x:300,y:300,id:"color",kind:10},{x:100,y:100,id:"cell"},
{x:150,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:100,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:50,y:250,id:"cell"}],name:{key:"corn"}},bunny8x7:{width:350,height:400,items:[{x:50,y:150,id:"color",kind:24},{x:50,y:100,
id:"color",kind:24},{x:50,y:50,id:"color",kind:24},{x:50,y:0,id:"color",kind:24},{x:100,y:0,id:"color",kind:24},{x:200,y:0,id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:250,y:50,id:"color",kind:24},{x:250,y:100,id:"color",kind:24},{x:250,y:150,id:"color",kind:24},{x:250,y:200,id:"color",kind:24},{x:250,y:250,id:"color",kind:24},{x:250,y:300,id:"color",kind:24},{x:200,y:350,id:"color",kind:24},{x:150,y:350,id:"color",kind:24},{x:100,y:350,id:"color",kind:24},{x:50,y:300,id:"color",kind:24},
{x:50,y:250,id:"color",kind:24},{x:50,y:200,id:"color",kind:24},{x:100,y:200,id:"color",kind:24},{x:150,y:200,id:"color",kind:24},{x:200,y:200,id:"color",kind:24},{x:150,y:150,id:"color",kind:24},{x:150,y:250,id:"color",kind:24},{x:100,y:300,id:"color",kind:24},{x:200,y:300,id:"color",kind:24},{x:100,y:150,id:"color",kind:31},{x:100,y:100,id:"color",kind:31},{x:100,y:50,id:"color",kind:31},{x:200,y:50,id:"color",kind:31},{x:200,y:100,id:"color",kind:31},{x:200,y:150,id:"color",kind:31},{x:100,y:250,
id:"color",kind:3},{x:200,y:250,id:"color",kind:3},{x:150,y:300,id:"color",kind:32},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:250,
y:250,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:300,id:"cell"}],name:{key:"bunny"}},star8x7:{width:350,height:400,items:[{x:0,y:350,id:"color",kind:9},{x:50,y:350,id:"color",kind:9},{x:50,y:300,id:"color",kind:9},{x:100,y:300,id:"color",kind:9},{x:100,y:250,id:"color",kind:9},{x:150,y:250,id:"color",kind:9},{x:200,y:250,id:"color",kind:9},{x:200,y:300,id:"color",kind:9},{x:250,y:300,id:"color",kind:9},{x:250,y:350,id:"color",kind:9},{x:300,y:350,id:"color",
kind:9},{x:250,y:200,id:"color",kind:9},{x:200,y:200,id:"color",kind:9},{x:200,y:150,id:"color",kind:9},{x:250,y:150,id:"color",kind:9},{x:300,y:150,id:"color",kind:9},{x:150,y:200,id:"color",kind:9},{x:150,y:150,id:"color",kind:9},{x:100,y:200,id:"color",kind:9},{x:100,y:150,id:"color",kind:9},{x:150,y:100,id:"color",kind:9},{x:200,y:100,id:"color",kind:9},{x:50,y:200,id:"color",kind:9},{x:0,y:150,id:"color",kind:17},{x:50,y:150,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},{x:150,y:50,id:"color",
kind:17},{x:150,y:0,id:"color",kind:17},{x:0,y:300,id:"color",kind:1},{x:0,y:250,id:"color",kind:1},{x:0,y:200,id:"color",kind:1},{x:50,y:250,id:"color",kind:1},{x:100,y:350,id:"color",kind:1},{x:150,y:350,id:"color",kind:1},{x:150,y:300,id:"color",kind:1},{x:200,y:350,id:"color",kind:1},{x:250,y:250,id:"color",kind:1},{x:300,y:300,id:"color",kind:1},{x:300,y:250,id:"color",kind:1},{x:300,y:200,id:"color",kind:1},{x:300,y:100,id:"color",kind:1},{x:300,y:50,id:"color",kind:1},{x:300,y:0,id:"color",
kind:1},{x:250,y:0,id:"color",kind:1},{x:250,y:50,id:"color",kind:1},{x:250,y:100,id:"color",kind:1},{x:200,y:50,id:"color",kind:1},{x:200,y:0,id:"color",kind:1},{x:100,y:0,id:"color",kind:1},{x:100,y:50,id:"color",kind:1},{x:50,y:50,id:"color",kind:1},{x:50,y:100,id:"color",kind:1},{x:0,y:100,id:"color",kind:1},{x:0,y:50,id:"color",kind:1},{x:0,y:0,id:"color",kind:1},{x:50,y:0,id:"color",kind:1},{x:50,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,
y:250,id:"cell"},{x:250,y:350,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:50,y:300,
id:"cell"},{x:0,y:350,id:"cell"},{x:150,y:0,id:"cell"}],name:{key:"star"}},panda8x7:{width:350,height:400,items:[{x:50,y:50,id:"color",kind:0},{x:0,y:50,id:"color",kind:0},{x:50,y:0,id:"color",kind:0},{x:300,y:50,id:"color",kind:0},{x:250,y:0,id:"color",kind:0},{x:250,y:50,id:"color",kind:0},{x:50,y:150,id:"color",kind:0},{x:0,y:200,id:"color",kind:0},{x:250,y:150,id:"color",kind:0},{x:50,y:200,id:"color",kind:0},{x:100,y:300,id:"color",kind:0},{x:200,y:300,id:"color",kind:0},{x:0,y:100,id:"color",
kind:22},{x:0,y:300,id:"color",kind:22},{x:0,y:350,id:"color",kind:22},{x:50,y:350,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:300,y:200,id:"color",kind:0},{x:150,y:300,id:"color",kind:0},{x:150,y:350,id:"color",kind:0},{x:150,y:0,id:"color",kind:22},{x:300,y:100,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:250,y:200,id:"color",kind:0},{x:100,y:0,id:"color",kind:22},{x:200,y:0,
id:"color",kind:22},{x:100,y:350,id:"color",kind:22},{x:200,y:350,id:"color",kind:22},{x:100,y:100,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:100,y:200,id:"color",kind:23},{x:100,y:250,id:"color",kind:23},{x:50,y:250,id:"color",kind:23},{x:50,y:300,id:"color",kind:23},{x:150,y:250,id:"color",kind:23},{x:200,y:250,id:"color",kind:23},{x:250,y:250,id:"color",kind:23},{x:250,y:300,id:"color",kind:23},{x:200,y:200,id:"color",kind:23},{x:150,y:200,id:"color",kind:23},{x:150,y:150,id:"color",
kind:23},{x:200,y:150,id:"color",kind:23},{x:200,y:100,id:"color",kind:23},{x:50,y:100,id:"color",kind:23},{x:100,y:50,id:"color",kind:23},{x:200,y:50,id:"color",kind:23},{x:250,y:100,id:"color",kind:23},{x:0,y:250,id:"color",kind:23},{x:300,y:250,id:"color",kind:23},{x:0,y:150,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:0,y:0,id:"color",kind:0},{x:300,y:0,id:"color",kind:0},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:50,id:"cell"},
{x:50,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:0,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:50,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:250,y:150,id:"cell"},
{x:0,y:0,id:"cell"},{x:300,y:0,id:"cell"}],name:{key:"panda"}},heart8x8:{width:400,height:400,items:[{x:0,y:250,id:"color",kind:31},{x:0,y:300,id:"color",kind:31},{x:0,y:350,id:"color",kind:31},{x:50,y:350,id:"color",kind:31},{x:50,y:300,id:"color",kind:31},{x:100,y:350,id:"color",kind:31},{x:250,y:350,id:"color",kind:31},{x:300,y:300,id:"color",kind:31},{x:300,y:350,id:"color",kind:31},{x:350,y:350,id:"color",kind:31},{x:350,y:300,id:"color",kind:31},{x:350,y:250,id:"color",kind:31},{x:350,y:50,
id:"color",kind:31},{x:350,y:0,id:"color",kind:31},{x:300,y:0,id:"color",kind:31},{x:250,y:0,id:"color",kind:31},{x:200,y:0,id:"color",kind:31},{x:150,y:50,id:"color",kind:31},{x:200,y:50,id:"color",kind:31},{x:150,y:0,id:"color",kind:31},{x:100,y:0,id:"color",kind:31},{x:50,y:0,id:"color",kind:31},{x:0,y:0,id:"color",kind:31},{x:0,y:50,id:"color",kind:31},{x:150,y:300,id:"color",kind:29},{x:150,y:350,id:"color",kind:29},{x:200,y:350,id:"color",kind:29},{x:200,y:300,id:"color",kind:29},{x:150,y:250,
id:"color",kind:29},{x:200,y:250,id:"color",kind:29},{x:100,y:300,id:"color",kind:29},{x:250,y:300,id:"color",kind:29},{x:250,y:250,id:"color",kind:29},{x:200,y:200,id:"color",kind:29},{x:250,y:200,id:"color",kind:29},{x:300,y:250,id:"color",kind:29},{x:300,y:200,id:"color",kind:29},{x:250,y:150,id:"color",kind:29},{x:300,y:150,id:"color",kind:29},{x:350,y:200,id:"color",kind:29},{x:350,y:150,id:"color",kind:29},{x:350,y:100,id:"color",kind:29},{x:300,y:100,id:"color",kind:29},{x:100,y:250,id:"color",
kind:30},{x:100,y:200,id:"color",kind:30},{x:50,y:250,id:"color",kind:30},{x:50,y:200,id:"color",kind:30},{x:50,y:150,id:"color",kind:30},{x:0,y:200,id:"color",kind:30},{x:0,y:150,id:"color",kind:30},{x:0,y:100,id:"color",kind:30},{x:50,y:50,id:"color",kind:30},{x:100,y:50,id:"color",kind:30},{x:100,y:100,id:"color",kind:30},{x:150,y:100,id:"color",kind:30},{x:150,y:150,id:"color",kind:30},{x:150,y:200,id:"color",kind:30},{x:200,y:150,id:"color",kind:30},{x:200,y:100,id:"color",kind:30},{x:250,y:100,
id:"color",kind:30},{x:250,y:50,id:"color",kind:30},{x:300,y:50,id:"color",kind:30},{x:50,y:100,id:"color",kind:35},{x:100,y:150,id:"color",kind:35},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},
{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:200,
y:100,id:"cell"},{x:350,y:100,id:"cell"}],name:{key:"heart"}},deer8x8:{width:400,height:400,items:[{x:100,y:150,id:"color",kind:4},{x:150,y:150,id:"color",kind:4},{x:150,y:100,id:"color",kind:4},{x:200,y:100,id:"color",kind:4},{x:250,y:150,id:"color",kind:4},{x:250,y:200,id:"color",kind:4},{x:200,y:200,id:"color",kind:4},{x:150,y:200,id:"color",kind:4},{x:100,y:200,id:"color",kind:4},{x:200,y:250,id:"color",kind:4},{x:250,y:250,id:"color",kind:4},{x:250,y:300,id:"color",kind:4},{x:200,y:300,id:"color",
kind:4},{x:150,y:300,id:"color",kind:4},{x:150,y:350,id:"color",kind:4},{x:200,y:350,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:300,y:350,id:"color",kind:4},{x:350,y:350,id:"color",kind:4},{x:350,y:300,id:"color",kind:4},{x:300,y:300,id:"color",kind:4},{x:300,y:250,id:"color",kind:4},{x:100,y:250,id:"color",kind:0},{x:150,y:250,id:"color",kind:0},{x:200,y:150,id:"color",kind:4},{x:50,y:250,id:"color",kind:13},{x:0,y:250,id:"color",kind:13},{x:50,y:300,id:"color",kind:13},{x:100,y:300,id:"color",
kind:13},{x:100,y:350,id:"color",kind:13},{x:300,y:200,id:"color",kind:13},{x:350,y:200,id:"color",kind:13},{x:350,y:150,id:"color",kind:13},{x:50,y:0,id:"color",kind:21},{x:0,y:100,id:"color",kind:21},{x:100,y:100,id:"color",kind:21},{x:100,y:50,id:"color",kind:21},{x:150,y:50,id:"color",kind:21},{x:150,y:0,id:"color",kind:21},{x:200,y:0,id:"color",kind:21},{x:200,y:50,id:"color",kind:21},{x:250,y:0,id:"color",kind:21},{x:250,y:100,id:"color",kind:21},{x:350,y:0,id:"color",kind:21},{x:0,y:300,id:"color",
kind:14},{x:0,y:350,id:"color",kind:14},{x:50,y:350,id:"color",kind:14},{x:350,y:250,id:"color",kind:14},{x:0,y:150,id:"color",kind:33},{x:350,y:50,id:"color",kind:33},{x:50,y:200,id:"color",kind:33},{x:0,y:200,id:"color",kind:13},{x:50,y:150,id:"color",kind:25},{x:50,y:100,id:"color",kind:25},{x:50,y:50,id:"color",kind:25},{x:0,y:50,id:"color",kind:25},{x:0,y:0,id:"color",kind:25},{x:100,y:0,id:"color",kind:25},{x:250,y:50,id:"color",kind:25},{x:300,y:50,id:"color",kind:25},{x:300,y:0,id:"color",
kind:25},{x:300,y:100,id:"color",kind:25},{x:300,y:150,id:"color",kind:25},{x:350,y:100,id:"color",kind:25},{x:100,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:100,id:"cell"},
{x:100,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:0,y:0,id:"cell"}],name:{key:"deer"}},computer8x8:{width:400,
height:400,items:[{x:200,y:100,id:"color",kind:13},{x:250,y:100,id:"color",kind:13},{x:300,y:100,id:"color",kind:13},{x:200,y:50,id:"color",kind:13},{x:250,y:50,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:250,y:200,id:"color",kind:28},{x:50,y:300,id:"color",kind:28},{x:100,y:300,id:"color",kind:28},{x:150,y:300,id:"color",kind:28},{x:200,y:300,id:"color",kind:28},{x:300,y:300,id:"color",kind:28},{x:0,y:350,id:"color",kind:4},{x:50,y:350,id:"color",kind:4},{x:100,y:350,id:"color",kind:4},
{x:150,y:350,id:"color",kind:4},{x:200,y:350,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:300,y:350,id:"color",kind:4},{x:350,y:350,id:"color",kind:4},{x:200,y:150,id:"color",kind:22},{x:250,y:150,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:350,y:100,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:150,y:150,id:"color",kind:23},{x:150,y:100,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:200,y:0,id:"color",kind:23},{x:250,y:0,id:"color",
kind:23},{x:300,y:0,id:"color",kind:23},{x:350,y:0,id:"color",kind:23},{x:150,y:250,id:"color",kind:23},{x:200,y:250,id:"color",kind:23},{x:250,y:250,id:"color",kind:23},{x:300,y:250,id:"color",kind:23},{x:250,y:300,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:0,y:300,id:"color",kind:26},{x:0,y:250,id:"color",kind:26},{x:0,y:200,id:"color",kind:26},{x:0,y:150,id:"color",kind:26},{x:0,y:100,id:"color",kind:26},{x:0,y:50,id:"color",kind:26},{x:0,y:0,id:"color",kind:26},{x:50,y:0,id:"color",
kind:26},{x:50,y:50,id:"color",kind:26},{x:100,y:50,id:"color",kind:26},{x:100,y:0,id:"color",kind:26},{x:150,y:0,id:"color",kind:26},{x:100,y:100,id:"color",kind:26},{x:100,y:150,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:50,y:250,id:"color",kind:26},{x:100,y:250,id:"color",kind:26},{x:100,y:200,id:"color",kind:26},{x:150,y:200,id:"color",kind:26},{x:200,y:200,id:"color",kind:26},{x:300,y:200,id:"color",kind:26},{x:350,y:200,
id:"color",kind:26},{x:350,y:300,id:"color",kind:22},{x:0,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},
{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:250,y:150,id:"cell"}],name:{key:"computer"}},house8x8:{width:400,height:400,items:[{x:0,y:200,id:"color",kind:26},{x:0,y:150,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},{x:100,y:100,id:"color",kind:26},{x:100,y:50,id:"color",kind:26},{x:150,y:50,id:"color",kind:26},{x:150,y:0,
id:"color",kind:26},{x:200,y:0,id:"color",kind:26},{x:250,y:0,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:300,y:50,id:"color",kind:26},{x:300,y:100,id:"color",kind:26},{x:350,y:100,id:"color",kind:26},{x:350,y:150,id:"color",kind:26},{x:0,y:100,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:0,y:350,id:"color",
kind:11},{x:200,y:300,id:"color",kind:3},{x:200,y:250,id:"color",kind:3},{x:200,y:350,id:"color",kind:3},{x:100,y:300,id:"color",kind:6},{x:50,y:300,id:"color",kind:6},{x:50,y:350,id:"color",kind:6},{x:100,y:350,id:"color",kind:6},{x:100,y:200,id:"color",kind:6},{x:50,y:200,id:"color",kind:6},{x:50,y:250,id:"color",kind:6},{x:100,y:150,id:"color",kind:6},{x:150,y:100,id:"color",kind:6},{x:300,y:350,id:"color",kind:6},{x:350,y:350,id:"color",kind:6},{x:350,y:300,id:"color",kind:6},{x:300,y:300,id:"color",
kind:6},{x:350,y:250,id:"color",kind:6},{x:350,y:200,id:"color",kind:6},{x:300,y:200,id:"color",kind:6},{x:300,y:150,id:"color",kind:6},{x:250,y:100,id:"color",kind:6},{x:200,y:50,id:"color",kind:6},{x:100,y:250,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},{x:150,y:350,id:"color",kind:3},{x:150,y:300,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:150,y:200,id:"color",kind:3},{x:200,y:200,id:"color",kind:3},{x:250,y:200,id:"color",kind:6},{x:250,y:300,id:"color",kind:6},{x:250,y:350,
id:"color",kind:6},{x:250,y:250,id:"color",kind:22},{x:250,y:150,id:"color",kind:6},{x:200,y:150,id:"color",kind:6},{x:150,y:150,id:"color",kind:6},{x:200,y:100,id:"color",kind:22},{x:300,y:0,id:"color",kind:5},{x:350,y:0,id:"color",kind:5},{x:350,y:50,id:"color",kind:5},{x:50,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},
{x:150,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:0,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:200,
y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:300,id:"cell"}],name:{key:"house"}},elephant8x8:{width:400,height:400,items:[{x:0,y:250,id:"color",kind:27},{x:0,y:300,id:"color",kind:27},{x:50,y:350,id:"color",kind:27},{x:100,y:350,id:"color",kind:27},{x:150,y:300,id:"color",kind:27},{x:150,y:350,id:"color",kind:27},{x:150,y:150,id:"color",kind:27},{x:150,y:200,id:"color",kind:27},{x:150,y:250,id:"color",kind:27},{x:150,y:100,id:"color",kind:27},{x:200,y:50,id:"color",kind:27},{x:250,y:50,id:"color",
kind:27},{x:300,y:50,id:"color",kind:27},{x:350,y:0,id:"color",kind:27},{x:300,y:100,id:"color",kind:27},{x:350,y:100,id:"color",kind:27},{x:250,y:100,id:"color",kind:27},{x:200,y:100,id:"color",kind:27},{x:200,y:150,id:"color",kind:27},{x:250,y:150,id:"color",kind:27},{x:300,y:150,id:"color",kind:27},{x:350,y:150,id:"color",kind:27},{x:350,y:200,id:"color",kind:27},{x:300,y:200,id:"color",kind:27},{x:250,y:200,id:"color",kind:27},{x:200,y:250,id:"color",kind:27},{x:250,y:250,id:"color",kind:27},
{x:300,y:250,id:"color",kind:27},{x:300,y:300,id:"color",kind:27},{x:350,y:300,id:"color",kind:27},{x:350,y:250,id:"color",kind:27},{x:200,y:300,id:"color",kind:27},{x:200,y:350,id:"color",kind:27},{x:250,y:350,id:"color",kind:28},{x:300,y:350,id:"color",kind:28},{x:350,y:350,id:"color",kind:28},{x:250,y:300,id:"color",kind:28},{x:200,y:200,id:"color",kind:0},{x:50,y:250,id:"color",kind:27},{x:0,y:350,id:"color",kind:27},{x:0,y:200,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},{x:100,y:200,
id:"color",kind:20},{x:100,y:250,id:"color",kind:20},{x:100,y:300,id:"color",kind:20},{x:50,y:300,id:"color",kind:20},{x:100,y:150,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:0,
y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:250,y:0,id:"color",kind:27},{x:300,y:0,id:"color",kind:27},{x:350,y:50,id:"color",kind:27},{x:50,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},
{x:200,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:200,y:200,id:"cell"},{x:0,y:350,id:"cell"},{x:250,y:50,id:"cell"}],name:{key:"elephant"}},dolphin8x8:{width:400,height:400,items:[{x:0,y:300,id:"color",kind:16},{x:0,y:350,id:"color",kind:16},{x:50,y:350,id:"color",kind:16},{x:150,y:300,id:"color",kind:16},{x:350,y:300,id:"color",kind:16},{x:350,y:350,id:"color",kind:16},{x:300,y:350,id:"color",kind:16},{x:200,y:250,id:"color",kind:16},{x:150,y:250,id:"color",
kind:16},{x:100,y:250,id:"color",kind:16},{x:0,y:200,id:"color",kind:19},{x:50,y:200,id:"color",kind:19},{x:150,y:200,id:"color",kind:19},{x:200,y:200,id:"color",kind:19},{x:150,y:150,id:"color",kind:19},{x:100,y:150,id:"color",kind:19},{x:50,y:150,id:"color",kind:19},{x:0,y:150,id:"color",kind:19},{x:100,y:100,id:"color",kind:19},{x:50,y:100,id:"color",kind:19},{x:0,y:100,id:"color",kind:19},{x:100,y:0,id:"color",kind:19},{x:300,y:0,id:"color",kind:19},{x:350,y:0,id:"color",kind:19},{x:350,y:50,
id:"color",kind:19},{x:50,y:0,id:"color",kind:8},{x:0,y:0,id:"color",kind:8},{x:0,y:50,id:"color",kind:8},{x:50,y:50,id:"color",kind:24},{x:100,y:50,id:"color",kind:24},{x:150,y:50,id:"color",kind:24},{x:150,y:0,id:"color",kind:24},{x:200,y:0,id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:200,y:50,id:"color",kind:24},{x:250,y:50,id:"color",kind:24},{x:300,y:50,id:"color",kind:24},{x:150,y:100,id:"color",kind:24},{x:200,y:100,id:"color",kind:24},{x:250,y:100,id:"color",kind:24},{x:300,y:100,
id:"color",kind:24},{x:350,y:100,id:"color",kind:24},{x:350,y:150,id:"color",kind:24},{x:300,y:150,id:"color",kind:24},{x:200,y:150,id:"color",kind:24},{x:250,y:150,id:"color",kind:24},{x:250,y:200,id:"color",kind:24},{x:300,y:200,id:"color",kind:24},{x:350,y:200,id:"color",kind:24},{x:350,y:250,id:"color",kind:24},{x:250,y:250,id:"color",kind:24},{x:300,y:250,id:"color",kind:24},{x:300,y:300,id:"color",kind:24},{x:200,y:300,id:"color",kind:24},{x:250,y:300,id:"color",kind:24},{x:250,y:350,id:"color",
kind:24},{x:200,y:350,id:"color",kind:24},{x:150,y:350,id:"color",kind:24},{x:100,y:350,id:"color",kind:24},{x:100,y:300,id:"color",kind:24},{x:50,y:300,id:"color",kind:24},{x:50,y:250,id:"color",kind:24},{x:0,y:250,id:"color",kind:24},{x:100,y:200,id:"color",kind:24},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:250,
y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:50,
y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:0,id:"cell"}],name:{key:"dolphin"}},teabag8x8:{width:400,height:400,items:[{x:50,y:300,id:"color",kind:4},{x:50,y:250,id:"color",kind:4},{x:150,y:300,id:"color",kind:4},{x:100,y:300,id:"color",kind:3},{x:100,y:250,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:0,y:350,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:50,y:200,id:"color",
kind:22},{x:50,y:150,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:200,y:200,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:200,y:350,id:"color",kind:22},{x:100,y:150,id:"color",kind:27},{x:100,y:50,id:"color",kind:27},{x:150,y:0,id:"color",kind:27},{x:250,y:0,id:"color",kind:27},{x:200,y:0,id:"color",kind:27},{x:350,y:50,id:"color",kind:27},{x:350,y:100,id:"color",kind:27},{x:300,
y:0,id:"color",kind:27},{x:50,y:100,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:50,y:350,id:"color",kind:3},{x:150,y:350,id:"color",kind:3},{x:100,y:350,id:"color",kind:4},{x:250,y:350,id:"color",kind:33},{x:300,y:350,id:"color",kind:33},{x:300,y:300,id:"color",kind:33},{x:350,y:300,id:"color",kind:33},{x:350,y:350,id:"color",kind:33},{x:250,y:300,id:"color",kind:33},{x:250,y:250,id:"color",kind:33},{x:250,y:200,id:"color",kind:33},{x:250,y:150,id:"color",
kind:33},{x:200,y:150,id:"color",kind:33},{x:250,y:100,id:"color",kind:33},{x:300,y:100,id:"color",kind:33},{x:300,y:50,id:"color",kind:33},{x:250,y:50,id:"color",kind:33},{x:200,y:50,id:"color",kind:33},{x:200,y:100,id:"color",kind:33},{x:150,y:50,id:"color",kind:33},{x:350,y:0,id:"color",kind:33},{x:100,y:0,id:"color",kind:33},{x:50,y:0,id:"color",kind:33},{x:0,y:0,id:"color",kind:33},{x:0,y:50,id:"color",kind:33},{x:50,y:50,id:"color",kind:33},{x:0,y:100,id:"color",kind:33},{x:0,y:150,id:"color",
kind:33},{x:300,y:150,id:"color",kind:6},{x:350,y:150,id:"color",kind:6},{x:350,y:200,id:"color",kind:6},{x:350,y:250,id:"color",kind:6},{x:300,y:250,id:"color",kind:6},{x:300,y:200,id:"color",kind:6},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:250,id:"cell"},{x:0,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:0,
y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"}],name:{key:"tea_bag"}},mug8x8:{width:400,height:400,items:[{x:0,
y:50,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:50,y:300,id:"color",kind:20},{x:100,y:300,id:"color",kind:20},{x:50,y:350,id:"color",kind:19},{x:100,y:350,id:"color",kind:19},{x:150,y:350,id:"color",kind:19},{x:200,y:350,id:"color",kind:19},{x:150,y:300,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:250,y:300,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},
{x:250,y:200,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:200,y:100,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:200,y:250,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:100,y:250,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:100,y:150,
id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:300,y:100,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:350,y:200,id:"color",kind:19},{x:300,y:250,id:"color",kind:19},{x:50,y:250,id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:0,y:350,id:"color",kind:4},
{x:250,y:350,id:"color",kind:4},{x:300,y:350,id:"color",kind:4},{x:350,y:350,id:"color",kind:4},{x:300,y:300,id:"color",kind:5},{x:350,y:300,id:"color",kind:5},{x:350,y:250,id:"color",kind:5},{x:300,y:200,id:"color",kind:5},{x:300,y:150,id:"color",kind:5},{x:350,y:0,id:"color",kind:5},{x:300,y:0,id:"color",kind:5},{x:250,y:0,id:"color",kind:5},{x:150,y:0,id:"color",kind:5},{x:200,y:0,id:"color",kind:5},{x:100,y:0,id:"color",kind:5},{x:50,y:0,id:"color",kind:5},{x:0,y:0,id:"color",kind:5},{x:50,y:150,
id:"color",kind:22},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},
{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:200,id:"cell"}],name:{key:"unnamed"}},
bee8x8:{width:400,height:400,items:[{x:150,y:100,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:100,y:50,id:"color",kind:22},{x:250,y:200,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:350,y:300,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},{x:50,y:300,
id:"color",kind:17},{x:150,y:250,id:"color",kind:17},{x:100,y:200,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:200,y:150,id:"color",kind:3},{x:250,y:100,id:"color",kind:3},{x:250,y:50,id:"color",kind:0},{x:300,y:100,id:"color",kind:0},{x:150,y:200,id:"color",kind:0},{x:100,y:150,id:"color",kind:0},{x:200,y:250,id:"color",kind:0},{x:50,y:250,id:"color",kind:0},{x:100,y:300,id:"color",kind:0},{x:50,y:200,id:"color",kind:17},{x:100,y:250,id:"color",kind:17},
{x:150,y:300,id:"color",kind:17},{x:200,y:100,id:"color",kind:4},{x:250,y:150,id:"color",kind:4},{x:0,y:0,id:"color",kind:23},{x:0,y:50,id:"color",kind:23},{x:50,y:100,id:"color",kind:23},{x:50,y:150,id:"color",kind:23},{x:0,y:100,id:"color",kind:23},{x:0,y:150,id:"color",kind:23},{x:0,y:200,id:"color",kind:23},{x:0,y:250,id:"color",kind:23},{x:0,y:300,id:"color",kind:23},{x:0,y:350,id:"color",kind:23},{x:50,y:350,id:"color",kind:23},{x:100,y:350,id:"color",kind:23},{x:150,y:350,id:"color",kind:23},
{x:200,y:350,id:"color",kind:23},{x:200,y:300,id:"color",kind:23},{x:250,y:300,id:"color",kind:23},{x:250,y:350,id:"color",kind:23},{x:300,y:350,id:"color",kind:23},{x:350,y:350,id:"color",kind:23},{x:350,y:200,id:"color",kind:23},{x:300,y:150,id:"color",kind:23},{x:350,y:150,id:"color",kind:23},{x:350,y:100,id:"color",kind:23},{x:350,y:50,id:"color",kind:23},{x:300,y:50,id:"color",kind:23},{x:350,y:0,id:"color",kind:23},{x:300,y:0,id:"color",kind:23},{x:250,y:0,id:"color",kind:23},{x:200,y:50,id:"color",
kind:23},{x:200,y:0,id:"color",kind:23},{x:150,y:0,id:"color",kind:23},{x:50,y:300,id:"cell"},{x:100,y:150,id:"cell"},{x:200,y:250,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:100,id:"cell"},{x:50,y:250,
id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:50,y:200,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:150,id:"cell"}],name:{key:"bee"}},pond8x8:{width:400,height:400,items:[{x:100,y:250,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:150,y:300,id:"color",kind:22},{x:100,y:300,id:"color",kind:22},{x:150,y:350,id:"color",
kind:22},{x:50,y:300,id:"color",kind:8},{x:100,y:350,id:"color",kind:8},{x:150,y:250,id:"color",kind:8},{x:150,y:200,id:"color",kind:5},{x:50,y:350,id:"color",kind:5},{x:200,y:350,id:"color",kind:8},{x:250,y:300,id:"color",kind:24},{x:250,y:350,id:"color",kind:24},{x:300,y:350,id:"color",kind:24},{x:0,y:350,id:"color",kind:24},{x:0,y:300,id:"color",kind:12},{x:0,y:250,id:"color",kind:12},{x:0,y:200,id:"color",kind:12},{x:0,y:150,id:"color",kind:12},{x:50,y:150,id:"color",kind:12},{x:50,y:100,id:"color",
kind:12},{x:0,y:100,id:"color",kind:12},{x:50,y:50,id:"color",kind:12},{x:0,y:50,id:"color",kind:12},{x:50,y:0,id:"color",kind:12},{x:100,y:0,id:"color",kind:12},{x:100,y:50,id:"color",kind:12},{x:100,y:100,id:"color",kind:12},{x:150,y:100,id:"color",kind:12},{x:150,y:50,id:"color",kind:12},{x:150,y:0,id:"color",kind:12},{x:200,y:50,id:"color",kind:12},{x:200,y:100,id:"color",kind:12},{x:200,y:150,id:"color",kind:12},{x:250,y:150,id:"color",kind:12},{x:250,y:200,id:"color",kind:12},{x:250,y:250,id:"color",
kind:12},{x:300,y:250,id:"color",kind:12},{x:300,y:300,id:"color",kind:12},{x:350,y:300,id:"color",kind:12},{x:350,y:250,id:"color",kind:12},{x:300,y:200,id:"color",kind:12},{x:350,y:350,id:"color",kind:12},{x:300,y:100,id:"color",kind:12},{x:250,y:100,id:"color",kind:12},{x:200,y:0,id:"color",kind:12},{x:350,y:200,id:"color",kind:12},{x:250,y:50,id:"color",kind:13},{x:250,y:0,id:"color",kind:13},{x:300,y:0,id:"color",kind:13},{x:350,y:150,id:"color",kind:13},{x:300,y:150,id:"color",kind:13},{x:350,
y:0,id:"color",kind:13},{x:0,y:0,id:"color",kind:13},{x:200,y:200,id:"color",kind:24},{x:50,y:200,id:"color",kind:24},{x:350,y:50,id:"color",kind:14},{x:300,y:50,id:"color",kind:14},{x:350,y:100,id:"color",kind:14},{x:0,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:0,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:50,y:350,
id:"cell"},{x:50,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:350,y:50,id:"cell"}],name:{key:"koi_pond"}},park8x8:{width:400,height:400,items:[{x:50,y:300,id:"color",kind:14},{x:100,y:300,id:"color",kind:14},{x:150,y:300,id:"color",kind:14},{x:0,y:250,id:"color",kind:13},{x:50,y:250,id:"color",kind:13},{x:100,y:250,
id:"color",kind:13},{x:150,y:250,id:"color",kind:3},{x:200,y:200,id:"color",kind:3},{x:250,y:200,id:"color",kind:3},{x:300,y:200,id:"color",kind:3},{x:350,y:250,id:"color",kind:3},{x:0,y:200,id:"color",kind:4},{x:0,y:150,id:"color",kind:4},{x:0,y:100,id:"color",kind:4},{x:50,y:100,id:"color",kind:11},{x:0,y:50,id:"color",kind:11},{x:50,y:50,id:"color",kind:11},{x:100,y:50,id:"color",kind:11},{x:50,y:0,id:"color",kind:11},{x:0,y:0,id:"color",kind:11},{x:50,y:350,id:"color",kind:12},{x:100,y:350,id:"color",
kind:12},{x:150,y:350,id:"color",kind:12},{x:200,y:350,id:"color",kind:12},{x:200,y:300,id:"color",kind:12},{x:300,y:300,id:"color",kind:12},{x:250,y:300,id:"color",kind:12},{x:250,y:350,id:"color",kind:12},{x:300,y:350,id:"color",kind:12},{x:350,y:350,id:"color",kind:12},{x:350,y:300,id:"color",kind:14},{x:0,y:350,id:"color",kind:14},{x:0,y:300,id:"color",kind:13},{x:200,y:250,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:100,
y:200,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:100,y:150,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:200,y:100,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:300,y:0,id:"color",
kind:20},{x:300,y:100,id:"color",kind:20},{x:300,y:150,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:50,y:200,id:"color",kind:11},{x:100,y:0,id:"color",kind:11},{x:150,y:0,id:"color",kind:11},{x:300,y:50,id:"color",kind:17},{x:300,y:50,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:250,id:"cell"},
{x:50,y:300,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:0,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:350,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:0,
y:250,id:"cell"}],name:{key:"the_park"}},grapes8x8:{width:400,height:400,items:[{x:150,y:100,id:"color",kind:33},{x:200,y:50,id:"color",kind:33},{x:250,y:100,id:"color",kind:33},{x:300,y:150,id:"color",kind:33},{x:250,y:150,id:"color",kind:33},{x:200,y:150,id:"color",kind:33},{x:150,y:200,id:"color",kind:33},{x:200,y:200,id:"color",kind:33},{x:250,y:250,id:"color",kind:33},{x:200,y:250,id:"color",kind:33},{x:250,y:300,id:"color",kind:33},{x:200,y:350,id:"color",kind:33},{x:150,y:350,id:"color",kind:33},
{x:200,y:300,id:"color",kind:34},{x:250,y:350,id:"color",kind:34},{x:300,y:300,id:"color",kind:34},{x:300,y:250,id:"color",kind:34},{x:250,y:200,id:"color",kind:34},{x:350,y:200,id:"color",kind:34},{x:350,y:150,id:"color",kind:34},{x:350,y:100,id:"color",kind:34},{x:300,y:100,id:"color",kind:34},{x:300,y:50,id:"color",kind:34},{x:250,y:50,id:"color",kind:13},{x:250,y:0,id:"color",kind:13},{x:150,y:0,id:"color",kind:13},{x:200,y:0,id:"color",kind:13},{x:100,y:0,id:"color",kind:13},{x:50,y:0,id:"color",
kind:13},{x:0,y:50,id:"color",kind:13},{x:0,y:100,id:"color",kind:13},{x:0,y:150,id:"color",kind:13},{x:50,y:200,id:"color",kind:13},{x:50,y:150,id:"color",kind:13},{x:0,y:0,id:"color",kind:13},{x:50,y:250,id:"color",kind:13},{x:50,y:300,id:"color",kind:13},{x:0,y:300,id:"color",kind:13},{x:0,y:350,id:"color",kind:13},{x:200,y:100,id:"color",kind:34},{x:300,y:200,id:"color",kind:33},{x:0,y:250,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:50,y:350,id:"color",kind:20},{x:100,y:350,id:"color",
kind:20},{x:100,y:300,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:100,y:250,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:100,y:150,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,
y:250,id:"color",kind:20},{x:350,y:300,id:"color",kind:20},{x:350,y:350,id:"color",kind:20},{x:300,y:350,id:"color",kind:20},{x:0,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:50,id:"cell"},
{x:150,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"}],name:{key:"grapes"}},pearl8x8:{width:400,height:400,items:[{x:100,y:250,
id:"color",kind:32},{x:100,y:200,id:"color",kind:32},{x:50,y:200,id:"color",kind:32},{x:50,y:150,id:"color",kind:32},{x:50,y:100,id:"color",kind:32},{x:50,y:50,id:"color",kind:32},{x:100,y:50,id:"color",kind:32},{x:150,y:50,id:"color",kind:32},{x:100,y:100,id:"color",kind:32},{x:100,y:150,id:"color",kind:32},{x:150,y:150,id:"color",kind:32},{x:150,y:100,id:"color",kind:32},{x:200,y:100,id:"color",kind:32},{x:200,y:50,id:"color",kind:32},{x:250,y:50,id:"color",kind:32},{x:250,y:100,id:"color",kind:32},
{x:250,y:150,id:"color",kind:32},{x:200,y:150,id:"color",kind:32},{x:250,y:200,id:"color",kind:32},{x:0,y:100,id:"color",kind:2},{x:0,y:150,id:"color",kind:2},{x:50,y:250,id:"color",kind:1},{x:250,y:250,id:"color",kind:1},{x:0,y:200,id:"color",kind:1},{x:150,y:250,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:200,y:200,id:"color",kind:22},{x:0,y:350,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:350,y:350,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:350,y:250,id:"color",
kind:20},{x:350,y:200,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:150,y:200,id:"color",kind:23},{x:150,y:0,id:"color",kind:2},{x:200,y:0,id:"color",kind:2},{x:250,y:0,id:"color",kind:2},{x:300,y:50,id:"color",kind:2},{x:300,y:100,id:"color",kind:2},{x:50,y:300,id:"color",kind:2},{x:100,y:300,id:"color",kind:2},{x:150,y:300,id:"color",
kind:2},{x:150,y:350,id:"color",kind:2},{x:200,y:350,id:"color",kind:2},{x:200,y:300,id:"color",kind:2},{x:250,y:300,id:"color",kind:2},{x:300,y:300,id:"color",kind:2},{x:350,y:300,id:"color",kind:2},{x:0,y:50,id:"color",kind:1},{x:50,y:0,id:"color",kind:1},{x:100,y:0,id:"color",kind:1},{x:300,y:200,id:"color",kind:1},{x:300,y:150,id:"color",kind:1},{x:0,y:300,id:"color",kind:1},{x:50,y:350,id:"color",kind:1},{x:100,y:350,id:"color",kind:1},{x:250,y:350,id:"color",kind:1},{x:300,y:350,id:"color",
kind:1},{x:0,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},
{x:250,y:50,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"}],name:{key:"pearl"}},stove8x8:{width:400,height:400,items:[{x:150,y:100,id:"color",kind:27},{x:150,y:150,id:"color",kind:27},{x:150,y:200,id:"color",kind:27},{x:200,y:100,id:"color",kind:27},{x:250,y:100,id:"color",kind:27},{x:250,y:200,id:"color",kind:27},{x:250,y:150,id:"color",kind:27},{x:200,y:150,id:"color",
kind:27},{x:200,y:200,id:"color",kind:27},{x:100,y:100,id:"color",kind:28},{x:50,y:100,id:"color",kind:28},{x:0,y:100,id:"color",kind:28},{x:300,y:100,id:"color",kind:27},{x:300,y:150,id:"color",kind:27},{x:300,y:200,id:"color",kind:27},{x:350,y:200,id:"color",kind:27},{x:350,y:150,id:"color",kind:27},{x:350,y:100,id:"color",kind:27},{x:200,y:250,id:"color",kind:0},{x:150,y:250,id:"color",kind:0},{x:150,y:300,id:"color",kind:0},{x:300,y:250,id:"color",kind:0},{x:350,y:250,id:"color",kind:0},{x:350,
y:300,id:"color",kind:0},{x:200,y:300,id:"color",kind:8},{x:250,y:300,id:"color",kind:8},{x:300,y:300,id:"color",kind:8},{x:0,y:350,id:"color",kind:4},{x:50,y:350,id:"color",kind:4},{x:100,y:350,id:"color",kind:4},{x:150,y:350,id:"color",kind:4},{x:200,y:350,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:300,y:350,id:"color",kind:4},{x:350,y:350,id:"color",kind:4},{x:0,y:300,id:"color",kind:34},{x:0,y:250,id:"color",kind:34},{x:0,y:200,id:"color",kind:34},{x:0,y:150,id:"color",kind:34},{x:50,
y:150,id:"color",kind:34},{x:50,y:200,id:"color",kind:34},{x:50,y:250,id:"color",kind:34},{x:50,y:300,id:"color",kind:34},{x:100,y:300,id:"color",kind:34},{x:100,y:250,id:"color",kind:34},{x:100,y:200,id:"color",kind:34},{x:100,y:150,id:"color",kind:34},{x:100,y:50,id:"color",kind:34},{x:50,y:50,id:"color",kind:34},{x:0,y:50,id:"color",kind:34},{x:50,y:0,id:"color",kind:34},{x:350,y:50,id:"color",kind:34},{x:300,y:0,id:"color",kind:34},{x:250,y:0,id:"color",kind:34},{x:350,y:0,id:"color",kind:34},
{x:150,y:50,id:"color",kind:34},{x:200,y:50,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:200,y:0,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:250,y:250,id:"color",kind:34},{x:0,y:0,id:"color",kind:22},{x:0,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},
{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:0,y:350,id:"cell"}],name:{key:"stove"}},rose8x8:{width:400,height:400,items:[{x:300,y:200,id:"color",kind:30},{x:200,
y:250,id:"color",kind:30},{x:150,y:200,id:"color",kind:30},{x:150,y:150,id:"color",kind:30},{x:300,y:150,id:"color",kind:30},{x:300,y:100,id:"color",kind:30},{x:350,y:100,id:"color",kind:30},{x:300,y:50,id:"color",kind:30},{x:150,y:350,id:"color",kind:34},{x:100,y:350,id:"color",kind:34},{x:50,y:300,id:"color",kind:34},{x:100,y:300,id:"color",kind:34},{x:50,y:250,id:"color",kind:34},{x:0,y:250,id:"color",kind:34},{x:0,y:200,id:"color",kind:34},{x:0,y:150,id:"color",kind:34},{x:50,y:200,id:"color",
kind:34},{x:250,y:350,id:"color",kind:33},{x:300,y:300,id:"color",kind:33},{x:300,y:350,id:"color",kind:33},{x:350,y:300,id:"color",kind:33},{x:350,y:250,id:"color",kind:33},{x:350,y:200,id:"color",kind:33},{x:250,y:300,id:"color",kind:33},{x:300,y:250,id:"color",kind:33},{x:350,y:350,id:"color",kind:33},{x:200,y:350,id:"color",kind:33},{x:150,y:300,id:"color",kind:29},{x:100,y:250,id:"color",kind:29},{x:100,y:200,id:"color",kind:29},{x:250,y:200,id:"color",kind:30},{x:250,y:250,id:"color",kind:30},
{x:200,y:150,id:"color",kind:30},{x:200,y:100,id:"color",kind:30},{x:150,y:100,id:"color",kind:30},{x:100,y:100,id:"color",kind:30},{x:50,y:100,id:"color",kind:30},{x:150,y:250,id:"color",kind:30},{x:200,y:300,id:"color",kind:30},{x:0,y:300,id:"color",kind:22},{x:0,y:350,id:"color",kind:22},{x:50,y:350,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},
{x:100,y:0,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:350,y:0,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:250,y:150,id:"color",kind:29},{x:250,y:100,id:"color",kind:29},{x:250,y:50,id:"color",kind:29},{x:150,y:50,id:"color",kind:29},{x:200,y:0,id:"color",kind:29},{x:250,y:0,id:"color",kind:30},{x:150,y:0,id:"color",kind:30},{x:100,y:150,id:"color",kind:30},{x:200,y:200,id:"color",kind:29},{x:200,y:50,id:"color",kind:30},{x:100,y:50,id:"color",
kind:30},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:300,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:50,id:"cell"},
{x:350,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:350,y:350,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:100,y:100,id:"cell"},{x:300,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"}],name:{key:"rose"}},alpaca8x8:{width:400,height:400,items:[{x:100,y:200,id:"color",kind:3},{x:150,y:200,
id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:200,y:200,id:"color",kind:3},{x:200,y:150,id:"color",kind:3},{x:150,y:100,id:"color",kind:4},{x:200,y:50,id:"color",kind:4},{x:200,y:100,id:"color",kind:4},{x:250,y:50,id:"color",kind:4},{x:250,y:100,id:"color",kind:4},{x:300,y:100,id:"color",kind:4},{x:300,y:150,id:"color",kind:4},{x:250,y:150,id:"color",kind:4},{x:250,y:200,id:"color",kind:4},{x:200,y:250,id:"color",kind:4},{x:150,y:250,id:"color",kind:4},{x:250,y:250,id:"color",kind:4},{x:300,
y:250,id:"color",kind:4},{x:300,y:200,id:"color",kind:4},{x:350,y:100,id:"color",kind:4},{x:350,y:200,id:"color",kind:4},{x:350,y:150,id:"color",kind:4},{x:300,y:0,id:"color",kind:3},{x:200,y:0,id:"color",kind:3},{x:250,y:300,id:"color",kind:4},{x:300,y:300,id:"color",kind:4},{x:350,y:300,id:"color",kind:4},{x:350,y:250,id:"color",kind:4},{x:350,y:350,id:"color",kind:4},{x:300,y:350,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:0,y:250,id:"color",kind:4},{x:0,y:300,id:"color",kind:4},{x:50,
y:300,id:"color",kind:4},{x:50,y:350,id:"color",kind:4},{x:0,y:350,id:"color",kind:4},{x:100,y:350,id:"color",kind:4},{x:150,y:350,id:"color",kind:34},{x:200,y:300,id:"color",kind:34},{x:200,y:350,id:"color",kind:34},{x:150,y:300,id:"color",kind:34},{x:100,y:300,id:"color",kind:34},{x:100,y:250,id:"color",kind:34},{x:50,y:250,id:"color",kind:34},{x:50,y:200,id:"color",kind:34},{x:0,y:200,id:"color",kind:34},{x:0,y:100,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},
{x:50,y:0,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:350,y:50,id:"color",kind:3},{x:300,y:50,id:"color",kind:3},{x:150,y:150,id:"color",kind:3},{x:0,y:250,id:"cell"},{x:50,y:300,
id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:250,y:50,id:"cell"},
{x:350,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"}],name:{key:"alpaca"}},desert8x8:{width:400,height:400,items:[{x:0,y:250,id:"color",kind:6},{x:50,y:250,id:"color",kind:6},{x:100,y:250,id:"color",kind:6},{x:150,y:300,id:"color",kind:6},{x:200,y:300,id:"color",kind:6},{x:200,y:350,id:"color",kind:6},{x:250,y:350,id:"color",kind:6},{x:300,y:350,id:"color",kind:6},{x:350,y:350,id:"color",
kind:6},{x:150,y:350,id:"color",kind:6},{x:100,y:350,id:"color",kind:6},{x:50,y:350,id:"color",kind:6},{x:0,y:350,id:"color",kind:6},{x:0,y:300,id:"color",kind:6},{x:50,y:300,id:"color",kind:6},{x:100,y:300,id:"color",kind:6},{x:150,y:250,id:"color",kind:7},{x:200,y:250,id:"color",kind:7},{x:250,y:250,id:"color",kind:7},{x:250,y:300,id:"color",kind:7},{x:300,y:300,id:"color",kind:7},{x:300,y:250,id:"color",kind:7},{x:350,y:250,id:"color",kind:7},{x:350,y:300,id:"color",kind:7},{x:200,y:200,id:"color",
kind:7},{x:250,y:200,id:"color",kind:7},{x:300,y:200,id:"color",kind:7},{x:350,y:200,id:"color",kind:7},{x:300,y:150,id:"color",kind:7},{x:250,y:150,id:"color",kind:7},{x:350,y:150,id:"color",kind:7},{x:300,y:100,id:"color",kind:7},{x:350,y:100,id:"color",kind:7},{x:0,y:150,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:100,y:50,id:"color",kind:22},{x:100,y:100,id:"color",
kind:22},{x:150,y:100,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:200,y:0,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:350,y:0,id:"color",kind:22},{x:50,y:50,id:"color",kind:17},{x:100,y:150,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:150,y:150,id:"color",
kind:22},{x:200,y:150,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:50,y:200,id:"color",kind:6},{x:0,y:200,id:"color",kind:6},{x:50,y:50,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:150,y:250,
id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:100,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:300,id:"cell"}],name:{key:"desert"}},sheep8x8:{width:400,height:400,items:[{x:250,y:150,id:"color",kind:4},{x:250,y:200,id:"color",kind:4},{x:300,y:200,id:"color",kind:4},{x:300,y:150,id:"color",kind:4},{x:350,y:100,id:"color",kind:4},{x:200,y:100,id:"color",kind:4},{x:350,
y:250,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:150,y:300,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:200,y:300,id:"color",kind:4},{x:200,y:350,id:"color",kind:4},{x:50,y:300,id:"color",kind:4},{x:50,y:350,id:"color",kind:4},{x:100,y:250,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},{x:350,y:200,id:"color",
kind:22},{x:50,y:200,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:50,y:150,id:"color",kind:23},{x:50,y:100,id:"color",kind:23},{x:100,y:100,id:"color",kind:23},{x:150,y:100,id:"color",kind:23},{x:150,y:150,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:200,y:150,id:"color",kind:23},{x:200,y:200,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:100,y:50,id:"color",kind:23},{x:300,y:100,id:"color",kind:23},{x:250,y:100,id:"color",kind:23},{x:350,
y:150,id:"color",kind:23},{x:50,y:50,id:"color",kind:23},{x:0,y:100,id:"color",kind:23},{x:0,y:50,id:"color",kind:21},{x:0,y:0,id:"color",kind:21},{x:50,y:0,id:"color",kind:21},{x:100,y:0,id:"color",kind:21},{x:150,y:0,id:"color",kind:21},{x:200,y:0,id:"color",kind:21},{x:250,y:0,id:"color",kind:21},{x:300,y:0,id:"color",kind:21},{x:350,y:0,id:"color",kind:21},{x:0,y:350,id:"color",kind:34},{x:250,y:350,id:"color",kind:34},{x:350,y:350,id:"color",kind:34},{x:0,y:300,id:"color",kind:21},{x:350,y:300,
id:"color",kind:21},{x:250,y:50,id:"color",kind:23},{x:150,y:200,id:"color",kind:23},{x:300,y:350,id:"color",kind:3},{x:150,y:350,id:"color",kind:3},{x:100,y:300,id:"color",kind:22},{x:100,y:350,id:"color",kind:34},{x:300,y:300,id:"color",kind:22},{x:300,y:50,id:"color",kind:21},{x:350,y:50,id:"color",kind:21},{x:200,y:50,id:"color",kind:23},{x:200,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:350,
id:"cell"},{x:200,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:0,
y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:0,id:"cell"},{x:150,y:350,id:"cell"}],name:{key:"sheep"}},clock8x8:{width:400,height:400,items:[{x:200,y:100,id:"color",kind:19},{x:200,y:150,id:"color",kind:19},{x:200,y:200,id:"color",kind:19},{x:100,y:100,id:"color",kind:18},{x:150,y:150,id:"color",kind:18},{x:100,y:150,id:"color",kind:18},{x:50,y:300,id:"color",kind:16},{x:150,y:300,id:"color",
kind:16},{x:50,y:0,id:"color",kind:16},{x:150,y:0,id:"color",kind:16},{x:200,y:0,id:"color",kind:16},{x:0,y:0,id:"color",kind:16},{x:150,y:250,id:"color",kind:19},{x:100,y:250,id:"color",kind:19},{x:50,y:250,id:"color",kind:19},{x:0,y:200,id:"color",kind:19},{x:0,y:150,id:"color",kind:19},{x:0,y:100,id:"color",kind:19},{x:50,y:50,id:"color",kind:19},{x:150,y:50,id:"color",kind:19},{x:100,y:50,id:"color",kind:19},{x:50,y:200,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:50,y:100,id:"color",
kind:22},{x:150,y:100,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:0,y:250,id:"color",kind:19},{x:200,y:250,id:"color",kind:19},{x:200,y:50,id:"color",kind:19},{x:0,y:50,id:"color",kind:19},{x:0,y:300,id:"color",kind:35},{x:300,y:0,id:"color",kind:35},{x:300,y:50,id:"color",kind:35},{x:350,y:0,id:"color",kind:35},{x:300,y:100,id:"color",kind:35},{x:300,y:150,id:"color",kind:35},{x:250,y:300,id:"color",kind:35},{x:0,y:350,id:"color",kind:4},{x:50,y:350,id:"color",
kind:4},{x:100,y:350,id:"color",kind:4},{x:150,y:350,id:"color",kind:4},{x:200,y:350,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:300,y:350,id:"color",kind:4},{x:350,y:350,id:"color",kind:4},{x:100,y:0,id:"color",kind:35},{x:250,y:0,id:"color",kind:35},{x:250,y:50,id:"color",kind:35},{x:250,y:100,id:"color",kind:35},{x:250,y:150,id:"color",kind:35},{x:250,y:200,id:"color",kind:35},{x:250,y:250,id:"color",kind:35},{x:200,y:300,id:"color",kind:35},{x:100,y:300,id:"color",kind:35},{x:300,y:300,
id:"color",kind:3},{x:300,y:250,id:"color",kind:3},{x:300,y:200,id:"color",kind:3},{x:350,y:200,id:"color",kind:3},{x:350,y:250,id:"color",kind:3},{x:350,y:300,id:"color",kind:3},{x:350,y:150,id:"color",kind:13},{x:350,y:100,id:"color",kind:13},{x:350,y:50,id:"color",kind:13},{x:50,y:300,id:"cell"},{x:0,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},
{x:300,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:100,y:350,id:"cell"},{x:0,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,
id:"cell"},{x:200,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"}],name:{key:"alarm_clock"}},fishbowl8x8:{width:400,height:400,items:[{x:100,y:350,id:"color",kind:22},{x:150,y:350,id:"color",kind:22},{x:200,y:350,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:350,y:100,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:350,y:200,id:"color",kind:22},{x:150,
y:100,id:"color",kind:21},{x:150,y:150,id:"color",kind:21},{x:100,y:150,id:"color",kind:21},{x:100,y:200,id:"color",kind:21},{x:150,y:200,id:"color",kind:21},{x:200,y:200,id:"color",kind:21},{x:250,y:200,id:"color",kind:21},{x:350,y:250,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:50,y:300,id:"color",kind:22},{x:50,y:100,id:"color",kind:21},
{x:50,y:250,id:"color",kind:21},{x:150,y:250,id:"color",kind:21},{x:100,y:300,id:"color",kind:6},{x:150,y:300,id:"color",kind:6},{x:200,y:300,id:"color",kind:6},{x:250,y:300,id:"color",kind:6},{x:200,y:250,id:"color",kind:6},{x:250,y:250,id:"color",kind:6},{x:300,y:250,id:"color",kind:6},{x:100,y:250,id:"color",kind:34},{x:50,y:200,id:"color",kind:34},{x:50,y:150,id:"color",kind:34},{x:100,y:100,id:"color",kind:34},{x:300,y:200,id:"color",kind:21},{x:300,y:100,id:"color",kind:21},{x:200,y:150,id:"color",
kind:21},{x:250,y:150,id:"color",kind:21},{x:300,y:150,id:"color",kind:21},{x:250,y:50,id:"color",kind:21},{x:150,y:50,id:"color",kind:21},{x:100,y:50,id:"color",kind:21},{x:50,y:50,id:"color",kind:21},{x:300,y:50,id:"color",kind:21},{x:200,y:50,id:"color",kind:21},{x:200,y:100,id:"color",kind:8},{x:250,y:100,id:"color",kind:5},{x:0,y:300,id:"color",kind:23},{x:0,y:350,id:"color",kind:23},{x:50,y:350,id:"color",kind:23},{x:300,y:350,id:"color",kind:23},{x:350,y:350,id:"color",kind:23},{x:350,y:300,
id:"color",kind:23},{x:350,y:0,id:"color",kind:23},{x:250,y:0,id:"color",kind:23},{x:200,y:0,id:"color",kind:23},{x:150,y:0,id:"color",kind:23},{x:100,y:0,id:"color",kind:23},{x:0,y:0,id:"color",kind:23},{x:100,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:50,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:100,
y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:300,y:0,id:"cell"}],name:{key:"fish_bowl"}},brush8x8:{width:400,height:400,items:[{x:50,y:150,id:"color",
kind:0},{x:100,y:150,id:"color",kind:0},{x:150,y:150,id:"color",kind:0},{x:50,y:200,id:"color",kind:4},{x:100,y:200,id:"color",kind:4},{x:150,y:200,id:"color",kind:4},{x:100,y:250,id:"color",kind:3},{x:100,y:300,id:"color",kind:3},{x:50,y:100,id:"color",kind:29},{x:100,y:100,id:"color",kind:29},{x:150,y:100,id:"color",kind:29},{x:50,y:50,id:"color",kind:30},{x:50,y:0,id:"color",kind:30},{x:100,y:0,id:"color",kind:30},{x:100,y:50,id:"color",kind:30},{x:150,y:50,id:"color",kind:30},{x:150,y:0,id:"color",
kind:30},{x:200,y:0,id:"color",kind:30},{x:250,y:200,id:"color",kind:30},{x:250,y:150,id:"color",kind:30},{x:300,y:200,id:"color",kind:30},{x:300,y:250,id:"color",kind:30},{x:300,y:300,id:"color",kind:30},{x:350,y:300,id:"color",kind:30},{x:350,y:350,id:"color",kind:30},{x:350,y:250,id:"color",kind:30},{x:350,y:200,id:"color",kind:30},{x:350,y:150,id:"color",kind:30},{x:300,y:150,id:"color",kind:30},{x:300,y:100,id:"color",kind:30},{x:250,y:100,id:"color",kind:30},{x:250,y:50,id:"color",kind:30},
{x:250,y:0,id:"color",kind:30},{x:300,y:0,id:"color",kind:30},{x:300,y:50,id:"color",kind:30},{x:350,y:50,id:"color",kind:30},{x:350,y:0,id:"color",kind:30},{x:350,y:100,id:"color",kind:30},{x:0,y:0,id:"color",kind:30},{x:50,y:300,id:"color",kind:7},{x:50,y:350,id:"color",kind:7},{x:100,y:350,id:"color",kind:7},{x:150,y:350,id:"color",kind:7},{x:150,y:300,id:"color",kind:6},{x:0,y:50,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:0,
y:250,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:0,y:350,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},{x:200,y:200,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:200,y:350,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:300,y:350,id:"color",
kind:22},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,
y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"}],name:{key:"paint_brush"}},melon8x8:{width:400,height:400,items:[{x:50,y:300,id:"color",kind:34},{x:100,y:350,id:"color",kind:34},{x:150,y:350,id:"color",kind:34},{x:200,y:350,id:"color",kind:34},{x:250,y:350,id:"color",kind:34},{x:50,y:350,id:"color",
kind:34},{x:0,y:300,id:"color",kind:34},{x:300,y:350,id:"color",kind:34},{x:350,y:300,id:"color",kind:34},{x:300,y:300,id:"color",kind:34},{x:0,y:250,id:"color",kind:26},{x:100,y:250,id:"color",kind:26},{x:100,y:300,id:"color",kind:26},{x:50,y:250,id:"color",kind:26},{x:150,y:250,id:"color",kind:26},{x:150,y:300,id:"color",kind:26},{x:200,y:250,id:"color",kind:26},{x:250,y:250,id:"color",kind:26},{x:250,y:300,id:"color",kind:26},{x:300,y:250,id:"color",kind:26},{x:350,y:250,id:"color",kind:26},{x:300,
y:200,id:"color",kind:26},{x:200,y:200,id:"color",kind:26},{x:150,y:200,id:"color",kind:26},{x:250,y:200,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:100,y:150,id:"color",kind:26},{x:150,y:150,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:300,y:150,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:100,y:100,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:150,y:50,id:"color",
kind:26},{x:100,y:50,id:"color",kind:26},{x:150,y:0,id:"color",kind:26},{x:200,y:0,id:"color",kind:26},{x:150,y:100,id:"color",kind:0},{x:100,y:200,id:"color",kind:0},{x:200,y:300,id:"color",kind:0},{x:250,y:150,id:"color",kind:0},{x:0,y:350,id:"color",kind:24},{x:0,y:200,id:"color",kind:24},{x:0,y:150,id:"color",kind:24},{x:0,y:100,id:"color",kind:24},{x:0,y:50,id:"color",kind:24},{x:0,y:0,id:"color",kind:24},{x:50,y:0,id:"color",kind:24},{x:50,y:50,id:"color",kind:24},{x:50,y:100,id:"color",kind:24},
{x:100,y:0,id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:300,y:0,id:"color",kind:24},{x:300,y:50,id:"color",kind:24},{x:350,y:0,id:"color",kind:24},{x:350,y:50,id:"color",kind:24},{x:300,y:100,id:"color",kind:24},{x:350,y:100,id:"color",kind:24},{x:350,y:150,id:"color",kind:24},{x:350,y:200,id:"color",kind:24},{x:350,y:350,id:"color",kind:24},{x:0,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,
id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:350,y:300,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:100,y:250,id:"cell"},
{x:200,y:200,id:"cell"}],name:{key:"melon_slice"}},mushroom8x8:{width:400,height:400,items:[{x:200,y:350,id:"color",kind:7},{x:250,y:300,id:"color",kind:7},{x:250,y:350,id:"color",kind:7},{x:300,y:350,id:"color",kind:7},{x:300,y:300,id:"color",kind:7},{x:300,y:250,id:"color",kind:7},{x:250,y:200,id:"color",kind:7},{x:300,y:200,id:"color",kind:7},{x:200,y:150,id:"color",kind:6},{x:200,y:300,id:"color",kind:6},{x:150,y:350,id:"color",kind:6},{x:200,y:200,id:"color",kind:6},{x:250,y:250,id:"color",kind:6},
{x:250,y:150,id:"color",kind:7},{x:350,y:100,id:"color",kind:26},{x:300,y:100,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:150,y:100,id:"color",kind:26},{x:150,y:50,id:"color",kind:26},{x:300,y:50,id:"color",kind:26},{x:100,y:100,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},{x:0,y:100,id:"color",kind:26},{x:100,y:50,id:"color",kind:26},{x:50,y:50,id:"color",kind:26},{x:150,y:0,id:"color",
kind:26},{x:200,y:0,id:"color",kind:26},{x:250,y:0,id:"color",kind:26},{x:0,y:250,id:"color",kind:34},{x:0,y:300,id:"color",kind:34},{x:0,y:350,id:"color",kind:34},{x:50,y:350,id:"color",kind:34},{x:100,y:350,id:"color",kind:34},{x:100,y:300,id:"color",kind:34},{x:350,y:350,id:"color",kind:34},{x:350,y:300,id:"color",kind:34},{x:0,y:50,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:350,y:0,id:"color",
kind:22},{x:350,y:50,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:350,y:200,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:150,y:300,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:50,y:300,id:"color",kind:22},
{x:50,y:200,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:150,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:0,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:50,y:50,id:"cell"},
{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:50,id:"cell"}],name:{key:"toadstool"}},cake8x8:{width:400,height:400,items:[{x:300,y:150,id:"color",
kind:3},{x:250,y:150,id:"color",kind:3},{x:200,y:150,id:"color",kind:3},{x:150,y:150,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:50,y:150,id:"color",kind:3},{x:100,y:200,id:"color",kind:4},{x:150,y:200,id:"color",kind:4},{x:200,y:200,id:"color",kind:4},{x:250,y:200,id:"color",kind:4},{x:300,y:200,id:"color",kind:3},{x:300,y:250,id:"color",kind:3},{x:300,y:300,id:"color",kind:3},{x:250,y:250,id:"color",kind:3},{x:200,y:250,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:100,y:250,id:"color",
kind:3},{x:50,y:250,id:"color",kind:3},{x:0,y:350,id:"color",kind:22},{x:50,y:350,id:"color",kind:22},{x:100,y:350,id:"color",kind:22},{x:150,y:350,id:"color",kind:22},{x:200,y:350,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:350,y:350,id:"color",kind:22},{x:350,y:300,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:200,y:100,id:"color",kind:23},{x:250,y:100,id:"color",kind:23},{x:300,y:100,id:"color",kind:23},{x:200,y:50,id:"color",kind:26},{x:250,
y:50,id:"color",kind:26},{x:250,y:0,id:"color",kind:26},{x:0,y:250,id:"color",kind:35},{x:0,y:200,id:"color",kind:35},{x:0,y:150,id:"color",kind:35},{x:0,y:100,id:"color",kind:35},{x:0,y:50,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:50,y:50,id:"color",kind:35},{x:100,y:50,id:"color",kind:35},{x:150,y:50,id:"color",kind:23},{x:150,y:100,id:"color",kind:23},{x:100,y:0,id:"color",kind:35},{x:150,y:0,id:"color",kind:35},{x:200,y:0,id:"color",kind:35},{x:300,y:0,
id:"color",kind:35},{x:350,y:50,id:"color",kind:35},{x:350,y:100,id:"color",kind:35},{x:350,y:0,id:"color",kind:35},{x:350,y:250,id:"color",kind:35},{x:350,y:200,id:"color",kind:35},{x:350,y:150,id:"color",kind:35},{x:250,y:300,id:"color",kind:4},{x:200,y:300,id:"color",kind:4},{x:150,y:300,id:"color",kind:4},{x:100,y:300,id:"color",kind:4},{x:50,y:100,id:"color",kind:35},{x:100,y:100,id:"color",kind:23},{x:300,y:50,id:"color",kind:23},{x:50,y:200,id:"color",kind:4},{x:50,y:300,id:"color",kind:4},
{x:200,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,
y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:300,y:50,id:"cell"}],name:{key:"choco_cake"}},swan8x8:{width:400,height:400,items:[{x:200,y:350,id:"color",kind:8},{x:150,y:350,id:"color",kind:5},{x:0,y:350,id:"color",kind:20},{x:50,y:350,id:"color",kind:20},{x:100,y:350,id:"color",kind:20},{x:50,y:300,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:250,y:350,id:"color",kind:20},{x:300,y:350,id:"color",
kind:20},{x:300,y:300,id:"color",kind:20},{x:350,y:300,id:"color",kind:20},{x:350,y:350,id:"color",kind:20},{x:200,y:50,id:"color",kind:0},{x:250,y:50,id:"color",kind:8},{x:200,y:0,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:150,y:0,id:"color",kind:23},{x:100,y:0,id:"color",kind:23},{x:50,y:50,id:"color",kind:23},{x:50,y:100,id:"color",kind:23},{x:50,y:150,id:"color",kind:23},{x:50,y:250,id:"color",kind:23},{x:100,y:300,id:"color",kind:23},{x:150,y:300,id:"color",kind:23},{x:200,y:300,
id:"color",kind:23},{x:250,y:300,id:"color",kind:23},{x:250,y:250,id:"color",kind:23},{x:200,y:200,id:"color",kind:23},{x:150,y:200,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:150,y:150,id:"color",kind:23},{x:200,y:150,id:"color",kind:23},{x:300,y:200,id:"color",kind:23},{x:350,y:200,id:"color",kind:23},{x:300,y:250,id:"color",kind:23},{x:100,y:50,id:"color",kind:23},{x:0,y:200,id:"color",kind:23},{x:0,y:150,id:"color",kind:23},{x:0,y:100,id:"color",kind:23},{x:100,y:100,id:"color",kind:21},
{x:0,y:50,id:"color",kind:21},{x:0,y:0,id:"color",kind:21},{x:50,y:0,id:"color",kind:21},{x:150,y:100,id:"color",kind:21},{x:200,y:100,id:"color",kind:21},{x:250,y:100,id:"color",kind:21},{x:250,y:150,id:"color",kind:21},{x:300,y:150,id:"color",kind:21},{x:300,y:100,id:"color",kind:21},{x:350,y:100,id:"color",kind:21},{x:350,y:50,id:"color",kind:21},{x:350,y:0,id:"color",kind:21},{x:300,y:0,id:"color",kind:21},{x:300,y:50,id:"color",kind:21},{x:250,y:0,id:"color",kind:21},{x:100,y:250,id:"color",
kind:22},{x:150,y:250,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:250,y:200,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:350,y:250,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:350,y:150,id:"color",kind:23},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:250,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,
id:"cell"},{x:200,y:300,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:350,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:100,y:50,id:"cell"},{x:0,y:200,id:"cell"},{x:350,y:150,id:"cell"}],name:{key:"swan"}},bike8x8:{width:400,height:400,items:[{x:250,y:100,id:"color",kind:4},{x:300,
y:100,id:"color",kind:4},{x:0,y:350,id:"color",kind:25},{x:50,y:350,id:"color",kind:25},{x:100,y:350,id:"color",kind:25},{x:150,y:350,id:"color",kind:25},{x:200,y:350,id:"color",kind:25},{x:250,y:350,id:"color",kind:25},{x:300,y:350,id:"color",kind:25},{x:350,y:350,id:"color",kind:25},{x:100,y:100,id:"color",kind:26},{x:100,y:150,id:"color",kind:26},{x:100,y:200,id:"color",kind:26},{x:150,y:200,id:"color",kind:26},{x:200,y:200,id:"color",kind:26},{x:250,y:200,id:"color",kind:26},{x:250,y:150,id:"color",
kind:26},{x:0,y:250,id:"color",kind:0},{x:50,y:200,id:"color",kind:0},{x:50,y:300,id:"color",kind:0},{x:100,y:250,id:"color",kind:0},{x:250,y:250,id:"color",kind:0},{x:300,y:300,id:"color",kind:0},{x:350,y:250,id:"color",kind:0},{x:300,y:200,id:"color",kind:0},{x:100,y:50,id:"color",kind:3},{x:150,y:0,id:"color",kind:3},{x:0,y:300,id:"color",kind:20},{x:50,y:250,id:"color",kind:20},{x:100,y:300,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:200,y:300,id:"color",
kind:20},{x:200,y:250,id:"color",kind:20},{x:250,y:300,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:350,y:300,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:150,y:50,
id:"color",kind:20},{x:200,y:100,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:300,y:150,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:0,y:250,
id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:100,y:50,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:150,y:0,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},
{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:150,id:"cell"}],name:{key:"bicycle"}},bread8x8:{width:400,height:400,items:[{x:0,y:200,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:0,y:250,id:"color",kind:25},{x:0,y:300,id:"color",kind:25},{x:0,y:350,id:"color",kind:25},{x:150,y:350,id:"color",kind:7},{x:150,y:300,id:"color",kind:7},{x:150,y:150,id:"color",kind:7},{x:150,y:100,id:"color",kind:7},{x:350,y:100,id:"color",kind:7},{x:350,
y:150,id:"color",kind:7},{x:350,y:200,id:"color",kind:7},{x:250,y:200,id:"color",kind:7},{x:250,y:150,id:"color",kind:7},{x:300,y:150,id:"color",kind:7},{x:200,y:100,id:"color",kind:7},{x:200,y:350,id:"color",kind:7},{x:150,y:0,id:"color",kind:6},{x:300,y:0,id:"color",kind:6},{x:0,y:50,id:"color",kind:17},{x:0,y:100,id:"color",kind:17},{x:200,y:150,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:200,y:250,id:"color",kind:17},{x:200,y:300,id:"color",kind:17},{x:250,y:300,id:"color",kind:17},
{x:250,y:350,id:"color",kind:17},{x:250,y:250,id:"color",kind:17},{x:300,y:200,id:"color",kind:17},{x:300,y:250,id:"color",kind:17},{x:300,y:300,id:"color",kind:17},{x:300,y:350,id:"color",kind:17},{x:350,y:300,id:"color",kind:17},{x:350,y:250,id:"color",kind:17},{x:200,y:0,id:"color",kind:4},{x:250,y:50,id:"color",kind:4},{x:350,y:0,id:"color",kind:4},{x:300,y:50,id:"color",kind:7},{x:350,y:50,id:"color",kind:7},{x:250,y:100,id:"color",kind:7},{x:200,y:50,id:"color",kind:7},{x:150,y:50,id:"color",
kind:7},{x:300,y:100,id:"color",kind:17},{x:100,y:200,id:"color",kind:7},{x:100,y:250,id:"color",kind:7},{x:100,y:300,id:"color",kind:7},{x:100,y:350,id:"color",kind:7},{x:100,y:150,id:"color",kind:7},{x:100,y:100,id:"color",kind:7},{x:100,y:50,id:"color",kind:4},{x:150,y:200,id:"color",kind:17},{x:150,y:250,id:"color",kind:17},{x:350,y:350,id:"color",kind:7},{x:50,y:350,id:"color",kind:35},{x:50,y:300,id:"color",kind:35},{x:50,y:250,id:"color",kind:35},{x:50,y:200,id:"color",kind:35},{x:50,y:150,
id:"color",kind:35},{x:50,y:100,id:"color",kind:35},{x:50,y:50,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:100,y:0,id:"color",kind:35},{x:250,y:0,id:"color",kind:35},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:100,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},
{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:350,
y:0,id:"cell"}],name:{key:"buttered_toast"}},purse8x8:{width:400,height:400,items:[{x:0,y:300,id:"color",kind:2},{x:0,y:250,id:"color",kind:2},{x:50,y:250,id:"color",kind:2},{x:50,y:300,id:"color",kind:2},{x:50,y:350,id:"color",kind:2},{x:100,y:350,id:"color",kind:2},{x:100,y:300,id:"color",kind:2},{x:150,y:350,id:"color",kind:2},{x:200,y:350,id:"color",kind:2},{x:200,y:300,id:"color",kind:2},{x:250,y:300,id:"color",kind:2},{x:250,y:350,id:"color",kind:2},{x:300,y:300,id:"color",kind:2},{x:300,y:250,
id:"color",kind:2},{x:250,y:250,id:"color",kind:2},{x:50,y:200,id:"color",kind:1},{x:100,y:250,id:"color",kind:1},{x:100,y:200,id:"color",kind:1},{x:150,y:200,id:"color",kind:1},{x:200,y:250,id:"color",kind:1},{x:200,y:200,id:"color",kind:1},{x:250,y:200,id:"color",kind:1},{x:0,y:200,id:"color",kind:32},{x:0,y:150,id:"color",kind:32},{x:0,y:100,id:"color",kind:32},{x:50,y:50,id:"color",kind:32},{x:100,y:0,id:"color",kind:32},{x:150,y:0,id:"color",kind:32},{x:200,y:0,id:"color",kind:32},{x:250,y:0,
id:"color",kind:32},{x:300,y:0,id:"color",kind:32},{x:350,y:50,id:"color",kind:32},{x:350,y:100,id:"color",kind:32},{x:350,y:150,id:"color",kind:32},{x:300,y:200,id:"color",kind:32},{x:150,y:250,id:"color",kind:1},{x:300,y:150,id:"color",kind:32},{x:0,y:350,id:"color",kind:22},{x:350,y:350,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:350,y:300,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:350,y:200,id:"color",kind:22},{x:350,y:0,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},
{x:300,y:100,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:250,y:150,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:100,y:50,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:0,y:50,id:"color",
kind:22},{x:0,y:0,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:150,y:300,id:"color",kind:32},{x:0,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},
{x:250,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:300,y:150,id:"cell"}],name:{key:"purse"}},bed8x8:{width:400,height:400,items:[{x:50,y:100,id:"color",kind:33},{x:150,y:100,id:"color",kind:33},{x:150,y:150,id:"color",kind:33},{x:150,
y:200,id:"color",kind:33},{x:200,y:200,id:"color",kind:33},{x:200,y:150,id:"color",kind:33},{x:200,y:100,id:"color",kind:33},{x:250,y:100,id:"color",kind:33},{x:250,y:150,id:"color",kind:33},{x:250,y:200,id:"color",kind:33},{x:300,y:200,id:"color",kind:33},{x:300,y:150,id:"color",kind:33},{x:300,y:100,id:"color",kind:33},{x:350,y:100,id:"color",kind:33},{x:350,y:150,id:"color",kind:33},{x:350,y:200,id:"color",kind:33},{x:50,y:250,id:"color",kind:34},{x:150,y:250,id:"color",kind:34},{x:200,y:250,id:"color",
kind:34},{x:250,y:250,id:"color",kind:34},{x:300,y:250,id:"color",kind:34},{x:350,y:250,id:"color",kind:34},{x:0,y:350,id:"color",kind:3},{x:100,y:350,id:"color",kind:3},{x:150,y:350,id:"color",kind:3},{x:200,y:350,id:"color",kind:3},{x:250,y:350,id:"color",kind:3},{x:300,y:350,id:"color",kind:3},{x:350,y:350,id:"color",kind:3},{x:0,y:200,id:"color",kind:4},{x:0,y:150,id:"color",kind:4},{x:0,y:100,id:"color",kind:4},{x:0,y:50,id:"color",kind:4},{x:0,y:0,id:"color",kind:4},{x:50,y:300,id:"color",kind:4},
{x:0,y:300,id:"color",kind:35},{x:100,y:300,id:"color",kind:35},{x:150,y:300,id:"color",kind:35},{x:200,y:300,id:"color",kind:35},{x:250,y:300,id:"color",kind:35},{x:300,y:300,id:"color",kind:35},{x:350,y:300,id:"color",kind:35},{x:350,y:50,id:"color",kind:35},{x:350,y:0,id:"color",kind:35},{x:300,y:0,id:"color",kind:35},{x:300,y:50,id:"color",kind:35},{x:250,y:50,id:"color",kind:35},{x:250,y:0,id:"color",kind:35},{x:200,y:0,id:"color",kind:35},{x:200,y:50,id:"color",kind:35},{x:150,y:0,id:"color",
kind:35},{x:100,y:50,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:100,y:0,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:100,y:250,id:"color",kind:34},{x:100,y:150,id:"color",kind:33},{x:100,y:100,id:"color",kind:33},{x:50,y:50,id:"color",kind:22},{x:0,y:250,id:"color",kind:4},{x:50,y:350,id:"color",kind:4},{x:100,y:200,id:"color",kind:34},{x:50,y:200,id:"color",kind:34},{x:50,y:150,id:"color",kind:34},{x:50,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,
id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:50,
y:50,id:"cell"}],name:{key:"bed"}},tadpole8x8:{width:400,height:400,items:[{x:0,y:300,id:"color",kind:1},{x:0,y:250,id:"color",kind:1},{x:50,y:300,id:"color",kind:1},{x:50,y:350,id:"color",kind:1},{x:100,y:350,id:"color",kind:1},{x:100,y:300,id:"color",kind:1},{x:50,y:250,id:"color",kind:1},{x:50,y:200,id:"color",kind:1},{x:100,y:200,id:"color",kind:1},{x:150,y:200,id:"color",kind:1},{x:150,y:250,id:"color",kind:1},{x:150,y:300,id:"color",kind:1},{x:150,y:350,id:"color",kind:1},{x:200,y:300,id:"color",
kind:1},{x:200,y:250,id:"color",kind:1},{x:250,y:250,id:"color",kind:1},{x:300,y:200,id:"color",kind:1},{x:300,y:150,id:"color",kind:1},{x:250,y:100,id:"color",kind:1},{x:250,y:300,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:350,y:200,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:350,y:100,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:250,y:200,id:"color",kind:23},{x:250,y:150,id:"color",kind:23},{x:200,
y:150,id:"color",kind:23},{x:200,y:100,id:"color",kind:23},{x:150,y:100,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:200,y:50,id:"color",kind:23},{x:200,y:0,id:"color",kind:23},{x:250,y:0,id:"color",kind:23},{x:250,y:50,id:"color",kind:23},{x:300,y:0,id:"color",kind:23},{x:300,y:50,id:"color",kind:23},{x:300,y:100,id:"color",kind:23},{x:0,y:350,id:"color",kind:24},{x:200,y:350,id:"color",kind:24},{x:300,y:350,id:"color",kind:24},{x:250,y:350,id:"color",kind:24},{x:350,y:350,id:"color",kind:24},
{x:350,y:300,id:"color",kind:24},{x:200,y:200,id:"color",kind:24},{x:150,y:150,id:"color",kind:24},{x:100,y:150,id:"color",kind:24},{x:50,y:150,id:"color",kind:24},{x:0,y:200,id:"color",kind:24},{x:0,y:150,id:"color",kind:24},{x:0,y:100,id:"color",kind:24},{x:50,y:100,id:"color",kind:24},{x:50,y:50,id:"color",kind:24},{x:0,y:50,id:"color",kind:24},{x:0,y:0,id:"color",kind:24},{x:50,y:0,id:"color",kind:24},{x:100,y:0,id:"color",kind:24},{x:100,y:50,id:"color",kind:24},{x:100,y:100,id:"color",kind:24},
{x:150,y:0,id:"color",kind:24},{x:350,y:0,id:"color",kind:24},{x:100,y:250,id:"color",kind:0},{x:50,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:250,
y:0,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:250,id:"cell"},{x:250,y:300,id:"cell"}],name:{key:"tadpole"}},book8x8:{width:400,height:400,items:[{x:200,y:250,id:"color",kind:7},{x:250,y:250,id:"color",kind:7},{x:350,y:300,id:"color",kind:7},{x:300,y:250,id:"color",kind:7},{x:350,y:250,id:"color",kind:7},{x:350,y:200,id:"color",kind:7},
{x:350,y:150,id:"color",kind:7},{x:350,y:100,id:"color",kind:7},{x:350,y:50,id:"color",kind:7},{x:300,y:0,id:"color",kind:7},{x:250,y:0,id:"color",kind:7},{x:200,y:50,id:"color",kind:7},{x:250,y:50,id:"color",kind:7},{x:200,y:100,id:"color",kind:7},{x:200,y:150,id:"color",kind:7},{x:200,y:200,id:"color",kind:7},{x:150,y:250,id:"color",kind:6},{x:150,y:200,id:"color",kind:6},{x:150,y:150,id:"color",kind:6},{x:150,y:100,id:"color",kind:6},{x:150,y:50,id:"color",kind:6},{x:100,y:0,id:"color",kind:6},
{x:50,y:0,id:"color",kind:6},{x:50,y:50,id:"color",kind:6},{x:300,y:50,id:"color",kind:7},{x:0,y:50,id:"color",kind:6},{x:100,y:50,id:"color",kind:6},{x:0,y:100,id:"color",kind:6},{x:0,y:150,id:"color",kind:6},{x:50,y:150,id:"color",kind:6},{x:100,y:150,id:"color",kind:6},{x:0,y:200,id:"color",kind:6},{x:0,y:250,id:"color",kind:6},{x:50,y:250,id:"color",kind:6},{x:100,y:250,id:"color",kind:6},{x:0,y:300,id:"color",kind:6},{x:0,y:350,id:"color",kind:18},{x:150,y:350,id:"color",kind:18},{x:150,y:0,
id:"color",kind:18},{x:0,y:0,id:"color",kind:18},{x:50,y:350,id:"color",kind:18},{x:100,y:350,id:"color",kind:18},{x:50,y:300,id:"color",kind:6},{x:100,y:300,id:"color",kind:6},{x:250,y:300,id:"color",kind:7},{x:300,y:300,id:"color",kind:7},{x:250,y:350,id:"color",kind:19},{x:300,y:350,id:"color",kind:19},{x:350,y:350,id:"color",kind:19},{x:200,y:0,id:"color",kind:19},{x:350,y:0,id:"color",kind:19},{x:250,y:200,id:"color",kind:13},{x:300,y:200,id:"color",kind:13},{x:300,y:150,id:"color",kind:13},
{x:250,y:150,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:300,y:100,id:"color",kind:20},{x:50,y:100,id:"color",kind:0},{x:100,y:100,id:"color",kind:0},{x:50,y:200,id:"color",kind:0},{x:100,y:200,id:"color",kind:0},{x:150,y:300,id:"color",kind:18},{x:200,y:350,id:"color",kind:19},{x:200,y:300,id:"color",kind:19},{x:150,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:300,id:"cell"},{x:50,
y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:0,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},
{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"}],name:{key:"picture_book"}},bear8x8:{width:400,height:400,items:[{x:150,y:250,id:"color",kind:0},{x:100,y:300,id:"color",kind:0},{x:200,y:300,id:"color",kind:0},{x:100,y:250,id:"color",kind:6},{x:150,y:200,id:"color",kind:6},{x:200,y:250,id:"color",kind:6},{x:150,y:300,id:"color",kind:6},{x:50,y:350,id:"color",kind:4},{x:100,y:350,id:"color",kind:4},{x:150,y:350,id:"color",kind:4},
{x:200,y:350,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:250,y:300,id:"color",kind:4},{x:300,y:200,id:"color",kind:4},{x:250,y:250,id:"color",kind:4},{x:50,y:300,id:"color",kind:4},{x:50,y:250,id:"color",kind:4},{x:0,y:300,id:"color",kind:4},{x:0,y:250,id:"color",kind:4},{x:0,y:150,id:"color",kind:4},{x:0,y:100,id:"color",kind:4},{x:50,y:100,id:"color",kind:4},{x:100,y:100,id:"color",kind:4},{x:150,y:150,id:"color",kind:4},{x:150,y:100,id:"color",kind:4},{x:200,y:100,id:"color",kind:4},
{x:250,y:100,id:"color",kind:4},{x:300,y:100,id:"color",kind:4},{x:300,y:150,id:"color",kind:4},{x:0,y:0,id:"color",kind:4},{x:0,y:50,id:"color",kind:4},{x:50,y:0,id:"color",kind:4},{x:100,y:50,id:"color",kind:4},{x:200,y:50,id:"color",kind:4},{x:250,y:0,id:"color",kind:4},{x:300,y:0,id:"color",kind:4},{x:300,y:50,id:"color",kind:4},{x:0,y:200,id:"color",kind:4},{x:100,y:200,id:"color",kind:6},{x:200,y:200,id:"color",kind:6},{x:50,y:50,id:"color",kind:7},{x:50,y:200,id:"color",kind:0},{x:100,y:150,
id:"color",kind:0},{x:250,y:200,id:"color",kind:0},{x:50,y:150,id:"color",kind:22},{x:300,y:350,id:"color",kind:3},{x:350,y:250,id:"color",kind:3},{x:350,y:300,id:"color",kind:3},{x:350,y:350,id:"color",kind:3},{x:300,y:250,id:"color",kind:4},{x:300,y:300,id:"color",kind:4},{x:350,y:200,id:"color",kind:3},{x:0,y:350,id:"color",kind:33},{x:100,y:0,id:"color",kind:33},{x:150,y:50,id:"color",kind:33},{x:150,y:0,id:"color",kind:33},{x:200,y:0,id:"color",kind:33},{x:350,y:0,id:"color",kind:33},{x:350,
y:50,id:"color",kind:33},{x:350,y:100,id:"color",kind:33},{x:350,y:150,id:"color",kind:33},{x:250,y:50,id:"color",kind:7},{x:200,y:150,id:"color",kind:0},{x:250,y:150,id:"color",kind:22},{x:50,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},
{x:300,y:50,id:"cell"},{x:50,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:50,y:150,id:"cell"},{x:250,y:150,id:"cell"}],name:{key:"bear"}},trafficlight8x8:{width:400,height:400,
items:[{x:50,y:350,id:"color",kind:28},{x:100,y:350,id:"color",kind:28},{x:100,y:300,id:"color",kind:28},{x:100,y:250,id:"color",kind:28},{x:50,y:250,id:"color",kind:28},{x:0,y:250,id:"color",kind:28},{x:150,y:300,id:"color",kind:28},{x:150,y:250,id:"color",kind:28},{x:150,y:200,id:"color",kind:28},{x:100,y:200,id:"color",kind:28},{x:100,y:150,id:"color",kind:28},{x:50,y:150,id:"color",kind:28},{x:0,y:150,id:"color",kind:28},{x:150,y:150,id:"color",kind:28},{x:100,y:100,id:"color",kind:28},{x:100,
y:50,id:"color",kind:28},{x:50,y:50,id:"color",kind:28},{x:0,y:50,id:"color",kind:28},{x:150,y:100,id:"color",kind:28},{x:100,y:0,id:"color",kind:27},{x:150,y:0,id:"color",kind:27},{x:200,y:0,id:"color",kind:27},{x:250,y:0,id:"color",kind:27},{x:300,y:0,id:"color",kind:27},{x:350,y:0,id:"color",kind:27},{x:350,y:50,id:"color",kind:27},{x:350,y:100,id:"color",kind:27},{x:350,y:150,id:"color",kind:27},{x:350,y:200,id:"color",kind:27},{x:350,y:250,id:"color",kind:27},{x:350,y:300,id:"color",kind:27},
{x:350,y:350,id:"color",kind:27},{x:50,y:100,id:"color",kind:26},{x:50,y:200,id:"color",kind:17},{x:50,y:300,id:"color",kind:13},{x:300,y:250,id:"color",kind:27},{x:300,y:300,id:"color",kind:27},{x:300,y:350,id:"color",kind:27},{x:0,y:350,id:"color",kind:21},{x:0,y:300,id:"color",kind:21},{x:0,y:200,id:"color",kind:21},{x:0,y:100,id:"color",kind:21},{x:0,y:0,id:"color",kind:21},{x:50,y:0,id:"color",kind:21},{x:200,y:50,id:"color",kind:21},{x:200,y:100,id:"color",kind:21},{x:200,y:150,id:"color",kind:21},
{x:200,y:200,id:"color",kind:21},{x:200,y:250,id:"color",kind:21},{x:200,y:300,id:"color",kind:21},{x:200,y:350,id:"color",kind:21},{x:250,y:350,id:"color",kind:21},{x:250,y:300,id:"color",kind:21},{x:250,y:250,id:"color",kind:21},{x:250,y:200,id:"color",kind:21},{x:250,y:150,id:"color",kind:21},{x:300,y:200,id:"color",kind:21},{x:300,y:150,id:"color",kind:21},{x:300,y:100,id:"color",kind:21},{x:250,y:100,id:"color",kind:21},{x:250,y:50,id:"color",kind:21},{x:300,y:50,id:"color",kind:21},{x:150,y:50,
id:"color",kind:21},{x:150,y:350,id:"color",kind:21},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:150,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:50,id:"cell"},{x:100,
y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:350,id:"cell"}],name:{key:"traffic_light"}},fire8x8:{width:400,height:400,items:[{x:50,y:350,id:"color",kind:4},{x:100,y:350,id:"color",kind:4},{x:150,y:300,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:150,y:350,id:"color",
kind:3},{x:100,y:300,id:"color",kind:3},{x:200,y:350,id:"color",kind:3},{x:300,y:350,id:"color",kind:3},{x:200,y:300,id:"color",kind:3},{x:150,y:250,id:"color",kind:26},{x:200,y:250,id:"color",kind:26},{x:250,y:300,id:"color",kind:26},{x:200,y:200,id:"color",kind:26},{x:100,y:200,id:"color",kind:26},{x:50,y:250,id:"color",kind:26},{x:50,y:300,id:"color",kind:26},{x:300,y:250,id:"color",kind:26},{x:250,y:150,id:"color",kind:26},{x:0,y:350,id:"color",kind:3},{x:350,y:350,id:"color",kind:4},{x:300,y:300,
id:"color",kind:4},{x:250,y:200,id:"color",kind:26},{x:150,y:100,id:"color",kind:26},{x:200,y:0,id:"color",kind:26},{x:100,y:50,id:"color",kind:26},{x:100,y:250,id:"color",kind:17},{x:150,y:200,id:"color",kind:17},{x:100,y:150,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:200,y:150,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:50,y:100,id:"color",kind:17},{x:250,y:50,id:"color",kind:17},{x:300,y:150,id:"color",kind:17},{x:300,y:200,id:"color",kind:17},
{x:250,y:250,id:"color",kind:17},{x:150,y:50,id:"color",kind:8},{x:250,y:0,id:"color",kind:8},{x:100,y:0,id:"color",kind:8},{x:0,y:200,id:"color",kind:8},{x:350,y:100,id:"color",kind:8},{x:350,y:150,id:"color",kind:8},{x:350,y:0,id:"color",kind:8},{x:0,y:300,id:"color",kind:1},{x:0,y:250,id:"color",kind:1},{x:50,y:200,id:"color",kind:1},{x:50,y:150,id:"color",kind:1},{x:0,y:150,id:"color",kind:1},{x:0,y:100,id:"color",kind:1},{x:0,y:50,id:"color",kind:1},{x:50,y:50,id:"color",kind:1},{x:50,y:0,id:"color",
kind:1},{x:0,y:0,id:"color",kind:1},{x:150,y:0,id:"color",kind:1},{x:200,y:50,id:"color",kind:1},{x:250,y:100,id:"color",kind:1},{x:300,y:100,id:"color",kind:1},{x:300,y:50,id:"color",kind:1},{x:300,y:0,id:"color",kind:1},{x:350,y:50,id:"color",kind:1},{x:350,y:200,id:"color",kind:1},{x:350,y:250,id:"color",kind:1},{x:350,y:300,id:"color",kind:1},{x:0,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,
id:"cell"},{x:300,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:350,y:0,id:"cell"},
{x:200,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"}],name:{key:"campfire"}},drink8x8:{width:400,height:400,items:[{x:50,y:350,id:"color",kind:22},{x:100,y:350,id:"color",kind:22},{x:150,y:350,id:"color",kind:22},{x:100,y:300,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},
{x:200,y:100,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:50,y:100,id:"color",kind:33},{x:100,y:100,id:"color",kind:33},{x:150,y:100,id:"color",kind:33},{x:100,y:150,id:"color",kind:33},{x:150,y:50,id:"color",kind:30},{x:150,y:0,id:"color",kind:30},{x:200,y:0,id:"color",kind:30},{x:250,y:0,id:"color",kind:30},{x:250,y:50,id:"color",kind:30},{x:0,y:350,id:"color",kind:35},{x:0,y:300,id:"color",kind:35},{x:50,y:300,id:"color",kind:35},{x:50,y:250,id:"color",kind:35},{x:0,y:250,id:"color",
kind:35},{x:0,y:200,id:"color",kind:35},{x:50,y:200,id:"color",kind:35},{x:0,y:150,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:50,y:50,id:"color",kind:35},{x:100,y:50,id:"color",kind:35},{x:100,y:0,id:"color",kind:35},{x:200,y:200,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:300,y:250,id:"color",kind:31},{x:300,y:300,id:"color",kind:31},{x:200,y:350,id:"color",
kind:35},{x:150,y:300,id:"color",kind:35},{x:150,y:250,id:"color",kind:35},{x:150,y:200,id:"color",kind:35},{x:200,y:150,id:"color",kind:35},{x:250,y:150,id:"color",kind:35},{x:300,y:200,id:"color",kind:35},{x:350,y:150,id:"color",kind:35},{x:300,y:150,id:"color",kind:35},{x:300,y:100,id:"color",kind:35},{x:250,y:100,id:"color",kind:35},{x:350,y:100,id:"color",kind:35},{x:350,y:50,id:"color",kind:35},{x:300,y:50,id:"color",kind:35},{x:300,y:0,id:"color",kind:35},{x:350,y:0,id:"color",kind:35},{x:350,
y:300,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:350,y:200,id:"color",kind:22},{x:350,y:350,id:"color",kind:35},{x:250,y:200,id:"color",kind:35},{x:250,y:250,id:"color",kind:31},{x:250,y:300,id:"color",kind:31},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},
{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:200,id:"cell"},{x:250,y:350,id:"cell"},{x:350,y:250,id:"cell"}],name:{key:"drinks"}},leaf8x8:{width:400,height:400,items:[{x:0,y:300,id:"color",kind:14},{x:0,y:250,id:"color",
kind:14},{x:100,y:300,id:"color",kind:14},{x:150,y:350,id:"color",kind:14},{x:50,y:300,id:"color",kind:14},{x:50,y:350,id:"color",kind:14},{x:100,y:350,id:"color",kind:14},{x:150,y:300,id:"color",kind:14},{x:200,y:250,id:"color",kind:14},{x:200,y:200,id:"color",kind:14},{x:200,y:150,id:"color",kind:14},{x:300,y:100,id:"color",kind:14},{x:350,y:150,id:"color",kind:14},{x:350,y:200,id:"color",kind:14},{x:300,y:300,id:"color",kind:14},{x:250,y:350,id:"color",kind:14},{x:200,y:350,id:"color",kind:14},
{x:200,y:300,id:"color",kind:14},{x:250,y:300,id:"color",kind:14},{x:250,y:250,id:"color",kind:14},{x:300,y:250,id:"color",kind:14},{x:300,y:200,id:"color",kind:14},{x:250,y:150,id:"color",kind:14},{x:300,y:150,id:"color",kind:14},{x:250,y:200,id:"color",kind:14},{x:100,y:250,id:"color",kind:13},{x:100,y:200,id:"color",kind:13},{x:100,y:150,id:"color",kind:13},{x:100,y:100,id:"color",kind:13},{x:150,y:50,id:"color",kind:13},{x:150,y:100,id:"color",kind:13},{x:200,y:50,id:"color",kind:13},{x:350,y:100,
id:"color",kind:13},{x:350,y:50,id:"color",kind:13},{x:350,y:0,id:"color",kind:13},{x:300,y:0,id:"color",kind:13},{x:0,y:350,id:"color",kind:26},{x:300,y:350,id:"color",kind:26},{x:350,y:350,id:"color",kind:26},{x:350,y:300,id:"color",kind:26},{x:350,y:250,id:"color",kind:26},{x:300,y:50,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:250,y:0,id:"color",kind:26},{x:200,y:0,id:"color",kind:26},{x:150,y:0,id:"color",kind:26},{x:100,y:0,id:"color",kind:26},{x:50,y:0,id:"color",kind:26},{x:0,y:0,
id:"color",kind:26},{x:0,y:50,id:"color",kind:26},{x:0,y:100,id:"color",kind:26},{x:0,y:150,id:"color",kind:26},{x:0,y:200,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:50,y:250,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},{x:50,y:50,id:"color",kind:26},{x:100,y:50,id:"color",kind:26},{x:250,y:100,id:"color",kind:14},{x:200,y:100,id:"color",kind:13},{x:150,y:150,id:"color",kind:13},{x:150,y:200,id:"color",kind:13},{x:150,y:250,id:"color",kind:13},{x:0,
y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:300,
id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:300,y:100,id:"cell"}],name:{key:"leaf"}},dragonfly8x8:{width:400,height:400,items:[{x:50,y:50,id:"color",kind:16},{x:50,y:100,id:"color",kind:16},{x:100,y:100,id:"color",kind:16},{x:100,y:50,id:"color",kind:16},{x:100,y:150,id:"color",kind:1},{x:150,y:150,id:"color",kind:1},{x:150,y:100,id:"color",kind:1},{x:200,y:200,id:"color",
kind:16},{x:200,y:250,id:"color",kind:16},{x:250,y:250,id:"color",kind:16},{x:250,y:200,id:"color",kind:16},{x:300,y:300,id:"color",kind:16},{x:350,y:350,id:"color",kind:16},{x:100,y:200,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:50,y:300,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:250,
y:50,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:350,y:0,id:"color",kind:22},{x:0,y:350,id:"color",kind:22},{x:250,y:300,id:"color",kind:16},{x:300,y:250,id:"color",kind:16},{x:300,y:350,id:"color",kind:1},{x:350,y:300,id:"color",kind:1},{x:0,y:50,id:"color",kind:1},{x:50,y:0,id:"color",kind:1},{x:150,y:250,id:"color",kind:23},{x:150,y:300,id:"color",kind:23},{x:150,y:350,id:"color",kind:23},{x:250,y:150,id:"color",kind:23},
{x:300,y:150,id:"color",kind:23},{x:350,y:150,id:"color",kind:23},{x:0,y:200,id:"color",kind:24},{x:0,y:150,id:"color",kind:24},{x:50,y:150,id:"color",kind:24},{x:0,y:100,id:"color",kind:24},{x:0,y:0,id:"color",kind:24},{x:100,y:0,id:"color",kind:24},{x:150,y:50,id:"color",kind:24},{x:150,y:0,id:"color",kind:24},{x:200,y:0,id:"color",kind:24},{x:50,y:350,id:"color",kind:24},{x:100,y:350,id:"color",kind:24},{x:100,y:300,id:"color",kind:24},{x:200,y:300,id:"color",kind:24},{x:200,y:350,id:"color",kind:24},
{x:250,y:350,id:"color",kind:24},{x:300,y:200,id:"color",kind:24},{x:350,y:200,id:"color",kind:24},{x:350,y:250,id:"color",kind:24},{x:350,y:100,id:"color",kind:24},{x:350,y:50,id:"color",kind:24},{x:300,y:100,id:"color",kind:24},{x:200,y:150,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:0,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:200,id:"cell"},
{x:0,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:0,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,
id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:200,id:"cell"}],name:{key:"dragonfly "}},volcano8x8:{width:400,height:400,items:[{x:50,y:300,id:"color",kind:3},{x:100,y:300,id:"color",kind:3},{x:250,y:300,id:"color",kind:3},{x:300,y:300,id:"color",kind:3},{x:350,y:250,id:"color",kind:3},{x:300,y:250,id:"color",kind:3},{x:250,y:250,id:"color",kind:3},{x:100,y:250,id:"color",kind:4},{x:150,y:300,id:"color",kind:4},{x:200,y:250,id:"color",
kind:4},{x:150,y:250,id:"color",kind:4},{x:200,y:300,id:"color",kind:4},{x:150,y:200,id:"color",kind:4},{x:250,y:200,id:"color",kind:4},{x:250,y:150,id:"color",kind:4},{x:200,y:200,id:"color",kind:4},{x:200,y:150,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:300,y:100,id:"color",kind:26},{x:150,y:350,id:"color",kind:4},{x:100,y:350,id:"color",kind:4},{x:200,y:350,id:"color",kind:4},{x:50,y:350,id:"color",kind:13},{x:0,y:350,id:"color",kind:13},{x:0,y:300,
id:"color",kind:13},{x:0,y:250,id:"color",kind:13},{x:250,y:350,id:"color",kind:13},{x:300,y:350,id:"color",kind:13},{x:350,y:350,id:"color",kind:13},{x:350,y:300,id:"color",kind:13},{x:50,y:250,id:"color",kind:14},{x:50,y:200,id:"color",kind:14},{x:100,y:200,id:"color",kind:14},{x:350,y:200,id:"color",kind:14},{x:100,y:150,id:"color",kind:14},{x:300,y:50,id:"color",kind:25},{x:250,y:0,id:"color",kind:25},{x:200,y:0,id:"color",kind:25},{x:150,y:0,id:"color",kind:25},{x:100,y:0,id:"color",kind:25},
{x:50,y:50,id:"color",kind:25},{x:50,y:0,id:"color",kind:25},{x:0,y:0,id:"color",kind:25},{x:300,y:0,id:"color",kind:25},{x:350,y:50,id:"color",kind:25},{x:350,y:100,id:"color",kind:26},{x:350,y:150,id:"color",kind:3},{x:300,y:150,id:"color",kind:26},{x:300,y:200,id:"color",kind:26},{x:0,y:200,id:"color",kind:24},{x:0,y:150,id:"color",kind:24},{x:0,y:100,id:"color",kind:24},{x:50,y:100,id:"color",kind:24},{x:50,y:150,id:"color",kind:24},{x:100,y:100,id:"color",kind:24},{x:100,y:50,id:"color",kind:24},
{x:150,y:150,id:"color",kind:24},{x:150,y:100,id:"color",kind:24},{x:150,y:50,id:"color",kind:24},{x:200,y:50,id:"color",kind:24},{x:250,y:50,id:"color",kind:25},{x:350,y:0,id:"color",kind:24},{x:0,y:50,id:"color",kind:25},{x:0,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:250,
y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:0,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:200,id:"cell"},{x:0,y:50,id:"cell"}],
name:{key:"volcano"}},coral8x8:{width:400,height:400,items:[{x:200,y:200,id:"color",kind:26},{x:200,y:250,id:"color",kind:26},{x:250,y:200,id:"color",kind:26},{x:300,y:200,id:"color",kind:26},{x:300,y:50,id:"color",kind:26},{x:300,y:150,id:"color",kind:26},{x:300,y:100,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:250,y:0,id:"color",kind:26},{x:350,y:150,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:150,y:150,id:"color",kind:26},{x:150,y:100,id:"color",kind:26},{x:150,y:50,id:"color",
kind:26},{x:100,y:100,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},{x:50,y:50,id:"color",kind:26},{x:150,y:250,id:"color",kind:27},{x:150,y:300,id:"color",kind:27},{x:100,y:250,id:"color",kind:27},{x:100,y:300,id:"color",kind:27},{x:50,y:300,id:"color",kind:27},{x:50,y:350,id:"color",kind:27},{x:0,y:350,id:"color",kind:27},{x:100,y:350,id:"color",kind:27},{x:0,y:250,id:"color",kind:33},{x:0,y:300,id:"color",kind:34},{x:50,y:200,id:"color",kind:33},{x:300,y:350,id:"color",kind:31},{x:350,y:250,
id:"color",kind:31},{x:350,y:350,id:"color",kind:32},{x:0,y:200,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:100,y:150,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:200,y:100,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:350,
y:100,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:21},{x:100,y:0,id:"color",kind:21},{x:350,y:0,id:"color",kind:21},{x:0,y:100,id:"color",kind:21},{x:100,y:50,id:"color",kind:21},{x:200,y:50,id:"color",kind:21},{x:350,y:200,id:"color",kind:21},{x:100,y:200,id:"color",kind:21},{x:250,y:350,id:"color",kind:28},{x:300,y:300,id:"color",kind:28},{x:250,y:300,id:"color",kind:28},{x:200,y:350,id:"color",kind:28},{x:150,y:350,id:"color",kind:28},
{x:50,y:250,id:"color",kind:34},{x:350,y:300,id:"color",kind:31},{x:200,y:300,id:"color",kind:28},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:50,
y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:150,y:350,id:"cell"}],name:{key:"coral"}},bracelet8x8:{width:400,height:400,items:[{x:0,y:150,id:"color",kind:30},{x:100,y:200,
id:"color",kind:30},{x:150,y:200,id:"color",kind:30},{x:200,y:200,id:"color",kind:30},{x:50,y:200,id:"color",kind:30},{x:0,y:200,id:"color",kind:31},{x:100,y:250,id:"color",kind:31},{x:150,y:250,id:"color",kind:31},{x:200,y:250,id:"color",kind:31},{x:50,y:250,id:"color",kind:31},{x:250,y:200,id:"color",kind:31},{x:50,y:300,id:"color",kind:7},{x:100,y:350,id:"color",kind:7},{x:100,y:300,id:"color",kind:7},{x:150,y:300,id:"color",kind:7},{x:200,y:350,id:"color",kind:7},{x:200,y:300,id:"color",kind:7},
{x:50,y:350,id:"color",kind:7},{x:150,y:350,id:"color",kind:7},{x:0,y:350,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:350,y:200,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:350,y:300,id:"color",kind:22},{x:350,y:350,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:250,y:50,id:"color",kind:7},{x:50,y:50,id:"color",kind:6},{x:350,y:100,id:"color",
kind:22},{x:0,y:0,id:"color",kind:6},{x:50,y:0,id:"color",kind:6},{x:50,y:150,id:"color",kind:7},{x:100,y:150,id:"color",kind:7},{x:150,y:150,id:"color",kind:7},{x:200,y:150,id:"color",kind:7},{x:250,y:150,id:"color",kind:30},{x:250,y:100,id:"color",kind:7},{x:0,y:100,id:"color",kind:6},{x:0,y:50,id:"color",kind:6},{x:150,y:100,id:"color",kind:7},{x:200,y:100,id:"color",kind:7},{x:200,y:50,id:"color",kind:7},{x:300,y:50,id:"color",kind:7},{x:350,y:50,id:"color",kind:7},{x:100,y:50,id:"color",kind:6},
{x:100,y:0,id:"color",kind:6},{x:150,y:0,id:"color",kind:6},{x:200,y:0,id:"color",kind:7},{x:300,y:100,id:"color",kind:7},{x:50,y:100,id:"color",kind:7},{x:100,y:100,id:"color",kind:7},{x:150,y:50,id:"color",kind:7},{x:250,y:0,id:"color",kind:7},{x:250,y:350,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:350,y:0,id:"color",kind:22},{x:50,y:350,id:"cell"},{x:50,
y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:50,y:250,id:"cell"},{x:200,y:350,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:150,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:0,y:0,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:0,id:"cell"},
{x:200,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:100,id:"cell"}],name:{key:"bracelet"}},backpack8x8:{width:400,height:400,items:[{x:300,y:350,id:"color",kind:18},{x:250,y:350,id:"color",kind:18},{x:200,y:350,id:"color",kind:18},{x:350,y:300,id:"color",kind:18},{x:350,y:200,id:"color",kind:18},{x:350,y:250,id:"color",kind:18},{x:150,y:350,id:"color",kind:18},{x:150,y:300,id:"color",kind:18},{x:150,y:250,
id:"color",kind:18},{x:150,y:150,id:"color",kind:19},{x:150,y:100,id:"color",kind:19},{x:300,y:100,id:"color",kind:19},{x:300,y:150,id:"color",kind:19},{x:200,y:150,id:"color",kind:19},{x:250,y:150,id:"color",kind:19},{x:250,y:100,id:"color",kind:19},{x:200,y:100,id:"color",kind:19},{x:300,y:200,id:"color",kind:19},{x:350,y:150,id:"color",kind:19},{x:200,y:250,id:"color",kind:18},{x:200,y:300,id:"color",kind:18},{x:250,y:300,id:"color",kind:18},{x:300,y:250,id:"color",kind:18},{x:300,y:300,id:"color",
kind:18},{x:50,y:100,id:"color",kind:16},{x:0,y:150,id:"color",kind:16},{x:0,y:200,id:"color",kind:16},{x:0,y:250,id:"color",kind:16},{x:0,y:300,id:"color",kind:16},{x:50,y:350,id:"color",kind:16},{x:100,y:350,id:"color",kind:16},{x:150,y:50,id:"color",kind:19},{x:200,y:50,id:"color",kind:19},{x:250,y:50,id:"color",kind:19},{x:300,y:50,id:"color",kind:19},{x:350,y:100,id:"color",kind:19},{x:150,y:0,id:"color",kind:16},{x:200,y:0,id:"color",kind:16},{x:250,y:0,id:"color",kind:16},{x:250,y:200,id:"color",
kind:17},{x:250,y:250,id:"color",kind:17},{x:100,y:300,id:"color",kind:18},{x:100,y:250,id:"color",kind:18},{x:100,y:200,id:"color",kind:18},{x:150,y:200,id:"color",kind:19},{x:200,y:200,id:"color",kind:19},{x:100,y:150,id:"color",kind:19},{x:100,y:100,id:"color",kind:19},{x:50,y:300,id:"color",kind:7},{x:50,y:250,id:"color",kind:7},{x:50,y:200,id:"color",kind:7},{x:50,y:150,id:"color",kind:7},{x:0,y:350,id:"color",kind:7},{x:350,y:350,id:"color",kind:7},{x:350,y:50,id:"color",kind:7},{x:350,y:0,
id:"color",kind:7},{x:300,y:0,id:"color",kind:7},{x:100,y:0,id:"color",kind:7},{x:100,y:50,id:"color",kind:7},{x:50,y:50,id:"color",kind:7},{x:50,y:0,id:"color",kind:7},{x:0,y:0,id:"color",kind:7},{x:0,y:50,id:"color",kind:7},{x:0,y:100,id:"color",kind:7},{x:100,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},
{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,
y:200,id:"cell"}],name:{key:"backpack "}},orca8x8:{width:400,height:400,items:[{x:0,y:100,id:"color",kind:0},{x:0,y:50,id:"color",kind:0},{x:50,y:50,id:"color",kind:0},{x:100,y:0,id:"color",kind:0},{x:150,y:0,id:"color",kind:0},{x:50,y:100,id:"color",kind:0},{x:200,y:100,id:"color",kind:0},{x:150,y:100,id:"color",kind:0},{x:200,y:0,id:"color",kind:0},{x:250,y:50,id:"color",kind:0},{x:300,y:100,id:"color",kind:0},{x:350,y:150,id:"color",kind:0},{x:300,y:250,id:"color",kind:0},{x:350,y:250,id:"color",
kind:0},{x:350,y:200,id:"color",kind:0},{x:300,y:300,id:"color",kind:0},{x:250,y:350,id:"color",kind:0},{x:150,y:350,id:"color",kind:0},{x:200,y:350,id:"color",kind:0},{x:100,y:350,id:"color",kind:0},{x:0,y:300,id:"color",kind:0},{x:50,y:300,id:"color",kind:0},{x:100,y:300,id:"color",kind:0},{x:100,y:250,id:"color",kind:0},{x:250,y:300,id:"color",kind:0},{x:200,y:150,id:"color",kind:0},{x:250,y:100,id:"color",kind:0},{x:250,y:150,id:"color",kind:0},{x:250,y:200,id:"color",kind:0},{x:250,y:250,id:"color",
kind:0},{x:300,y:200,id:"color",kind:0},{x:300,y:150,id:"color",kind:0},{x:100,y:100,id:"color",kind:0},{x:300,y:50,id:"color",kind:0},{x:250,y:0,id:"color",kind:0},{x:350,y:0,id:"color",kind:0},{x:300,y:0,id:"color",kind:0},{x:50,y:350,id:"color",kind:0},{x:50,y:200,id:"color",kind:0},{x:50,y:250,id:"color",kind:0},{x:200,y:200,id:"color",kind:0},{x:0,y:150,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},
{x:150,y:300,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:0,y:350,id:"color",kind:20},{x:350,y:350,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,y:150,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:150,y:150,id:"color",kind:23},{x:150,y:200,id:"color",kind:22},{x:100,y:50,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:200,y:50,id:"color",kind:22},{x:300,y:350,id:"color",
kind:0},{x:350,y:300,id:"color",kind:0},{x:200,y:250,id:"color",kind:22},{x:0,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},
{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"}],name:{key:"orca"}},souppan8x8:{width:400,
height:400,items:[{x:50,y:200,id:"color",kind:27},{x:50,y:250,id:"color",kind:27},{x:50,y:150,id:"color",kind:27},{x:100,y:300,id:"color",kind:27},{x:150,y:300,id:"color",kind:27},{x:200,y:300,id:"color",kind:27},{x:250,y:300,id:"color",kind:27},{x:300,y:250,id:"color",kind:27},{x:300,y:200,id:"color",kind:27},{x:50,y:300,id:"color",kind:28},{x:50,y:350,id:"color",kind:28},{x:100,y:350,id:"color",kind:28},{x:150,y:350,id:"color",kind:28},{x:200,y:350,id:"color",kind:28},{x:250,y:350,id:"color",kind:28},
{x:300,y:350,id:"color",kind:28},{x:300,y:300,id:"color",kind:28},{x:300,y:150,id:"color",kind:27},{x:100,y:100,id:"color",kind:27},{x:150,y:100,id:"color",kind:27},{x:100,y:150,id:"color",kind:28},{x:100,y:250,id:"color",kind:26},{x:150,y:250,id:"color",kind:26},{x:200,y:250,id:"color",kind:26},{x:250,y:250,id:"color",kind:26},{x:0,y:250,id:"color",kind:28},{x:0,y:200,id:"color",kind:28},{x:350,y:250,id:"color",kind:28},{x:350,y:200,id:"color",kind:28},{x:250,y:150,id:"color",kind:28},{x:250,y:200,
id:"color",kind:26},{x:100,y:200,id:"color",kind:26},{x:150,y:150,id:"color",kind:28},{x:150,y:200,id:"color",kind:26},{x:250,y:100,id:"color",kind:27},{x:200,y:200,id:"color",kind:25},{x:200,y:150,id:"color",kind:25},{x:200,y:100,id:"color",kind:25},{x:200,y:50,id:"color",kind:25},{x:200,y:0,id:"color",kind:25},{x:250,y:0,id:"color",kind:25},{x:0,y:350,id:"color",kind:10},{x:0,y:300,id:"color",kind:10},{x:350,y:350,id:"color",kind:10},{x:350,y:300,id:"color",kind:10},{x:350,y:150,id:"color",kind:10},
{x:350,y:100,id:"color",kind:10},{x:300,y:100,id:"color",kind:10},{x:300,y:50,id:"color",kind:10},{x:250,y:50,id:"color",kind:10},{x:300,y:0,id:"color",kind:10},{x:350,y:0,id:"color",kind:10},{x:350,y:50,id:"color",kind:10},{x:150,y:0,id:"color",kind:10},{x:150,y:50,id:"color",kind:10},{x:100,y:50,id:"color",kind:10},{x:100,y:0,id:"color",kind:10},{x:50,y:0,id:"color",kind:10},{x:0,y:0,id:"color",kind:10},{x:0,y:50,id:"color",kind:10},{x:50,y:50,id:"color",kind:10},{x:50,y:100,id:"color",kind:10},
{x:0,y:100,id:"color",kind:10},{x:0,y:150,id:"color",kind:10},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:200,y:300,id:"cell"},
{x:250,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"}],name:{key:"soup_pan"}},tent8x8:{width:400,height:400,items:[{x:150,y:300,id:"color",kind:12},{x:200,y:300,id:"color",kind:12},{x:250,y:300,id:"color",kind:12},{x:350,y:300,id:"color",kind:12},{x:200,y:250,id:"color",
kind:12},{x:250,y:250,id:"color",kind:12},{x:250,y:200,id:"color",kind:12},{x:300,y:200,id:"color",kind:12},{x:350,y:250,id:"color",kind:12},{x:350,y:200,id:"color",kind:12},{x:300,y:150,id:"color",kind:12},{x:300,y:300,id:"color",kind:15},{x:100,y:300,id:"color",kind:4},{x:100,y:250,id:"color",kind:4},{x:300,y:100,id:"color",kind:4},{x:0,y:350,id:"color",kind:13},{x:50,y:350,id:"color",kind:13},{x:100,y:350,id:"color",kind:13},{x:150,y:350,id:"color",kind:13},{x:200,y:350,id:"color",kind:13},{x:250,
y:350,id:"color",kind:13},{x:300,y:350,id:"color",kind:13},{x:350,y:350,id:"color",kind:13},{x:0,y:250,id:"color",kind:14},{x:0,y:300,id:"color",kind:14},{x:50,y:300,id:"color",kind:14},{x:0,y:200,id:"color",kind:3},{x:0,y:150,id:"color",kind:3},{x:0,y:100,id:"color",kind:14},{x:50,y:100,id:"color",kind:14},{x:100,y:50,id:"color",kind:14},{x:50,y:50,id:"color",kind:14},{x:0,y:50,id:"color",kind:14},{x:0,y:0,id:"color",kind:14},{x:50,y:0,id:"color",kind:14},{x:100,y:0,id:"color",kind:14},{x:150,y:0,
id:"color",kind:14},{x:200,y:0,id:"color",kind:14},{x:50,y:150,id:"color",kind:14},{x:100,y:100,id:"color",kind:14},{x:50,y:250,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:100,y:150,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:150,y:100,id:"color",
kind:20},{x:150,y:50,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:200,y:100,id:"color",kind:17},{x:300,y:250,id:"color",kind:15},{x:350,y:150,id:"color",kind:20},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:250,
id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:200,y:100,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,
y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:0,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"}],name:{key:"tent"}},cookie8x8:{width:400,height:400,items:[{x:0,y:150,id:"color",kind:4},{x:50,y:100,id:"color",kind:4},{x:50,y:50,id:"color",kind:4},{x:200,y:50,id:"color",kind:4},{x:150,y:0,id:"color",kind:4},{x:50,y:300,id:"color",kind:4},{x:100,y:350,id:"color",kind:4},{x:100,y:300,id:"color",kind:4},{x:150,y:250,id:"color",kind:4},{x:100,y:200,
id:"color",kind:4},{x:200,y:250,id:"color",kind:4},{x:250,y:300,id:"color",kind:4},{x:200,y:350,id:"color",kind:4},{x:300,y:250,id:"color",kind:4},{x:300,y:300,id:"color",kind:4},{x:350,y:200,id:"color",kind:4},{x:350,y:150,id:"color",kind:4},{x:350,y:250,id:"color",kind:4},{x:250,y:100,id:"color",kind:4},{x:200,y:150,id:"color",kind:4},{x:100,y:0,id:"color",kind:3},{x:100,y:50,id:"color",kind:3},{x:150,y:50,id:"color",kind:3},{x:250,y:50,id:"color",kind:3},{x:250,y:0,id:"color",kind:3},{x:150,y:350,
id:"color",kind:3},{x:250,y:350,id:"color",kind:3},{x:0,y:250,id:"color",kind:3},{x:50,y:250,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:150,y:150,id:"color",kind:3},{x:250,y:200,id:"color",kind:3},{x:300,y:200,id:"color",kind:3},{x:250,y:250,id:"color",kind:3},{x:50,y:200,id:"color",kind:4},{x:50,y:150,id:"color",kind:4},{x:100,y:250,id:"color",kind:4},{x:200,y:200,id:"color",kind:4},{x:100,y:100,id:"color",kind:4},{x:150,y:100,id:"color",kind:4},{x:200,y:100,id:"color",kind:4},{x:300,
y:150,id:"color",kind:4},{x:200,y:0,id:"color",kind:4},{x:300,y:100,id:"color",kind:4},{x:300,y:50,id:"color",kind:4},{x:0,y:200,id:"color",kind:3},{x:200,y:300,id:"color",kind:3},{x:150,y:300,id:"color",kind:3},{x:350,y:100,id:"color",kind:3},{x:150,y:200,id:"color",kind:3},{x:0,y:300,id:"color",kind:20},{x:0,y:350,id:"color",kind:20},{x:50,y:350,id:"color",kind:20},{x:300,y:350,id:"color",kind:20},{x:350,y:350,id:"color",kind:20},{x:350,y:300,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},
{x:350,y:0,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:250,y:150,id:"color",kind:3},{x:0,y:100,id:"color",kind:3},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:200,
y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:250,y:150,id:"cell"}],name:{key:"choco_cookie"}},
magictrick8x8:{width:400,height:400,items:[{x:50,y:350,id:"color",kind:0},{x:50,y:300,id:"color",kind:0},{x:0,y:200,id:"color",kind:0},{x:100,y:300,id:"color",kind:0},{x:150,y:300,id:"color",kind:0},{x:150,y:350,id:"color",kind:0},{x:200,y:350,id:"color",kind:0},{x:200,y:300,id:"color",kind:0},{x:50,y:200,id:"color",kind:0},{x:100,y:200,id:"color",kind:0},{x:150,y:200,id:"color",kind:0},{x:200,y:200,id:"color",kind:0},{x:250,y:200,id:"color",kind:0},{x:150,y:50,id:"color",kind:22},{x:150,y:0,id:"color",
kind:22},{x:100,y:0,id:"color",kind:23},{x:100,y:50,id:"color",kind:23},{x:100,y:100,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:150,y:150,id:"color",kind:23},{x:150,y:100,id:"color",kind:23},{x:150,y:250,id:"color",kind:23},{x:200,y:250,id:"color",kind:23},{x:200,y:150,id:"color",kind:31},{x:200,y:100,id:"color",kind:23},{x:0,y:350,id:"color",kind:16},{x:0,y:300,id:"color",kind:16},{x:0,y:250,id:"color",kind:16},{x:250,y:250,id:"color",kind:16},{x:250,y:300,id:"color",kind:16},{x:250,
y:350,id:"color",kind:16},{x:300,y:200,id:"color",kind:16},{x:300,y:150,id:"color",kind:16},{x:250,y:150,id:"color",kind:16},{x:250,y:100,id:"color",kind:16},{x:200,y:50,id:"color",kind:16},{x:200,y:0,id:"color",kind:16},{x:250,y:0,id:"color",kind:16},{x:250,y:50,id:"color",kind:16},{x:300,y:0,id:"color",kind:16},{x:300,y:50,id:"color",kind:16},{x:300,y:100,id:"color",kind:16},{x:350,y:0,id:"color",kind:16},{x:0,y:150,id:"color",kind:16},{x:0,y:100,id:"color",kind:16},{x:50,y:150,id:"color",kind:16},
{x:50,y:100,id:"color",kind:16},{x:50,y:50,id:"color",kind:16},{x:0,y:50,id:"color",kind:16},{x:0,y:0,id:"color",kind:16},{x:50,y:0,id:"color",kind:16},{x:350,y:300,id:"color",kind:7},{x:350,y:350,id:"color",kind:7},{x:300,y:350,id:"color",kind:7},{x:300,y:300,id:"color",kind:7},{x:300,y:250,id:"color",kind:7},{x:350,y:250,id:"color",kind:0},{x:350,y:200,id:"color",kind:0},{x:350,y:100,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:350,y:150,id:"color",kind:0},{x:100,y:250,id:"color",kind:22},
{x:50,y:250,id:"color",kind:22},{x:100,y:350,id:"color",kind:0},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},
{x:200,y:100,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:50,y:250,id:"cell"},{x:200,y:250,id:"cell"}],name:{key:"magic_hat"}},handmirror8x8:{width:400,height:400,items:[{x:0,y:50,id:"color",kind:17},{x:0,y:100,id:"color",kind:17},{x:0,y:150,id:"color",kind:17},{x:50,y:200,id:"color",kind:17},
{x:100,y:250,id:"color",kind:17},{x:150,y:250,id:"color",kind:17},{x:200,y:250,id:"color",kind:17},{x:250,y:100,id:"color",kind:17},{x:50,y:0,id:"color",kind:17},{x:100,y:0,id:"color",kind:17},{x:150,y:0,id:"color",kind:17},{x:250,y:150,id:"color",kind:17},{x:250,y:200,id:"color",kind:17},{x:250,y:250,id:"color",kind:17},{x:350,y:350,id:"color",kind:17},{x:50,y:100,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:250,y:300,id:"color",kind:8},{x:300,y:350,id:"color",kind:8},{x:300,y:300,id:"color",
kind:8},{x:300,y:250,id:"color",kind:8},{x:350,y:300,id:"color",kind:8},{x:100,y:200,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:100,y:100,id:"color",kind:23},{x:100,y:50,id:"color",kind:23},{x:50,y:150,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:200,y:200,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:0,y:250,id:"color",kind:32},{x:0,
y:300,id:"color",kind:32},{x:50,y:300,id:"color",kind:32},{x:0,y:350,id:"color",kind:32},{x:50,y:350,id:"color",kind:32},{x:100,y:350,id:"color",kind:32},{x:100,y:300,id:"color",kind:32},{x:150,y:300,id:"color",kind:32},{x:150,y:350,id:"color",kind:32},{x:200,y:350,id:"color",kind:32},{x:200,y:300,id:"color",kind:32},{x:250,y:350,id:"color",kind:32},{x:350,y:250,id:"color",kind:32},{x:350,y:200,id:"color",kind:32},{x:300,y:200,id:"color",kind:32},{x:300,y:150,id:"color",kind:32},{x:350,y:150,id:"color",
kind:32},{x:350,y:100,id:"color",kind:32},{x:300,y:100,id:"color",kind:32},{x:300,y:50,id:"color",kind:32},{x:350,y:50,id:"color",kind:32},{x:350,y:0,id:"color",kind:32},{x:300,y:0,id:"color",kind:32},{x:250,y:0,id:"color",kind:32},{x:250,y:50,id:"color",kind:17},{x:200,y:50,id:"color",kind:17},{x:0,y:200,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:50,y:250,id:"color",kind:17},{x:0,y:0,id:"color",kind:17},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:200,id:"cell"},
{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:200,y:0,id:"cell"},{x:0,y:0,id:"cell"}],
name:{key:"hand mirror"}},waterfall8x8:{width:400,height:400,items:[{x:150,y:350,id:"color",kind:22},{x:100,y:300,id:"color",kind:22},{x:50,y:350,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:350,y:350,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:0,y:150,id:"color",kind:27},{x:50,y:0,id:"color",kind:21},{x:100,y:0,id:"color",kind:21},{x:100,y:50,id:"color",kind:21},{x:150,y:50,id:"color",kind:21},{x:150,y:0,id:"color",kind:21},{x:200,y:0,id:"color",
kind:21},{x:200,y:50,id:"color",kind:21},{x:250,y:50,id:"color",kind:21},{x:250,y:0,id:"color",kind:21},{x:300,y:0,id:"color",kind:21},{x:300,y:50,id:"color",kind:21},{x:350,y:0,id:"color",kind:21},{x:250,y:350,id:"color",kind:22},{x:150,y:250,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:250,y:200,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:200,
y:100,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:100,y:350,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:200,y:350,id:"color",kind:20},{x:250,y:300,id:"color",kind:20},{x:0,y:100,id:"color",kind:27},{x:0,y:50,id:"color",kind:27},{x:50,y:50,id:"color",kind:27},{x:50,y:100,id:"color",kind:27},{x:100,y:100,id:"color",kind:27},{x:100,y:150,id:"color",kind:27},{x:200,y:250,id:"color",kind:20},{x:300,y:150,id:"color",
kind:27},{x:300,y:100,id:"color",kind:27},{x:350,y:50,id:"color",kind:27},{x:350,y:100,id:"color",kind:27},{x:350,y:150,id:"color",kind:27},{x:300,y:200,id:"color",kind:27},{x:100,y:200,id:"color",kind:27},{x:50,y:150,id:"color",kind:28},{x:50,y:200,id:"color",kind:28},{x:0,y:200,id:"color",kind:28},{x:0,y:250,id:"color",kind:28},{x:50,y:300,id:"color",kind:28},{x:100,y:250,id:"color",kind:28},{x:50,y:250,id:"color",kind:28},{x:0,y:350,id:"color",kind:28},{x:300,y:250,id:"color",kind:28},{x:350,y:300,
id:"color",kind:28},{x:350,y:250,id:"color",kind:28},{x:350,y:200,id:"color",kind:28},{x:0,y:0,id:"color",kind:27},{x:0,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:200,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:150,
id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:0,y:0,id:"cell"}],name:{key:"waterfall"}},chest8x8:{width:400,height:400,items:[{x:50,y:300,id:"color",kind:3},{x:50,y:250,id:"color",
kind:3},{x:100,y:250,id:"color",kind:3},{x:100,y:300,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:100,y:100,id:"color",kind:3},{x:50,y:100,id:"color",kind:3},{x:50,y:150,id:"color",kind:3},{x:150,y:50,id:"color",kind:4},{x:200,y:50,id:"color",kind:4},{x:200,y:100,id:"color",kind:4},{x:200,y:150,id:"color",kind:4},{x:250,y:150,id:"color",kind:4},{x:250,y:100,id:"color",kind:4},{x:250,y:50,id:"color",kind:4},{x:300,y:100,id:"color",kind:4},{x:300,y:150,id:"color",kind:4},{x:200,y:250,id:"color",
kind:4},{x:200,y:300,id:"color",kind:4},{x:250,y:300,id:"color",kind:4},{x:300,y:300,id:"color",kind:4},{x:300,y:250,id:"color",kind:4},{x:0,y:350,id:"color",kind:8},{x:50,y:350,id:"color",kind:8},{x:100,y:350,id:"color",kind:8},{x:100,y:200,id:"color",kind:8},{x:50,y:200,id:"color",kind:8},{x:0,y:200,id:"color",kind:8},{x:0,y:300,id:"color",kind:8},{x:0,y:250,id:"color",kind:8},{x:0,y:150,id:"color",kind:8},{x:0,y:100,id:"color",kind:8},{x:100,y:50,id:"color",kind:8},{x:150,y:200,id:"color",kind:17},
{x:150,y:250,id:"color",kind:17},{x:150,y:300,id:"color",kind:17},{x:150,y:350,id:"color",kind:17},{x:150,y:100,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:300,y:50,id:"color",kind:17},{x:350,y:100,id:"color",kind:17},{x:350,y:150,id:"color",kind:17},{x:350,y:200,id:"color",kind:17},{x:350,y:300,id:"color",kind:17},{x:350,y:350,id:"color",kind:17},{x:350,y:250,id:"color",kind:17},{x:300,y:350,id:"color",kind:17},{x:250,y:350,id:"color",kind:17},{x:200,y:350,id:"color",kind:17},{x:250,
y:0,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:150,y:0,id:"color",kind:17},{x:50,y:50,id:"color",kind:8},{x:100,y:0,id:"color",kind:17},{x:0,y:50,id:"color",kind:2},{x:0,y:0,id:"color",kind:2},{x:50,y:0,id:"color",kind:2},{x:300,y:0,id:"color",kind:2},{x:350,y:0,id:"color",kind:2},{x:350,y:50,id:"color",kind:2},{x:200,y:200,id:"color",kind:17},{x:300,y:200,id:"color",kind:17},{x:250,y:250,id:"color",kind:17},{x:250,y:200,id:"color",kind:17},{x:150,y:350,id:"cell"},{x:150,y:300,id:"cell"},
{x:150,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:0,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,
id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:0,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"}],name:{key:"treasure_chest"}},chimney8x8:{width:400,height:400,items:[{x:200,y:250,id:"color",kind:4},{x:200,y:200,id:"color",kind:4},{x:250,y:200,id:"color",kind:4},{x:300,y:200,id:"color",kind:4},{x:300,y:250,id:"color",kind:4},{x:250,y:250,id:"color",kind:4},{x:250,y:300,id:"color",kind:4},
{x:300,y:300,id:"color",kind:4},{x:150,y:300,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:150,y:200,id:"color",kind:3},{x:100,y:200,id:"color",kind:3},{x:100,y:250,id:"color",kind:3},{x:100,y:350,id:"color",kind:26},{x:100,y:300,id:"color",kind:26},{x:50,y:300,id:"color",kind:26},{x:50,y:250,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:350,y:200,id:"color",kind:26},{x:100,y:150,id:"color",kind:3},{x:150,y:150,id:"color",kind:3},{x:200,y:150,id:"color",kind:4},{x:250,y:150,id:"color",
kind:4},{x:300,y:150,id:"color",kind:4},{x:0,y:200,id:"color",kind:26},{x:350,y:250,id:"color",kind:26},{x:350,y:300,id:"color",kind:26},{x:350,y:350,id:"color",kind:26},{x:150,y:350,id:"color",kind:26},{x:50,y:350,id:"color",kind:26},{x:0,y:350,id:"color",kind:26},{x:0,y:300,id:"color",kind:26},{x:0,y:250,id:"color",kind:26},{x:300,y:350,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:200,y:350,id:"color",kind:4},{x:200,y:300,id:"color",kind:4},{x:250,y:100,id:"color",kind:22},{x:200,y:100,
id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:100,y:50,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:0,y:150,id:"color",kind:24},{x:50,y:150,id:"color",kind:24},{x:50,y:100,id:"color",kind:24},{x:100,y:100,id:"color",kind:24},{x:50,y:50,id:"color",kind:24},{x:0,y:50,id:"color",kind:24},{x:0,y:100,id:"color",kind:24},{x:200,y:0,
id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:250,y:50,id:"color",kind:24},{x:300,y:50,id:"color",kind:24},{x:300,y:0,id:"color",kind:24},{x:350,y:0,id:"color",kind:24},{x:350,y:50,id:"color",kind:24},{x:300,y:100,id:"color",kind:24},{x:350,y:100,id:"color",kind:24},{x:350,y:150,id:"color",kind:24},{x:0,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},
{x:250,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},
{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:350,id:"cell"}],name:{key:"chimney"}},salt8x8:{width:400,height:400,items:[{x:250,y:50,id:"color",kind:27},{x:300,y:50,id:"color",kind:27},{x:350,y:50,id:"color",kind:27},{x:250,y:100,id:"color",kind:28},{x:300,y:100,id:"color",kind:28},{x:350,y:100,id:"color",kind:28},{x:200,y:350,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:300,
y:300,id:"color",kind:22},{x:200,y:300,id:"color",kind:23},{x:250,y:300,id:"color",kind:23},{x:250,y:250,id:"color",kind:23},{x:200,y:250,id:"color",kind:23},{x:200,y:200,id:"color",kind:23},{x:250,y:200,id:"color",kind:23},{x:250,y:150,id:"color",kind:23},{x:300,y:150,id:"color",kind:23},{x:350,y:350,id:"color",kind:0},{x:300,y:350,id:"color",kind:0},{x:350,y:300,id:"color",kind:0},{x:300,y:250,id:"color",kind:0},{x:300,y:200,id:"color",kind:0},{x:350,y:200,id:"color",kind:0},{x:50,y:0,id:"color",
kind:27},{x:100,y:0,id:"color",kind:27},{x:150,y:0,id:"color",kind:27},{x:50,y:50,id:"color",kind:28},{x:100,y:50,id:"color",kind:28},{x:150,y:50,id:"color",kind:28},{x:50,y:100,id:"color",kind:4},{x:100,y:100,id:"color",kind:4},{x:0,y:150,id:"color",kind:4},{x:0,y:200,id:"color",kind:4},{x:0,y:250,id:"color",kind:4},{x:0,y:300,id:"color",kind:3},{x:0,y:350,id:"color",kind:3},{x:50,y:350,id:"color",kind:3},{x:100,y:300,id:"color",kind:3},{x:100,y:350,id:"color",kind:3},{x:150,y:350,id:"color",kind:3},
{x:150,y:300,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:100,y:200,id:"color",kind:3},{x:150,y:100,id:"color",kind:3},{x:200,y:150,id:"color",kind:3},{x:50,y:300,id:"color",kind:0},{x:50,y:250,id:"color",kind:0},{x:50,y:200,id:"color",kind:0},{x:100,y:250,id:"color",kind:0},{x:150,y:200,id:"color",kind:0},{x:150,y:150,id:"color",kind:0},{x:100,y:150,id:"color",kind:0},{x:50,y:150,id:"color",kind:0},{x:0,y:100,id:"color",kind:17},{x:0,y:50,id:"color",kind:17},{x:0,y:0,id:"color",kind:17},
{x:200,y:0,id:"color",kind:17},{x:200,y:50,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:250,y:0,id:"color",kind:17},{x:300,y:0,id:"color",kind:17},{x:350,y:0,id:"color",kind:17},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:0,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:100,id:"cell"},{x:300,y:200,
id:"cell"},{x:350,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:0,
y:150,id:"cell"},{x:0,y:250,id:"cell"}],name:{key:"salt_&_pepper"}},glasses8x8:{width:400,height:400,items:[{x:0,y:250,id:"color",kind:2},{x:0,y:300,id:"color",kind:2},{x:50,y:350,id:"color",kind:2},{x:100,y:350,id:"color",kind:2},{x:100,y:250,id:"color",kind:2},{x:50,y:250,id:"color",kind:2},{x:200,y:250,id:"color",kind:2},{x:200,y:300,id:"color",kind:2},{x:250,y:350,id:"color",kind:2},{x:300,y:350,id:"color",kind:2},{x:350,y:300,id:"color",kind:2},{x:300,y:250,id:"color",kind:2},{x:250,y:250,id:"color",
kind:2},{x:0,y:200,id:"color",kind:1},{x:50,y:150,id:"color",kind:1},{x:50,y:200,id:"color",kind:1},{x:100,y:150,id:"color",kind:1},{x:100,y:100,id:"color",kind:1},{x:150,y:50,id:"color",kind:1},{x:150,y:100,id:"color",kind:1},{x:350,y:250,id:"color",kind:1},{x:350,y:200,id:"color",kind:1},{x:350,y:150,id:"color",kind:1},{x:350,y:100,id:"color",kind:1},{x:350,y:50,id:"color",kind:1},{x:350,y:0,id:"color",kind:1},{x:150,y:300,id:"color",kind:1},{x:50,y:300,id:"color",kind:22},{x:100,y:300,id:"color",
kind:22},{x:250,y:300,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:200,y:0,id:"color",kind:1},{x:250,y:0,id:"color",kind:1},{x:250,y:50,id:"color",kind:1},{x:200,y:50,id:"color",kind:1},{x:250,y:100,id:"color",kind:1},{x:0,y:350,id:"color",kind:33},{x:150,y:350,id:"color",kind:33},{x:200,y:350,id:"color",kind:33},{x:350,y:350,id:"color",kind:33},{x:150,y:250,id:"color",kind:33},{x:150,y:200,id:"color",kind:33},{x:100,y:200,id:"color",kind:33},{x:150,y:150,id:"color",kind:33},{x:200,y:150,
id:"color",kind:33},{x:200,y:100,id:"color",kind:33},{x:200,y:200,id:"color",kind:33},{x:250,y:200,id:"color",kind:33},{x:250,y:150,id:"color",kind:33},{x:300,y:200,id:"color",kind:33},{x:300,y:150,id:"color",kind:33},{x:300,y:100,id:"color",kind:33},{x:300,y:50,id:"color",kind:33},{x:300,y:0,id:"color",kind:33},{x:150,y:0,id:"color",kind:33},{x:100,y:0,id:"color",kind:33},{x:100,y:50,id:"color",kind:33},{x:50,y:50,id:"color",kind:33},{x:50,y:0,id:"color",kind:33},{x:0,y:0,id:"color",kind:33},{x:0,
y:50,id:"color",kind:33},{x:0,y:100,id:"color",kind:33},{x:0,y:150,id:"color",kind:33},{x:50,y:100,id:"color",kind:33},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:250,id:"cell"},{x:350,
y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:0,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"}],name:{key:"glasses"}},lamp8x8:{width:400,height:400,items:[{x:0,y:250,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:0,y:150,id:"color",
kind:22},{x:50,y:150,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:300,y:0,id:"color",kind:26},{x:250,y:0,id:"color",kind:26},{x:200,y:0,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:300,y:50,id:"color",kind:26},{x:300,y:100,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:150,y:100,id:"color",kind:26},{x:150,y:150,id:"color",kind:26},{x:200,
y:150,id:"color",kind:26},{x:250,y:150,id:"color",kind:26},{x:300,y:150,id:"color",kind:26},{x:350,y:150,id:"color",kind:26},{x:350,y:100,id:"color",kind:26},{x:250,y:350,id:"color",kind:3},{x:200,y:350,id:"color",kind:3},{x:300,y:350,id:"color",kind:3},{x:0,y:350,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:100,y:300,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:200,y:250,id:"color",
kind:20},{x:200,y:300,id:"color",kind:20},{x:300,y:300,id:"color",kind:20},{x:350,y:300,id:"color",kind:20},{x:350,y:350,id:"color",kind:20},{x:350,y:250,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:300,y:200,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:0,
y:100,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:250,y:200,id:"color",kind:4},{x:250,y:250,id:"color",kind:4},{x:250,y:300,id:"color",kind:4},{x:50,y:250,id:"color",kind:27},{x:50,y:300,id:"color",kind:27},{x:50,y:350,id:"color",kind:27},{x:100,y:350,id:"color",kind:27},{x:150,y:350,id:"color",kind:27},{x:50,y:200,id:"color",kind:28},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},
{x:300,y:0,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:300,y:50,id:"cell"},{x:150,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:100,
y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:150,id:"cell"},{x:300,y:350,id:"cell"}],name:{key:"lamp"}},horse8x8:{width:400,height:400,items:[{x:0,y:250,id:"color",kind:4},{x:50,y:300,id:"color",kind:4},{x:50,y:250,id:"color",kind:4},{x:0,y:300,id:"color",kind:4},{x:100,y:250,id:"color",kind:4},{x:50,y:200,id:"color",kind:4},{x:100,y:150,id:"color",kind:4},{x:150,y:200,id:"color",kind:4},{x:100,y:200,id:"color",kind:4},{x:150,y:250,id:"color",kind:4},
{x:200,y:200,id:"color",kind:4},{x:200,y:150,id:"color",kind:4},{x:150,y:100,id:"color",kind:4},{x:200,y:100,id:"color",kind:4},{x:300,y:100,id:"color",kind:4},{x:250,y:100,id:"color",kind:4},{x:350,y:150,id:"color",kind:4},{x:350,y:300,id:"color",kind:4},{x:350,y:350,id:"color",kind:4},{x:350,y:250,id:"color",kind:4},{x:350,y:200,id:"color",kind:4},{x:300,y:200,id:"color",kind:4},{x:300,y:150,id:"color",kind:4},{x:250,y:200,id:"color",kind:4},{x:250,y:150,id:"color",kind:4},{x:250,y:250,id:"color",
kind:4},{x:300,y:250,id:"color",kind:4},{x:200,y:250,id:"color",kind:4},{x:300,y:300,id:"color",kind:4},{x:250,y:300,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:300,y:350,id:"color",kind:4},{x:200,y:50,id:"color",kind:4},{x:200,y:0,id:"color",kind:4},{x:150,y:50,id:"color",kind:3},{x:100,y:50,id:"color",kind:3},{x:50,y:100,id:"color",kind:3},{x:100,y:100,id:"color",kind:3},{x:50,y:150,id:"color",kind:3},{x:250,y:50,id:"color",kind:3},{x:300,y:50,id:"color",kind:3},{x:350,y:50,id:"color",
kind:3},{x:350,y:100,id:"color",kind:3},{x:150,y:300,id:"color",kind:3},{x:200,y:300,id:"color",kind:3},{x:200,y:350,id:"color",kind:3},{x:150,y:350,id:"color",kind:3},{x:150,y:150,id:"color",kind:1},{x:0,y:350,id:"color",kind:21},{x:50,y:350,id:"color",kind:21},{x:100,y:350,id:"color",kind:21},{x:100,y:300,id:"color",kind:21},{x:0,y:200,id:"color",kind:21},{x:0,y:150,id:"color",kind:21},{x:0,y:100,id:"color",kind:21},{x:0,y:50,id:"color",kind:21},{x:0,y:0,id:"color",kind:21},{x:50,y:0,id:"color",
kind:21},{x:50,y:50,id:"color",kind:21},{x:100,y:0,id:"color",kind:21},{x:150,y:0,id:"color",kind:21},{x:250,y:0,id:"color",kind:21},{x:300,y:0,id:"color",kind:21},{x:350,y:0,id:"color",kind:21},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:50,
id:"cell"},{x:350,y:100,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:250,y:350,id:"cell"},{x:150,y:150,id:"cell"},{x:350,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:150,id:"cell"}],name:{key:"horse"}},golf8x8:{width:400,height:400,items:[{x:100,y:300,id:"color",kind:26},{x:150,y:300,id:"color",kind:26},{x:150,y:350,id:"color",kind:26},{x:100,y:250,id:"color",kind:22},{x:150,y:250,
id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:100,y:200,id:"color",kind:23},{x:50,y:250,id:"color",kind:28},{x:0,y:250,id:"color",kind:28},{x:0,y:200,id:"color",kind:28},{x:50,y:200,id:"color",kind:28},{x:50,y:150,id:"color",kind:28},{x:0,y:150,id:"color",kind:28},{x:100,y:150,id:"color",kind:28},{x:150,y:150,id:"color",kind:28},{x:250,y:250,id:"color",kind:27},{x:250,y:200,id:"color",kind:27},{x:250,y:150,id:"color",kind:27},{x:300,y:50,id:"color",kind:27},{x:300,y:0,id:"color",kind:27},
{x:0,y:350,id:"color",kind:34},{x:50,y:350,id:"color",kind:34},{x:100,y:350,id:"color",kind:34},{x:200,y:350,id:"color",kind:34},{x:250,y:350,id:"color",kind:34},{x:300,y:350,id:"color",kind:34},{x:350,y:350,id:"color",kind:34},{x:200,y:150,id:"color",kind:28},{x:200,y:200,id:"color",kind:28},{x:200,y:250,id:"color",kind:28},{x:300,y:100,id:"color",kind:27},{x:300,y:150,id:"color",kind:27},{x:300,y:200,id:"color",kind:27},{x:350,y:0,id:"color",kind:27},{x:350,y:50,id:"color",kind:27},{x:0,y:300,id:"color",
kind:20},{x:50,y:300,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:250,y:300,id:"color",kind:20},{x:300,y:300,id:"color",kind:20},{x:350,y:300,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:350,y:250,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:200,
y:100,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:150,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:150,
y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:350,id:"cell"},
{x:300,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:0,y:350,id:"cell"}],name:{key:"golf"}},pizza8x8:{width:400,height:400,items:[{x:0,y:100,id:"color",kind:6},{x:50,y:0,id:"color",kind:6},{x:100,y:50,id:"color",kind:6},{x:150,y:50,id:"color",kind:6},{x:150,y:0,id:"color",kind:6},{x:200,y:0,id:"color",kind:6},{x:250,y:50,id:"color",kind:6},{x:250,y:0,id:"color",kind:6},{x:300,y:50,id:"color",kind:6},{x:350,y:50,id:"color",kind:6},{x:350,y:100,id:"color",kind:6},{x:0,y:50,id:"color",
kind:4},{x:50,y:50,id:"color",kind:4},{x:100,y:0,id:"color",kind:4},{x:200,y:50,id:"color",kind:4},{x:300,y:0,id:"color",kind:4},{x:50,y:100,id:"color",kind:26},{x:0,y:150,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:150,y:200,id:"color",kind:26},{x:200,y:350,id:"color",kind:26},{x:250,y:300,id:"color",kind:26},{x:300,y:250,id:"color",kind:26},{x:100,y:250,id:"color",kind:17},{x:50,y:250,id:"color",kind:17},{x:100,y:200,id:"color",kind:17},{x:100,y:150,id:"color",
kind:17},{x:150,y:250,id:"color",kind:17},{x:150,y:300,id:"color",kind:17},{x:200,y:300,id:"color",kind:17},{x:250,y:250,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:300,y:200,id:"color",kind:17},{x:300,y:150,id:"color",kind:17},{x:350,y:150,id:"color",kind:17},{x:50,y:150,id:"color",kind:13},{x:200,y:250,id:"color",kind:13},{x:100,y:300,id:"color",kind:13},{x:250,y:350,id:"color",kind:17},{x:250,y:150,id:"color",kind:13},{x:250,y:200,id:"color",kind:26},{x:50,y:300,id:"color",kind:17},
{x:50,y:350,id:"color",kind:17},{x:0,y:350,id:"color",kind:35},{x:0,y:300,id:"color",kind:35},{x:0,y:250,id:"color",kind:35},{x:0,y:200,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:100,y:350,id:"color",kind:35},{x:300,y:350,id:"color",kind:35},{x:300,y:300,id:"color",kind:35},{x:350,y:350,id:"color",kind:35},{x:350,y:300,id:"color",kind:35},{x:350,y:250,id:"color",kind:35},{x:350,y:200,id:"color",kind:35},{x:350,y:0,id:"color",kind:35},{x:150,y:350,id:"color",kind:17},{x:250,y:100,id:"color",
kind:26},{x:300,y:100,id:"color",kind:26},{x:150,y:100,id:"color",kind:26},{x:100,y:100,id:"color",kind:26},{x:150,y:150,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:0,y:150,id:"cell"},
{x:50,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:300,id:"cell"},{x:150,y:350,id:"cell"}],name:{key:"pizza"}},rain8x8:{width:400,height:400,items:[{x:0,y:100,id:"color",
kind:25},{x:50,y:100,id:"color",kind:25},{x:50,y:50,id:"color",kind:25},{x:100,y:50,id:"color",kind:25},{x:100,y:100,id:"color",kind:25},{x:150,y:100,id:"color",kind:25},{x:200,y:50,id:"color",kind:25},{x:250,y:0,id:"color",kind:25},{x:300,y:0,id:"color",kind:25},{x:300,y:50,id:"color",kind:25},{x:250,y:50,id:"color",kind:25},{x:200,y:100,id:"color",kind:25},{x:250,y:100,id:"color",kind:25},{x:300,y:100,id:"color",kind:25},{x:350,y:100,id:"color",kind:25},{x:350,y:50,id:"color",kind:25},{x:100,y:150,
id:"color",kind:25},{x:150,y:150,id:"color",kind:25},{x:200,y:150,id:"color",kind:25},{x:250,y:150,id:"color",kind:25},{x:50,y:150,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:0,y:350,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:150,y:0,id:"color",kind:24},{x:200,y:0,id:"color",kind:24},
{x:350,y:150,id:"color",kind:24},{x:350,y:200,id:"color",kind:24},{x:300,y:250,id:"color",kind:24},{x:350,y:300,id:"color",kind:24},{x:300,y:350,id:"color",kind:24},{x:250,y:250,id:"color",kind:24},{x:250,y:200,id:"color",kind:24},{x:200,y:200,id:"color",kind:24},{x:200,y:300,id:"color",kind:24},{x:200,y:350,id:"color",kind:24},{x:150,y:350,id:"color",kind:24},{x:150,y:300,id:"color",kind:24},{x:100,y:250,id:"color",kind:24},{x:100,y:200,id:"color",kind:24},{x:50,y:300,id:"color",kind:24},{x:50,y:250,
id:"color",kind:24},{x:0,y:200,id:"color",kind:24},{x:0,y:250,id:"color",kind:24},{x:50,y:350,id:"color",kind:24},{x:100,y:300,id:"color",kind:24},{x:200,y:250,id:"color",kind:24},{x:300,y:300,id:"color",kind:24},{x:350,y:250,id:"color",kind:24},{x:350,y:350,id:"color",kind:22},{x:100,y:350,id:"color",kind:22},{x:100,y:0,id:"color",kind:25},{x:50,y:0,id:"color",kind:25},{x:0,y:50,id:"color",kind:25},{x:350,y:0,id:"color",kind:25},{x:150,y:50,id:"color",kind:25},{x:0,y:0,id:"color",kind:24},{x:0,y:150,
id:"color",kind:24},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:150,y:200,id:"cell"},
{x:150,y:250,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:350,y:350,id:"cell"}],name:{key:"rain"}},toaster8x8:{width:400,height:400,items:[{x:50,y:300,id:"color",kind:27},{x:50,y:250,id:"color",kind:27},{x:50,y:200,id:"color",kind:27},{x:100,y:150,id:"color",kind:27},{x:150,y:150,id:"color",kind:27},{x:200,y:150,id:"color",kind:27},{x:250,y:150,id:"color",kind:27},{x:300,
y:200,id:"color",kind:27},{x:300,y:250,id:"color",kind:27},{x:300,y:300,id:"color",kind:27},{x:200,y:300,id:"color",kind:27},{x:100,y:300,id:"color",kind:27},{x:150,y:300,id:"color",kind:27},{x:250,y:300,id:"color",kind:27},{x:250,y:250,id:"color",kind:27},{x:250,y:200,id:"color",kind:27},{x:200,y:200,id:"color",kind:27},{x:200,y:250,id:"color",kind:27},{x:150,y:250,id:"color",kind:27},{x:150,y:200,id:"color",kind:27},{x:100,y:250,id:"color",kind:27},{x:100,y:200,id:"color",kind:27},{x:50,y:350,id:"color",
kind:28},{x:100,y:350,id:"color",kind:28},{x:150,y:350,id:"color",kind:28},{x:200,y:350,id:"color",kind:28},{x:250,y:350,id:"color",kind:28},{x:300,y:350,id:"color",kind:28},{x:350,y:250,id:"color",kind:28},{x:350,y:200,id:"color",kind:28},{x:0,y:350,id:"color",kind:28},{x:0,y:300,id:"color",kind:27},{x:0,y:250,id:"color",kind:27},{x:0,y:200,id:"color",kind:27},{x:50,y:150,id:"color",kind:27},{x:50,y:100,id:"color",kind:7},{x:200,y:50,id:"color",kind:7},{x:100,y:50,id:"color",kind:7},{x:50,y:50,id:"color",
kind:4},{x:100,y:0,id:"color",kind:4},{x:150,y:0,id:"color",kind:4},{x:200,y:0,id:"color",kind:4},{x:250,y:50,id:"color",kind:4},{x:100,y:100,id:"color",kind:6},{x:150,y:50,id:"color",kind:6},{x:250,y:100,id:"color",kind:6},{x:200,y:100,id:"color",kind:6},{x:150,y:100,id:"color",kind:7},{x:300,y:150,id:"color",kind:27},{x:0,y:150,id:"color",kind:27},{x:0,y:100,id:"color",kind:12},{x:0,y:50,id:"color",kind:12},{x:0,y:0,id:"color",kind:12},{x:50,y:0,id:"color",kind:12},{x:250,y:0,id:"color",kind:12},
{x:300,y:0,id:"color",kind:12},{x:300,y:50,id:"color",kind:12},{x:350,y:0,id:"color",kind:12},{x:350,y:50,id:"color",kind:12},{x:350,y:100,id:"color",kind:12},{x:300,y:100,id:"color",kind:12},{x:350,y:150,id:"color",kind:12},{x:350,y:300,id:"color",kind:12},{x:350,y:350,id:"color",kind:12},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:250,id:"cell"},
{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:200,id:"cell"}],
name:{key:"toaster"}},cheese8x8:{width:400,height:400,items:[{x:50,y:300,id:"color",kind:17},{x:100,y:250,id:"color",kind:17},{x:100,y:150,id:"color",kind:17},{x:100,y:200,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},{x:0,y:50,id:"color",kind:17},{x:100,y:50,id:"color",kind:17},{x:150,y:50,id:"color",kind:17},{x:50,y:100,id:"color",kind:17},{x:200,y:50,id:"color",kind:17},{x:250,y:50,id:"color",kind:17},{x:300,y:150,id:"color",kind:17},{x:300,y:200,id:"color",kind:17},{x:300,y:250,id:"color",
kind:17},{x:300,y:300,id:"color",kind:17},{x:200,y:300,id:"color",kind:17},{x:150,y:300,id:"color",kind:17},{x:0,y:0,id:"color",kind:8},{x:50,y:0,id:"color",kind:8},{x:100,y:0,id:"color",kind:8},{x:150,y:0,id:"color",kind:8},{x:200,y:0,id:"color",kind:8},{x:250,y:0,id:"color",kind:8},{x:300,y:50,id:"color",kind:8},{x:350,y:100,id:"color",kind:8},{x:350,y:150,id:"color",kind:8},{x:350,y:200,id:"color",kind:8},{x:350,y:250,id:"color",kind:8},{x:350,y:300,id:"color",kind:8},{x:300,y:350,id:"color",kind:8},
{x:250,y:350,id:"color",kind:8},{x:200,y:350,id:"color",kind:8},{x:150,y:350,id:"color",kind:8},{x:100,y:350,id:"color",kind:8},{x:50,y:350,id:"color",kind:8},{x:200,y:250,id:"color",kind:17},{x:150,y:200,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:250,y:250,id:"color",kind:17},{x:250,y:100,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:100,y:300,id:"color",kind:9},{x:150,y:250,id:"color",kind:9},{x:250,y:300,id:"color",kind:9},{x:200,y:200,id:"color",kind:9},{x:250,y:200,id:"color",
kind:9},{x:250,y:150,id:"color",kind:9},{x:200,y:150,id:"color",kind:9},{x:150,y:100,id:"color",kind:9},{x:50,y:50,id:"color",kind:9},{x:0,y:350,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:50,y:250,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:350,y:350,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,y:0,id:"color",
kind:20},{x:300,y:0,id:"color",kind:20},{x:300,y:100,id:"color",kind:9},{x:0,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:150,y:300,id:"cell"},
{x:100,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:300,y:300,id:"cell"}],name:{key:"cheese"}},goat8x8:{width:400,height:400,items:[{x:50,y:50,id:"color",kind:25},{x:50,y:0,id:"color",kind:25},{x:150,y:50,id:"color",kind:25},
{x:150,y:0,id:"color",kind:25},{x:50,y:100,id:"color",kind:4},{x:100,y:100,id:"color",kind:4},{x:0,y:100,id:"color",kind:4},{x:150,y:100,id:"color",kind:4},{x:200,y:100,id:"color",kind:4},{x:350,y:250,id:"color",kind:4},{x:350,y:300,id:"color",kind:4},{x:300,y:300,id:"color",kind:4},{x:50,y:200,id:"color",kind:4},{x:150,y:200,id:"color",kind:4},{x:100,y:150,id:"color",kind:4},{x:100,y:250,id:"color",kind:31},{x:100,y:200,id:"color",kind:4},{x:50,y:150,id:"color",kind:16},{x:150,y:150,id:"color",kind:16},
{x:50,y:350,id:"color",kind:20},{x:50,y:300,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:0,y:350,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:300,
y:100,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:200,y:200,id:"color",kind:3},{x:200,y:250,id:"color",kind:3},{x:300,y:350,id:"color",kind:4},{x:350,y:350,id:"color",kind:4},{x:100,y:300,id:"color",kind:4},{x:300,y:250,id:"color",kind:4},{x:350,y:200,id:"color",kind:4},{x:150,y:350,id:"color",kind:20},{x:250,y:200,id:"color",kind:3},{x:250,y:150,id:"color",kind:20},
{x:300,y:150,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:50,y:250,id:"color",kind:4},{x:150,y:250,id:"color",kind:4},{x:100,y:350,id:"color",kind:4},{x:250,y:250,id:"color",kind:3},{x:300,y:200,id:"color",kind:3},{x:200,y:150,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:200,y:350,id:"color",kind:20},{x:200,y:300,id:"color",kind:3},{x:250,y:300,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:50,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:150,y:50,id:"cell"},
{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:200,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:350,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:250,
y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:200,y:300,id:"cell"}],name:{key:"goat"}},iceskates8x8:{width:400,height:400,items:[{x:0,y:350,id:"color",kind:22},{x:50,y:350,id:"color",kind:22},{x:100,y:350,id:"color",kind:22},{x:150,y:350,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:350,y:350,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:200,y:350,id:"color",kind:22},{x:50,y:300,id:"color",kind:25},{x:100,y:300,id:"color",kind:25},{x:150,y:300,id:"color",
kind:25},{x:200,y:300,id:"color",kind:25},{x:250,y:300,id:"color",kind:25},{x:300,y:300,id:"color",kind:25},{x:350,y:250,id:"color",kind:25},{x:0,y:250,id:"color",kind:25},{x:100,y:250,id:"color",kind:25},{x:250,y:250,id:"color",kind:25},{x:50,y:200,id:"color",kind:3},{x:50,y:150,id:"color",kind:3},{x:100,y:200,id:"color",kind:3},{x:150,y:200,id:"color",kind:3},{x:200,y:200,id:"color",kind:3},{x:250,y:200,id:"color",kind:3},{x:300,y:200,id:"color",kind:3},{x:100,y:150,id:"color",kind:26},{x:100,y:100,
id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:250,y:150,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:300,y:150,id:"color",kind:26},{x:300,y:100,id:"color",kind:26},{x:300,y:50,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:250,y:0,id:"color",kind:26},{x:300,y:0,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},{x:100,y:50,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:200,y:0,id:"color",kind:26},{x:150,y:50,id:"color",kind:17},
{x:150,y:100,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:0,y:300,id:"color",kind:35},{x:50,y:250,id:"color",kind:35},{x:150,y:250,id:"color",kind:35},{x:200,y:250,id:"color",kind:35},{x:300,y:250,id:"color",kind:35},{x:350,y:300,id:"color",kind:35},{x:350,y:200,id:"color",kind:35},{x:350,y:150,id:"color",kind:35},{x:350,y:100,id:"color",kind:35},{x:350,y:50,id:"color",kind:35},{x:350,y:0,id:"color",kind:35},{x:0,y:200,id:"color",kind:35},{x:0,y:150,id:"color",kind:35},{x:0,y:100,id:"color",
kind:35},{x:0,y:50,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:50,y:50,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:100,y:0,id:"color",kind:35},{x:150,y:0,id:"color",kind:35},{x:0,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:250,
y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"}],name:{key:"ice_skate"}},microphone8x8:{width:400,
height:400,items:[{x:250,y:50,id:"color",kind:0},{x:250,y:100,id:"color",kind:0},{x:300,y:100,id:"color",kind:0},{x:350,y:150,id:"color",kind:0},{x:350,y:200,id:"color",kind:0},{x:350,y:250,id:"color",kind:0},{x:350,y:300,id:"color",kind:0},{x:300,y:350,id:"color",kind:0},{x:150,y:150,id:"color",kind:28},{x:150,y:200,id:"color",kind:28},{x:150,y:250,id:"color",kind:28},{x:150,y:300,id:"color",kind:28},{x:150,y:350,id:"color",kind:28},{x:100,y:100,id:"color",kind:0},{x:100,y:50,id:"color",kind:0},
{x:150,y:100,id:"color",kind:27},{x:150,y:50,id:"color",kind:27},{x:50,y:100,id:"color",kind:25},{x:50,y:50,id:"color",kind:25},{x:0,y:50,id:"color",kind:25},{x:0,y:100,id:"color",kind:25},{x:200,y:100,id:"color",kind:0},{x:200,y:50,id:"color",kind:0},{x:0,y:150,id:"color",kind:8},{x:50,y:150,id:"color",kind:8},{x:100,y:150,id:"color",kind:8},{x:100,y:200,id:"color",kind:8},{x:100,y:250,id:"color",kind:8},{x:100,y:300,id:"color",kind:8},{x:100,y:350,id:"color",kind:8},{x:50,y:350,id:"color",kind:8},
{x:50,y:300,id:"color",kind:8},{x:50,y:250,id:"color",kind:8},{x:50,y:200,id:"color",kind:8},{x:0,y:200,id:"color",kind:8},{x:0,y:250,id:"color",kind:8},{x:0,y:300,id:"color",kind:8},{x:0,y:350,id:"color",kind:8},{x:200,y:350,id:"color",kind:8},{x:250,y:350,id:"color",kind:8},{x:350,y:350,id:"color",kind:8},{x:300,y:300,id:"color",kind:8},{x:250,y:300,id:"color",kind:8},{x:200,y:250,id:"color",kind:8},{x:200,y:300,id:"color",kind:8},{x:250,y:250,id:"color",kind:8},{x:300,y:250,id:"color",kind:8},
{x:300,y:200,id:"color",kind:8},{x:250,y:200,id:"color",kind:8},{x:200,y:200,id:"color",kind:8},{x:200,y:150,id:"color",kind:8},{x:250,y:150,id:"color",kind:8},{x:300,y:150,id:"color",kind:8},{x:350,y:100,id:"color",kind:8},{x:300,y:50,id:"color",kind:8},{x:350,y:50,id:"color",kind:8},{x:350,y:0,id:"color",kind:8},{x:300,y:0,id:"color",kind:8},{x:250,y:0,id:"color",kind:8},{x:200,y:0,id:"color",kind:8},{x:150,y:0,id:"color",kind:8},{x:100,y:0,id:"color",kind:8},{x:50,y:0,id:"color",kind:8},{x:0,y:0,
id:"color",kind:8},{x:0,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,
id:"cell"}],name:{key:"microphone"}},wateringcan8x8:{width:400,height:400,items:[{x:300,y:100,id:"color",kind:15},{x:250,y:250,id:"color",kind:15},{x:300,y:200,id:"color",kind:15},{x:350,y:150,id:"color",kind:15},{x:250,y:0,id:"color",kind:15},{x:300,y:0,id:"color",kind:15},{x:300,y:50,id:"color",kind:15},{x:50,y:200,id:"color",kind:15},{x:50,y:250,id:"color",kind:15},{x:0,y:250,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:0,y:350,id:"color",kind:20},{x:100,y:200,id:"color",kind:15},{x:200,
y:300,id:"color",kind:15},{x:200,y:250,id:"color",kind:12},{x:200,y:200,id:"color",kind:12},{x:150,y:200,id:"color",kind:12},{x:200,y:150,id:"color",kind:12},{x:250,y:100,id:"color",kind:12},{x:300,y:150,id:"color",kind:12},{x:250,y:200,id:"color",kind:12},{x:250,y:150,id:"color",kind:12},{x:200,y:100,id:"color",kind:12},{x:150,y:150,id:"color",kind:12},{x:150,y:100,id:"color",kind:12},{x:150,y:50,id:"color",kind:12},{x:100,y:100,id:"color",kind:12},{x:200,y:50,id:"color",kind:12},{x:50,y:350,id:"color",
kind:22},{x:50,y:300,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:100,y:300,id:"color",kind:22},{x:100,y:350,id:"color",kind:22},{x:150,y:350,id:"color",kind:22},{x:150,y:300,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:200,y:350,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},{x:350,y:350,id:"color",kind:22},{x:350,y:300,id:"color",kind:22},
{x:350,y:250,id:"color",kind:22},{x:350,y:200,id:"color",kind:22},{x:350,y:100,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:350,y:0,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:200,y:0,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:100,y:50,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},
{x:0,y:200,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:0,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},
{x:300,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:50,id:"cell"}],name:{key:"watering_can"}},shuttle8x8:{width:400,height:400,items:[{x:0,y:300,id:"color",kind:0},{x:50,y:300,id:"color",kind:0},{x:100,y:350,id:"color",kind:0},{x:150,y:350,id:"color",kind:0},{x:200,y:350,id:"color",kind:0},
{x:250,y:350,id:"color",kind:0},{x:300,y:300,id:"color",kind:0},{x:350,y:300,id:"color",kind:0},{x:200,y:300,id:"color",kind:0},{x:0,y:250,id:"color",kind:23},{x:0,y:200,id:"color",kind:23},{x:100,y:300,id:"color",kind:23},{x:100,y:250,id:"color",kind:23},{x:100,y:200,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:100,y:100,id:"color",kind:23},{x:150,y:0,id:"color",kind:23},{x:350,y:200,id:"color",kind:23},{x:350,y:250,id:"color",kind:23},{x:150,y:250,id:"color",kind:23},{x:150,y:100,id:"color",
kind:23},{x:350,y:150,id:"color",kind:16},{x:300,y:100,id:"color",kind:16},{x:300,y:50,id:"color",kind:16},{x:300,y:0,id:"color",kind:16},{x:350,y:0,id:"color",kind:16},{x:100,y:0,id:"color",kind:16},{x:0,y:0,id:"color",kind:16},{x:0,y:50,id:"color",kind:16},{x:50,y:50,id:"color",kind:16},{x:50,y:100,id:"color",kind:16},{x:0,y:150,id:"color",kind:16},{x:50,y:150,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},{x:300,y:200,id:"color",
kind:22},{x:300,y:150,id:"color",kind:22},{x:150,y:50,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:0,y:100,id:"color",kind:17},{x:50,y:0,id:"color",kind:17},{x:350,y:50,id:"color",kind:17},{x:350,y:100,id:"color",kind:16},{x:200,y:250,id:"color",kind:23},{x:200,y:200,id:"color",kind:23},{x:200,y:150,id:"color",kind:23},{x:250,y:300,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:250,y:200,id:"color",kind:22},{x:250,y:150,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:250,
y:50,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:200,y:0,id:"color",kind:22},{x:50,y:350,id:"color",kind:26},{x:300,y:350,id:"color",kind:26},{x:350,y:350,id:"color",kind:16},{x:0,y:350,id:"color",kind:16},{x:150,y:200,id:"color",kind:27},{x:150,y:150,id:"color",kind:27},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:300,id:"cell"},{x:0,y:250,
id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:50,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:150,id:"cell"}],name:{key:"space_shuttle"}},door8x8:{width:400,
height:400,items:[{x:250,y:150,id:"color",kind:4},{x:300,y:150,id:"color",kind:4},{x:300,y:100,id:"color",kind:4},{x:300,y:50,id:"color",kind:4},{x:300,y:0,id:"color",kind:4},{x:250,y:0,id:"color",kind:4},{x:200,y:0,id:"color",kind:4},{x:150,y:0,id:"color",kind:4},{x:150,y:50,id:"color",kind:4},{x:150,y:100,id:"color",kind:4},{x:150,y:200,id:"color",kind:4},{x:150,y:250,id:"color",kind:4},{x:150,y:300,id:"color",kind:4},{x:200,y:300,id:"color",kind:4},{x:250,y:300,id:"color",kind:4},{x:300,y:300,
id:"color",kind:4},{x:300,y:250,id:"color",kind:4},{x:300,y:200,id:"color",kind:4},{x:200,y:200,id:"color",kind:6},{x:250,y:200,id:"color",kind:6},{x:250,y:250,id:"color",kind:6},{x:200,y:250,id:"color",kind:6},{x:200,y:100,id:"color",kind:6},{x:200,y:50,id:"color",kind:6},{x:250,y:50,id:"color",kind:6},{x:250,y:100,id:"color",kind:6},{x:0,y:350,id:"color",kind:24},{x:50,y:350,id:"color",kind:24},{x:100,y:350,id:"color",kind:24},{x:150,y:350,id:"color",kind:24},{x:200,y:350,id:"color",kind:24},{x:250,
y:350,id:"color",kind:24},{x:300,y:350,id:"color",kind:24},{x:350,y:350,id:"color",kind:24},{x:100,y:300,id:"color",kind:22},{x:50,y:300,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:50,y:100,id:"color",
kind:22},{x:50,y:50,id:"color",kind:22},{x:100,y:50,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:0,y:150,id:"color",kind:33},{x:0,y:100,id:"color",kind:33},{x:0,y:50,id:"color",kind:33},{x:150,y:150,id:"color",kind:3},{x:200,y:150,id:"color",kind:4},{x:350,y:300,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:350,y:200,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:350,y:100,id:"color",kind:22},{x:350,y:50,id:"color",
kind:22},{x:350,y:0,id:"color",kind:22},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:100,id:"cell"},{x:200,y:300,id:"cell"},
{x:250,y:300,id:"cell"},{x:300,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"}],name:{key:"door"}},bubblegum8x8:{width:400,height:400,items:[{x:250,y:250,id:"color",kind:7},{x:250,y:200,id:"color",kind:7},{x:250,y:150,id:"color",kind:7},{x:250,y:100,id:"color",kind:7},{x:250,y:50,id:"color",kind:7},{x:250,y:0,id:"color",kind:7},{x:200,y:100,id:"color",kind:7},{x:300,y:0,id:"color",kind:7},{x:300,y:50,id:"color",
kind:7},{x:300,y:100,id:"color",kind:7},{x:300,y:150,id:"color",kind:7},{x:300,y:200,id:"color",kind:7},{x:350,y:250,id:"color",kind:7},{x:300,y:250,id:"color",kind:7},{x:350,y:200,id:"color",kind:7},{x:350,y:150,id:"color",kind:7},{x:350,y:100,id:"color",kind:7},{x:350,y:50,id:"color",kind:7},{x:350,y:0,id:"color",kind:7},{x:350,y:300,id:"color",kind:7},{x:350,y:350,id:"color",kind:7},{x:200,y:200,id:"color",kind:31},{x:150,y:200,id:"color",kind:31},{x:150,y:150,id:"color",kind:31},{x:150,y:250,
id:"color",kind:31},{x:100,y:300,id:"color",kind:31},{x:100,y:250,id:"color",kind:31},{x:100,y:150,id:"color",kind:31},{x:100,y:100,id:"color",kind:31},{x:100,y:200,id:"color",kind:31},{x:50,y:300,id:"color",kind:31},{x:50,y:250,id:"color",kind:31},{x:50,y:200,id:"color",kind:31},{x:50,y:100,id:"color",kind:31},{x:0,y:150,id:"color",kind:31},{x:0,y:250,id:"color",kind:31},{x:0,y:200,id:"color",kind:31},{x:50,y:150,id:"color",kind:35},{x:0,y:100,id:"color",kind:10},{x:0,y:50,id:"color",kind:10},{x:0,
y:0,id:"color",kind:10},{x:50,y:0,id:"color",kind:10},{x:50,y:50,id:"color",kind:10},{x:100,y:50,id:"color",kind:10},{x:100,y:0,id:"color",kind:10},{x:150,y:0,id:"color",kind:10},{x:150,y:50,id:"color",kind:10},{x:150,y:100,id:"color",kind:10},{x:200,y:50,id:"color",kind:10},{x:200,y:0,id:"color",kind:10},{x:200,y:150,id:"color",kind:10},{x:200,y:250,id:"color",kind:10},{x:200,y:300,id:"color",kind:10},{x:150,y:300,id:"color",kind:10},{x:150,y:350,id:"color",kind:10},{x:100,y:350,id:"color",kind:10},
{x:50,y:350,id:"color",kind:10},{x:0,y:350,id:"color",kind:10},{x:0,y:300,id:"color",kind:10},{x:200,y:350,id:"color",kind:10},{x:250,y:350,id:"color",kind:10},{x:250,y:300,id:"color",kind:10},{x:300,y:300,id:"color",kind:10},{x:300,y:350,id:"color",kind:10},{x:350,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:300,
y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"}],name:{key:"bubblegum"}},shootingstar8x8:{width:400,height:400,items:[{x:50,y:300,id:"color",kind:17},{x:100,y:300,id:"color",kind:17},{x:100,
y:250,id:"color",kind:17},{x:0,y:350,id:"color",kind:21},{x:0,y:300,id:"color",kind:21},{x:0,y:250,id:"color",kind:21},{x:50,y:250,id:"color",kind:21},{x:50,y:350,id:"color",kind:21},{x:100,y:350,id:"color",kind:21},{x:150,y:300,id:"color",kind:21},{x:150,y:250,id:"color",kind:21},{x:100,y:200,id:"color",kind:21},{x:150,y:200,id:"color",kind:21},{x:150,y:150,id:"color",kind:21},{x:100,y:150,id:"color",kind:21},{x:50,y:200,id:"color",kind:21},{x:200,y:100,id:"color",kind:21},{x:200,y:150,id:"color",
kind:21},{x:150,y:100,id:"color",kind:21},{x:250,y:50,id:"color",kind:21},{x:300,y:0,id:"color",kind:21},{x:250,y:100,id:"color",kind:21},{x:300,y:50,id:"color",kind:21},{x:350,y:0,id:"color",kind:21},{x:250,y:250,id:"color",kind:21},{x:200,y:0,id:"color",kind:21},{x:0,y:200,id:"color",kind:1},{x:0,y:150,id:"color",kind:1},{x:0,y:100,id:"color",kind:1},{x:50,y:150,id:"color",kind:1},{x:0,y:50,id:"color",kind:1},{x:50,y:50,id:"color",kind:1},{x:50,y:0,id:"color",kind:1},{x:100,y:0,id:"color",kind:1},
{x:100,y:100,id:"color",kind:1},{x:150,y:50,id:"color",kind:1},{x:150,y:0,id:"color",kind:1},{x:200,y:50,id:"color",kind:1},{x:250,y:0,id:"color",kind:1},{x:350,y:100,id:"color",kind:1},{x:350,y:150,id:"color",kind:1},{x:300,y:150,id:"color",kind:1},{x:350,y:250,id:"color",kind:1},{x:300,y:250,id:"color",kind:1},{x:350,y:300,id:"color",kind:1},{x:350,y:350,id:"color",kind:1},{x:300,y:350,id:"color",kind:1},{x:200,y:350,id:"color",kind:1},{x:200,y:300,id:"color",kind:1},{x:250,y:300,id:"color",kind:1},
{x:200,y:250,id:"color",kind:1},{x:250,y:200,id:"color",kind:1},{x:300,y:200,id:"color",kind:1},{x:100,y:50,id:"color",kind:21},{x:50,y:100,id:"color",kind:21},{x:150,y:350,id:"color",kind:21},{x:350,y:50,id:"color",kind:21},{x:300,y:100,id:"color",kind:21},{x:250,y:150,id:"color",kind:21},{x:200,y:200,id:"color",kind:21},{x:250,y:350,id:"color",kind:21},{x:300,y:300,id:"color",kind:17},{x:350,y:200,id:"color",kind:17},{x:0,y:0,id:"color",kind:17},{x:0,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:0,
y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:50,y:300,id:"cell"},
{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:250,y:350,id:"cell"}],name:{key:"shooting_star"}},bell8x8:{width:400,height:400,items:[{x:100,y:300,id:"color",kind:3},{x:150,y:300,id:"color",kind:3},{x:200,y:300,id:"color",kind:3},{x:250,y:300,id:"color",kind:3},{x:50,y:350,id:"color",kind:4},{x:100,y:350,id:"color",kind:4},{x:150,
y:350,id:"color",kind:4},{x:200,y:350,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:300,y:350,id:"color",kind:4},{x:50,y:150,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:150,y:0,id:"color",kind:28},{x:200,y:0,id:"color",kind:28},{x:0,y:150,id:"color",kind:27},{x:0,y:200,id:"color",kind:27},{x:50,y:100,id:"color",kind:27},{x:100,y:50,id:"color",kind:27},{x:250,y:50,id:"color",kind:27},{x:200,y:50,id:"color",kind:27},{x:150,y:50,id:"color",kind:27},{x:250,y:100,id:"color",kind:27},
{x:300,y:100,id:"color",kind:27},{x:350,y:150,id:"color",kind:27},{x:350,y:200,id:"color",kind:27},{x:350,y:250,id:"color",kind:27},{x:300,y:250,id:"color",kind:27},{x:250,y:250,id:"color",kind:27},{x:200,y:250,id:"color",kind:27},{x:150,y:250,id:"color",kind:27},{x:100,y:250,id:"color",kind:27},{x:50,y:250,id:"color",kind:27},{x:0,y:250,id:"color",kind:27},{x:50,y:200,id:"color",kind:27},{x:100,y:200,id:"color",kind:27},{x:100,y:150,id:"color",kind:27},{x:150,y:100,id:"color",kind:27},{x:150,y:150,
id:"color",kind:27},{x:150,y:200,id:"color",kind:27},{x:200,y:200,id:"color",kind:27},{x:200,y:150,id:"color",kind:27},{x:200,y:100,id:"color",kind:27},{x:250,y:150,id:"color",kind:27},{x:250,y:200,id:"color",kind:27},{x:300,y:200,id:"color",kind:27},{x:300,y:150,id:"color",kind:27},{x:0,y:300,id:"color",kind:35},{x:50,y:300,id:"color",kind:35},{x:0,y:350,id:"color",kind:35},{x:300,y:300,id:"color",kind:35},{x:350,y:300,id:"color",kind:35},{x:350,y:350,id:"color",kind:35},{x:350,y:100,id:"color",
kind:35},{x:350,y:50,id:"color",kind:35},{x:300,y:50,id:"color",kind:35},{x:300,y:0,id:"color",kind:35},{x:350,y:0,id:"color",kind:35},{x:250,y:0,id:"color",kind:35},{x:100,y:0,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:0,y:50,id:"color",kind:35},{x:50,y:50,id:"color",kind:35},{x:0,y:100,id:"color",kind:35},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:250,y:300,
id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:150,
y:100,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:150,id:"cell"}],name:{key:"bell"}},winter8x8:{width:400,height:400,items:[{x:0,y:300,id:"color",kind:3},{x:0,y:250,id:"color",kind:3},{x:0,y:200,id:"color",kind:3},{x:0,y:150,id:"color",kind:3},{x:0,y:100,id:"color",kind:3},{x:50,y:50,id:"color",kind:3},{x:100,y:0,id:"color",kind:3},{x:50,y:150,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:150,y:100,
id:"color",kind:3},{x:50,y:300,id:"color",kind:24},{x:50,y:250,id:"color",kind:24},{x:50,y:200,id:"color",kind:24},{x:0,y:0,id:"color",kind:24},{x:100,y:50,id:"color",kind:24},{x:150,y:0,id:"color",kind:24},{x:200,y:0,id:"color",kind:24},{x:200,y:50,id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:300,y:0,id:"color",kind:24},{x:300,y:50,id:"color",kind:24},{x:350,y:0,id:"color",kind:24},{x:350,y:50,id:"color",kind:24},{x:250,y:50,id:"color",kind:24},{x:200,y:100,id:"color",kind:24},{x:350,y:100,
id:"color",kind:24},{x:200,y:150,id:"color",kind:24},{x:150,y:150,id:"color",kind:24},{x:150,y:200,id:"color",kind:24},{x:100,y:250,id:"color",kind:24},{x:100,y:200,id:"color",kind:24},{x:150,y:250,id:"color",kind:24},{x:150,y:300,id:"color",kind:24},{x:100,y:300,id:"color",kind:24},{x:200,y:200,id:"color",kind:24},{x:350,y:200,id:"color",kind:24},{x:350,y:150,id:"color",kind:8},{x:300,y:200,id:"color",kind:0},{x:300,y:300,id:"color",kind:0},{x:0,y:350,id:"color",kind:23},{x:50,y:350,id:"color",kind:23},
{x:100,y:350,id:"color",kind:23},{x:150,y:350,id:"color",kind:23},{x:200,y:350,id:"color",kind:23},{x:250,y:350,id:"color",kind:23},{x:300,y:350,id:"color",kind:23},{x:350,y:350,id:"color",kind:23},{x:50,y:100,id:"color",kind:23},{x:100,y:100,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:50,y:0,id:"color",kind:23},{x:0,y:50,id:"color",kind:23},{x:200,y:300,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:250,y:300,id:"color",kind:23},{x:250,y:250,id:"color",kind:23},{x:300,y:250,id:"color",
kind:23},{x:350,y:250,id:"color",kind:23},{x:350,y:300,id:"color",kind:23},{x:250,y:200,id:"color",kind:23},{x:250,y:150,id:"color",kind:23},{x:300,y:150,id:"color",kind:23},{x:300,y:100,id:"color",kind:23},{x:250,y:100,id:"color",kind:23},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:100,
id:"cell"},{x:50,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:250,id:"cell"}],
name:{key:"winter"}},spring8x8:{width:400,height:400,items:[{x:0,y:300,id:"color",kind:3},{x:0,y:250,id:"color",kind:3},{x:0,y:200,id:"color",kind:3},{x:0,y:150,id:"color",kind:3},{x:0,y:100,id:"color",kind:3},{x:50,y:50,id:"color",kind:3},{x:100,y:0,id:"color",kind:3},{x:50,y:150,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:150,y:100,id:"color",kind:3},{x:50,y:100,id:"color",kind:31},{x:50,y:200,id:"color",kind:31},{x:150,y:150,id:"color",kind:31},{x:150,y:50,id:"color",kind:31},{x:200,
y:100,id:"color",kind:31},{x:100,y:50,id:"color",kind:31},{x:150,y:0,id:"color",kind:31},{x:50,y:0,id:"color",kind:31},{x:0,y:50,id:"color",kind:31},{x:0,y:350,id:"color",kind:34},{x:50,y:350,id:"color",kind:34},{x:100,y:350,id:"color",kind:34},{x:200,y:350,id:"color",kind:34},{x:150,y:350,id:"color",kind:34},{x:250,y:350,id:"color",kind:34},{x:300,y:350,id:"color",kind:34},{x:350,y:350,id:"color",kind:34},{x:300,y:300,id:"color",kind:34},{x:250,y:300,id:"color",kind:34},{x:200,y:300,id:"color",kind:34},
{x:50,y:300,id:"color",kind:34},{x:150,y:300,id:"color",kind:33},{x:150,y:250,id:"color",kind:33},{x:350,y:300,id:"color",kind:33},{x:250,y:250,id:"color",kind:33},{x:250,y:200,id:"color",kind:33},{x:150,y:200,id:"color",kind:30},{x:350,y:250,id:"color",kind:26},{x:250,y:150,id:"color",kind:32},{x:50,y:250,id:"color",kind:20},{x:100,y:300,id:"color",kind:20},{x:100,y:250,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:200,y:50,
id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:300,y:100,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:300,y:150,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:300,y:200,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},
{x:200,y:250,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:50,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,
id:"cell"},{x:250,y:150,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:50,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:100,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:350,id:"cell"}],name:{key:"spring"}},summer8x8:{width:400,height:400,items:[{x:0,y:300,
id:"color",kind:3},{x:0,y:250,id:"color",kind:3},{x:0,y:200,id:"color",kind:3},{x:0,y:150,id:"color",kind:3},{x:0,y:100,id:"color",kind:3},{x:50,y:50,id:"color",kind:3},{x:100,y:0,id:"color",kind:3},{x:50,y:150,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:150,y:100,id:"color",kind:3},{x:100,y:200,id:"color",kind:13},{x:100,y:100,id:"color",kind:13},{x:50,y:100,id:"color",kind:13},{x:0,y:50,id:"color",kind:13},{x:50,y:0,id:"color",kind:13},{x:100,y:50,id:"color",kind:13},{x:150,y:150,id:"color",
kind:13},{x:200,y:50,id:"color",kind:13},{x:200,y:100,id:"color",kind:13},{x:150,y:0,id:"color",kind:13},{x:0,y:350,id:"color",kind:14},{x:50,y:350,id:"color",kind:14},{x:100,y:350,id:"color",kind:14},{x:50,y:300,id:"color",kind:14},{x:100,y:300,id:"color",kind:14},{x:150,y:350,id:"color",kind:14},{x:200,y:350,id:"color",kind:14},{x:250,y:350,id:"color",kind:14},{x:300,y:350,id:"color",kind:14},{x:350,y:350,id:"color",kind:14},{x:350,y:300,id:"color",kind:14},{x:300,y:300,id:"color",kind:14},{x:50,
y:200,id:"color",kind:13},{x:300,y:50,id:"color",kind:17},{x:300,y:100,id:"color",kind:17},{x:350,y:100,id:"color",kind:17},{x:350,y:50,id:"color",kind:17},{x:0,y:0,id:"color",kind:21},{x:150,y:50,id:"color",kind:21},{x:200,y:0,id:"color",kind:21},{x:250,y:0,id:"color",kind:21},{x:250,y:50,id:"color",kind:21},{x:300,y:0,id:"color",kind:21},{x:350,y:0,id:"color",kind:21},{x:350,y:150,id:"color",kind:21},{x:300,y:150,id:"color",kind:21},{x:250,y:100,id:"color",kind:21},{x:250,y:150,id:"color",kind:21},
{x:200,y:150,id:"color",kind:21},{x:200,y:200,id:"color",kind:21},{x:150,y:200,id:"color",kind:21},{x:150,y:250,id:"color",kind:21},{x:100,y:250,id:"color",kind:21},{x:50,y:250,id:"color",kind:21},{x:150,y:300,id:"color",kind:21},{x:200,y:300,id:"color",kind:21},{x:250,y:300,id:"color",kind:21},{x:200,y:250,id:"color",kind:21},{x:250,y:250,id:"color",kind:21},{x:250,y:200,id:"color",kind:21},{x:300,y:200,id:"color",kind:21},{x:300,y:250,id:"color",kind:21},{x:350,y:250,id:"color",kind:21},{x:350,
y:200,id:"color",kind:21},{x:300,y:100,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:300,y:50,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:300,id:"cell"},
{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:50,id:"cell"}],name:{key:"summer"}},autumn8x8:{width:400,height:400,items:[{x:0,y:300,id:"color",kind:3},{x:0,y:250,id:"color",kind:3},{x:0,y:200,id:"color",kind:3},{x:0,y:150,id:"color",kind:3},{x:0,y:100,id:"color",kind:3},{x:50,y:50,id:"color",kind:3},{x:100,y:0,id:"color",kind:3},{x:50,y:150,id:"color",
kind:3},{x:100,y:150,id:"color",kind:3},{x:150,y:100,id:"color",kind:3},{x:0,y:50,id:"color",kind:26},{x:50,y:0,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},{x:100,y:100,id:"color",kind:26},{x:100,y:50,id:"color",kind:26},{x:150,y:0,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:150,y:150,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:0,y:350,id:"color",kind:17},{x:50,y:300,id:"color",kind:17},{x:150,y:350,id:"color",kind:17},{x:250,y:350,id:"color",
kind:17},{x:300,y:350,id:"color",kind:17},{x:350,y:300,id:"color",kind:17},{x:100,y:350,id:"color",kind:8},{x:100,y:300,id:"color",kind:8},{x:200,y:350,id:"color",kind:8},{x:350,y:350,id:"color",kind:8},{x:0,y:0,id:"color",kind:24},{x:50,y:250,id:"color",kind:24},{x:100,y:250,id:"color",kind:24},{x:100,y:200,id:"color",kind:24},{x:150,y:50,id:"color",kind:24},{x:150,y:200,id:"color",kind:24},{x:150,y:250,id:"color",kind:24},{x:150,y:300,id:"color",kind:24},{x:200,y:250,id:"color",kind:24},{x:200,
y:200,id:"color",kind:24},{x:200,y:150,id:"color",kind:24},{x:200,y:0,id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:250,y:50,id:"color",kind:24},{x:250,y:100,id:"color",kind:24},{x:250,y:150,id:"color",kind:24},{x:250,y:250,id:"color",kind:24},{x:250,y:300,id:"color",kind:24},{x:350,y:250,id:"color",kind:24},{x:350,y:150,id:"color",kind:24},{x:350,y:100,id:"color",kind:24},{x:350,y:50,id:"color",kind:24},{x:300,y:50,id:"color",kind:24},{x:300,y:0,id:"color",kind:24},{x:350,y:0,id:"color",
kind:24},{x:200,y:300,id:"color",kind:26},{x:300,y:300,id:"color",kind:26},{x:50,y:350,id:"color",kind:26},{x:300,y:250,id:"color",kind:24},{x:350,y:200,id:"color",kind:24},{x:300,y:200,id:"color",kind:24},{x:250,y:200,id:"color",kind:24},{x:300,y:150,id:"color",kind:24},{x:300,y:100,id:"color",kind:24},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},
{x:100,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:250,y:350,id:"cell"}],name:{key:"autumn"}},donut8x8:{width:400,height:400,items:[{x:50,y:150,id:"color",kind:33},{x:250,y:250,id:"color",kind:33},{x:200,y:0,id:"color",kind:17},{x:0,y:200,id:"color",
kind:17},{x:350,y:150,id:"color",kind:17},{x:100,y:0,id:"color",kind:20},{x:100,y:250,id:"color",kind:20},{x:300,y:100,id:"color",kind:20},{x:50,y:50,id:"color",kind:26},{x:300,y:200,id:"color",kind:26},{x:100,y:200,id:"color",kind:31},{x:50,y:200,id:"color",kind:31},{x:50,y:250,id:"color",kind:31},{x:100,y:150,id:"color",kind:31},{x:100,y:100,id:"color",kind:31},{x:100,y:50,id:"color",kind:31},{x:50,y:100,id:"color",kind:31},{x:0,y:100,id:"color",kind:31},{x:0,y:150,id:"color",kind:31},{x:150,y:50,
id:"color",kind:31},{x:150,y:0,id:"color",kind:31},{x:200,y:50,id:"color",kind:31},{x:250,y:50,id:"color",kind:31},{x:250,y:0,id:"color",kind:31},{x:250,y:100,id:"color",kind:31},{x:300,y:50,id:"color",kind:31},{x:250,y:150,id:"color",kind:31},{x:250,y:200,id:"color",kind:31},{x:300,y:150,id:"color",kind:31},{x:350,y:100,id:"color",kind:31},{x:350,y:200,id:"color",kind:31},{x:200,y:250,id:"color",kind:31},{x:150,y:250,id:"color",kind:31},{x:200,y:300,id:"color",kind:31},{x:200,y:100,id:"color",kind:6},
{x:50,y:300,id:"color",kind:7},{x:0,y:250,id:"color",kind:7},{x:100,y:350,id:"color",kind:7},{x:150,y:300,id:"color",kind:7},{x:100,y:300,id:"color",kind:31},{x:150,y:350,id:"color",kind:7},{x:250,y:350,id:"color",kind:7},{x:300,y:300,id:"color",kind:7},{x:350,y:250,id:"color",kind:7},{x:150,y:100,id:"color",kind:6},{x:200,y:350,id:"color",kind:31},{x:300,y:250,id:"color",kind:31},{x:250,y:300,id:"color",kind:31},{x:50,y:350,id:"color",kind:35},{x:0,y:350,id:"color",kind:35},{x:0,y:300,id:"color",
kind:35},{x:300,y:350,id:"color",kind:35},{x:350,y:350,id:"color",kind:35},{x:350,y:300,id:"color",kind:35},{x:200,y:200,id:"color",kind:35},{x:200,y:150,id:"color",kind:35},{x:150,y:150,id:"color",kind:35},{x:150,y:200,id:"color",kind:35},{x:0,y:50,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:300,y:0,id:"color",kind:35},{x:350,y:0,id:"color",kind:35},{x:350,y:50,id:"color",kind:35},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,
y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:150,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:100,id:"cell"},
{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:250,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:300,y:150,id:"cell"},{x:200,y:50,id:"cell"},{x:50,y:250,id:"cell"},{x:200,y:350,id:"cell"}],name:{key:"sprinkled_donut"}},santa8x8:{width:400,height:400,items:[{x:100,y:200,id:"color",kind:7},{x:150,y:200,id:"color",kind:7},{x:200,y:200,id:"color",kind:7},{x:100,y:150,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:200,y:150,
id:"color",kind:22},{x:250,y:150,id:"color",kind:22},{x:150,y:300,id:"color",kind:7},{x:200,y:300,id:"color",kind:7},{x:100,y:250,id:"color",kind:23},{x:150,y:250,id:"color",kind:23},{x:200,y:250,id:"color",kind:23},{x:250,y:250,id:"color",kind:23},{x:200,y:350,id:"color",kind:22},{x:150,y:350,id:"color",kind:23},{x:100,y:300,id:"color",kind:23},{x:50,y:150,id:"color",kind:23},{x:50,y:200,id:"color",kind:23},{x:50,y:300,id:"color",kind:23},{x:50,y:250,id:"color",kind:23},{x:300,y:250,id:"color",kind:23},
{x:300,y:200,id:"color",kind:23},{x:100,y:100,id:"color",kind:26},{x:150,y:100,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:150,y:50,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:200,y:0,id:"color",kind:26},{x:250,y:0,id:"color",kind:26},{x:300,y:0,id:"color",kind:26},{x:350,y:0,id:"color",kind:23},{x:300,y:50,id:"color",kind:23},{x:350,y:50,id:"color",kind:22},{x:0,y:250,id:"color",kind:13},{x:0,y:200,id:"color",
kind:13},{x:0,y:150,id:"color",kind:13},{x:0,y:100,id:"color",kind:13},{x:0,y:50,id:"color",kind:13},{x:0,y:0,id:"color",kind:13},{x:50,y:0,id:"color",kind:13},{x:50,y:50,id:"color",kind:13},{x:50,y:100,id:"color",kind:13},{x:100,y:50,id:"color",kind:13},{x:100,y:0,id:"color",kind:13},{x:150,y:0,id:"color",kind:13},{x:300,y:100,id:"color",kind:13},{x:350,y:100,id:"color",kind:13},{x:350,y:150,id:"color",kind:13},{x:350,y:200,id:"color",kind:13},{x:350,y:250,id:"color",kind:13},{x:300,y:350,id:"color",
kind:26},{x:350,y:300,id:"color",kind:26},{x:350,y:350,id:"color",kind:26},{x:0,y:300,id:"color",kind:26},{x:0,y:350,id:"color",kind:26},{x:50,y:350,id:"color",kind:26},{x:100,y:350,id:"color",kind:23},{x:250,y:350,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:250,y:300,id:"color",kind:23},{x:250,y:200,id:"color",kind:7},{x:100,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,
y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:100,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,
id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:300,y:50,id:"cell"}],name:{key:"santa"}},hedgehog8x8:{width:400,height:400,items:[{x:50,y:250,id:"color",kind:7},{x:100,y:250,id:"color",kind:7},{x:150,y:200,id:"color",kind:7},{x:150,y:250,id:"color",kind:7},{x:200,y:250,id:"color",kind:7},{x:300,y:250,id:"color",kind:7},{x:350,y:200,id:"color",kind:7},{x:350,y:250,id:"color",kind:7},{x:100,y:200,id:"color",kind:0},{x:0,y:250,id:"color",kind:7},
{x:0,y:200,id:"color",kind:3},{x:200,y:200,id:"color",kind:3},{x:250,y:250,id:"color",kind:3},{x:300,y:200,id:"color",kind:3},{x:250,y:150,id:"color",kind:3},{x:300,y:100,id:"color",kind:3},{x:350,y:150,id:"color",kind:3},{x:350,y:100,id:"color",kind:3},{x:150,y:300,id:"color",kind:7},{x:200,y:300,id:"color",kind:7},{x:250,y:300,id:"color",kind:7},{x:300,y:300,id:"color",kind:7},{x:350,y:300,id:"color",kind:7},{x:150,y:50,id:"color",kind:4},{x:150,y:100,id:"color",kind:4},{x:250,y:100,id:"color",
kind:4},{x:100,y:150,id:"color",kind:4},{x:250,y:50,id:"color",kind:4},{x:300,y:150,id:"color",kind:4},{x:350,y:50,id:"color",kind:4},{x:150,y:150,id:"color",kind:3},{x:250,y:200,id:"color",kind:3},{x:200,y:100,id:"color",kind:4},{x:200,y:150,id:"color",kind:4},{x:150,y:350,id:"color",kind:4},{x:350,y:350,id:"color",kind:4},{x:100,y:300,id:"color",kind:7},{x:50,y:300,id:"color",kind:7},{x:300,y:50,id:"color",kind:3},{x:300,y:0,id:"color",kind:3},{x:350,y:0,id:"color",kind:3},{x:200,y:50,id:"color",
kind:3},{x:100,y:0,id:"color",kind:4},{x:100,y:100,id:"color",kind:4},{x:200,y:0,id:"color",kind:4},{x:0,y:300,id:"color",kind:13},{x:100,y:350,id:"color",kind:13},{x:250,y:350,id:"color",kind:13},{x:300,y:350,id:"color",kind:13},{x:0,y:350,id:"color",kind:14},{x:50,y:350,id:"color",kind:14},{x:200,y:350,id:"color",kind:14},{x:50,y:200,id:"color",kind:14},{x:0,y:150,id:"color",kind:14},{x:50,y:100,id:"color",kind:14},{x:0,y:50,id:"color",kind:14},{x:50,y:150,id:"color",kind:13},{x:0,y:100,id:"color",
kind:13},{x:50,y:50,id:"color",kind:13},{x:100,y:50,id:"color",kind:13},{x:50,y:0,id:"color",kind:13},{x:0,y:0,id:"color",kind:13},{x:150,y:0,id:"color",kind:13},{x:250,y:0,id:"color",kind:13},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:100,
y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:250,id:"cell"}],name:{key:"hedgehog"}},clouds8x8:{width:400,height:400,items:[{x:0,y:250,id:"color",kind:20},{x:50,y:250,id:"color",
kind:20},{x:100,y:300,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:50,y:300,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:0,y:350,id:"color",kind:20},{x:50,y:350,id:"color",kind:20},{x:150,y:350,id:"color",kind:20},{x:200,y:350,id:"color",kind:20},{x:100,y:350,id:"color",kind:20},{x:250,y:300,id:"color",kind:20},{x:300,y:300,id:"color",kind:20},{x:350,y:300,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:300,y:200,id:"color",kind:20},{x:300,
y:250,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:350,y:250,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:250,
y:0,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:0,y:150,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:200,y:200,id:"color",kind:22},{x:250,y:200,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:0,y:100,id:"color",kind:23},{x:50,y:100,id:"color",
kind:23},{x:50,y:50,id:"color",kind:23},{x:50,y:150,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:100,y:100,id:"color",kind:23},{x:100,y:50,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:150,y:100,id:"color",kind:23},{x:150,y:150,id:"color",kind:23},{x:200,y:150,id:"color",kind:23},{x:200,y:100,id:"color",kind:23},{x:250,y:150,id:"color",kind:23},{x:300,y:100,id:"color",kind:23},{x:250,y:350,id:"color",kind:23},{x:300,y:350,id:"color",kind:23},{x:350,y:350,id:"color",kind:23},{x:0,
y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,
id:"cell"},{x:50,y:150,id:"cell"}],name:{key:"clouds"}},boot8x8:{width:400,height:400,items:[{x:0,y:50,id:"color",kind:12},{x:0,y:100,id:"color",kind:12},{x:50,y:100,id:"color",kind:12},{x:50,y:50,id:"color",kind:12},{x:100,y:50,id:"color",kind:12},{x:50,y:150,id:"color",kind:12},{x:50,y:200,id:"color",kind:12},{x:50,y:250,id:"color",kind:12},{x:50,y:300,id:"color",kind:12},{x:100,y:300,id:"color",kind:12},{x:100,y:150,id:"color",kind:12},{x:150,y:250,id:"color",kind:12},{x:100,y:250,id:"color",kind:12},
{x:250,y:250,id:"color",kind:12},{x:250,y:200,id:"color",kind:12},{x:300,y:250,id:"color",kind:12},{x:350,y:250,id:"color",kind:12},{x:300,y:200,id:"color",kind:12},{x:350,y:300,id:"color",kind:12},{x:300,y:300,id:"color",kind:12},{x:150,y:300,id:"color",kind:12},{x:200,y:300,id:"color",kind:12},{x:250,y:300,id:"color",kind:12},{x:200,y:250,id:"color",kind:12},{x:50,y:350,id:"color",kind:15},{x:100,y:350,id:"color",kind:15},{x:200,y:350,id:"color",kind:15},{x:250,y:350,id:"color",kind:15},{x:300,
y:350,id:"color",kind:15},{x:350,y:350,id:"color",kind:15},{x:100,y:200,id:"color",kind:15},{x:100,y:100,id:"color",kind:15},{x:50,y:0,id:"color",kind:12},{x:0,y:0,id:"color",kind:12},{x:0,y:150,id:"color",kind:12},{x:0,y:200,id:"color",kind:12},{x:0,y:250,id:"color",kind:12},{x:0,y:300,id:"color",kind:12},{x:0,y:350,id:"color",kind:15},{x:200,y:200,id:"color",kind:12},{x:100,y:0,id:"color",kind:15},{x:150,y:350,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},
{x:150,y:100,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:200,y:0,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},{x:250,y:150,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:300,y:100,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:350,y:0,id:"color",
kind:22},{x:350,y:100,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:350,y:200,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:0,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:0,y:250,
id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:100,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:100,id:"cell"},{x:300,y:300,id:"cell"}],name:{key:"boot"}},scissors8x8:{width:400,height:400,items:[{x:0,y:200,id:"color",kind:27},{x:0,y:250,id:"color",kind:27},{x:50,y:200,id:"color",kind:27},{x:50,y:300,id:"color",kind:27},{x:100,y:250,id:"color",kind:27},
{x:0,y:300,id:"color",kind:27},{x:150,y:300,id:"color",kind:28},{x:150,y:250,id:"color",kind:28},{x:200,y:250,id:"color",kind:28},{x:150,y:350,id:"color",kind:28},{x:200,y:350,id:"color",kind:28},{x:250,y:300,id:"color",kind:28},{x:150,y:200,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:100,y:50,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:200,y:200,id:"color",kind:23},{x:250,y:150,
id:"color",kind:23},{x:300,y:100,id:"color",kind:23},{x:350,y:50,id:"color",kind:23},{x:300,y:150,id:"color",kind:23},{x:350,y:100,id:"color",kind:23},{x:0,y:350,id:"color",kind:26},{x:50,y:350,id:"color",kind:26},{x:100,y:350,id:"color",kind:26},{x:50,y:250,id:"color",kind:26},{x:100,y:150,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},{x:50,y:50,id:"color",kind:26},{x:100,y:0,id:"color",kind:26},{x:50,y:0,id:"color",kind:26},{x:0,y:0,id:"color",kind:26},{x:0,
y:50,id:"color",kind:26},{x:0,y:100,id:"color",kind:26},{x:0,y:150,id:"color",kind:26},{x:200,y:300,id:"color",kind:26},{x:300,y:350,id:"color",kind:26},{x:350,y:350,id:"color",kind:26},{x:350,y:300,id:"color",kind:26},{x:300,y:300,id:"color",kind:26},{x:300,y:250,id:"color",kind:26},{x:350,y:250,id:"color",kind:26},{x:350,y:200,id:"color",kind:26},{x:300,y:200,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:200,y:0,id:"color",
kind:26},{x:250,y:0,id:"color",kind:26},{x:250,y:50,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:300,y:50,id:"color",kind:26},{x:300,y:0,id:"color",kind:26},{x:350,y:0,id:"color",kind:26},{x:100,y:200,id:"color",kind:27},{x:250,y:350,id:"color",kind:28},{x:350,y:150,id:"color",kind:23},{x:100,y:300,id:"color",kind:27},{x:250,y:250,id:"color",kind:26},{x:50,y:300,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:150,
y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:200,id:"cell"},{x:250,y:350,
id:"cell"},{x:350,y:150,id:"cell"},{x:100,y:300,id:"cell"}],name:{key:"scissors"}},chocolate8x8:{width:400,height:400,items:[{x:50,y:200,id:"color",kind:3},{x:50,y:150,id:"color",kind:3},{x:100,y:100,id:"color",kind:3},{x:150,y:50,id:"color",kind:3},{x:150,y:100,id:"color",kind:3},{x:100,y:150,id:"color",kind:3},{x:150,y:150,id:"color",kind:3},{x:150,y:0,id:"color",kind:3},{x:100,y:200,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:50,y:250,id:"color",kind:26},{x:100,y:250,id:"color",kind:26},
{x:150,y:250,id:"color",kind:26},{x:50,y:350,id:"color",kind:26},{x:50,y:100,id:"color",kind:3},{x:200,y:0,id:"color",kind:3},{x:200,y:50,id:"color",kind:3},{x:200,y:100,id:"color",kind:3},{x:200,y:200,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},{x:200,y:250,id:"color",kind:26},{x:200,y:300,id:"color",kind:26},{x:200,y:350,id:"color",kind:26},{x:300,y:150,id:"color",kind:3},{x:350,y:350,id:"color",kind:3},{x:300,y:350,id:"color",kind:3},{x:0,y:0,id:"color",kind:3},{x:0,y:350,id:"color",kind:17},
{x:0,y:300,id:"color",kind:17},{x:0,y:250,id:"color",kind:17},{x:0,y:200,id:"color",kind:17},{x:0,y:150,id:"color",kind:17},{x:0,y:100,id:"color",kind:17},{x:0,y:50,id:"color",kind:17},{x:50,y:50,id:"color",kind:17},{x:50,y:0,id:"color",kind:17},{x:100,y:0,id:"color",kind:17},{x:250,y:0,id:"color",kind:17},{x:250,y:50,id:"color",kind:17},{x:300,y:0,id:"color",kind:17},{x:300,y:50,id:"color",kind:17},{x:350,y:0,id:"color",kind:17},{x:350,y:50,id:"color",kind:17},{x:250,y:100,id:"color",kind:17},{x:300,
y:100,id:"color",kind:17},{x:350,y:100,id:"color",kind:17},{x:350,y:150,id:"color",kind:17},{x:350,y:200,id:"color",kind:17},{x:300,y:200,id:"color",kind:17},{x:250,y:200,id:"color",kind:17},{x:250,y:150,id:"color",kind:17},{x:250,y:250,id:"color",kind:17},{x:300,y:250,id:"color",kind:17},{x:300,y:300,id:"color",kind:17},{x:350,y:300,id:"color",kind:17},{x:350,y:250,id:"color",kind:17},{x:250,y:300,id:"color",kind:17},{x:250,y:350,id:"color",kind:17},{x:50,y:300,id:"color",kind:26},{x:100,y:300,id:"color",
kind:26},{x:150,y:300,id:"color",kind:26},{x:150,y:350,id:"color",kind:26},{x:100,y:350,id:"color",kind:26},{x:100,y:50,id:"color",kind:3},{x:50,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:50,
y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:0,y:0,id:"cell"},{x:100,y:50,id:"cell"}],name:{key:"chocolate_bar"}},magnifier8x8:{width:400,height:400,items:[{x:150,y:50,id:"color",kind:27},{x:150,y:100,id:"color",kind:27},{x:150,y:150,id:"color",kind:27},{x:200,y:0,id:"color",kind:27},{x:250,y:0,id:"color",kind:27},{x:300,
y:0,id:"color",kind:27},{x:300,y:200,id:"color",kind:28},{x:250,y:200,id:"color",kind:28},{x:350,y:150,id:"color",kind:28},{x:350,y:100,id:"color",kind:28},{x:350,y:50,id:"color",kind:28},{x:200,y:150,id:"color",kind:22},{x:250,y:150,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:300,y:100,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:100,y:200,id:"color",kind:25},{x:50,y:300,id:"color",kind:0},{x:50,y:250,id:"color",
kind:0},{x:0,y:300,id:"color",kind:0},{x:50,y:350,id:"color",kind:0},{x:100,y:300,id:"color",kind:0},{x:0,y:350,id:"color",kind:0},{x:150,y:250,id:"color",kind:25},{x:150,y:200,id:"color",kind:25},{x:0,y:200,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:100,y:350,id:"color",kind:20},{x:150,y:350,id:"color",kind:20},{x:200,y:350,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:250,y:350,id:"color",kind:20},{x:350,y:250,id:"color",kind:20},{x:350,y:200,
id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:200,y:100,id:"color",kind:23},{x:250,y:50,id:"color",kind:23},{x:200,y:200,id:"color",kind:28},{x:300,y:350,id:"color",kind:20},{x:350,y:350,id:"color",kind:20},{x:350,y:300,id:"color",kind:20},{x:300,y:300,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:250,y:300,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:200,y:250,id:"color",kind:20},{x:100,y:150,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},
{x:50,y:150,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:100,y:250,id:"color",kind:0},{x:150,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:150,
y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:200,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},
{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"}],name:{key:"magnifier"}},hanger8x8:{width:400,height:400,items:[{x:50,y:350,id:"color",kind:22},{x:100,y:350,id:"color",kind:22},{x:150,y:350,id:"color",kind:22},{x:200,y:350,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:350,y:300,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},
{x:150,y:200,id:"color",kind:22},{x:200,y:200,id:"color",kind:22},{x:250,y:200,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:150,y:150,id:"color",kind:33},{x:100,y:100,id:"color",kind:33},{x:100,y:50,id:"color",kind:33},{x:150,y:0,id:"color",kind:33},{x:200,y:0,id:"color",kind:33},{x:250,y:50,id:"color",kind:33},{x:250,y:100,id:"color",kind:33},{x:50,y:300,id:"color",kind:35},{x:50,y:250,id:"color",kind:35},{x:100,y:250,id:"color",kind:35},{x:100,y:300,id:"color",kind:35},{x:150,y:300,id:"color",
kind:35},{x:150,y:250,id:"color",kind:35},{x:200,y:250,id:"color",kind:35},{x:200,y:300,id:"color",kind:35},{x:250,y:300,id:"color",kind:35},{x:250,y:250,id:"color",kind:35},{x:300,y:250,id:"color",kind:35},{x:300,y:300,id:"color",kind:35},{x:350,y:200,id:"color",kind:35},{x:300,y:150,id:"color",kind:35},{x:350,y:150,id:"color",kind:35},{x:350,y:100,id:"color",kind:35},{x:300,y:100,id:"color",kind:35},{x:300,y:50,id:"color",kind:35},{x:350,y:50,id:"color",kind:35},{x:300,y:0,id:"color",kind:35},{x:250,
y:0,id:"color",kind:35},{x:350,y:0,id:"color",kind:35},{x:250,y:150,id:"color",kind:35},{x:200,y:150,id:"color",kind:35},{x:200,y:100,id:"color",kind:35},{x:150,y:50,id:"color",kind:35},{x:200,y:50,id:"color",kind:35},{x:100,y:0,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:0,y:50,id:"color",kind:35},{x:50,y:50,id:"color",kind:35},{x:50,y:100,id:"color",kind:35},{x:0,y:100,id:"color",kind:35},{x:0,y:150,id:"color",kind:35},{x:0,y:200,id:"color",kind:35},{x:50,y:150,
id:"color",kind:35},{x:100,y:150,id:"color",kind:35},{x:350,y:350,id:"color",kind:22},{x:0,y:350,id:"color",kind:22},{x:150,y:100,id:"color",kind:33},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},
{x:50,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:0,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:150,y:100,id:"cell"}],name:{key:"clothes_hanger"}},bowtie8x8:{width:400,height:400,items:[{x:50,y:300,id:"color",kind:0},{x:100,y:350,id:"color",kind:0},{x:250,y:350,id:"color",kind:0},{x:300,y:300,id:"color",kind:0},{x:350,y:350,id:"color",kind:0},{x:300,y:350,id:"color",
kind:0},{x:350,y:300,id:"color",kind:0},{x:50,y:350,id:"color",kind:0},{x:0,y:350,id:"color",kind:0},{x:0,y:300,id:"color",kind:0},{x:100,y:0,id:"color",kind:7},{x:150,y:0,id:"color",kind:7},{x:200,y:0,id:"color",kind:7},{x:250,y:0,id:"color",kind:7},{x:200,y:100,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:200,y:350,id:"color",
kind:22},{x:150,y:350,id:"color",kind:22},{x:150,y:200,id:"color",kind:8},{x:150,y:150,id:"color",kind:8},{x:200,y:150,id:"color",kind:8},{x:200,y:200,id:"color",kind:8},{x:250,y:150,id:"color",kind:5},{x:250,y:200,id:"color",kind:5},{x:300,y:150,id:"color",kind:5},{x:300,y:100,id:"color",kind:5},{x:350,y:100,id:"color",kind:5},{x:350,y:150,id:"color",kind:5},{x:350,y:200,id:"color",kind:5},{x:350,y:250,id:"color",kind:5},{x:300,y:250,id:"color",kind:5},{x:300,y:200,id:"color",kind:5},{x:100,y:200,
id:"color",kind:5},{x:50,y:250,id:"color",kind:5},{x:50,y:200,id:"color",kind:5},{x:100,y:150,id:"color",kind:5},{x:50,y:150,id:"color",kind:5},{x:50,y:100,id:"color",kind:5},{x:0,y:100,id:"color",kind:5},{x:0,y:150,id:"color",kind:5},{x:0,y:200,id:"color",kind:5},{x:0,y:250,id:"color",kind:5},{x:0,y:0,id:"color",kind:13},{x:50,y:0,id:"color",kind:13},{x:50,y:50,id:"color",kind:13},{x:0,y:50,id:"color",kind:13},{x:350,y:50,id:"color",kind:13},{x:300,y:50,id:"color",kind:13},{x:300,y:0,id:"color",
kind:13},{x:350,y:0,id:"color",kind:13},{x:100,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:250,
y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:300,id:"cell"}],name:{key:"bowtie"}},kite8x8:{width:400,height:400,items:[{x:150,y:100,id:"color",kind:4},{x:200,y:100,id:"color",kind:4},{x:300,y:100,id:"color",kind:4},{x:350,y:100,id:"color",
kind:4},{x:250,y:0,id:"color",kind:4},{x:250,y:50,id:"color",kind:4},{x:250,y:150,id:"color",kind:4},{x:250,y:250,id:"color",kind:4},{x:250,y:300,id:"color",kind:4},{x:250,y:200,id:"color",kind:4},{x:250,y:100,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},{x:200,y:200,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:100,y:300,id:"color",kind:22},{x:50,y:350,id:"color",kind:22},{x:0,y:350,id:"color",kind:22},{x:100,y:100,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:150,y:300,
id:"color",kind:21},{x:150,y:350,id:"color",kind:21},{x:200,y:350,id:"color",kind:21},{x:300,y:350,id:"color",kind:21},{x:350,y:350,id:"color",kind:21},{x:350,y:300,id:"color",kind:21},{x:350,y:250,id:"color",kind:21},{x:100,y:250,id:"color",kind:21},{x:50,y:250,id:"color",kind:21},{x:0,y:250,id:"color",kind:21},{x:0,y:300,id:"color",kind:21},{x:100,y:200,id:"color",kind:21},{x:100,y:150,id:"color",kind:21},{x:50,y:150,id:"color",kind:21},{x:50,y:200,id:"color",kind:21},{x:0,y:200,id:"color",kind:21},
{x:0,y:100,id:"color",kind:21},{x:0,y:150,id:"color",kind:21},{x:50,y:100,id:"color",kind:21},{x:50,y:50,id:"color",kind:21},{x:0,y:50,id:"color",kind:21},{x:0,y:0,id:"color",kind:21},{x:50,y:0,id:"color",kind:21},{x:100,y:0,id:"color",kind:21},{x:200,y:300,id:"color",kind:5},{x:200,y:250,id:"color",kind:5},{x:150,y:200,id:"color",kind:5},{x:150,y:150,id:"color",kind:5},{x:100,y:50,id:"color",kind:5},{x:150,y:50,id:"color",kind:5},{x:200,y:50,id:"color",kind:5},{x:200,y:0,id:"color",kind:5},{x:150,
y:0,id:"color",kind:5},{x:300,y:50,id:"color",kind:5},{x:300,y:0,id:"color",kind:5},{x:350,y:0,id:"color",kind:5},{x:350,y:50,id:"color",kind:5},{x:300,y:150,id:"color",kind:5},{x:300,y:200,id:"color",kind:5},{x:300,y:250,id:"color",kind:5},{x:300,y:300,id:"color",kind:5},{x:350,y:200,id:"color",kind:5},{x:350,y:150,id:"color",kind:5},{x:50,y:300,id:"color",kind:21},{x:100,y:350,id:"color",kind:22},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:200,
y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},
{x:200,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:100,y:350,id:"cell"}],name:{key:"flying_kite"}},beard8x8:{width:400,height:400,items:[{x:50,y:50,id:"color",kind:6},{x:50,y:100,id:"color",kind:6},{x:300,y:50,id:"color",kind:6},{x:300,y:100,id:"color",kind:6},{x:100,y:250,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:200,y:250,id:"color",kind:3},{x:250,y:250,id:"color",kind:3},{x:250,y:200,id:"color",kind:3},{x:250,y:150,
id:"color",kind:3},{x:200,y:150,id:"color",kind:3},{x:150,y:150,id:"color",kind:4},{x:100,y:150,id:"color",kind:4},{x:100,y:200,id:"color",kind:4},{x:150,y:300,id:"color",kind:3},{x:200,y:300,id:"color",kind:3},{x:250,y:300,id:"color",kind:3},{x:100,y:300,id:"color",kind:3},{x:150,y:350,id:"color",kind:3},{x:200,y:350,id:"color",kind:3},{x:50,y:250,id:"color",kind:1},{x:0,y:300,id:"color",kind:1},{x:50,y:300,id:"color",kind:1},{x:0,y:350,id:"color",kind:1},{x:50,y:350,id:"color",kind:1},{x:100,y:350,
id:"color",kind:1},{x:300,y:250,id:"color",kind:1},{x:350,y:300,id:"color",kind:1},{x:300,y:300,id:"color",kind:1},{x:300,y:350,id:"color",kind:1},{x:250,y:350,id:"color",kind:1},{x:350,y:350,id:"color",kind:1},{x:250,y:50,id:"color",kind:0},{x:0,y:250,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:50,y:0,id:"color",
kind:22},{x:300,y:0,id:"color",kind:22},{x:350,y:0,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:350,y:100,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:350,y:200,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:150,y:200,id:"color",kind:7},{x:200,y:200,id:"color",kind:7},{x:100,y:0,id:"color",kind:7},{x:150,y:50,id:"color",kind:7},{x:100,y:100,id:"color",kind:7},{x:150,y:100,id:"color",kind:7},{x:200,y:100,
id:"color",kind:7},{x:250,y:100,id:"color",kind:7},{x:200,y:50,id:"color",kind:7},{x:200,y:0,id:"color",kind:7},{x:150,y:0,id:"color",kind:7},{x:250,y:0,id:"color",kind:7},{x:100,y:50,id:"color",kind:0},{x:0,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:250,id:"cell"},
{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"}],name:{key:"beard"}},fountain8x8:{width:400,height:400,items:[{x:100,
y:150,id:"color",kind:27},{x:150,y:150,id:"color",kind:27},{x:50,y:300,id:"color",kind:27},{x:100,y:300,id:"color",kind:27},{x:150,y:300,id:"color",kind:27},{x:200,y:300,id:"color",kind:27},{x:250,y:300,id:"color",kind:27},{x:200,y:350,id:"color",kind:27},{x:150,y:350,id:"color",kind:27},{x:100,y:350,id:"color",kind:27},{x:300,y:300,id:"color",kind:27},{x:250,y:350,id:"color",kind:27},{x:350,y:300,id:"color",kind:27},{x:300,y:350,id:"color",kind:27},{x:50,y:350,id:"color",kind:27},{x:0,y:300,id:"color",
kind:27},{x:250,y:150,id:"color",kind:27},{x:150,y:200,id:"color",kind:28},{x:150,y:250,id:"color",kind:28},{x:150,y:100,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:100,y:0,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:200,y:0,id:"color",kind:20},{x:250,y:0,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:300,y:100,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:300,y:250,
id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:50,y:250,id:"color",kind:22},{x:200,y:250,id:"color",kind:28},{x:200,y:200,id:"color",kind:28},{x:200,y:150,id:"color",kind:27},{x:200,y:100,id:"color",kind:20},{x:0,y:250,id:"color",kind:21},{x:0,y:200,id:"color",kind:21},{x:0,y:150,id:"color",kind:21},{x:0,y:100,id:"color",kind:21},{x:0,y:50,id:"color",kind:21},{x:0,y:0,id:"color",kind:21},{x:50,y:0,id:"color",kind:21},{x:100,y:50,
id:"color",kind:21},{x:100,y:100,id:"color",kind:21},{x:100,y:200,id:"color",kind:21},{x:100,y:250,id:"color",kind:21},{x:250,y:250,id:"color",kind:21},{x:250,y:200,id:"color",kind:21},{x:250,y:100,id:"color",kind:21},{x:250,y:50,id:"color",kind:21},{x:300,y:0,id:"color",kind:21},{x:350,y:0,id:"color",kind:21},{x:350,y:50,id:"color",kind:21},{x:350,y:100,id:"color",kind:21},{x:350,y:150,id:"color",kind:21},{x:350,y:250,id:"color",kind:21},{x:350,y:200,id:"color",kind:21},{x:350,y:350,id:"color",kind:21},
{x:0,y:350,id:"color",kind:21},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:100,y:0,id:"cell"},
{x:50,y:50,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:250,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"}],name:{key:"fountain"}},crocodile8x8:{width:400,height:400,items:[{x:50,y:150,id:"color",kind:13},{x:100,y:200,id:"color",kind:13},{x:150,y:150,id:"color",kind:13},{x:100,y:150,id:"color",kind:13},{x:150,y:100,id:"color",kind:13},{x:200,y:100,id:"color",
kind:13},{x:250,y:50,id:"color",kind:13},{x:300,y:0,id:"color",kind:13},{x:0,y:250,id:"color",kind:14},{x:0,y:200,id:"color",kind:13},{x:100,y:250,id:"color",kind:13},{x:200,y:50,id:"color",kind:13},{x:250,y:0,id:"color",kind:13},{x:50,y:250,id:"color",kind:13},{x:50,y:200,id:"color",kind:1},{x:150,y:200,id:"color",kind:23},{x:200,y:150,id:"color",kind:23},{x:250,y:100,id:"color",kind:23},{x:300,y:50,id:"color",kind:23},{x:150,y:250,id:"color",kind:24},{x:200,y:250,id:"color",kind:24},{x:300,y:250,
id:"color",kind:24},{x:250,y:250,id:"color",kind:24},{x:350,y:250,id:"color",kind:24},{x:200,y:300,id:"color",kind:24},{x:150,y:300,id:"color",kind:24},{x:100,y:300,id:"color",kind:24},{x:50,y:300,id:"color",kind:24},{x:350,y:350,id:"color",kind:24},{x:250,y:350,id:"color",kind:24},{x:200,y:350,id:"color",kind:24},{x:0,y:350,id:"color",kind:24},{x:50,y:350,id:"color",kind:24},{x:0,y:300,id:"color",kind:22},{x:100,y:350,id:"color",kind:22},{x:150,y:350,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},
{x:300,y:350,id:"color",kind:22},{x:350,y:300,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:0,y:150,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:50,y:0,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},
{x:200,y:200,id:"color",kind:20},{x:250,y:200,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:300,y:200,id:"color",kind:20},{x:300,y:150,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:300,y:100,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:0,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,
y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:50,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:350,id:"cell"},{x:250,y:250,id:"cell"},{x:150,y:300,id:"cell"},
{x:100,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:150,y:250,id:"cell"}],name:{key:"crocodile"}},smile8x8:{width:400,height:400,items:[{x:50,y:100,id:"color",kind:29},{x:250,y:100,id:"color",kind:29},{x:50,y:150,id:"color",kind:29},{x:250,y:150,id:"color",kind:29},{x:100,y:100,id:"color",kind:23},{x:150,y:100,id:"color",kind:23},{x:0,y:0,id:"color",kind:4},{x:0,y:50,id:"color",kind:4},{x:0,y:150,id:"color",kind:4},{x:0,y:200,id:"color",kind:4},{x:50,y:200,id:"color",kind:4},{x:50,y:250,id:"color",
kind:4},{x:250,y:200,id:"color",kind:4},{x:250,y:250,id:"color",kind:4},{x:300,y:200,id:"color",kind:4},{x:300,y:150,id:"color",kind:4},{x:300,y:50,id:"color",kind:4},{x:300,y:0,id:"color",kind:4},{x:250,y:50,id:"color",kind:4},{x:50,y:50,id:"color",kind:4},{x:50,y:0,id:"color",kind:4},{x:250,y:0,id:"color",kind:4},{x:200,y:50,id:"color",kind:3},{x:150,y:50,id:"color",kind:3},{x:100,y:50,id:"color",kind:3},{x:100,y:0,id:"color",kind:4},{x:150,y:0,id:"color",kind:4},{x:200,y:0,id:"color",kind:4},{x:100,
y:300,id:"color",kind:4},{x:150,y:300,id:"color",kind:4},{x:200,y:300,id:"color",kind:4},{x:100,y:250,id:"color",kind:3},{x:150,y:250,id:"color",kind:3},{x:200,y:250,id:"color",kind:3},{x:50,y:300,id:"color",kind:3},{x:50,y:350,id:"color",kind:3},{x:100,y:350,id:"color",kind:3},{x:150,y:350,id:"color",kind:3},{x:200,y:350,id:"color",kind:3},{x:250,y:350,id:"color",kind:3},{x:250,y:300,id:"color",kind:3},{x:350,y:50,id:"color",kind:3},{x:350,y:0,id:"color",kind:3},{x:0,y:100,id:"color",kind:4},{x:300,
y:100,id:"color",kind:4},{x:0,y:250,id:"color",kind:7},{x:0,y:300,id:"color",kind:7},{x:0,y:350,id:"color",kind:7},{x:300,y:350,id:"color",kind:7},{x:300,y:300,id:"color",kind:7},{x:300,y:250,id:"color",kind:7},{x:350,y:350,id:"color",kind:7},{x:350,y:300,id:"color",kind:7},{x:350,y:250,id:"color",kind:7},{x:350,y:200,id:"color",kind:7},{x:350,y:150,id:"color",kind:7},{x:350,y:100,id:"color",kind:7},{x:200,y:200,id:"color",kind:31},{x:150,y:200,id:"color",kind:31},{x:100,y:200,id:"color",kind:31},
{x:100,y:150,id:"color",kind:29},{x:150,y:150,id:"color",kind:29},{x:200,y:150,id:"color",kind:29},{x:200,y:100,id:"color",kind:22},{x:50,y:100,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:250,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},
{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"}],name:{key:"smile"}},peas8x8:{width:400,height:400,items:[{x:0,y:100,id:"color",kind:14},{x:0,y:150,id:"color",
kind:14},{x:50,y:200,id:"color",kind:14},{x:0,y:200,id:"color",kind:14},{x:50,y:250,id:"color",kind:14},{x:100,y:250,id:"color",kind:14},{x:100,y:300,id:"color",kind:14},{x:150,y:300,id:"color",kind:14},{x:150,y:350,id:"color",kind:14},{x:200,y:350,id:"color",kind:14},{x:250,y:350,id:"color",kind:14},{x:50,y:100,id:"color",kind:13},{x:150,y:200,id:"color",kind:13},{x:50,y:150,id:"color",kind:34},{x:250,y:300,id:"color",kind:34},{x:300,y:350,id:"color",kind:14},{x:300,y:300,id:"color",kind:14},{x:350,
y:300,id:"color",kind:14},{x:350,y:350,id:"color",kind:14},{x:0,y:50,id:"color",kind:13},{x:50,y:0,id:"color",kind:13},{x:150,y:50,id:"color",kind:34},{x:150,y:0,id:"color",kind:34},{x:350,y:150,id:"color",kind:34},{x:0,y:250,id:"color",kind:9},{x:0,y:300,id:"color",kind:9},{x:0,y:350,id:"color",kind:9},{x:50,y:350,id:"color",kind:9},{x:50,y:300,id:"color",kind:9},{x:100,y:350,id:"color",kind:9},{x:50,y:50,id:"color",kind:9},{x:100,y:50,id:"color",kind:9},{x:100,y:0,id:"color",kind:9},{x:100,y:100,
id:"color",kind:9},{x:150,y:100,id:"color",kind:9},{x:150,y:150,id:"color",kind:9},{x:200,y:150,id:"color",kind:9},{x:200,y:200,id:"color",kind:9},{x:300,y:250,id:"color",kind:9},{x:350,y:250,id:"color",kind:9},{x:250,y:100,id:"color",kind:9},{x:200,y:100,id:"color",kind:9},{x:250,y:50,id:"color",kind:9},{x:300,y:0,id:"color",kind:9},{x:300,y:50,id:"color",kind:9},{x:350,y:0,id:"color",kind:9},{x:350,y:50,id:"color",kind:9},{x:0,y:0,id:"color",kind:13},{x:200,y:0,id:"color",kind:34},{x:200,y:50,id:"color",
kind:34},{x:350,y:100,id:"color",kind:34},{x:300,y:150,id:"color",kind:34},{x:300,y:100,id:"color",kind:34},{x:250,y:0,id:"color",kind:9},{x:350,y:200,id:"color",kind:9},{x:100,y:150,id:"color",kind:34},{x:100,y:200,id:"color",kind:34},{x:200,y:250,id:"color",kind:34},{x:250,y:250,id:"color",kind:34},{x:200,y:300,id:"color",kind:14},{x:150,y:250,id:"color",kind:13},{x:250,y:150,id:"color",kind:9},{x:250,y:200,id:"color",kind:9},{x:300,y:200,id:"color",kind:9},{x:50,y:0,id:"cell"},{x:0,y:50,id:"cell"},
{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:0,y:0,id:"cell"},{x:150,y:50,
id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:350,y:150,id:"cell"},{x:200,y:250,id:"cell"}],name:{key:"peas"}},tutu8x8:{width:400,height:400,items:[{x:100,y:50,id:"color",kind:31},{x:200,y:50,id:"color",kind:31},{x:200,y:100,id:"color",kind:31},{x:150,y:100,id:"color",kind:31},{x:100,y:100,id:"color",kind:31},{x:150,y:150,id:"color",kind:31},{x:200,y:200,id:"color",kind:31},{x:150,y:200,id:"color",
kind:31},{x:100,y:200,id:"color",kind:31},{x:150,y:250,id:"color",kind:31},{x:100,y:250,id:"color",kind:35},{x:0,y:250,id:"color",kind:35},{x:0,y:300,id:"color",kind:35},{x:50,y:300,id:"color",kind:35},{x:100,y:350,id:"color",kind:35},{x:100,y:300,id:"color",kind:35},{x:150,y:350,id:"color",kind:35},{x:200,y:300,id:"color",kind:35},{x:150,y:300,id:"color",kind:35},{x:200,y:250,id:"color",kind:35},{x:250,y:300,id:"color",kind:35},{x:200,y:350,id:"color",kind:35},{x:250,y:250,id:"color",kind:35},{x:300,
y:250,id:"color",kind:35},{x:300,y:300,id:"color",kind:35},{x:350,y:200,id:"color",kind:35},{x:350,y:250,id:"color",kind:35},{x:50,y:200,id:"color",kind:35},{x:50,y:250,id:"color",kind:35},{x:50,y:50,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:100,y:0,id:"color",kind:35},{x:200,y:0,id:"color",kind:35},{x:250,y:0,id:"color",kind:35},{x:250,y:50,id:"color",kind:35},{x:200,y:150,id:"color",kind:31},{x:100,y:150,id:"color",kind:31},{x:150,y:50,id:"color",kind:7},{x:150,y:0,id:"color",kind:7},
{x:300,y:50,id:"color",kind:7},{x:350,y:50,id:"color",kind:7},{x:0,y:50,id:"color",kind:7},{x:0,y:200,id:"color",kind:10},{x:0,y:150,id:"color",kind:10},{x:0,y:100,id:"color",kind:10},{x:50,y:100,id:"color",kind:10},{x:50,y:150,id:"color",kind:10},{x:0,y:0,id:"color",kind:10},{x:300,y:0,id:"color",kind:10},{x:350,y:0,id:"color",kind:10},{x:250,y:150,id:"color",kind:10},{x:300,y:200,id:"color",kind:10},{x:300,y:150,id:"color",kind:10},{x:300,y:100,id:"color",kind:10},{x:250,y:100,id:"color",kind:10},
{x:350,y:100,id:"color",kind:10},{x:350,y:150,id:"color",kind:10},{x:300,y:350,id:"color",kind:10},{x:350,y:350,id:"color",kind:10},{x:350,y:300,id:"color",kind:10},{x:0,y:350,id:"color",kind:10},{x:250,y:200,id:"color",kind:35},{x:250,y:350,id:"color",kind:35},{x:50,y:350,id:"color",kind:35},{x:0,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:50,
id:"cell"},{x:350,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:250,y:200,id:"cell"},
{x:300,y:250,id:"cell"},{x:150,y:100,id:"cell"},{x:250,y:250,id:"cell"}],name:{key:"tutu"}},tornado8x8:{width:400,height:400,items:[{x:100,y:50,id:"color",kind:27},{x:0,y:0,id:"color",kind:27},{x:50,y:50,id:"color",kind:27},{x:50,y:0,id:"color",kind:27},{x:100,y:0,id:"color",kind:27},{x:150,y:50,id:"color",kind:27},{x:150,y:0,id:"color",kind:27},{x:100,y:100,id:"color",kind:27},{x:150,y:100,id:"color",kind:27},{x:200,y:0,id:"color",kind:27},{x:100,y:150,id:"color",kind:27},{x:150,y:200,id:"color",
kind:27},{x:200,y:200,id:"color",kind:27},{x:200,y:250,id:"color",kind:27},{x:250,y:250,id:"color",kind:27},{x:250,y:300,id:"color",kind:27},{x:300,y:300,id:"color",kind:27},{x:300,y:350,id:"color",kind:27},{x:50,y:100,id:"color",kind:27},{x:50,y:150,id:"color",kind:27},{x:100,y:200,id:"color",kind:27},{x:150,y:150,id:"color",kind:28},{x:200,y:100,id:"color",kind:28},{x:250,y:50,id:"color",kind:28},{x:300,y:0,id:"color",kind:28},{x:350,y:0,id:"color",kind:28},{x:200,y:50,id:"color",kind:28},{x:250,
y:0,id:"color",kind:28},{x:0,y:50,id:"color",kind:28},{x:0,y:100,id:"color",kind:25},{x:0,y:150,id:"color",kind:25},{x:200,y:150,id:"color",kind:25},{x:250,y:150,id:"color",kind:25},{x:300,y:100,id:"color",kind:25},{x:350,y:50,id:"color",kind:25},{x:350,y:100,id:"color",kind:25},{x:350,y:150,id:"color",kind:25},{x:250,y:200,id:"color",kind:25},{x:300,y:200,id:"color",kind:25},{x:350,y:200,id:"color",kind:25},{x:300,y:250,id:"color",kind:25},{x:350,y:250,id:"color",kind:25},{x:350,y:300,id:"color",
kind:25},{x:350,y:350,id:"color",kind:25},{x:250,y:350,id:"color",kind:25},{x:200,y:350,id:"color",kind:25},{x:150,y:350,id:"color",kind:25},{x:100,y:250,id:"color",kind:25},{x:100,y:300,id:"color",kind:25},{x:150,y:300,id:"color",kind:25},{x:100,y:350,id:"color",kind:25},{x:50,y:350,id:"color",kind:25},{x:50,y:300,id:"color",kind:25},{x:50,y:250,id:"color",kind:25},{x:0,y:200,id:"color",kind:25},{x:50,y:200,id:"color",kind:25},{x:0,y:300,id:"color",kind:25},{x:0,y:350,id:"color",kind:25},{x:0,y:250,
id:"color",kind:28},{x:300,y:150,id:"color",kind:28},{x:300,y:50,id:"color",kind:28},{x:250,y:100,id:"color",kind:28},{x:150,y:250,id:"color",kind:27},{x:200,y:300,id:"color",kind:27},{x:0,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:200,id:"cell"},
{x:150,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:350,id:"cell"},{x:0,y:250,id:"cell"},{x:300,y:150,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:50,y:0,id:"cell"}],name:{key:"tornado"}},balloon8x8:{width:400,height:400,items:[{x:50,y:0,id:"color",kind:26},{x:100,y:0,
id:"color",kind:26},{x:150,y:0,id:"color",kind:26},{x:0,y:50,id:"color",kind:26},{x:0,y:100,id:"color",kind:26},{x:0,y:150,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:150,y:150,id:"color",kind:26},{x:150,y:50,id:"color",kind:26},{x:100,y:50,id:"color",kind:26},{x:100,y:100,id:"color",kind:26},{x:50,y:100,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:200,y:100,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:100,y:200,id:"color",kind:26},{x:150,
y:200,id:"color",kind:26},{x:100,y:250,id:"color",kind:26},{x:50,y:50,id:"color",kind:35},{x:0,y:200,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:50,y:250,id:"color",kind:20},{x:50,y:300,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:0,y:350,id:"color",kind:20},{x:50,y:350,id:"color",kind:20},{x:100,y:350,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:200,y:250,id:"color",kind:20},{x:250,y:300,id:"color",kind:20},
{x:300,y:300,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:350,y:350,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:250,y:200,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:250,y:0,id:"color",
kind:20},{x:200,y:0,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:100,y:300,id:"color",kind:23},{x:150,y:350,id:"color",kind:23},{x:200,y:350,id:"color",kind:23},{x:350,y:300,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:300,y:150,id:"color",kind:22},{x:300,y:100,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:100,y:150,id:"color",kind:26},{x:150,y:100,id:"color",kind:26},{x:100,
y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:0,y:50,id:"cell"},
{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:100,id:"cell"}],name:{key:"balloon"}},spades8x8:{width:400,height:400,items:[{x:150,y:300,id:"color",kind:34},{x:200,y:300,id:"color",kind:34},{x:200,y:350,id:"color",kind:34},{x:150,y:350,id:"color",kind:34},{x:100,y:350,id:"color",kind:34},{x:250,y:350,id:"color",kind:34},{x:250,y:250,id:"color",kind:34},{x:300,y:300,id:"color",kind:34},
{x:350,y:250,id:"color",kind:34},{x:300,y:250,id:"color",kind:34},{x:200,y:250,id:"color",kind:34},{x:150,y:250,id:"color",kind:34},{x:200,y:200,id:"color",kind:34},{x:250,y:150,id:"color",kind:34},{x:250,y:200,id:"color",kind:34},{x:300,y:200,id:"color",kind:34},{x:300,y:150,id:"color",kind:34},{x:350,y:150,id:"color",kind:34},{x:350,y:200,id:"color",kind:34},{x:300,y:100,id:"color",kind:34},{x:50,y:250,id:"color",kind:33},{x:100,y:200,id:"color",kind:33},{x:150,y:150,id:"color",kind:33},{x:200,
y:100,id:"color",kind:33},{x:250,y:50,id:"color",kind:33},{x:200,y:50,id:"color",kind:33},{x:200,y:0,id:"color",kind:33},{x:150,y:0,id:"color",kind:33},{x:100,y:50,id:"color",kind:33},{x:150,y:100,id:"color",kind:33},{x:100,y:150,id:"color",kind:33},{x:50,y:100,id:"color",kind:33},{x:0,y:250,id:"color",kind:33},{x:0,y:200,id:"color",kind:33},{x:0,y:150,id:"color",kind:33},{x:50,y:150,id:"color",kind:33},{x:50,y:200,id:"color",kind:33},{x:250,y:100,id:"color",kind:33},{x:200,y:150,id:"color",kind:33},
{x:150,y:200,id:"color",kind:33},{x:100,y:250,id:"color",kind:33},{x:50,y:300,id:"color",kind:33},{x:0,y:350,id:"color",kind:35},{x:50,y:350,id:"color",kind:35},{x:0,y:300,id:"color",kind:35},{x:100,y:300,id:"color",kind:35},{x:250,y:300,id:"color",kind:35},{x:300,y:350,id:"color",kind:35},{x:350,y:350,id:"color",kind:35},{x:350,y:300,id:"color",kind:35},{x:350,y:100,id:"color",kind:35},{x:350,y:50,id:"color",kind:35},{x:300,y:50,id:"color",kind:35},{x:350,y:0,id:"color",kind:35},{x:300,y:0,id:"color",
kind:35},{x:250,y:0,id:"color",kind:35},{x:100,y:0,id:"color",kind:35},{x:50,y:0,id:"color",kind:35},{x:50,y:50,id:"color",kind:35},{x:0,y:50,id:"color",kind:35},{x:0,y:0,id:"color",kind:35},{x:0,y:100,id:"color",kind:35},{x:100,y:100,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:100,
y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,
id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:50,id:"cell"}],name:{key:"spades"}},paperboat8x8:{width:400,height:400,items:[{x:0,y:250,id:"color",kind:20},{x:50,y:250,id:"color",kind:20},{x:50,y:200,id:"color",kind:23},{x:0,y:150,id:"color",kind:23},{x:50,y:150,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:200,y:150,id:"color",kind:23},
{x:250,y:150,id:"color",kind:23},{x:300,y:150,id:"color",kind:23},{x:200,y:100,id:"color",kind:22},{x:250,y:50,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:0,y:300,id:"color",kind:20},{x:50,y:300,id:"color",kind:20},{x:100,y:300,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:250,y:300,id:"color",kind:20},{x:300,y:300,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:350,y:250,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:350,y:300,id:"color",kind:20},{x:350,y:350,
id:"color",kind:20},{x:300,y:350,id:"color",kind:20},{x:250,y:350,id:"color",kind:20},{x:200,y:350,id:"color",kind:20},{x:100,y:350,id:"color",kind:20},{x:150,y:350,id:"color",kind:20},{x:50,y:350,id:"color",kind:20},{x:0,y:350,id:"color",kind:20},{x:0,y:200,id:"color",kind:21},{x:350,y:200,id:"color",kind:21},{x:0,y:100,id:"color",kind:21},{x:50,y:100,id:"color",kind:21},{x:100,y:100,id:"color",kind:21},{x:100,y:50,id:"color",kind:21},{x:50,y:50,id:"color",kind:21},{x:0,y:50,id:"color",kind:21},
{x:0,y:0,id:"color",kind:21},{x:50,y:0,id:"color",kind:21},{x:100,y:0,id:"color",kind:21},{x:150,y:0,id:"color",kind:21},{x:150,y:50,id:"color",kind:21},{x:200,y:0,id:"color",kind:21},{x:300,y:0,id:"color",kind:21},{x:300,y:50,id:"color",kind:21},{x:300,y:100,id:"color",kind:21},{x:350,y:100,id:"color",kind:21},{x:350,y:50,id:"color",kind:21},{x:350,y:0,id:"color",kind:21},{x:200,y:50,id:"color",kind:23},{x:250,y:0,id:"color",kind:23},{x:150,y:100,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},
{x:250,y:250,id:"color",kind:22},{x:300,y:200,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:0,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,
y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:0,y:250,id:"cell"},{x:350,y:250,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:150,y:300,id:"cell"}],name:{key:"paper_boat"}},pencil8x8:{width:400,height:400,items:[{x:0,y:350,id:"color",kind:28},{x:0,y:300,id:"color",kind:7},{x:50,y:300,
id:"color",kind:7},{x:50,y:350,id:"color",kind:7},{x:50,y:250,id:"color",kind:17},{x:100,y:300,id:"color",kind:17},{x:150,y:250,id:"color",kind:17},{x:100,y:200,id:"color",kind:17},{x:200,y:200,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:200,y:100,id:"color",kind:17},{x:250,y:150,id:"color",kind:17},{x:250,y:50,id:"color",kind:24},{x:300,y:50,id:"color",kind:24},{x:300,y:100,id:"color",kind:24},{x:300,y:0,id:"color",kind:31},{x:350,y:0,id:"color",kind:31},{x:350,y:50,id:"color",kind:31},
{x:100,y:250,id:"color",kind:4},{x:150,y:200,id:"color",kind:4},{x:200,y:150,id:"color",kind:4},{x:250,y:100,id:"color",kind:4},{x:100,y:350,id:"color",kind:27},{x:150,y:350,id:"color",kind:27},{x:200,y:350,id:"color",kind:27},{x:250,y:350,id:"color",kind:27},{x:300,y:350,id:"color",kind:27},{x:300,y:300,id:"color",kind:27},{x:350,y:300,id:"color",kind:27},{x:350,y:250,id:"color",kind:27},{x:350,y:200,id:"color",kind:27},{x:0,y:250,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:0,y:150,id:"color",
kind:22},{x:0,y:0,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:100,y:50,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:200,y:50,id:"color",kind:22},{x:200,y:0,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:350,y:100,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:300,y:200,id:"color",
kind:22},{x:300,y:250,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:250,y:200,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:200,y:300,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:150,y:300,id:"color",kind:22},{x:350,y:350,id:"color",kind:22},{x:300,y:150,id:"color",kind:27},{x:100,y:150,id:"color",kind:27},{x:50,y:150,id:"color",kind:27},{x:0,y:100,id:"color",kind:27},{x:0,y:50,id:"color",kind:27},{x:50,y:0,id:"color",kind:27},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},
{x:50,y:300,id:"cell"},{x:0,y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:250,
y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:300,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:0,id:"cell"}],name:{key:"pencil"}},phonograph8x8:{width:400,height:400,items:[{x:100,y:350,id:"color",kind:4},{x:150,y:350,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:300,y:350,id:"color",kind:4},
{x:200,y:350,id:"color",kind:4},{x:100,y:300,id:"color",kind:28},{x:150,y:300,id:"color",kind:28},{x:200,y:300,id:"color",kind:28},{x:250,y:300,id:"color",kind:28},{x:300,y:300,id:"color",kind:28},{x:150,y:250,id:"color",kind:0},{x:300,y:200,id:"color",kind:17},{x:300,y:150,id:"color",kind:17},{x:350,y:100,id:"color",kind:17},{x:300,y:100,id:"color",kind:17},{x:300,y:50,id:"color",kind:17},{x:150,y:0,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:100,y:100,id:"color",kind:17},{x:100,y:50,
id:"color",kind:17},{x:200,y:150,id:"color",kind:17},{x:250,y:150,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:250,y:0,id:"color",kind:17},{x:300,y:250,id:"color",kind:17},{x:350,y:150,id:"color",kind:17},{x:350,y:200,id:"color",kind:17},{x:250,y:250,id:"color",kind:17},{x:150,y:50,id:"color",kind:8},{x:150,y:100,id:"color",kind:8},{x:200,y:100,id:"color",kind:8},{x:200,y:50,id:"color",kind:8},{x:250,y:50,id:"color",kind:8},{x:250,y:100,id:"color",kind:8},{x:50,y:350,id:"color",kind:4},{x:50,
y:300,id:"color",kind:28},{x:0,y:350,id:"color",kind:4},{x:350,y:350,id:"color",kind:4},{x:0,y:300,id:"color",kind:12},{x:0,y:250,id:"color",kind:12},{x:50,y:250,id:"color",kind:12},{x:100,y:250,id:"color",kind:12},{x:50,y:200,id:"color",kind:12},{x:50,y:150,id:"color",kind:12},{x:0,y:150,id:"color",kind:12},{x:0,y:200,id:"color",kind:12},{x:100,y:200,id:"color",kind:12},{x:100,y:150,id:"color",kind:12},{x:50,y:100,id:"color",kind:12},{x:0,y:100,id:"color",kind:12},{x:0,y:50,id:"color",kind:12},{x:50,
y:50,id:"color",kind:12},{x:50,y:0,id:"color",kind:12},{x:0,y:0,id:"color",kind:12},{x:100,y:0,id:"color",kind:12},{x:300,y:0,id:"color",kind:12},{x:350,y:0,id:"color",kind:12},{x:350,y:50,id:"color",kind:12},{x:250,y:200,id:"color",kind:12},{x:200,y:250,id:"color",kind:12},{x:200,y:200,id:"color",kind:12},{x:150,y:200,id:"color",kind:12},{x:350,y:250,id:"color",kind:12},{x:350,y:300,id:"color",kind:12},{x:100,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:0,id:"cell"},{x:200,
y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:50,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:0,y:350,
id:"cell"},{x:350,y:350,id:"cell"}],name:{key:"phonograph"}},beach8x8:{width:400,height:400,items:[{x:0,y:250,id:"color",kind:6},{x:50,y:200,id:"color",kind:6},{x:100,y:200,id:"color",kind:6},{x:150,y:250,id:"color",kind:6},{x:200,y:300,id:"color",kind:6},{x:250,y:300,id:"color",kind:6},{x:300,y:300,id:"color",kind:6},{x:350,y:250,id:"color",kind:6},{x:150,y:350,id:"color",kind:6},{x:250,y:350,id:"color",kind:6},{x:300,y:350,id:"color",kind:6},{x:350,y:300,id:"color",kind:6},{x:150,y:300,id:"color",
kind:7},{x:100,y:300,id:"color",kind:7},{x:100,y:350,id:"color",kind:7},{x:50,y:350,id:"color",kind:7},{x:0,y:350,id:"color",kind:7},{x:200,y:350,id:"color",kind:7},{x:350,y:350,id:"color",kind:7},{x:0,y:300,id:"color",kind:7},{x:50,y:300,id:"color",kind:7},{x:50,y:250,id:"color",kind:7},{x:100,y:250,id:"color",kind:7},{x:0,y:0,id:"color",kind:19},{x:0,y:50,id:"color",kind:19},{x:50,y:50,id:"color",kind:19},{x:50,y:0,id:"color",kind:19},{x:100,y:50,id:"color",kind:19},{x:100,y:100,id:"color",kind:19},
{x:150,y:100,id:"color",kind:19},{x:200,y:150,id:"color",kind:19},{x:250,y:150,id:"color",kind:19},{x:300,y:150,id:"color",kind:19},{x:300,y:100,id:"color",kind:19},{x:350,y:100,id:"color",kind:19},{x:350,y:0,id:"color",kind:19},{x:350,y:50,id:"color",kind:19},{x:250,y:100,id:"color",kind:19},{x:200,y:100,id:"color",kind:19},{x:200,y:50,id:"color",kind:19},{x:250,y:50,id:"color",kind:19},{x:300,y:50,id:"color",kind:19},{x:300,y:0,id:"color",kind:19},{x:200,y:0,id:"color",kind:19},{x:150,y:0,id:"color",
kind:19},{x:150,y:50,id:"color",kind:19},{x:100,y:0,id:"color",kind:19},{x:250,y:0,id:"color",kind:19},{x:0,y:100,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:250,y:250,id:"color",kind:20},{x:300,y:200,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:250,y:200,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:150,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:300,y:250,
id:"color",kind:22},{x:350,y:200,id:"color",kind:22},{x:150,y:150,id:"color",kind:20},{x:100,y:150,id:"color",kind:22},{x:0,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:50,
y:350,id:"cell"},{x:0,y:350,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:100,y:150,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:350,y:150,id:"cell"}],name:{key:"sea_shore"}},pelican8x8:{width:400,height:400,items:[{x:350,
y:100,id:"color",kind:5},{x:300,y:100,id:"color",kind:5},{x:250,y:100,id:"color",kind:5},{x:200,y:100,id:"color",kind:5},{x:350,y:150,id:"color",kind:8},{x:300,y:200,id:"color",kind:8},{x:300,y:250,id:"color",kind:8},{x:250,y:250,id:"color",kind:8},{x:250,y:200,id:"color",kind:8},{x:250,y:150,id:"color",kind:8},{x:300,y:150,id:"color",kind:8},{x:200,y:150,id:"color",kind:8},{x:200,y:200,id:"color",kind:8},{x:200,y:250,id:"color",kind:8},{x:250,y:50,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},
{x:50,y:0,id:"color",kind:20},{x:50,y:50,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:0,y:50,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:200,y:350,id:"color",kind:20},{x:250,
y:350,id:"color",kind:20},{x:300,y:350,id:"color",kind:20},{x:300,y:300,id:"color",kind:20},{x:350,y:300,id:"color",kind:20},{x:350,y:250,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:350,y:350,id:"color",kind:20},{x:200,y:300,id:"color",kind:8},{x:250,y:300,id:"color",kind:8},{x:100,y:50,id:"color",kind:16},{x:50,y:350,id:"color",kind:22},{x:0,y:350,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:0,y:250,id:"color",kind:23},{x:50,y:250,id:"color",kind:23},{x:50,y:300,id:"color",kind:23},
{x:100,y:300,id:"color",kind:23},{x:100,y:350,id:"color",kind:23},{x:150,y:350,id:"color",kind:23},{x:150,y:300,id:"color",kind:23},{x:100,y:250,id:"color",kind:23},{x:100,y:200,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:100,y:100,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:150,y:0,id:"color",kind:23},{x:100,y:0,id:"color",kind:23},{x:200,y:50,id:"color",kind:23},{x:150,y:250,id:"color",kind:8},{x:150,y:200,id:"color",kind:8},{x:150,y:150,id:"color",kind:8},{x:150,y:100,id:"color",
kind:5},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:200,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:250,id:"cell"},{x:250,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:200,id:"cell"},
{x:50,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"}],name:{key:"pelican"}},seagull8x8:{width:400,height:400,items:[{x:0,y:100,id:"color",kind:8},{x:150,y:150,id:"color",kind:27},{x:150,y:250,id:"color",kind:27},{x:200,y:250,id:"color",kind:27},{x:200,y:150,id:"color",kind:27},{x:250,y:250,id:"color",kind:27},{x:300,y:250,id:"color",kind:27},{x:100,y:50,id:"color",kind:0},{x:100,y:0,id:"color",
kind:23},{x:150,y:0,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:50,y:150,id:"color",kind:23},{x:100,y:200,id:"color",kind:23},{x:50,y:250,id:"color",kind:23},{x:100,y:300,id:"color",kind:23},{x:150,y:300,id:"color",kind:23},{x:200,y:300,id:"color",kind:23},{x:200,y:350,id:"color",kind:8},{x:0,y:200,id:"color",kind:24},{x:0,y:250,id:"color",kind:24},{x:0,y:300,id:"color",kind:24},{x:0,y:350,id:"color",kind:24},{x:50,y:350,id:"color",kind:24},{x:100,y:350,id:"color",kind:24},{x:150,y:350,
id:"color",kind:24},{x:250,y:350,id:"color",kind:24},{x:300,y:350,id:"color",kind:24},{x:350,y:350,id:"color",kind:24},{x:0,y:50,id:"color",kind:24},{x:0,y:0,id:"color",kind:24},{x:50,y:0,id:"color",kind:24},{x:200,y:0,id:"color",kind:24},{x:200,y:50,id:"color",kind:24},{x:200,y:100,id:"color",kind:24},{x:250,y:150,id:"color",kind:24},{x:300,y:200,id:"color",kind:24},{x:350,y:200,id:"color",kind:24},{x:350,y:150,id:"color",kind:24},{x:300,y:150,id:"color",kind:24},{x:250,y:100,id:"color",kind:24},
{x:250,y:50,id:"color",kind:24},{x:300,y:50,id:"color",kind:24},{x:300,y:100,id:"color",kind:24},{x:350,y:100,id:"color",kind:24},{x:350,y:50,id:"color",kind:24},{x:350,y:0,id:"color",kind:24},{x:300,y:0,id:"color",kind:24},{x:250,y:0,id:"color",kind:24},{x:50,y:100,id:"color",kind:23},{x:150,y:100,id:"color",kind:23},{x:50,y:200,id:"color",kind:23},{x:150,y:200,id:"color",kind:27},{x:200,y:200,id:"color",kind:27},{x:250,y:200,id:"color",kind:27},{x:350,y:250,id:"color",kind:27},{x:300,y:300,id:"color",
kind:22},{x:250,y:300,id:"color",kind:22},{x:0,y:150,id:"color",kind:24},{x:50,y:50,id:"color",kind:23},{x:50,y:300,id:"color",kind:24},{x:350,y:300,id:"color",kind:24},{x:0,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:300,
y:250,id:"cell"},{x:350,y:250,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"}],name:{key:"seagull"}},crab8x8:{width:400,height:400,items:[{x:100,y:250,id:"color",kind:26},{x:250,y:250,id:"color",kind:26},{x:50,y:300,id:"color",kind:26},{x:300,y:300,id:"color",kind:26},{x:350,y:350,id:"color",kind:26},{x:100,y:200,id:"color",kind:26},{x:150,y:200,id:"color",
kind:26},{x:200,y:200,id:"color",kind:26},{x:250,y:200,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:0,y:200,id:"color",kind:26},{x:0,y:100,id:"color",kind:26},{x:0,y:50,id:"color",kind:26},{x:50,y:50,id:"color",kind:26},{x:300,y:200,id:"color",kind:26},{x:350,y:200,id:"color",kind:26},{x:350,y:100,id:"color",kind:26},{x:300,y:0,id:"color",kind:26},{x:50,y:0,id:"color",kind:26},{x:100,y:0,id:"color",kind:26},{x:0,y:150,id:"color",kind:26},{x:350,y:50,id:"color",kind:26},{x:350,y:150,id:"color",
kind:26},{x:250,y:0,id:"color",kind:26},{x:300,y:50,id:"color",kind:26},{x:50,y:250,id:"color",kind:20},{x:0,y:250,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:50,y:350,id:"color",kind:20},{x:100,y:350,id:"color",kind:20},{x:150,y:350,id:"color",kind:20},{x:200,y:350,id:"color",kind:20},{x:250,y:350,id:"color",kind:20},{x:300,y:350,id:"color",kind:20},{x:350,y:300,id:"color",kind:20},{x:350,y:250,id:"color",kind:20},{x:300,y:250,id:"color",kind:20},{x:300,y:150,id:"color",kind:20},{x:350,
y:0,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:200,y:100,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:100,y:150,id:"color",kind:20},{x:50,y:150,id:"color",kind:20},{x:0,y:0,id:"color",kind:20},{x:0,y:350,id:"color",kind:26},
{x:150,y:250,id:"color",kind:7},{x:200,y:250,id:"color",kind:7},{x:200,y:300,id:"color",kind:7},{x:150,y:300,id:"color",kind:7},{x:50,y:100,id:"color",kind:7},{x:100,y:100,id:"color",kind:7},{x:300,y:100,id:"color",kind:7},{x:250,y:100,id:"color",kind:7},{x:100,y:300,id:"color",kind:26},{x:250,y:300,id:"color",kind:26},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:250,
y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:250,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:100,id:"cell"},{x:0,y:100,id:"cell"}],name:{key:"crab"}},diamonds8x8:{width:400,
height:400,items:[{x:150,y:350,id:"color",kind:19},{x:200,y:350,id:"color",kind:19},{x:250,y:300,id:"color",kind:19},{x:300,y:250,id:"color",kind:19},{x:350,y:200,id:"color",kind:19},{x:350,y:150,id:"color",kind:19},{x:300,y:100,id:"color",kind:19},{x:100,y:300,id:"color",kind:19},{x:250,y:150,id:"color",kind:19},{x:200,y:200,id:"color",kind:19},{x:150,y:250,id:"color",kind:19},{x:150,y:300,id:"color",kind:19},{x:200,y:300,id:"color",kind:19},{x:200,y:250,id:"color",kind:19},{x:250,y:250,id:"color",
kind:19},{x:250,y:200,id:"color",kind:19},{x:300,y:150,id:"color",kind:19},{x:50,y:250,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:200,y:100,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:300,y:200,id:"color",kind:19},{x:200,y:50,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:100,y:50,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:50,y:100,id:"color",kind:20},{x:50,y:150,
id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},{x:100,y:150,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:100,y:250,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:0,y:250,id:"color",kind:33},{x:0,y:300,id:"color",kind:33},{x:0,y:350,id:"color",kind:33},{x:50,y:350,id:"color",kind:33},{x:50,y:300,id:"color",kind:33},{x:100,y:350,id:"color",kind:33},
{x:250,y:350,id:"color",kind:33},{x:300,y:300,id:"color",kind:33},{x:300,y:350,id:"color",kind:33},{x:350,y:350,id:"color",kind:33},{x:350,y:300,id:"color",kind:33},{x:350,y:250,id:"color",kind:33},{x:350,y:100,id:"color",kind:33},{x:350,y:50,id:"color",kind:33},{x:300,y:50,id:"color",kind:33},{x:300,y:0,id:"color",kind:33},{x:350,y:0,id:"color",kind:33},{x:250,y:0,id:"color",kind:33},{x:100,y:0,id:"color",kind:33},{x:50,y:0,id:"color",kind:33},{x:50,y:50,id:"color",kind:33},{x:0,y:0,id:"color",kind:33},
{x:0,y:50,id:"color",kind:33},{x:0,y:100,id:"color",kind:33},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:200,
id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:150,y:150,id:"cell"},{x:350,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:250,id:"cell"}],name:{key:"diamonds"}},woods8x8:{width:400,height:400,items:[{x:50,y:300,id:"color",kind:4},{x:50,y:250,id:"color",kind:4},{x:50,y:200,id:"color",kind:4},{x:300,y:300,id:"color",kind:4},{x:300,
y:250,id:"color",kind:4},{x:100,y:200,id:"color",kind:3},{x:100,y:300,id:"color",kind:3},{x:50,y:150,id:"color",kind:4},{x:200,y:300,id:"color",kind:3},{x:200,y:250,id:"color",kind:3},{x:200,y:150,id:"color",kind:3},{x:350,y:300,id:"color",kind:3},{x:350,y:250,id:"color",kind:3},{x:350,y:200,id:"color",kind:3},{x:0,y:300,id:"color",kind:3},{x:0,y:250,id:"color",kind:3},{x:150,y:300,id:"color",kind:4},{x:150,y:250,id:"color",kind:4},{x:300,y:200,id:"color",kind:4},{x:300,y:150,id:"color",kind:4},{x:300,
y:100,id:"color",kind:4},{x:0,y:150,id:"color",kind:13},{x:0,y:100,id:"color",kind:13},{x:50,y:100,id:"color",kind:13},{x:100,y:50,id:"color",kind:13},{x:100,y:100,id:"color",kind:13},{x:0,y:50,id:"color",kind:13},{x:50,y:0,id:"color",kind:13},{x:150,y:200,id:"color",kind:13},{x:150,y:150,id:"color",kind:13},{x:150,y:100,id:"color",kind:13},{x:200,y:50,id:"color",kind:13},{x:150,y:0,id:"color",kind:13},{x:250,y:100,id:"color",kind:13},{x:250,y:150,id:"color",kind:13},{x:350,y:100,id:"color",kind:13},
{x:300,y:50,id:"color",kind:13},{x:300,y:0,id:"color",kind:13},{x:350,y:0,id:"color",kind:13},{x:350,y:50,id:"color",kind:13},{x:250,y:0,id:"color",kind:13},{x:0,y:200,id:"color",kind:14},{x:100,y:150,id:"color",kind:14},{x:250,y:200,id:"color",kind:14},{x:350,y:150,id:"color",kind:14},{x:200,y:100,id:"color",kind:14},{x:250,y:300,id:"color",kind:14},{x:250,y:50,id:"color",kind:14},{x:200,y:0,id:"color",kind:14},{x:100,y:0,id:"color",kind:14},{x:50,y:50,id:"color",kind:14},{x:0,y:0,id:"color",kind:14},
{x:150,y:50,id:"color",kind:14},{x:200,y:200,id:"color",kind:13},{x:100,y:250,id:"color",kind:13},{x:250,y:250,id:"color",kind:14},{x:100,y:350,id:"color",kind:33},{x:150,y:350,id:"color",kind:33},{x:250,y:350,id:"color",kind:33},{x:350,y:350,id:"color",kind:33},{x:300,y:350,id:"color",kind:34},{x:200,y:350,id:"color",kind:34},{x:50,y:350,id:"color",kind:34},{x:0,y:350,id:"color",kind:34},{x:250,y:150,id:"cell"},{x:250,y:100,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:300,y:50,id:"cell"},
{x:300,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:100,y:250,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:50,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:200,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:200,y:300,id:"cell"},
{x:200,y:250,id:"cell"},{x:200,y:150,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:300,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:0,y:350,id:"cell"},{x:300,y:300,id:"cell"}],name:{key:"woods"}},camera8x8:{width:400,height:400,items:[{x:250,y:0,id:"color",kind:28},{x:300,y:0,id:"color",kind:28},{x:0,y:250,id:"color",kind:18},{x:350,y:300,id:"color",kind:18},{x:50,y:300,id:"color",kind:18},{x:0,y:100,id:"color",kind:18},{x:50,y:50,id:"color",
kind:18},{x:100,y:50,id:"color",kind:18},{x:150,y:50,id:"color",kind:18},{x:200,y:50,id:"color",kind:18},{x:200,y:100,id:"color",kind:18},{x:250,y:50,id:"color",kind:18},{x:300,y:50,id:"color",kind:18},{x:350,y:50,id:"color",kind:18},{x:350,y:100,id:"color",kind:18},{x:350,y:150,id:"color",kind:18},{x:350,y:250,id:"color",kind:18},{x:300,y:300,id:"color",kind:18},{x:350,y:200,id:"color",kind:18},{x:250,y:300,id:"color",kind:18},{x:200,y:300,id:"color",kind:18},{x:150,y:300,id:"color",kind:18},{x:100,
y:300,id:"color",kind:18},{x:200,y:150,id:"color",kind:28},{x:200,y:200,id:"color",kind:28},{x:150,y:250,id:"color",kind:28},{x:100,y:250,id:"color",kind:28},{x:100,y:200,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:100,y:150,id:"color",kind:23},{x:200,y:250,id:"color",kind:18},{x:250,y:250,id:"color",kind:18},{x:250,y:200,id:"color",kind:18},{x:250,y:150,id:"color",kind:18},{x:300,y:150,id:"color",kind:18},{x:300,y:200,id:"color",kind:18},{x:300,y:250,
id:"color",kind:18},{x:250,y:100,id:"color",kind:17},{x:300,y:100,id:"color",kind:17},{x:50,y:100,id:"color",kind:18},{x:0,y:150,id:"color",kind:18},{x:0,y:200,id:"color",kind:18},{x:50,y:250,id:"color",kind:18},{x:150,y:350,id:"color",kind:27},{x:200,y:350,id:"color",kind:27},{x:150,y:100,id:"color",kind:27},{x:100,y:100,id:"color",kind:27},{x:50,y:150,id:"color",kind:27},{x:50,y:200,id:"color",kind:27},{x:0,y:350,id:"color",kind:8},{x:50,y:350,id:"color",kind:8},{x:100,y:350,id:"color",kind:8},
{x:250,y:350,id:"color",kind:8},{x:300,y:350,id:"color",kind:8},{x:350,y:350,id:"color",kind:8},{x:350,y:0,id:"color",kind:8},{x:0,y:50,id:"color",kind:8},{x:0,y:0,id:"color",kind:8},{x:50,y:0,id:"color",kind:8},{x:100,y:0,id:"color",kind:8},{x:150,y:0,id:"color",kind:8},{x:200,y:0,id:"color",kind:8},{x:0,y:300,id:"color",kind:8},{x:50,y:150,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:350,id:"cell"},{x:200,
y:350,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:50,id:"cell"},{x:300,y:50,id:"cell"},
{x:250,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:300,id:"cell"}],name:{key:"camera"}},fishing8x8:{width:400,height:400,items:[{x:350,y:250,id:"color",kind:4},{x:350,y:200,id:"color",kind:4},{x:300,y:150,id:"color",kind:4},{x:300,y:100,id:"color",kind:4},{x:250,y:50,id:"color",kind:4},{x:200,y:0,id:"color",kind:4},{x:150,y:0,id:"color",kind:4},{x:100,y:0,id:"color",kind:4},{x:50,y:0,id:"color",kind:4},
{x:0,y:50,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:0,y:200,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:50,y:350,id:"color",kind:22},{x:100,y:350,id:"color",kind:22},{x:150,y:350,id:"color",kind:22},{x:150,y:300,id:"color",kind:22},{x:150,y:250,id:"color",kind:26},{x:100,y:250,id:"color",kind:26},{x:100,y:200,id:"color",kind:23},{x:150,y:200,id:"color",kind:23},{x:0,y:300,id:"color",kind:22},{x:100,y:150,id:"color",kind:24},{x:100,y:100,id:"color",
kind:24},{x:150,y:100,id:"color",kind:24},{x:0,y:350,id:"color",kind:33},{x:50,y:300,id:"color",kind:33},{x:100,y:300,id:"color",kind:33},{x:50,y:250,id:"color",kind:33},{x:50,y:200,id:"color",kind:33},{x:50,y:150,id:"color",kind:33},{x:50,y:100,id:"color",kind:33},{x:50,y:50,id:"color",kind:33},{x:0,y:0,id:"color",kind:33},{x:100,y:50,id:"color",kind:33},{x:150,y:50,id:"color",kind:33},{x:200,y:50,id:"color",kind:33},{x:300,y:0,id:"color",kind:33},{x:350,y:0,id:"color",kind:33},{x:350,y:50,id:"color",
kind:33},{x:350,y:100,id:"color",kind:33},{x:250,y:150,id:"color",kind:33},{x:250,y:100,id:"color",kind:33},{x:200,y:100,id:"color",kind:33},{x:200,y:150,id:"color",kind:33},{x:150,y:150,id:"color",kind:33},{x:200,y:200,id:"color",kind:33},{x:250,y:200,id:"color",kind:33},{x:300,y:200,id:"color",kind:33},{x:300,y:250,id:"color",kind:33},{x:250,y:250,id:"color",kind:33},{x:200,y:250,id:"color",kind:33},{x:200,y:300,id:"color",kind:33},{x:250,y:300,id:"color",kind:33},{x:200,y:350,id:"color",kind:33},
{x:250,y:350,id:"color",kind:33},{x:300,y:350,id:"color",kind:33},{x:300,y:300,id:"color",kind:33},{x:350,y:150,id:"color",kind:4},{x:350,y:300,id:"color",kind:3},{x:350,y:350,id:"color",kind:3},{x:300,y:50,id:"color",kind:4},{x:250,y:0,id:"color",kind:4},{x:350,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:350,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},
{x:150,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:200,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:350,y:150,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:0,id:"cell"}],name:{key:"fishing_pole"}},riverbed8x8:{width:400,
height:400,items:[{x:100,y:300,id:"color",kind:4},{x:300,y:300,id:"color",kind:4},{x:350,y:250,id:"color",kind:4},{x:100,y:350,id:"color",kind:4},{x:50,y:300,id:"color",kind:4},{x:250,y:350,id:"color",kind:4},{x:350,y:300,id:"color",kind:4},{x:0,y:300,id:"color",kind:3},{x:0,y:350,id:"color",kind:3},{x:50,y:350,id:"color",kind:3},{x:300,y:350,id:"color",kind:3},{x:350,y:350,id:"color",kind:3},{x:200,y:350,id:"color",kind:3},{x:150,y:350,id:"color",kind:4},{x:0,y:0,id:"color",kind:20},{x:50,y:0,id:"color",
kind:20},{x:100,y:50,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:150,y:100,id:"color",kind:20},{x:350,y:150,id:"color",kind:13},{x:200,y:150,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:50,y:250,id:"color",kind:14},{x:300,y:200,id:"color",kind:14},{x:300,y:250,id:"color",kind:14},{x:100,y:150,id:"color",kind:20},{x:100,y:100,id:"color",kind:20},{x:0,y:100,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},{x:0,y:250,
id:"color",kind:20},{x:100,y:250,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:100,y:0,id:"color",kind:22},{x:150,y:0,id:"color",kind:22},{x:200,y:0,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:300,y:100,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:300,y:150,id:"color",kind:20},{x:250,y:150,id:"color",kind:20},{x:250,y:200,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},
{x:200,y:300,id:"color",kind:20},{x:250,y:300,id:"color",kind:20},{x:0,y:50,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:150,y:50,id:"color",kind:22},{x:200,y:100,id:"color",kind:5},{x:100,y:200,id:"color",kind:5},{x:250,y:250,id:"color",kind:5},{x:150,y:200,id:"color",kind:8},{x:200,y:250,id:"color",kind:8},{x:250,y:100,id:"color",kind:8},{x:50,y:100,id:"color",kind:13},{x:50,y:150,id:"color",kind:20},{x:50,y:50,id:"color",kind:13},{x:0,y:200,id:"color",
kind:14},{x:0,y:150,id:"color",kind:14},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:150,id:"cell"},{x:100,y:200,id:"cell"},
{x:150,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:250,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:200,id:"cell"}],name:{key:"river_bed"}},pants8x8:{width:400,height:400,items:[{x:150,y:0,id:"color",kind:19},{x:200,y:100,id:"color",
kind:19},{x:150,y:100,id:"color",kind:19},{x:150,y:50,id:"color",kind:19},{x:100,y:100,id:"color",kind:19},{x:100,y:150,id:"color",kind:19},{x:50,y:150,id:"color",kind:19},{x:50,y:200,id:"color",kind:19},{x:100,y:200,id:"color",kind:19},{x:50,y:250,id:"color",kind:19},{x:0,y:250,id:"color",kind:19},{x:0,y:300,id:"color",kind:19},{x:250,y:150,id:"color",kind:19},{x:250,y:200,id:"color",kind:19},{x:300,y:200,id:"color",kind:19},{x:300,y:150,id:"color",kind:19},{x:300,y:250,id:"color",kind:19},{x:300,
y:300,id:"color",kind:19},{x:350,y:300,id:"color",kind:19},{x:350,y:250,id:"color",kind:19},{x:50,y:350,id:"color",kind:18},{x:0,y:350,id:"color",kind:18},{x:350,y:350,id:"color",kind:18},{x:300,y:350,id:"color",kind:18},{x:100,y:0,id:"color",kind:18},{x:100,y:50,id:"color",kind:18},{x:250,y:0,id:"color",kind:18},{x:250,y:50,id:"color",kind:18},{x:200,y:50,id:"color",kind:19},{x:200,y:0,id:"color",kind:19},{x:250,y:100,id:"color",kind:19},{x:0,y:200,id:"color",kind:31},{x:0,y:150,id:"color",kind:31},
{x:0,y:100,id:"color",kind:31},{x:50,y:100,id:"color",kind:31},{x:50,y:50,id:"color",kind:31},{x:0,y:50,id:"color",kind:31},{x:0,y:0,id:"color",kind:31},{x:50,y:0,id:"color",kind:31},{x:300,y:0,id:"color",kind:31},{x:300,y:50,id:"color",kind:31},{x:350,y:0,id:"color",kind:31},{x:350,y:50,id:"color",kind:31},{x:300,y:100,id:"color",kind:31},{x:350,y:100,id:"color",kind:31},{x:350,y:150,id:"color",kind:31},{x:350,y:200,id:"color",kind:31},{x:200,y:150,id:"color",kind:31},{x:150,y:150,id:"color",kind:31},
{x:150,y:200,id:"color",kind:31},{x:200,y:200,id:"color",kind:31},{x:150,y:250,id:"color",kind:31},{x:100,y:250,id:"color",kind:31},{x:100,y:300,id:"color",kind:31},{x:150,y:300,id:"color",kind:31},{x:150,y:350,id:"color",kind:31},{x:200,y:350,id:"color",kind:31},{x:200,y:300,id:"color",kind:31},{x:200,y:250,id:"color",kind:31},{x:250,y:250,id:"color",kind:31},{x:250,y:300,id:"color",kind:31},{x:50,y:300,id:"color",kind:19},{x:100,y:350,id:"color",kind:18},{x:250,y:350,id:"color",kind:18},{x:50,y:350,
id:"cell"},{x:0,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:300,
y:250,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:200,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:100,y:350,id:"cell"},{x:250,y:350,id:"cell"}],name:{key:"pants"}},rocket8x8:{width:400,height:400,items:[{x:350,y:350,id:"color",kind:26},{x:300,y:350,id:"color",kind:26},{x:350,y:300,id:"color",kind:26},{x:250,y:350,id:"color",kind:26},{x:250,y:300,id:"color",kind:26},{x:300,y:250,id:"color",kind:26},{x:300,y:300,
id:"color",kind:26},{x:350,y:250,id:"color",kind:26},{x:300,y:200,id:"color",kind:23},{x:250,y:150,id:"color",kind:23},{x:200,y:100,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:200,y:300,id:"color",kind:22},{x:150,y:250,id:"color",kind:22},{x:100,y:200,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:200,y:250,id:"color",kind:22},{x:150,y:200,id:"color",kind:22},{x:100,y:150,id:"color",kind:22},{x:150,y:100,id:"color",kind:23},{x:150,y:150,id:"color",kind:23},{x:200,y:150,id:"color",
kind:23},{x:200,y:200,id:"color",kind:23},{x:250,y:200,id:"color",kind:23},{x:250,y:250,id:"color",kind:23},{x:150,y:0,id:"color",kind:25},{x:0,y:0,id:"color",kind:25},{x:0,y:250,id:"color",kind:20},{x:0,y:300,id:"color",kind:20},{x:0,y:350,id:"color",kind:20},{x:50,y:250,id:"color",kind:20},{x:50,y:350,id:"color",kind:20},{x:50,y:300,id:"color",kind:20},{x:100,y:350,id:"color",kind:20},{x:100,y:300,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:150,y:350,id:"color",kind:20},{x:200,y:350,
id:"color",kind:20},{x:100,y:250,id:"color",kind:20},{x:50,y:200,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:300,y:100,id:"color",kind:20},{x:250,y:100,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:300,y:150,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},
{x:0,y:100,id:"color",kind:20},{x:100,y:0,id:"color",kind:20},{x:0,y:150,id:"color",kind:25},{x:200,y:0,id:"color",kind:25},{x:0,y:200,id:"color",kind:25},{x:0,y:50,id:"color",kind:25},{x:50,y:0,id:"color",kind:25},{x:100,y:100,id:"color",kind:23},{x:50,y:100,id:"color",kind:22},{x:100,y:50,id:"color",kind:23},{x:50,y:50,id:"color",kind:23},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:350,y:250,id:"cell"},
{x:250,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:150,y:250,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:50,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:50,id:"cell"},{x:150,y:0,id:"cell"},{x:200,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:100,id:"cell"},{x:200,y:200,
id:"cell"},{x:250,y:200,id:"cell"},{x:250,y:250,id:"cell"},{x:200,y:0,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:100,id:"cell"}],name:{key:"rocket"}},ambulance8x8:{width:400,height:400,items:[{x:50,y:300,id:"color",kind:26},{x:100,y:300,id:"color",kind:26},{x:150,y:300,id:"color",kind:26},{x:200,y:300,id:"color",kind:26},{x:250,y:300,id:"color",kind:26},{x:300,y:300,id:"color",kind:26},{x:350,y:300,id:"color",kind:26},{x:250,y:200,id:"color",kind:26},{x:250,
y:150,id:"color",kind:26},{x:250,y:100,id:"color",kind:26},{x:200,y:150,id:"color",kind:26},{x:300,y:150,id:"color",kind:26},{x:0,y:300,id:"color",kind:26},{x:0,y:250,id:"color",kind:23},{x:0,y:200,id:"color",kind:23},{x:50,y:200,id:"color",kind:23},{x:50,y:250,id:"color",kind:23},{x:100,y:150,id:"color",kind:20},{x:100,y:200,id:"color",kind:23},{x:100,y:250,id:"color",kind:23},{x:250,y:250,id:"color",kind:22},{x:300,y:250,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:300,y:200,id:"color",
kind:22},{x:350,y:200,id:"color",kind:22},{x:350,y:150,id:"color",kind:22},{x:350,y:100,id:"color",kind:22},{x:100,y:100,id:"color",kind:23},{x:150,y:50,id:"color",kind:23},{x:150,y:100,id:"color",kind:23},{x:200,y:100,id:"color",kind:23},{x:200,y:50,id:"color",kind:23},{x:250,y:50,id:"color",kind:23},{x:300,y:50,id:"color",kind:23},{x:300,y:100,id:"color",kind:23},{x:350,y:50,id:"color",kind:23},{x:0,y:0,id:"color",kind:21},{x:50,y:0,id:"color",kind:21},{x:100,y:0,id:"color",kind:21},{x:150,y:0,
id:"color",kind:21},{x:300,y:0,id:"color",kind:21},{x:350,y:0,id:"color",kind:21},{x:0,y:50,id:"color",kind:21},{x:50,y:50,id:"color",kind:21},{x:0,y:100,id:"color",kind:21},{x:50,y:100,id:"color",kind:21},{x:100,y:50,id:"color",kind:21},{x:0,y:150,id:"color",kind:21},{x:50,y:150,id:"color",kind:21},{x:50,y:350,id:"color",kind:28},{x:100,y:350,id:"color",kind:28},{x:300,y:350,id:"color",kind:28},{x:350,y:350,id:"color",kind:28},{x:0,y:350,id:"color",kind:21},{x:150,y:350,id:"color",kind:21},{x:200,
y:350,id:"color",kind:21},{x:250,y:350,id:"color",kind:21},{x:200,y:0,id:"color",kind:17},{x:250,y:0,id:"color",kind:17},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:200,id:"cell"},{x:50,y:200,id:"cell"},{x:100,y:200,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,
y:50,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:200,y:50,id:"cell"}],name:{key:"ambulance"}},lighthouse8x8:{width:400,height:400,items:[{x:100,y:250,id:"color",kind:18},{x:100,y:200,id:"color",kind:18},{x:150,y:250,id:"color",kind:18},{x:150,y:300,id:"color",kind:18},{x:150,y:200,id:"color",kind:18},{x:100,y:150,id:"color",
kind:18},{x:150,y:350,id:"color",kind:18},{x:50,y:0,id:"color",kind:16},{x:100,y:0,id:"color",kind:16},{x:50,y:100,id:"color",kind:16},{x:100,y:100,id:"color",kind:16},{x:100,y:50,id:"color",kind:18},{x:150,y:100,id:"color",kind:16},{x:150,y:0,id:"color",kind:16},{x:50,y:200,id:"color",kind:18},{x:50,y:350,id:"color",kind:18},{x:50,y:300,id:"color",kind:18},{x:50,y:250,id:"color",kind:18},{x:150,y:50,id:"color",kind:9},{x:50,y:50,id:"color",kind:9},{x:200,y:50,id:"color",kind:17},{x:250,y:0,id:"color",
kind:17},{x:250,y:50,id:"color",kind:17},{x:250,y:100,id:"color",kind:17},{x:300,y:0,id:"color",kind:17},{x:300,y:50,id:"color",kind:17},{x:300,y:100,id:"color",kind:17},{x:350,y:0,id:"color",kind:17},{x:350,y:50,id:"color",kind:17},{x:350,y:100,id:"color",kind:17},{x:350,y:150,id:"color",kind:17},{x:0,y:50,id:"color",kind:17},{x:0,y:0,id:"color",kind:1},{x:0,y:100,id:"color",kind:1},{x:200,y:100,id:"color",kind:1},{x:200,y:0,id:"color",kind:1},{x:0,y:150,id:"color",kind:1},{x:0,y:200,id:"color",
kind:1},{x:0,y:250,id:"color",kind:1},{x:0,y:300,id:"color",kind:1},{x:0,y:350,id:"color",kind:1},{x:200,y:200,id:"color",kind:1},{x:200,y:250,id:"color",kind:1},{x:200,y:300,id:"color",kind:1},{x:200,y:350,id:"color",kind:1},{x:250,y:350,id:"color",kind:1},{x:250,y:300,id:"color",kind:1},{x:250,y:250,id:"color",kind:1},{x:250,y:200,id:"color",kind:1},{x:250,y:150,id:"color",kind:1},{x:300,y:150,id:"color",kind:1},{x:300,y:200,id:"color",kind:1},{x:350,y:200,id:"color",kind:1},{x:300,y:250,id:"color",
kind:1},{x:350,y:250,id:"color",kind:1},{x:300,y:300,id:"color",kind:1},{x:350,y:300,id:"color",kind:1},{x:300,y:350,id:"color",kind:1},{x:350,y:350,id:"color",kind:1},{x:100,y:350,id:"color",kind:0},{x:100,y:300,id:"color",kind:0},{x:200,y:150,id:"color",kind:1},{x:50,y:150,id:"color",kind:18},{x:150,y:150,id:"color",kind:18},{x:50,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:150,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:150,y:150,
id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:0,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:0,id:"cell"},{x:100,y:150,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:100,id:"cell"}],name:{key:"lighthouse"}},nailpolish8x8:{width:400,height:400,items:[{x:300,y:300,id:"color",kind:31},
{x:250,y:300,id:"color",kind:31},{x:200,y:300,id:"color",kind:31},{x:250,y:250,id:"color",kind:31},{x:300,y:250,id:"color",kind:31},{x:300,y:200,id:"color",kind:31},{x:350,y:250,id:"color",kind:31},{x:350,y:300,id:"color",kind:31},{x:250,y:200,id:"color",kind:31},{x:200,y:250,id:"color",kind:31},{x:250,y:150,id:"color",kind:31},{x:300,y:150,id:"color",kind:31},{x:0,y:100,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:100,y:100,id:"color",kind:23},{x:100,y:50,id:"color",
kind:23},{x:100,y:0,id:"color",kind:23},{x:50,y:150,id:"color",kind:27},{x:50,y:200,id:"color",kind:27},{x:50,y:250,id:"color",kind:0},{x:50,y:300,id:"color",kind:31},{x:50,y:100,id:"color",kind:23},{x:50,y:50,id:"color",kind:23},{x:50,y:0,id:"color",kind:23},{x:0,y:300,id:"color",kind:7},{x:0,y:350,id:"color",kind:7},{x:50,y:350,id:"color",kind:7},{x:100,y:350,id:"color",kind:7},{x:100,y:300,id:"color",kind:35},{x:100,y:250,id:"color",kind:35},{x:250,y:100,id:"color",kind:30},{x:300,y:100,id:"color",
kind:30},{x:0,y:250,id:"color",kind:20},{x:0,y:200,id:"color",kind:20},{x:0,y:150,id:"color",kind:20},{x:100,y:150,id:"color",kind:20},{x:100,y:200,id:"color",kind:20},{x:150,y:200,id:"color",kind:20},{x:150,y:300,id:"color",kind:20},{x:150,y:250,id:"color",kind:20},{x:150,y:350,id:"color",kind:20},{x:200,y:350,id:"color",kind:20},{x:350,y:350,id:"color",kind:20},{x:350,y:200,id:"color",kind:20},{x:200,y:200,id:"color",kind:20},{x:200,y:150,id:"color",kind:20},{x:150,y:150,id:"color",kind:20},{x:150,
y:100,id:"color",kind:20},{x:200,y:100,id:"color",kind:20},{x:200,y:50,id:"color",kind:20},{x:150,y:50,id:"color",kind:20},{x:200,y:0,id:"color",kind:20},{x:250,y:0,id:"color",kind:20},{x:150,y:0,id:"color",kind:20},{x:250,y:50,id:"color",kind:20},{x:300,y:0,id:"color",kind:20},{x:300,y:50,id:"color",kind:20},{x:350,y:0,id:"color",kind:20},{x:350,y:50,id:"color",kind:20},{x:350,y:100,id:"color",kind:20},{x:350,y:150,id:"color",kind:20},{x:250,y:350,id:"color",kind:31},{x:300,y:350,id:"color",kind:31},
{x:0,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:100,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:250,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:0,y:100,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:50,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:100,id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:250,id:"cell"},
{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"}],name:{key:"nail_polish"}},clubs8x8:{width:400,height:400,items:[{x:50,y:250,id:"color",kind:8},{x:100,y:200,id:"color",kind:8},{x:0,y:200,id:"color",kind:8},{x:50,y:200,id:"color",kind:8},{x:150,y:200,id:"color",kind:8},{x:100,y:150,id:"color",kind:8},{x:150,y:100,id:"color",kind:8},{x:200,y:100,id:"color",
kind:8},{x:200,y:50,id:"color",kind:8},{x:100,y:50,id:"color",kind:8},{x:150,y:0,id:"color",kind:8},{x:200,y:0,id:"color",kind:8},{x:250,y:50,id:"color",kind:8},{x:0,y:150,id:"color",kind:8},{x:50,y:100,id:"color",kind:8},{x:150,y:150,id:"color",kind:8},{x:200,y:150,id:"color",kind:8},{x:100,y:350,id:"color",kind:5},{x:150,y:300,id:"color",kind:5},{x:200,y:250,id:"color",kind:5},{x:250,y:200,id:"color",kind:5},{x:300,y:150,id:"color",kind:5},{x:200,y:300,id:"color",kind:5},{x:150,y:350,id:"color",
kind:5},{x:200,y:350,id:"color",kind:5},{x:250,y:350,id:"color",kind:5},{x:300,y:250,id:"color",kind:5},{x:300,y:200,id:"color",kind:5},{x:350,y:200,id:"color",kind:5},{x:350,y:150,id:"color",kind:5},{x:150,y:250,id:"color",kind:5},{x:200,y:200,id:"color",kind:5},{x:250,y:150,id:"color",kind:5},{x:300,y:100,id:"color",kind:5},{x:50,y:150,id:"color",kind:17},{x:150,y:50,id:"color",kind:17},{x:0,y:350,id:"color",kind:22},{x:0,y:300,id:"color",kind:22},{x:0,y:250,id:"color",kind:22},{x:50,y:300,id:"color",
kind:22},{x:50,y:350,id:"color",kind:22},{x:100,y:300,id:"color",kind:22},{x:100,y:250,id:"color",kind:22},{x:250,y:250,id:"color",kind:22},{x:250,y:300,id:"color",kind:22},{x:300,y:300,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:350,y:350,id:"color",kind:22},{x:350,y:300,id:"color",kind:22},{x:350,y:250,id:"color",kind:22},{x:250,y:100,id:"color",kind:22},{x:350,y:100,id:"color",kind:22},{x:350,y:50,id:"color",kind:22},{x:300,y:50,id:"color",kind:22},{x:300,y:0,id:"color",kind:22},{x:350,
y:0,id:"color",kind:22},{x:250,y:0,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:50,y:50,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:0,y:50,id:"color",kind:22},{x:0,y:0,id:"color",kind:22},{x:50,y:0,id:"color",kind:22},{x:100,y:0,id:"color",kind:22},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:150,y:300,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:150,y:200,id:"cell"},
{x:100,y:200,id:"cell"},{x:50,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:0,y:200,id:"cell"},{x:0,y:150,id:"cell"},{x:100,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:150,y:100,id:"cell"},{x:150,y:150,id:"cell"},{x:200,y:150,id:"cell"},{x:200,y:100,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:350,y:150,
id:"cell"},{x:350,y:200,id:"cell"},{x:300,y:250,id:"cell"}],name:{key:"clubs"}},egg8x8:{width:400,height:400,items:[{x:50,y:250,id:"color",kind:7},{x:100,y:350,id:"color",kind:7},{x:150,y:350,id:"color",kind:7},{x:200,y:350,id:"color",kind:7},{x:300,y:250,id:"color",kind:7},{x:300,y:200,id:"color",kind:7},{x:250,y:200,id:"color",kind:7},{x:250,y:150,id:"color",kind:7},{x:200,y:200,id:"color",kind:7},{x:200,y:250,id:"color",kind:7},{x:150,y:250,id:"color",kind:7},{x:100,y:250,id:"color",kind:7},{x:100,
y:200,id:"color",kind:7},{x:100,y:300,id:"color",kind:7},{x:150,y:300,id:"color",kind:7},{x:250,y:300,id:"color",kind:7},{x:250,y:250,id:"color",kind:7},{x:200,y:300,id:"color",kind:7},{x:250,y:350,id:"color",kind:6},{x:300,y:300,id:"color",kind:6},{x:50,y:300,id:"color",kind:6},{x:50,y:200,id:"color",kind:23},{x:100,y:150,id:"color",kind:23},{x:150,y:200,id:"color",kind:23},{x:200,y:150,id:"color",kind:23},{x:300,y:150,id:"color",kind:23},{x:250,y:50,id:"color",kind:22},{x:50,y:100,id:"color",kind:23},
{x:350,y:250,id:"color",kind:33},{x:350,y:200,id:"color",kind:33},{x:350,y:150,id:"color",kind:33},{x:350,y:100,id:"color",kind:33},{x:350,y:50,id:"color",kind:33},{x:350,y:0,id:"color",kind:33},{x:200,y:0,id:"color",kind:22},{x:200,y:100,id:"color",kind:8},{x:150,y:100,id:"color",kind:8},{x:150,y:50,id:"color",kind:8},{x:200,y:50,id:"color",kind:8},{x:300,y:0,id:"color",kind:33},{x:250,y:0,id:"color",kind:33},{x:300,y:50,id:"color",kind:33},{x:100,y:0,id:"color",kind:33},{x:50,y:0,id:"color",kind:33},
{x:50,y:50,id:"color",kind:33},{x:0,y:0,id:"color",kind:33},{x:0,y:100,id:"color",kind:33},{x:0,y:50,id:"color",kind:33},{x:0,y:150,id:"color",kind:33},{x:0,y:200,id:"color",kind:33},{x:0,y:250,id:"color",kind:33},{x:100,y:100,id:"color",kind:8},{x:250,y:100,id:"color",kind:8},{x:100,y:50,id:"color",kind:23},{x:150,y:0,id:"color",kind:23},{x:150,y:150,id:"color",kind:8},{x:50,y:150,id:"color",kind:23},{x:300,y:100,id:"color",kind:23},{x:300,y:350,id:"color",kind:19},{x:350,y:300,id:"color",kind:19},
{x:350,y:350,id:"color",kind:19},{x:0,y:300,id:"color",kind:19},{x:0,y:350,id:"color",kind:19},{x:50,y:350,id:"color",kind:19},{x:100,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:50,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:150,y:250,id:"cell"},{x:200,y:200,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:250,y:300,id:"cell"},{x:300,y:250,id:"cell"},{x:150,y:350,id:"cell"},{x:250,y:350,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:200,id:"cell"},
{x:50,y:150,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:200,y:150,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:100,y:50,id:"cell"},{x:0,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"}],name:{key:"boiled_egg"}},lantern8x8:{width:400,height:400,items:[{x:0,y:50,id:"color",kind:25},{x:50,y:50,id:"color",kind:25},{x:100,y:50,id:"color",kind:25},
{x:150,y:50,id:"color",kind:25},{x:100,y:0,id:"color",kind:25},{x:50,y:0,id:"color",kind:25},{x:50,y:350,id:"color",kind:25},{x:50,y:300,id:"color",kind:25},{x:100,y:300,id:"color",kind:25},{x:100,y:350,id:"color",kind:25},{x:0,y:350,id:"color",kind:25},{x:150,y:350,id:"color",kind:25},{x:50,y:250,id:"color",kind:22},{x:50,y:200,id:"color",kind:22},{x:0,y:150,id:"color",kind:22},{x:0,y:100,id:"color",kind:22},{x:150,y:100,id:"color",kind:22},{x:150,y:150,id:"color",kind:22},{x:150,y:200,id:"color",
kind:22},{x:0,y:200,id:"color",kind:22},{x:50,y:150,id:"color",kind:22},{x:50,y:100,id:"color",kind:22},{x:100,y:100,id:"color",kind:22},{x:200,y:50,id:"color",kind:25},{x:150,y:0,id:"color",kind:25},{x:150,y:250,id:"color",kind:22},{x:200,y:200,id:"color",kind:22},{x:200,y:150,id:"color",kind:22},{x:200,y:100,id:"color",kind:22},{x:150,y:300,id:"color",kind:25},{x:200,y:350,id:"color",kind:25},{x:100,y:250,id:"color",kind:27},{x:100,y:150,id:"color",kind:8},{x:100,y:200,id:"color",kind:8},{x:0,y:250,
id:"color",kind:17},{x:0,y:300,id:"color",kind:17},{x:0,y:0,id:"color",kind:17},{x:200,y:0,id:"color",kind:17},{x:250,y:0,id:"color",kind:17},{x:250,y:50,id:"color",kind:17},{x:300,y:50,id:"color",kind:17},{x:300,y:100,id:"color",kind:17},{x:300,y:150,id:"color",kind:17},{x:300,y:200,id:"color",kind:17},{x:250,y:300,id:"color",kind:17},{x:200,y:300,id:"color",kind:17},{x:200,y:250,id:"color",kind:17},{x:250,y:250,id:"color",kind:17},{x:250,y:200,id:"color",kind:17},{x:250,y:150,id:"color",kind:17},
{x:250,y:100,id:"color",kind:17},{x:300,y:250,id:"color",kind:17},{x:350,y:200,id:"color",kind:17},{x:350,y:150,id:"color",kind:17},{x:350,y:100,id:"color",kind:17},{x:250,y:350,id:"color",kind:1},{x:300,y:350,id:"color",kind:1},{x:300,y:300,id:"color",kind:1},{x:350,y:300,id:"color",kind:1},{x:350,y:350,id:"color",kind:1},{x:350,y:250,id:"color",kind:1},{x:350,y:50,id:"color",kind:1},{x:350,y:0,id:"color",kind:1},{x:300,y:0,id:"color",kind:1},{x:100,y:250,id:"cell"},{x:100,y:200,id:"cell"},{x:100,
y:150,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,id:"cell"},{x:50,y:300,id:"cell"},{x:100,y:300,id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:150,y:300,id:"cell"},{x:200,y:350,id:"cell"},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:0,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:50,y:50,id:"cell"},{x:100,y:50,id:"cell"},{x:100,y:0,id:"cell"},{x:150,y:0,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:200,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,
id:"cell"},{x:250,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:250,y:200,id:"cell"},{x:200,y:250,id:"cell"},{x:200,y:300,id:"cell"},{x:250,y:300,id:"cell"},{x:250,y:250,id:"cell"},{x:300,y:250,id:"cell"},{x:300,y:200,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:300,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:350,y:150,id:"cell"},{x:350,y:200,id:"cell"}],name:{key:"lantern"}},thanks8x8:{width:400,height:400,items:[{x:300,y:200,id:"color",kind:23},{x:350,y:200,id:"color",kind:23},{x:350,
y:250,id:"color",kind:23},{x:300,y:250,id:"color",kind:23},{x:300,y:300,id:"color",kind:22},{x:350,y:300,id:"color",kind:22},{x:250,y:350,id:"color",kind:22},{x:300,y:350,id:"color",kind:22},{x:350,y:350,id:"color",kind:22},{x:200,y:300,id:"color",kind:7},{x:200,y:250,id:"color",kind:7},{x:150,y:300,id:"color",kind:7},{x:150,y:250,id:"color",kind:7},{x:100,y:300,id:"color",kind:7},{x:50,y:250,id:"color",kind:7},{x:0,y:200,id:"color",kind:7},{x:0,y:150,id:"color",kind:7},{x:50,y:150,id:"color",kind:7},
{x:50,y:200,id:"color",kind:7},{x:100,y:250,id:"color",kind:7},{x:100,y:200,id:"color",kind:7},{x:100,y:150,id:"color",kind:7},{x:150,y:150,id:"color",kind:7},{x:150,y:200,id:"color",kind:7},{x:200,y:200,id:"color",kind:7},{x:200,y:150,id:"color",kind:7},{x:200,y:0,id:"color",kind:7},{x:200,y:100,id:"color",kind:7},{x:200,y:50,id:"color",kind:7},{x:0,y:250,id:"color",kind:6},{x:50,y:300,id:"color",kind:6},{x:0,y:300,id:"color",kind:31},{x:50,y:350,id:"color",kind:31},{x:100,y:350,id:"color",kind:31},
{x:150,y:350,id:"color",kind:31},{x:200,y:350,id:"color",kind:31},{x:0,y:350,id:"color",kind:31},{x:300,y:100,id:"color",kind:31},{x:300,y:150,id:"color",kind:31},{x:350,y:150,id:"color",kind:31},{x:350,y:100,id:"color",kind:31},{x:350,y:50,id:"color",kind:31},{x:300,y:50,id:"color",kind:31},{x:300,y:0,id:"color",kind:31},{x:350,y:0,id:"color",kind:31},{x:0,y:100,id:"color",kind:31},{x:0,y:50,id:"color",kind:31},{x:0,y:0,id:"color",kind:31},{x:100,y:0,id:"color",kind:31},{x:50,y:50,id:"color",kind:31},
{x:50,y:0,id:"color",kind:31},{x:100,y:50,id:"color",kind:31},{x:250,y:300,id:"color",kind:22},{x:250,y:250,id:"color",kind:23},{x:250,y:200,id:"color",kind:23},{x:250,y:150,id:"color",kind:31},{x:250,y:100,id:"color",kind:31},{x:250,y:50,id:"color",kind:31},{x:100,y:100,id:"color",kind:31},{x:50,y:100,id:"color",kind:31},{x:150,y:100,id:"color",kind:6},{x:150,y:50,id:"color",kind:6},{x:150,y:0,id:"color",kind:6},{x:250,y:0,id:"color",kind:31},{x:0,y:300,id:"cell"},{x:0,y:350,id:"cell"},{x:50,y:350,
id:"cell"},{x:100,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:350,id:"cell"},{x:0,y:100,id:"cell"},{x:50,y:100,id:"cell"},{x:100,y:100,id:"cell"},{x:100,y:50,id:"cell"},{x:0,y:0,id:"cell"},{x:100,y:0,id:"cell"},{x:50,y:0,id:"cell"},{x:250,y:0,id:"cell"},{x:250,y:50,id:"cell"},{x:350,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:350,y:100,id:"cell"},{x:300,y:150,id:"cell"},{x:300,y:100,id:"cell"},{x:250,y:150,id:"cell"},{x:300,y:0,id:"cell"},{x:300,y:50,id:"cell"},{x:250,y:100,id:"cell"},{x:350,y:150,
id:"cell"},{x:350,y:200,id:"cell"},{x:350,y:250,id:"cell"},{x:300,y:350,id:"cell"},{x:350,y:300,id:"cell"},{x:0,y:50,id:"cell"},{x:50,y:50,id:"cell"}],name:{key:"thumbs_up"}},rainbow8x8:{width:400,height:400,items:[{x:0,y:300,id:"color",kind:26},{x:0,y:250,id:"color",kind:26},{x:50,y:150,id:"color",kind:26},{x:100,y:100,id:"color",kind:26},{x:50,y:200,id:"color",kind:26},{x:150,y:50,id:"color",kind:26},{x:200,y:50,id:"color",kind:26},{x:300,y:0,id:"color",kind:26},{x:250,y:0,id:"color",kind:26},{x:0,
y:350,id:"color",kind:8},{x:50,y:300,id:"color",kind:8},{x:50,y:250,id:"color",kind:8},{x:100,y:150,id:"color",kind:8},{x:150,y:100,id:"color",kind:8},{x:250,y:50,id:"color",kind:8},{x:300,y:50,id:"color",kind:8},{x:350,y:0,id:"color",kind:8},{x:50,y:350,id:"color",kind:17},{x:100,y:300,id:"color",kind:17},{x:100,y:250,id:"color",kind:17},{x:150,y:150,id:"color",kind:17},{x:250,y:100,id:"color",kind:17},{x:350,y:50,id:"color",kind:17},{x:300,y:100,id:"color",kind:17},{x:100,y:200,id:"color",kind:8},
{x:200,y:100,id:"color",kind:8},{x:200,y:150,id:"color",kind:17},{x:150,y:200,id:"color",kind:17},{x:100,y:350,id:"color",kind:34},{x:150,y:300,id:"color",kind:34},{x:150,y:250,id:"color",kind:34},{x:200,y:200,id:"color",kind:34},{x:250,y:150,id:"color",kind:34},{x:300,y:150,id:"color",kind:34},{x:350,y:100,id:"color",kind:34},{x:150,y:350,id:"color",kind:20},{x:200,y:300,id:"color",kind:20},{x:200,y:250,id:"color",kind:20},{x:250,y:200,id:"color",kind:20},{x:300,y:200,id:"color",kind:20},{x:350,
y:150,id:"color",kind:20},{x:200,y:350,id:"color",kind:16},{x:250,y:300,id:"color",kind:16},{x:250,y:250,id:"color",kind:16},{x:300,y:250,id:"color",kind:16},{x:350,y:200,id:"color",kind:16},{x:250,y:350,id:"color",kind:2},{x:300,y:300,id:"color",kind:2},{x:350,y:250,id:"color",kind:2},{x:0,y:200,id:"color",kind:21},{x:0,y:150,id:"color",kind:21},{x:0,y:100,id:"color",kind:21},{x:0,y:50,id:"color",kind:21},{x:0,y:0,id:"color",kind:21},{x:50,y:0,id:"color",kind:21},{x:50,y:50,id:"color",kind:21},{x:50,
y:100,id:"color",kind:21},{x:100,y:50,id:"color",kind:21},{x:100,y:0,id:"color",kind:21},{x:150,y:0,id:"color",kind:21},{x:200,y:0,id:"color",kind:21},{x:350,y:300,id:"color",kind:21},{x:300,y:350,id:"color",kind:21},{x:350,y:350,id:"color",kind:21},{x:0,y:300,id:"cell"},{x:0,y:250,id:"cell"},{x:50,y:200,id:"cell"},{x:50,y:150,id:"cell"},{x:100,y:100,id:"cell"},{x:150,y:50,id:"cell"},{x:200,y:50,id:"cell"},{x:250,y:0,id:"cell"},{x:300,y:0,id:"cell"},{x:350,y:50,id:"cell"},{x:300,y:100,id:"cell"},
{x:250,y:100,id:"cell"},{x:200,y:150,id:"cell"},{x:150,y:200,id:"cell"},{x:100,y:250,id:"cell"},{x:100,y:300,id:"cell"},{x:50,y:350,id:"cell"},{x:150,y:350,id:"cell"},{x:200,y:300,id:"cell"},{x:200,y:250,id:"cell"},{x:250,y:200,id:"cell"},{x:300,y:200,id:"cell"},{x:350,y:150,id:"cell"},{x:250,y:350,id:"cell"},{x:300,y:300,id:"cell"},{x:350,y:250,id:"cell"},{x:150,y:150,id:"cell"},{x:0,y:350,id:"cell"},{x:350,y:0,id:"cell"},{x:200,y:350,id:"cell"},{x:350,y:200,id:"cell"}],name:{key:"rainbow"}},Jj:"bathduck5x5 butterfly5x5 bell5x5 telephone5x5 tomato5x5 key5x5 fish5x5 coffeecup5x5 cherry5x5 puzzlepiece5x5 camel5x5 mouse5x6 guineapig5x6 car5x6 coffeebean6x5 sad6x5 smiley6x5 weights5x7 koala5x7 lollipop7x5 saturn5x7 necklace7x5 bus5x7 chair6x6 frog6x6 boat6x6 flower6x6 musicnote6x6 tractor6x6 cow6x6 shrub6x6 snail6x6 pear6x6 tree6x6 snake6x6 duck6x6 headphones6x7 strawberry7x6 squirrel6x7 plane6x7 shirt7x6 space6x7 earring7x6 lipstick6x7 dog6x7 city7x7 mountains7x7 baseball7x7 tv7x7 sunflower7x7 umbrella7x7 arrow7x7 cactus7x7 hat7x7 bird7x7 chicken7x7 teapot7x7 faucet7x7 hamburger7x7 turnip7x7 egg7x7 sun7x7 sword7x7 moon7x7 candle5x8 banana5x8 cat5x8 shovel8x5 flashlight5x8 well8x5 cellphone8x5 carrot8x5 question8x6 sunset6x8 wave8x6 ponytail6x8 sapling8x6 icescream8x6 lion8x6 hippo6x8 pickles8x6 apple6x8 corn8x7 bunny8x7 star8x7 panda8x7 heart8x8 deer8x8 computer8x8 house8x8 elephant8x8 dolphin8x8 teabag8x8 mug8x8 bee8x8 pond8x8 park8x8 grapes8x8 pearl8x8 stove8x8 rose8x8 alpaca8x8 desert8x8 sheep8x8 clock8x8 fishbowl8x8 brush8x8 melon8x8 mushroom8x8 cake8x8 swan8x8 bike8x8 bread8x8 purse8x8 bed8x8 tadpole8x8 book8x8 bear8x8 trafficlight8x8 fire8x8 drink8x8 leaf8x8 dragonfly8x8 volcano8x8 coral8x8 bracelet8x8 backpack8x8 orca8x8 souppan8x8 tent8x8 cookie8x8 magictrick8x8 handmirror8x8 waterfall8x8 chest8x8 chimney8x8 salt8x8 glasses8x8 lamp8x8 horse8x8 golf8x8 pizza8x8 rain8x8 toaster8x8 cheese8x8 goat8x8 iceskates8x8 microphone8x8 wateringcan8x8 shuttle8x8 door8x8 bubblegum8x8 shootingstar8x8 bell8x8 winter8x8 spring8x8 summer8x8 autumn8x8 donut8x8 santa8x8 hedgehog8x8 clouds8x8 boot8x8 scissors8x8 chocolate8x8 magnifier8x8 hanger8x8 bowtie8x8 kite8x8 beard8x8 fountain8x8 crocodile8x8 smile8x8 peas8x8 tutu8x8 tornado8x8 balloon8x8 spades8x8 paperboat8x8 pencil8x8 phonograph8x8 beach8x8 pelican8x8 seagull8x8 crab8x8 diamonds8x8 woods8x8 camera8x8 fishing8x8 riverbed8x8 pants8x8 rocket8x8 ambulance8x8 lighthouse8x8 nailpolish8x8 clubs8x8 egg8x8 lantern8x8 thanks8x8 rainbow8x8".split(" ")},
It:[]}}var Pe={};
function Qe(){Pe={jp:"Pixocross",buttons:{default_color:"puzzle",bigPlay:"puzzle"},gb:{bigPlay:{type:"image",p:ud,Y:J(38),Da:J(99),Cb:2,Yb:J(30),fontSize:L({big:46,small:30})}},Ab:{bl:.25,Ug:500},Yh:{uw:[{p:jd,x:0,y:0},{p:"undefined"!==typeof Rd?Rd:void 0,y:J(50,"round"),x:{align:"center"}}],Ef:{align:"top",offset:J(36)},Rh:J(546),jh:J(426)},Bj:{rp:{w:T.w,align:"center",g:"top",fontSize:J(46),fillColor:"#5a1f00"},tp:-9999,ko:{w:T.w,align:"center",g:"middle",fontSize:J(38),fillColor:"#fff"},lo:{align:"center",
offset:J(0)},mo:J(68,"round"),Sg:J(500),Wk:J(116)},rc:{Xb:J(14),$b:J(62),Pc:{w:T.w,align:"center",g:"middle",fontSize:J(42),fillColor:"#260844"},lA:!0,So:J(112),Ps:{w:T.w,align:"left",g:"top",fillColor:"#260844",fontSize:J(40)},To:J(160),Ss:J(400),Rs:J(110),Os:{w:T.w,align:"left",g:"top",fillColor:"#ffa536",fontSize:J(40)},Tq:J(216),Cv:{w:T.w,align:"center",g:"top",fillColor:"#260844",fontSize:J(40)},Dv:J(10),Bv:{w:T.w,align:"left",g:"top",fillColor:"#ffa536",fontSize:J(40)},Ev:{w:T.w,align:"left",
g:"top",fillColor:"#ffffff",fontSize:J(40)},Fv:J(160)},options:{Xb:J(8),Pf:800,Qf:ic,Nh:600,Oh:dc,dh:J(500),xf:J(0),bh:J(100),ah:J(100),$b:J(44),Pc:{w:T.w,align:"center",g:"middle",fontSize:J(40),fillColor:"#24918a"},Xj:{w:T.w,align:"center",g:"top",fontSize:J(40),fillColor:"#24918a"},Ri:J(130),Pi:J(260),Oi:J(410),Ni:J(510),tk:{w:T.w,g:"middle",align:"center",fontSize:J(32),fillColor:"#24918a"},wk:{w:T.w,align:"center",g:"top",fontSize:J(40),fillColor:"#24918a"},yk:J(100,"round"),uk:J(164,"round"),
vk:J(424,"round"),sk:J(510,"round"),rk:J(510,"round"),Cn:J(120),Rd:J(70),vi:J(90),sf:J(350),Ng:J(450),Pg:J(112),yi:J(548)},dj:{font:{w:T.w,align:"center",g:"middle",fontSize:J(54),fillColor:"#24918a"},yn:J(184),fl:"bigPlay",gl:J(132),Fi:J(420)},ej:{Fi:J(420)},ad:{Kq:{align:"center",offset:0},Jq:{w:T.w,align:"center",g:"top",fontSize:J(32),fillColor:"#06996b"},Bk:J(28),Ck:J(28),sn:9999,an:9999,$b:J(6),Pc:{w:T.w,align:"center",g:"top",fontSize:J(48),fillColor:"#24918a"}},ae:{Pf:800,Qf:ic,Nh:600,Oh:dc,
bn:{w:T.w,align:"center",g:"middle",fontSize:J(30),fillColor:"#24918a",fa:J(6)},un:{w:T.w,align:"center",g:"middle",fontSize:J(24),fillColor:"#24918a",fa:J(6)},Wj:J(460),Vj:J(210),vf:{align:"bottom",offset:J(-30)},sq:J(200),Xb:J(8),backgroundImage:qd}}}I.i=I.i||{};I.i.pj=function(){I.b.Gc()};I.i.xx=function(){};I.i.Ot=function(){};I.i.fm=function(){I.b.Gc()};I.i.ux=function(){};I.i.yp=function(){};I.i.Bp=function(){};I.i.Ap=function(){};I.i.vx=function(){};I.i.At=function(){};I.i.zp=function(){};
I.i.rt=function(){I.b.Gc()};I.i.st=function(){I.b.Gc()};I.i.Kf=function(){I.b.Gc()};I.i.qt=function(){I.b.Gc()};I.i.mt=function(b){void 0===I.b.Ph&&(I.b.Ph=new Re(!0));Se(b)};I.i.tr=function(){var b=I.b.Nc;void 0===I.b.Ph&&(I.b.Ph=new Re(!0));Te(b)};I.i.Gd=function(b){window.open(b)};I.i.vh=function(){return[{e:cd,url:I.q.nm}]};I.i.wx=function(){};I.qd=I.qd||{};I.qd.pj=function(){I.b.ii=!1};I.qd.Ot=function(){};I.qd.fm=function(){I.b.ii=!1};I.qd.Kf=function(){I.b.ii=!1};
function Ue(b,c){for(var d in b.prototype)c.prototype[d]=b.prototype[d]}function Ve(b,c,d,e){this.ok=this.Cf=b;this.As=c;this.duration=1;this.Bo=e;this.ce=d;this.Ki=null;this.lg=0}function We(b,c){b.lg+=c;b.lg>b.duration&&b.Ki&&(b.Ki(),b.Ki=null)}Ve.prototype.ea=function(){if(this.lg>=this.duration)return this.ce(this.duration,this.Cf,this.ok-this.Cf,this.duration);var b=this.ce(this.lg,this.Cf,this.ok-this.Cf,this.duration);this.Bo&&(b=this.Bo(b));return b};
function Xe(b,c){b.Cf=b.ea();b.ok=c;b.duration=b.As;b.Ki=void 0;b.lg=0}I.Us=void 0!==I.environment?I.environment:"development";I.pw=void 0!==I.ga?I.ga:I.Us;"undefined"!==typeof I.mediaUrl?ga(I.mediaUrl):ga(I.size);I.is="backButton";I.Qe="languageSet";I.pe="resizeEvent";I.version={builder:"1.8.3.0","build-time":"14:56:09","build-date":"09-09-2016",audio:F.Xa?"web audio api":F.Ea?"html5 audio":"no audio"};
I.yw=new function(){this.ee=this.Yt=3;l.s.cg&&(this.ee=3>l.xa.Sd?1:4.4>l.xa.Sd?2:3);l.xa.xj&&(this.ee=7>l.xa.Sd?2:3);l.xa.In&&(this.ee=8>l.xa.Sd?2:3);I.version.browser_name=l.name;I.version.browser_version=l.s.version;I.version.os_version=l.xa.version;I.version.browser_grade=this.ee};I.a={};"function"===typeof Le&&Le();"function"===typeof Oe&&Oe();"function"===typeof Qe&&Qe();"function"===typeof initGameThemeSettings&&initGameThemeSettings();I.a.r="undefined"!==typeof Ke?Ke:{};
I.a.o="undefined"!==typeof Ne?Ne:{};I.a.S="undefined"!==typeof Pe?Pe:{};I.a.jx="undefined"!==typeof gameThemeSettingsVar?gameThemeSettingsVar:{};I.Uf=window.publisherSettings;I.q="undefined"!==typeof game_configuration?game_configuration:{};"undefined"!==typeof Me&&(I.q=Me);if("undefined"!==typeof configuration_product)for(var Ye in configuration_product)I.q[Ye]=configuration_product[Ye];
(function(){var b,c,d,e,g;I.l={};I.l.Sn="undefined"!==typeof W?W:{};I.l.ob=void 0!==I.q.Cd&&void 0!==I.q.Cd.Ai?I.q.Cd.Ai:I.a.r.Cd.Ai;if(I.q.Gv)for(c=I.l.ob.length-1;0<=c;c--)0>I.q.Gv.indexOf(I.l.ob[c])&&I.l.ob.splice(c,1);try{if(e=function(){var b,c,d,e,g;c={};if(b=window.location.search.substring(1))for(b=b.split("&"),e=0,g=b.length;e<g;e++)d=b[e].split("="),c[d[0]]=d[1];return c}(),e.lang)for(d=e.lang.toLowerCase().split("+"),c=I.l.ob.length-1;0<=c;c--)0>d.indexOf(I.l.ob[c])&&I.l.ob.splice(c,1)}catch(h){}0===
I.l.ob.length&&I.l.ob.push("en-us");d=navigator.languages?navigator.languages:[navigator.language||navigator.userLanguage];for(c=0;c<d.length;c++)if("string"===typeof d[c]){g=d[c].toLowerCase();for(e=0;e<I.l.ob.length;e++)if(0<=I.l.ob[e].search(g)){b=I.l.ob[e];break}if(void 0!==b)break}void 0===b&&(b=void 0!==I.q.Cd&&void 0!==I.q.Cd.uj?I.q.Cd.uj:I.a.r.Cd.uj);I.l.Mk=0<=I.l.ob.indexOf(b)?b:I.l.ob[0];I.l.pi=I.l.Sn[I.l.Mk];if(void 0!==I.a.r.gb.language_toggle&&void 0!==I.a.r.gb.language_toggle.O){b=I.a.r.gb.language_toggle.O;
d=[];for(c=0;c<b.length;c++)0<=I.l.ob.indexOf(b[c].id)&&d.push(b[c]);I.a.r.gb.language_toggle.O=d}I.l.N=function(b,c){var d,e,g,h;if(void 0!==I.l.pi&&void 0!==I.l.pi[b]){d=I.l.pi[b];if(e=d.match(/#touch{.*}\s*{.*}/g))for(h=0;h<e.length;h++)g=(g=l.Yc.xn||l.Yc.Mm)?e[h].match(/{[^}]*}/g)[1]:e[h].match(/{[^}]*}/g)[0],g=g.substring(1,g.length-1),d=d.replace(e[h],g);return d}return c};I.l.Aq=function(b){I.l.Mk=b;I.l.pi=I.l.Sn[b];la(I.Qe,b)};I.l.$l=function(){return I.l.Mk};I.l.kt=function(){return I.l.ob};
I.l.Ct=function(b){return 0<=I.l.ob.indexOf(b)}})();I.Hs={xa:"",Du:"",Eu:"",Gs:""};I.d={};I.d.createEvent=function(b,c){var d,e,g,h;e=c.detail||{};g=c.bubbles||!1;h=c.cancelable||!1;if("function"===typeof CustomEvent)d=new CustomEvent(b,{detail:e,bubbles:g,cancelable:h});else try{d=document.createEvent("CustomEvent"),d.initCustomEvent(b,g,h,e)}catch(k){d=document.createEvent("Event"),d.initEvent(b,g,h),d.data=e}return d};
I.d.Qv=function(b){var c=Math.floor(b%6E4/1E3);return(0>b?"-":"")+Math.floor(b/6E4)+(10>c?":0":":")+c};I.d.Bh=function(b){function c(){}c.prototype=Ze.prototype;b.prototype=new c};I.d.fv=function(b,c,d,e,g,h){var k=!1,m=document.getElementById(b);m||(k=!0,m=document.createElement("canvas"),m.id=b);m.style.zIndex=c;m.style.top=d+"px";m.style.left=e+"px";m.width=g;m.height=h;k&&((b=document.getElementById("viewport"))?b.appendChild(m):document.body.appendChild(m));I.sd.push(m);return m};
(function(){var b,c,d,e,g,h,k;I.Hp=0;I.Ip=0;I.ck=!1;I.bw=l.s.cg&&l.s.Sd&&4<=l.s.Sd;I.ji=!1;I.yr=l.Yc.xn||l.Yc.Mm;I.orientation=0<=ba.indexOf("landscape")?"landscape":"portrait";k="landscape"===I.orientation?I.a.r.ol:I.a.r.sd;h="landscape"===I.orientation?I.a.o.ol:I.a.o.sd;if(void 0!==h){if(void 0!==h.Ec)for(b in h.Ec)k.Ec[b]=h.Ec[b];if(void 0!==h.hc)for(b in h.hc)k.hc[b]=h.hc[b]}c=function(){var b,c,d,e;if(I.bw&&!I.ji){I.ji=!0;if(b=document.getElementsByTagName("canvas"))for(c=0;c<b.length;c++)if(d=
b[c],!d.getContext||!d.getContext("2d")){I.ji=!1;return}c=document.createEvent("Event");c.Dy=[!1];c.initEvent("gameSetPause",!1,!1);window.dispatchEvent(c);e=[];for(c=0;c<b.length;c++){d=b[c];var g=d.getContext("2d");try{var h=g.getImageData(0,0,d.width,d.height);e.push(h)}catch(k){}g.clearRect(0,0,d.width,d.height);d.style.visibility="hidden"}setTimeout(function(){for(var c=0;c<b.length;c++)b[c].style.visibility="visible"},1);setTimeout(function(){for(var c=0;c<b.length;c++){var d=b[c].getContext("2d");
try{d.putImageData(e[c],0,0)}catch(g){}}c=document.createEvent("Event");c.initEvent("gameResume",!1,!1);window.dispatchEvent(c);I.ji=!1},100)}};d=function(){var b,d,e,g,h,B,r,s,t;"landscape"===I.orientation?(b=[window.innerWidth,window.innerHeight],d=[k.zf,k.jc],e=k.minWidth):(b=[window.innerHeight,window.innerWidth],d=[k.jc,k.zb],e=k.minHeight);g=d[0]/d[1];h=b[0]/b[1];B=e/d[1];h<g?(h=h<B?Math.floor(b[0]/B):b[1],g=b[0]):(h=b[1],g=Math.floor(b[1]*g));r=h/d[1];!I.yr&&1<r&&(g=Math.min(b[0],d[0]),h=Math.min(b[1],
d[1]),r=1);b="landscape"===I.orientation?g:h;d="landscape"===I.orientation?h:g;t=s=0;window.innerHeight<Math.floor(k.jc*r)&&(s=Math.max(k.Fj,window.innerHeight-Math.floor(k.jc*r)));window.innerWidth<Math.floor(k.zb*r)&&(t=Math.floor(Math.max(k.zf-k.zb,(window.innerWidth-Math.floor(k.zb*r))/r)),window.innerWidth<Math.floor(k.zb*r)+t*r&&(t+=Math.floor(Math.max((e-k.zf)/2,(window.innerWidth-(k.zb*r+t*r))/2/r))));I.qo=k.jc-k.Jo;I.ms=k.zb-k.zf;I.pa=s;I.Dw=t;I.Cw=Math.min(I.ms,-1*I.Ew);I.de=(k.hc.top||
k.He)-I.pa;I.T={top:-1*s,left:-1*t,height:Math.min(k.jc,Math.round(Math.min(d,window.innerHeight)/r)),width:Math.min(k.zb,Math.round(Math.min(b,window.innerWidth)/r))};I.ez="landscape"===I.orientation?{top:0,left:Math.floor((k.zf-k.minWidth)/2),width:k.minWidth,height:k.minHeight}:{top:Math.abs(k.Fj),left:k.Ge,width:k.zb,height:k.minHeight};e=Math.min(window.innerHeight,d);b=Math.min(window.innerWidth,b);"landscape"===I.orientation?document.getElementById("viewport").setAttribute("style","position:fixed; overflow:hidden; z-index: 0; width:"+
b+"px; left:50%; margin-left:"+-b/2+"px; height: "+e+"px; top:50%; margin-top:"+-e/2+"px"):document.getElementById("viewport").setAttribute("style","position:absolute; overflow:hidden; z-index: 0; width:"+b+"px; left:50%; margin-left:"+-b/2+"px; height: "+e+"px");e=function(b,c,d,e){var g,h,m,n;g=void 0!==c.top?c.top:k.He;h=void 0!==c.left?c.left:k.Ge;m=void 0!==c.width?c.width:k.zb;n=void 0!==c.height?c.height:k.jc;b.Pw=Math.floor(r*g);b.Ow=Math.floor(r*h);b.Qw=Math.floor(r*m);b.Nw=Math.floor(r*
n);!1!==d&&(g+=s);!1!==e&&(h+=t);b.setAttribute("style","position:absolute; left:"+Math.floor(r*h)+"px; top:"+Math.floor(r*g)+"px; width:"+Math.floor(r*m)+"px; height:"+Math.floor(r*n)+"px; z-index: "+c.depth)};e(I.$k,k.nl);e(I.Ol,k.Ec);e(I.Yl,k.hc,!1,!0);e(I.Dd,k.Ee);c();setTimeout(c,5E3);setTimeout(c,1E4);setTimeout(c,2E4);la(I.pe)};b=function(){if(I.Hp===window.innerHeight&&I.Ip===window.innerWidth||I.ck)return!1;document.documentElement.style["min-height"]=5E3;e=window.innerHeight;g=40;I.ck=window.setInterval(function(){document.documentElement.style.minHeight=
"";document.documentElement.style["min-height"]="";window.scrollTo(0,l.s.cg?1:0);g--;if((l.s.cg?0:window.innerHeight>e)||0>g)I.Ip=window.innerWidth,I.Hp=window.innerHeight,clearInterval(I.ck),I.ck=!1,document.documentElement.style["min-height"]=window.innerHeight+"px",document.getElementById("viewport").style.height=window.innerHeight+"px",d()},10)};I.sh=k.Ec.left||k.Ge;I.th=k.Ec.top||k.He;I.kj=k.Ec.width||k.zb;I.fj=k.Ec.height||k.jc;I.Me=k.hc.left||k.Ge;I.de=k.hc.top||k.He;I.lx=k.hc.width||k.zb;
I.kx=k.hc.height||k.jc;I.Vt=k.Ee.left||k.Ge;I.Wt=k.Ee.top||k.He;I.Xt=k.Ee.width||k.zb;I.Ut=k.Ee.height||k.jc;h=function(b){return I.d.fv(b.id,b.depth,void 0!==b.top?b.top:k.He,void 0!==b.left?b.left:k.Ge,void 0!==b.width?b.width:k.zb,void 0!==b.height?b.height:k.jc)};I.sd=[];I.$k=h(k.nl);I.Ol=h(k.Ec);I.Yl=h(k.hc);I.Dd=h(k.Ee);d();document.body.addEventListener("touchmove",function(b){b.preventDefault()},!0);document.body.addEventListener("touchstart",b,!0);window.addEventListener("resize",b,!0);window.setInterval(b,
200);I.Ub={};I.Ub[I.ph]=I.$k;I.Ub[I.Df]=I.Ol;I.Ub[I.uh]=I.Yl;I.Ub[I.Pl]=I.Dd;I.Ub[I.Le]=I.$k;I.Ub[I.oc]=I.Dd;I.Ub[I.cp]=I.Dd})();
I.d.$r=function(){var b,c;if(c=document.getElementById("viewport"))b=document.createElement("img"),b.className="banner",b.src=ia.Vd+"/media/banner_game_640x100.png",b.style.position="absolute",b.style.bottom="0px",b.style.width="100%",b.style.zIndex=300,c.appendChild(b),I.ps=!0,I.Vg=!0,c=function(b){I.ps&&I.Vg&&(I.i.Gd("http://www.tinglygames.com/html5-games/"),b.preventDefault(),b.stopPropagation?b.stopPropagation():b.cancelBubble=!0)},b.addEventListener("mouseup",c,!0),b.addEventListener("touchend",
c,!0),b.addEventListener("mousedown",function(b){I.Vg&&(b.preventDefault(),b.stopPropagation?b.stopPropagation():b.cancelBubble=!0)},!0),b.addEventListener("touchstart",function(b){I.Vg&&(b.preventDefault(),b.stopPropagation?b.stopPropagation():b.cancelBubble=!0)},!0)};I.d.Az=function(){var b,c=document.getElementsByClassName("banner");if(c){for(b=0;b<c.length;b++)c[b].style.display="inline";I.Vg=!0}};
I.d.qx=function(){var b,c=document.getElementsByClassName("banner");if(c){for(b=0;b<c.length;b++)c[b].style.display="none";I.Vg=!1}};I.d.Zl=function(b){return b===I.Ol?{x:I.sh,y:I.th}:b===I.Yl?{x:I.Me,y:I.de}:{x:I.Vt,y:I.Wt}};I.d.Ne=function(b){return I.Ub[b]};I.d.nb=function(b){return I.Ub[b]?(p.canvas!==I.Ub[b]&&p.nb(I.Ub[b]),!0):!1};I.d.bb=function(b,c){if(I.Ub[c]){var d=G;b.ua!==c&&(d.Kg=!0);b.ua=c;b.canvas=I.Ub[c]}};
I.d.h=function(b,c,d,e){var g;c=c||0;d=d||0;e=e||0;if("number"===typeof b)return b;if("object"===typeof b)switch(g=b.offset||0,b.align){case "center":return Math.round(c/2-(d/2-e))+g;case "left":case "top":return g-e;case "right":case "bottom":return c-d-g-e;default:return g+0}return 0};
I.d.qa=function(b,c,d,e){var g;c=c||0;d=d||0;if("number"===typeof b)return b;if("object"===typeof b)switch(g=b.offset||0,b.align){case "center":return"center"===e||"middle"===e?Math.round(c/2)+g:"left"===e||"top"===e?Math.round(c/2-d/2)+g:Math.round(c/2+d/2)-g;case "left":case "top":return"center"===e||"middle"===e?Math.round(d/2)+g:"left"===e||"top"===e?g:d+g;case "right":case "bottom":return"center"===e||"middle"===e?c-Math.round(d/2)-g:"left"===e||"top"===e?c-Math.round(d/2)-g:c-g;default:return g+
0}return 0};I.d.Iw=function(b,c,d,e){switch(e){case "center":case "middle":return Math.round(c/2)+b;case "left":case "top":return b;case "right":case "bottom":return d+b}return 0};function $e(b){this.depth=-99;I.d.bb(this,I.oc);this.j=!0;this.visible=!1;this.b=b;Nb(this)}$e.prototype.xh=function(){};$e.prototype.Jf=function(){};$e.prototype.ab=function(b,c,d){a:{var e=this.b,g;for(g=0;g<e.bc.length;++g)if(e.bc[g].ab&&e.bc[g].ab(b,c,d)){b=!0;break a}b=!1}return b};
$e.prototype.jb=function(b,c,d){var e;a:if(e=this.b,e.Oa&&b===e.Fn)b=e.Oa.a.x,c=e.Oa.a.y,e.Oa.Vm&&(b=e.Oa.Vm.x,c=e.Oa.Vm.y),Y?console.log("Component:\n x: tgScale("+(b+e.Oa.mf.x-Y.ya)+") + GameUISettingsOffsets.X,\n y: tgScale("+(c+e.Oa.mf.y-Y.za)+") + GameUISettingsOffsets.Y,"):console.log("Component:\n x: tgScale("+(b+e.Oa.mf.x)+"),\n y: tgScale("+(c+e.Oa.mf.y)+"),"),e.vr=!1,e=!0;else{for(var g=0;g<e.bc.length;++g)if(e.bc[g].jb&&e.bc[g].jb(b,c,d)){e=!0;break a}e=!1}return e};
function af(){this.ua=this.depth=0;this.wl=this.tb=this.j=this.visible=!1;this.bc=[];this.Xi={};this.Xi.Id=!1;this.Xo={};this.paused=this.Xo.Id=!1;this.yv=new x(0,0);this.Av=this.zv=0;this.Oa=null;this.Fn=this.xr=this.wr=-1;this.vr=!1;this.mb=this.lb=0;this.wj=null}a=af.prototype;a.Pb=function(){this.wj=new $e(this)};a.Qb=function(){this.wj&&(H(G,this.wj),this.wj=null)};
function bf(b,c,d){for(var e in c){var g=c[e];g.e?d[e]=new cf(b,g):g.fr?d[e]=new df(b,I.l.N(g.fr,"<"+g.fr+">"),g):g.H?d[e]=new df(b,I.l.N(g.H,"<"+g.H+">"),g):g.text&&(d[e]=new df(b,g.text,g))}}a.mn=function(b,c){this.lb=b;this.mb=c};function ef(b,c){b.Id&&(b.t+=c,b.t>=b.duration&&(b.Id=!1,b.yb&&b.yb()))}
a.ma=function(b){ef(this.Xi,b);ef(this.Xo,b);for(var c=0;c<this.bc.length;++c)this.bc[c].ma(b);if(this.Oa&&this.vr){b=Eb(this.Fn);c=G.ba[this.Fn].y;this.canvas===I.d.Ne(I.ph)&&this.Oa.oj(this.lb+I.Me,this.mb+I.de);var d=b-this.wr,e=c-this.xr;this.Oa.x+=d;this.Oa.y+=e;this.Oa.mf.x+=d;this.Oa.mf.y+=e;this.wr=b;this.xr=c;this.tb=!0}};a.pc=function(){if(this.tb){var b=I.d.Ne(I.ph);this.canvas!==b?this.canvas.X=this.tb:(p.nb(b),this.Ma())}};
a.Wi=function(b,c){for(var d=I.d.Ne(I.ph)===this.canvas,e=0;e<this.bc.length;++e){var g=this.bc[e];g.visible&&(d&&g.oj(b,c),g.Ma(b,c))}};a.Ma=function(){var b=0,c=0;I.d.Ne(I.uh)!==this.canvas&&(b=I.Me,c=I.de);this.paused?this.yv.n(this.zv+this.lb+b,this.Av+this.mb+c):this.Wi(this.lb+b,this.mb+c);this.tb=!1};function ff(){this.up=[];this.Yo=[];this.nn=null;this.po=void 0;this.Nl=!0}
function gf(b){function c(b,c){if(!c)return!1;var g=0;if("string"===typeof b){if(e(b))return!1}else for(g=0;g<b.length;++g)if(e(b[g]))return!1;if(c.Tw){if("string"===typeof b){if(d(b))return!0}else for(g=0;g<b.length;++g)if(d(b[g]))return!0;return!1}return!0}function d(b){for(var c in k)if(c===b||k[c]===b)return!0;return!1}function e(b){for(var c in h)if(c===b||h[c]===b)return!0;return!1}var g;if(b instanceof ff){if(1!==arguments.length)throw"When using GameUIOptions as argument to GameUIController constructor you should not use extraComponents of gameUiSettings as parameters anymore.";
g=b}else g=new ff,g.up=arguments[0],g.Yo=arguments[1],g.nn=arguments[2];var h=null,k=null,m=null,h=g.up,k=g.Yo,m=g.nn;this.Vh=g;void 0===this.Vh.po&&(this.Vh.po=!hf(I.b));af.apply(this,arguments);Nb(this);this.j=this.visible=!0;k=k||[];h=h||[];this.nk=2;this.m=m||jf;this.Ko=I.uh;void 0!==this.m.ua&&(this.Ko=this.m.ua);I.d.bb(this,this.Ko);this.ni=this.mi=0;this.m.background.pm&&(this.mi=this.m.background.pm);this.m.background.qm&&(this.ni=this.m.background.qm);this.m.background.elements||(this.zc=
this.m.background.e);this.m.background.tw?(bf(this,this.m.background.elements,{}),this.zc=this.m.background.e):(g=this.m.background.e,m=new af,bf(m,this.m.background.elements,[]),g||this.ua!==I.ph?(this.zc=new x(g.width,g.height),y(this.zc),g.n(0,0,0),m.Wi(-this.mi,-this.ni),A(this.zc)):(p.nb(I.d.Ne(this.ua)),m.Ma()));c("score",this.m.wq)&&(new kf(this,this.m.wq,"SCORE",0,!0),this.m.bv&&new cf(this,this.m.bv));c("highScore",this.m.Kc)&&new kf(this,this.m.Kc,"HIGHSCORE",0,!1);c("highScore",this.m.vp)&&
new cf(this,this.m.vp);this.pv=c(["stage","level"],this.m.ov)?new kf(this,this.m.ov,"STAGE",0,!1):new lf(0,0);c("lives",this.m.Jt)&&new kf(this,this.m.Jt,"LIVES",0,!1);this.mk=c("time",this.m.time)?new kf(this,this.m.time,"TIME",0,!1,function(b){var c=Math.floor(b%6E4/1E3);return Math.floor(b/6E4)+(10>c?":0":":")+c}):new lf(0,0);this.mk.dk(36E4);if(this.m.Mc&&this.m.rq)throw"Don't define both progress and progressFill in your game_ui settings";c("progress",this.m.Mc)?this.m.Mc.round?new mf(this,this.m.Mc):
new nf(this,this.m.Mc):c("progress",this.m.rq)&&new nf(this,this.m.rq);c("lives",this.m.xt)&&new cf(this,this.m.xt);c("difficulty",this.m.ul)?new df(this,of().toUpperCase(),this.m.ul):of();c("difficulty",this.m.Bf)&&(g=Ac,g=(this.m.Bf.images?this.m.Bf.images:[Bc,Ac,zc])[pf()],this.m.Bf.e||(this.m.Bf.e=g),this.Ks=new cf(this,this.m.Bf),this.Ks.zq(g));this.m.Pe&&!this.m.Pe.length&&(this.m.Pe=[this.m.Pe]);this.m.Bd&&!this.m.Bd.length&&(this.m.Bd=[this.m.Bd]);this.Fp=[];this.Gp=[];this.Fp[0]=c(["item",
"item0"],this.m.Pe)?new cf(this,this.m.Pe[0]):new lf(0,"");this.Gp[0]=c(["item","item0"],this.m.Bd)?new df(this,"",this.m.Bd[0]):new lf(0,"");if(this.m.Pe&&this.m.Bd)for(g=1;g<this.m.Bd.length;++g)c("item"+g,this.m.Bd[g])&&(this.Gp[g]=new df(this,"0 / 0",this.m.Bd[g]),this.Fp[g]=new cf(this,this.m.Pe[g]));for(var n in this.m)g=this.m[n],g.H&&new df(this,I.l.N(g.H,"<"+g.H+">")+(g.separator?g.separator:""),g);this.Up=this.ir=0;this.buttons={};for(n in this.m.buttons)g=qf(this,this.m.buttons[n]),this.buttons[n]=
g;this.m.Ym&&(g=qf(this,this.m.Ym),this.buttons.pauseButton=g);this.gh={};for(n in this.m.gh)g=this.m.gh[n],g=new rf[g.ys](this,g),this.gh[n]=g;this.mn(0,0)}Ue(af,gf);var rf={};function qf(b,c){var d=new sf(b,c,c.M);b.bc.push(d);d.mx=c;return d}a=gf.prototype;a.ln=function(b,c){this.buttons[c||"pauseButton"].ln(b)};function tf(b,c,d){b.buttons[d||"pauseButton"].yb=c}a.setTime=function(b){this.mk.dk(b);return this};a.getTime=function(){return this.mk.ea()};
a.Qb=function(){af.prototype.Qb.apply(this,arguments);p.nb(this.canvas);p.clear();for(var b in this.buttons)H(G,this.buttons[b])};
a.ma=function(b){1===this.nk&&this.setTime(this.getTime()+b);if(2===this.nk){if(this.ir&&1E3*this.ir>=this.getTime()){var c=Math.floor(this.getTime()/1E3),d=Math.floor(Math.max(this.getTime()-b,0)/1E3);c!==d&&(c=this.mk,c.Sb.t=0,c.Sb.tn=!0,c.font.setFillColor(c.Sb.color),c.oe(),"undefined"!==typeof a_gameui_timewarning_second&&F.play(a_gameui_timewarning_second))}this.setTime(Math.max(this.getTime()-b,0))}af.prototype.ma.apply(this,arguments);this.Up+=b};
a.Wi=function(b,c){this.zc&&(this.zc instanceof w?this.zc.kc(0,b+this.mi,c+this.ni,1):this.zc.kc(b+this.mi,c+this.ni,1));af.prototype.Wi.apply(this,arguments);this.wl&&this.zc&&pa(b,c,this.zc.width,this.zc.height,"blue",!0)};
function uf(b,c,d,e,g,h){this.b=b;this.width=g;this.height=h;this.va=null;this.x=d;this.y=e;this.visible=!0;this.a=c;this.alpha=void 0!==c.alpha?c.alpha:1;this.scale=void 0!==c.scale?c.scale:1;this.F={};this.F.lb=0;this.F.mb=0;this.F.scale=this.scale;this.F.alpha=this.alpha;this.F.na=0;this.v={};this.v.Id=!1;this.v.origin={};this.v.target={};this.v.t=0;this.a.Xi&&(vf(this,this.a.Xi),this.v.Id=!1);this.b.bc.push(this);wf||(wf={Tb:function(b){b.value instanceof x?b.va=b.value:(b.e=b.value,b.Aa=0)},
update:Z.xd,pb:Z.vd,end:Z.wd,Wc:ac,Xc:ac,Vc:function(b,c,d,e){return 1-ec(b,c,d,e)},Qo:function(b,c,d,e){return 1*ec(b,c,d,e)+1},Ro:function(b,c,d,e){return 1*ec(b,c,d,e)+1}})}var wf;
function vf(b,c){b.v.origin.x=void 0===c.x?b.x:c.x;b.v.origin.y=void 0===c.y?b.y:c.y;b.v.origin.alpha=void 0!==c.alpha?c.alpha:1;b.v.origin.scale=void 0!==c.scale?c.scale:1;b.v.target.x=b.x;b.v.target.y=b.y;b.v.target.alpha=b.alpha;b.v.target.scale=b.scale;b.v.duration=c.duration;b.v.Id=!0;b.v.ce=c.ce||ec;b.v.t=0;b.v.la=c.la||0;xf(b)}
function xf(b){b.v.t>=b.v.duration&&(b.v.t=b.v.duration,b.v.Id=!1);var c=b.v.ce(b.v.t,b.v.origin.x,b.v.target.x-b.v.origin.x,b.v.duration),d=b.v.ce(b.v.t,b.v.origin.y,b.v.target.y-b.v.origin.y,b.v.duration);b.F.lb=c-b.x;b.F.mb=d-b.y;b.F.alpha=b.v.ce(b.v.t,b.v.origin.alpha,b.v.target.alpha-b.v.origin.alpha,b.v.duration);b.F.scale=b.v.ce(b.v.t,b.v.origin.scale,b.v.target.scale-b.v.origin.scale,b.v.duration);b.b.tb=!0}a=uf.prototype;
a.Ma=function(b,c){this.va&&this.va.V(this.x+this.F.lb+b,this.y+this.F.mb+c,this.F.scale,this.F.scale,0,this.F.alpha)};a.oj=function(b,c){yf(this.x+this.F.lb+b,this.y+this.F.mb+c,this.width*this.F.scale,this.height*this.F.scale)};a.yj=function(b,c){return b>this.x+this.F.lb&&b<this.x+this.F.lb+this.width*this.F.scale&&c>this.y+this.F.mb&&c<this.y+this.F.mb+this.height*this.F.scale};a.Dq=function(b){this.visible!==b&&(this.visible=b,this.b.tb=!0)};
a.ma=function(b){this.v.Id&&(0<this.v.la?this.v.la-=b:(this.v.t+=-this.v.la,this.v.la=0,this.v.t+=b,xf(this)))};function lf(b,c){this.Mc=this.value=this.vj=c}lf.prototype.dk=function(b){this.value=b};lf.prototype.ea=function(){return this.value};lf.prototype.Cq=function(){};lf.prototype.zq=function(){};
function cf(b,c){this.Vm=c;this.a={};for(var d in c)this.a[d]=c[d];this.e=this.a.e;this.G=0;this.wf=this.a.wf;this.a.Wq&&(this.a.x+=this.e.Ha,this.a.y+=this.e.Ia);uf.call(this,b,this.a,this.a.x,this.a.y,this.e?this.e.width:1,this.e?this.e.height:1)}Ue(uf,cf);rf.GameUIImage=cf;function zf(b,c){b.G!==c&&(b.G=c,b.b.tb=!0)}a=cf.prototype;
a.Ma=function(b,c){this.e&&(this.wf&&(b+=-Math.floor(this.e.width/2),c+=-Math.floor(this.e.height/2)),this.e instanceof w?this.e.V(this.G,this.x+b+this.F.lb,this.y+c+this.F.mb,this.F.scale,this.F.scale,0,this.F.alpha):this.e.V(this.x+b+this.F.lb,this.y+c+this.F.mb,this.F.scale,this.F.scale,0,this.F.alpha),this.b.wl&&pa(this.x+b-this.e.Ha+1,this.y+c-this.e.Ia+1,this.e.width-2,this.e.height-2,"black",!0))};
a.yj=function(b,c){if(!this.e)return!1;var d=0,e=0;this.wf&&(d+=-Math.floor(this.e.width/2),e+=-Math.floor(this.e.height/2));d-=this.e.Ha;e-=this.e.Ia;return b>d+this.x+this.F.lb&&b<d+this.x+this.F.lb+this.width*this.F.scale&&c>e+this.y+this.F.mb&&c<e+this.y+this.F.mb+this.height*this.F.scale};a.oj=function(b,c){this.e&&(this.wf&&(b+=-Math.floor(this.e.width/2),c+=-Math.floor(this.e.height/2)),b-=this.e.Ha,c-=this.e.Ia,yf(this.x+this.F.lb+b,this.y+this.F.mb+c,this.width*this.F.scale,this.height*this.F.scale))};
a.am=function(b){b||(b=new ca(0,0));b.x=this.x+I.Me+this.b.lb;b.y=this.y+I.de+this.b.mb;return b};a.zq=function(b){b!==this.e&&(this.e=b,this.b.tb=!0,this.e&&(this.width=this.e.width,this.height=this.e.height))};
function df(b,c,d){"object"===typeof c&&(d=c,c=d.H?I.l.N(d.H,"<"+d.H+">"):d.text||"");this.text=c;this.font=d.font.da();d.Ic&&D(this.font,d.Ic);this.iq=d.x;this.jq=d.y;this.hq=d.Pa;this.Cu=this.font.fillColor;this.Zb=void 0===d.Zb?.2:d.Zb;uf.call(this,b,d,Math.floor(d.x-.1*d.Pa),Math.floor(d.y-.1*d.Ta),Math.floor(1.2*d.Pa),Math.floor(1.2*d.Ta));this.va=new x(this.width,this.height);switch(this.font.align){case "left":this.gf=Math.floor(.1*d.Pa);break;case "right":this.gf=Math.floor(1.1*d.Pa);break;
case "center":this.gf=Math.floor(.6*d.Pa);break;default:throw"Unknown alignment: "+this.font.align;}b=Math.floor(this.Zb*this.font.fontSize);switch(this.font.g){case "top":this.hf=Math.floor(.1*d.Ta);break;case "bottom":this.hf=Math.floor(1.1*d.Ta)+b;break;case "middle":this.hf=Math.floor(.6*d.Ta)+b;break;default:throw"Unknown baseline: "+this.font.g;}this.Sb={};this.Sb.color="red";this.Sb.duration=200;this.Sb.t=0;this.Sb.tn=!1;this.oe()}Ue(uf,df);rf.GameUIText=df;
df.prototype.ma=function(b){uf.prototype.ma.apply(this,arguments);this.Sb.tn&&(this.Sb.t+=b,this.Sb.duration<=this.Sb.t&&(this.Sb.tn=!1,this.font.setFillColor(this.Cu),this.oe()))};
df.prototype.oe=function(){this.va.clear();y(this.va);var b=this.font.Wa(this.text),c=1;b>this.hq&&(c=this.hq/b);this.font.V(this.text,this.gf,this.hf,c,c,0,1);this.b.wl&&(pa(0,0,this.va.width,this.va.height,"black",!0),pa(this.iq-this.x,this.jq-this.y,this.va.width-2*(this.iq-this.x),this.va.height-2*(this.jq-this.y),"red",!0),qa(this.gf-5,this.hf,this.gf+5,this.hf,"green",1),qa(this.gf,this.hf-5,this.gf,this.hf+5,"green",1));this.b.tb=!0;A(this.va)};
df.prototype.Cq=function(b){this.text!==b&&(this.text=b,this.oe())};function Af(b){return""+b}function Bf(b,c,d){return c+d}function kf(b,c,d,e,g,h){this.value=this.vj=e||0;this.Ak=-1;this.Ar=d;this.a=c;this.zr=-99999;this.lk=c.lk||0;this.bj=c.bj?c.bj:h||Af;d=Bf;g&&0!==this.a.Po&&(d=fc);this.ta=new Ve(this.vj,void 0===this.a.Po?500:this.a.Po,d);c.hh&&(this.hh="game_ui_"+c.hh);this.text=Cf(this)+this.bj(this.vj);df.call(this,b,this.text,c)}Ue(df,kf);rf.GameUIValue=kf;
kf.prototype.dk=function(b){this.value=b;Xe(this.ta,this.value)};kf.prototype.ea=function(){return this.value};kf.prototype.ur=function(b){var c=this.Ak;if(b||G.jj-this.zr>this.lk)c=this.bj(Math.floor(this.ta.ea()));this.Ak!==c&&(this.zr=G.jj,this.Ak=c,this.text=Cf(this)+c,this.oe())};kf.prototype.ma=function(b){df.prototype.ma.apply(this,arguments);We(this.ta,b);Math.floor(this.ta.ea())!==this.Ak&&this.ur()};
function Cf(b){var c="";b.a.gi&&(c=b.hh?I.l.N(b.hh,"<"+b.hh.toUpperCase()+">"):I.l.N("game_ui_"+b.Ar,"<"+b.Ar+">"));return c+(b.a.separator?b.a.separator:"")}function nf(b,c){this.dl=this.Mc=0;this.a=c;this.Th=this.Ze=0;this.e=c.e;this.Zd=c.Zd||c.e;this.om=c.om||null;this.a.Mj=this.a.Mj||0;this.a.Nj=this.a.Nj||0;this.Yk=!0;this.Uj=c.Uj||0;this.R=[];this.ta=new Ve(0,200,ic);this.fc=new Ve(0,200,ic);uf.call(this,b,c,c.x,c.y,this.e.width,this.e.height)}Ue(uf,nf);rf.GameUIProgress=nf;
nf.prototype.ma=function(b){We(this.ta,b);var c=this.ta.ea();c!==this.Ze&&(this.b.tb=!0,this.Ze=c);We(this.fc,b);b=this.fc.ea();b!==this.Th&&(this.b.tb=!0,this.Th=b);c+=b;if(this.Yk)for(b=0;b<this.R.length;++b){var d=c>=this.R[b].position&&this.Mc+this.dl>=this.R[b].position;this.R[b].complete!==d&&(this.a.R&&(this.b.tb=!0,this.Ze=c),this.R[b].complete=d)}};
nf.prototype.Ma=function(b,c){var d,e,g;if(0===this.Uj&&(0<this.fc.ea()&&this.Zd.I(0,this.width*this.ta.ea()/100,0,this.Zd.width*this.fc.ea()/100,this.Zd.height,b+this.x+this.width*this.ta.ea()/100,c+this.y),this.e.I(0,0,0,this.width*this.ta.ea()/100,this.height,b+this.x,c+this.y),this.a.R))for(d=0;d<this.R.length;++d)e=this.R[d],g=e.complete?s_ui_level_star_fill:s_ui_level_star_empty,g.n(0,b+this.x+this.width/100*e.position,c+this.y+this.a.R.y);if(1===this.Uj&&(0<this.fc.ea()&&this.Zd.I(0,0,this.height-
this.height*this.ta.ea()/100,this.width,this.height,b+this.x,c+this.y+(this.height-this.height*this.ta.ea()/100)),this.e.I(0,0,this.height-this.height*this.ta.ea()/100,this.width,this.height,b+this.x,c+this.y+(this.height-this.height*this.ta.ea()/100)),this.a.R))for(d=0;d<this.R.length;++d)e=this.R[d],g=e.complete?s_ui_level_star_fill:s_ui_level_star_empty,g.n(0,b+this.x+this.a.R.x,c+this.y+this.height-this.height/100*e.position);if(2===this.Uj&&(0<this.fc.ea()&&this.Zd.I(0,0,this.height*this.ta.ea()/
100,this.Zd.width,this.Zd.height*this.fc.ea()/100,b+this.x+this.width*this.ta.ea()/100,c+this.y),this.e.I(0,0,0,this.width,this.height*this.ta.ea()/100,b+this.x,c+this.y),this.a.R))for(d=0;d<this.R.length;++d)e=this.R[d],g=e.complete?s_ui_level_star_fill:s_ui_level_star_empty,g.n(0,b+this.x+this.a.R.x,c+this.y+this.height/100*e.position);this.om&&this.om.n(0,b+this.x+this.a.Mj,c+this.y+this.a.Nj)};function sf(b,c,d){this.pk=!1;this.di=-1;this.b=b;this.a=c;this.ln(d);cf.call(this,b,c)}Ue(cf,sf);
rf.GameUIButton=sf;sf.prototype.ln=function(b){var c=null,d=null,e=this.b,g=this.a;void 0===b&&(b=g.M?g.M:0);switch(b){case 0:c=e.Vh.Nl?yd:zd;d=function(){hf(I.b)?I.b.Yf(!1,!0,e.Vh.Nl):I.b.Yf();return!0};break;case 1:c=Ad;d=function(){I.b.Yf();return!0};break;case 2:c=s_btn_small_quit;d=function(){Df(e.Vh.Nl);return!0};break;case 3:c=g.e}this.yb=d;this.a.e=c};sf.prototype.ab=function(b,c,d){return this.yj(c-I.Me,d-I.de)?(this.pk=!0,this.di=b,zf(this,1),!0):!1};
sf.prototype.ma=function(b){cf.prototype.ma.apply(this,arguments);this.pk&&(this.yj(Eb(this.di)-I.Me,G.ba[this.di].y-I.de)?zf(this,1):zf(this,0))};sf.prototype.jb=function(b,c,d){return this.pk&&b===this.di?(zf(this,0),this.yj(c-I.Me,d-I.de)&&this.yb&&this.yb(),this.pk=!1,this.di=-1,!0):!1};
function mf(b,c){this.dl=this.Mc=0;this.a=c;this.Th=this.Ze=0;this.Yk=!0;this.R=[];this.color=c.color||"#00AEEF";this.vo=c.vo||"#FF0F64";this.to=c.to||"#FFED93";this.rs=void 0===c.blink||c.blink;this.tc=c.tc;this.Wg=!1;this.Ce=0;this.Di=1E3;this.Ei=0;this.ta=new Ve(0,200,ic);this.fc=new Ve(0,200,ic);uf.call(this,b,c,c.x,c.y,1,1)}Ue(uf,mf);rf.GameUIRoundProgress=mf;
mf.prototype.ma=function(b){We(this.ta,b);var c=this.ta.ea();c!==this.Ze&&(this.b.tb=!0,this.Ze=c);We(this.fc,b);var d=this.fc.ea();d!==this.Th&&(this.b.tb=!0,this.Th=d);this.Wg&&(this.Ce+=b,this.Ce>=this.Di?100===this.Mc?(this.Wg=!1,this.rs&&(this.Wg?this.Ce-=this.Di:(this.Wg=!0,this.Ei=this.Ce=0,Xe(this.ta,100)))):(this.Wg=!1,this.Ei=0,this.ta.Cf=0,this.ta.ok=0,Xe(this.ta,this.Mc)):this.Ei=(-Math.cos(this.Ce/this.Di*5*Math.PI*2)+1)/2,this.b.tb=!0);c+=d;if(this.Yk)for(b=0;b<this.R.length;++b)d=c>=
this.R[b].position&&this.Mc+this.dl>=this.R[b].position,this.R[b].complete!==d&&(this.a.R&&(this.b.tb=!0,this.Ze=c),this.R[b].complete=d)};mf.prototype.oj=function(b,c){this.tc&&yf(this.x+this.F.lb+b-this.tc.Ha,this.y+this.F.mb+c-this.tc.Ia,this.tc.width*this.F.scale,this.tc.height*this.F.scale)};
mf.prototype.Ma=function(b,c){var d,e;if(this.tc){e=this.ta.ea()/100;e=Math.max(e,0);e=Math.min(e,1);var g=p.context,h=this.tc.width/2-J(4),k=g.fillStyle;if(0<this.fc.ea()){var m=this.fc.ea()/100;g.beginPath();g.arc(this.x+b,this.y+c,h,.5*-Math.PI+2*e*Math.PI,2*(e+m)*Math.PI-.5*Math.PI,!1);g.lineTo(this.x+b,this.y+c);g.fillStyle=this.vo;g.fill()}g.beginPath();g.arc(this.x+b,this.y+c,h,.5*-Math.PI,2*e*Math.PI-.5*Math.PI,!1);g.lineTo(this.x+b,this.y+c);g.fillStyle=this.color;g.fill();this.Di&&(m=g.globalAlpha,
g.globalAlpha*=this.Ei,g.beginPath(),g.arc(this.x+b,this.y+c,h,.5*-Math.PI,2*e*Math.PI-.5*Math.PI,!1),g.lineTo(this.x+b,this.y+c),g.fillStyle=this.to,g.fill(),g.globalAlpha=m);if(this.a.R){var m=g.strokeStyle,n=g.lineWidth;g.strokeStyle="white";g.lineWidth=J(2);for(e=0;e<this.R.length;++e){d=this.R[e];d=d.position/100*Math.PI*2;var q=Math.cos(-.5*Math.PI+d)*h;d=Math.sin(-.5*Math.PI+d)*h;g.beginPath();g.moveTo(Math.round(b+this.x),Math.round(c+this.y));g.lineTo(Math.round(b+this.x+q),Math.round(c+
this.y+d));g.stroke()}g.strokeStyle=m;g.lineWidth=n}this.tc.n(0,b+this.x,c+this.y);if(this.a.R)for(e=0;e<this.R.length;++e)d=this.R[e],h=d.complete?s_star_filled:s_star_empty,d=d.position/100*Math.PI*2,h.n(0,Math.round(b+this.x+Math.cos(-.5*Math.PI+d)*this.a.R.uc*.5),Math.round(c+this.y+Math.sin(-.5*Math.PI+d)*this.a.R.uc*.5));g.fillStyle=k}};I.version=I.version||{};I.version.game_ui="2.1.0";var Ef=Ef||{},Y={ya:J(14),za:J(40)};
Ef.Fk={background:{e:wc,pm:J(0),qm:J(34),elements:[{e:yc,x:J(46)+Y.ya,y:J(16)+Y.za},{H:"game_ui_time_left",x:J(6)+Y.ya,y:J(52)+Y.za,Pa:J(100),Ta:J(20),Zb:.2,font:V,Ic:{fillColor:"#9fa9bf",fontSize:J(20),nc:"lower",align:"center",g:"top"}},{e:vc,x:J(9,"round")+Y.ya,y:J(124)+Y.za},{H:"game_ui_SCORE",x:J(6)+Y.ya,y:J(140)+Y.za,Pa:J(100),Ta:J(20),Zb:.2,font:V,Ic:{fillColor:"#9fa9bf",fontSize:J(20),nc:"lower",align:"center",g:"top"}},{e:vc,x:J(9,"round")+Y.ya,y:J(200)+Y.za},{H:"game_ui_HIGHSCORE",x:J(6)+
Y.ya,y:J(258)+Y.za,Pa:J(100),Ta:J(20),Zb:.2,font:V,Ic:{fillColor:"#9fa9bf",fontSize:J(20),nc:"lower",align:"center",g:"top"}},{e:vc,x:J(9,"round")+Y.ya,y:J(318)+Y.za}]},Ym:{x:J(6)+Y.ya,y:J(538)-J(86)+Y.za},time:{x:J(6)+Y.ya,y:J(80)+Y.za,Pa:J(100),Ta:J(38),Zb:.2,gi:!1,separator:"",font:V,Ic:{fontSize:J(38),fillColor:"#172348",align:"center",g:"top"}},wq:{x:J(6)+Y.ya,y:J(166)+Y.za,Pa:J(100),Ta:J(24),lk:50,Zb:.2,gi:!1,separator:"",font:V,Ic:{fontSize:J(24),fillColor:"#172348",align:"center",g:"top"}},
vp:{x:J(43,"round")+Y.ya,y:J(212)+Y.za,e:xc,wf:!1,Wq:!0},Kc:{x:J(6)+Y.ya,y:J(284)+Y.za,Pa:J(100),Ta:J(20),Zb:.2,gi:!1,separator:"",font:V,Ic:{fillColor:"#59668e",fontSize:J(20),align:"center",g:"top"}},ul:{x:J(6)+Y.ya,y:J(362)+Y.za,Pa:J(100),Ta:J(40),Zb:.2,gi:!1,separator:"",font:V,Ic:{fillColor:"#9fa9bf",fontSize:J(20),align:"center",g:"top",nc:"lower"}},Bf:{x:J(56)+Y.ya,y:J(340)+Y.za,e:Ac,wf:!1,Wq:!1}};
var jf=Ef.Fk,Z={ar:{},br:{},cr:{},dr:{},Rm:{},Sm:{},Hv:{},zt:{},Rr:function(){Z.ar={Tb:Z.Si,update:Z.xd,pb:Z.vd,end:Z.wd,font:ue,margin:20,Wc:ac,Xc:ac,Vc:kc([ec,$b,ec],[!1,!1,!0],[.1,.8,.1])};Z.br={Tb:Z.Si,update:Z.xd,pb:Z.vd,end:Z.wd,font:ve,margin:20,Wc:ac,Xc:ac,Vc:kc([ec,$b,ec],[!1,!1,!0],[.1,.8,.1])};Z.cr={Tb:Z.Si,update:Z.xd,pb:Z.vd,end:Z.wd,font:we,margin:20,Wc:ac,Xc:ac,Vc:kc([ec,$b,ec],[!1,!1,!0],[.1,.8,.1])};Z.dr={Tb:Z.Si,update:Z.xd,pb:Z.vd,end:Z.wd,font:xe,margin:20,Wc:ac,Xc:ac,Vc:kc([ec,
$b,ec],[!1,!1,!0],[.1,.8,.1])};Z.Rm={Tb:Z.Cs,update:Z.xd,pb:Z.vd,end:Z.wd,nh:ye,mh:ze,margin:20,Wc:ac,Xc:ac,Vc:kc([ec,$b,ec],[!1,!1,!0],[.1,.8,.1])};Z.Sm={Tb:Z.Ds,update:Z.xd,pb:Z.vd,end:Z.wd,nh:ye,mh:ze,margin:20,Wc:ac,Xc:ac,Vc:kc([ec,$b,ec],[!1,!1,!0],[.1,.8,.1])};Z.Hv={Tb:Z.Es,update:Z.xd,pb:Z.vd,end:Z.wd,Wc:ac,Xc:ac,Vc:kc([ec,$b,ec],[!1,!1,!0],[.1,.8,.1])};Z.zt={Tb:Z.Bs,update:Z.xd,pb:Z.vd,end:Z.wd,Wc:ac,Xc:ac,Vc:kc([ec,$b,ec],[!1,!1,!0],[.1,.8,.1])}},Hw:function(b){function c(b){var e,g={};for(e in b)g[e]=
"object"===typeof b[e]&&null!==b[e]?c(b[e]):b[e];return g}return c(b)},xz:function(b){Z.ar.font.w=b;Z.br.font.w=b;Z.cr.font.w=b;Z.dr.font.w=b},wz:function(b){Z.Rm.nh.w=b;Z.Rm.mh.w=b;Z.Sm.nh.w=b;Z.Sm.mh.w=b},rg:!1,Eb:[],vz:function(b){Z.rg=b},ox:function(){return Z.rg},Yu:function(b){var c,d;for(c=0;c<Z.Eb.length;c+=1)d=Z.Eb[c],void 0===d||void 0!==b&&d.kind!==b||0<d.Vf||(Z.Eb[c]=void 0)},Qr:function(){Z.rg=!1;Z.Eb=[]},ug:function(b,c,d,e){var g,h,k;void 0===e&&(e=Z.rg);if(e)for(h=0;h<Z.Eb.length;h+=
1)if(g=Z.Eb[h],void 0!==g&&g.ge&&g.kind===b&&g.font===c&&g.text===d)return g.Vf+=1,h;g={kind:b,font:c,text:d,Vf:1,ge:e};h=c.align;k=c.g;Ha(c,"center");Ia(c,"middle");e=c.Wa(d)+2*b.margin;b=Na(c,d)+2*b.margin;g.va=new x(e,b);y(g.va);c.n(d,e/2,b/2);A(g.va);Ha(c,h);Ia(c,k);for(h=0;h<Z.Eb.length;h+=1)if(void 0===Z.Eb[h])return Z.Eb[h]=g,h;Z.Eb.push(g);return Z.Eb.length-1},Or:function(b){var c=Z.Eb[b];c.Vf-=1;0>=c.Vf&&!c.ge&&(Z.Eb[b]=void 0)},Si:function(b){b.buffer=Z.ug(b.kind,b.kind.font,b.value,b.ge)},
Cs:function(b){var c=b.value.toString();b.buffer=0<=b.value?Z.ug(b.kind,b.kind.nh,c,b.ge):Z.ug(b.kind,b.kind.mh,c,b.ge)},Ds:function(b){var c=b.value.toString();0<b.value&&(c="+"+c);b.buffer=0<=b.value?Z.ug(b.kind,b.kind.nh,c,b.ge):Z.ug(b.kind,b.kind.mh,c,b.ge)},Es:function(b){b.va=b.value},Bs:function(b){b.e=b.value;b.Aa=0},xd:function(b){b.x=void 0!==b.kind.Wc?b.kind.Wc(b.time,b.ag,b.Uo-b.ag,b.duration):b.ag+b.time/b.duration*(b.Uo-b.ag);b.y=void 0!==b.kind.Xc?b.kind.Xc(b.time,b.bg,b.Vo-b.bg,b.duration):
b.bg+b.time/b.duration*(b.Vo-b.bg);void 0!==b.kind.Qo&&(b.Wf=b.kind.Qo(b.time,0,1,b.duration));void 0!==b.kind.Ro&&(b.Xf=b.kind.Ro(b.time,0,1,b.duration));void 0!==b.kind.Vc&&(b.alpha=b.kind.Vc(b.time,0,1,b.duration));void 0!==b.kind.Ns&&(b.na=b.kind.Ns(b.time,0,360,b.duration)%360);void 0!==b.e&&(b.Aa=b.time*b.e.G/b.duration)},vd:function(b){var c=p.context,d;void 0!==b.e&&null!==b.images?1===b.Wf&&1===b.Xf&&0===b.na?b.e.kc(Math.floor(b.Aa),b.x,b.y,b.alpha):b.e.V(Math.floor(b.Aa),b.x,b.y,b.Wf,b.Xf,
b.na,b.alpha):(d=void 0!==b.va&&null!==b.va?b.va:Z.Eb[b.buffer].va,1===b.Wf&&1===b.Xf&&0===b.na?d.kc(b.x-d.width/2,b.y-d.height/2,b.alpha):1E-4>Math.abs(b.Wf)||1E-4>Math.abs(b.Xf)||(c.save(),c.translate(b.x,b.y),c.rotate(-b.na*Math.PI/180),c.scale(b.Wf,b.Xf),d.kc(-d.width/2,-d.height/2,b.alpha),c.restore()))},wd:function(b){void 0!==b.buffer&&Z.Or(b.buffer)},pc:function(b){var c,d,e=!1;for(c=0;c<Z.eb.length;c+=1)d=Z.eb[c],void 0!==d&&(0<d.la?(d.la-=b,0>d.la&&(d.time+=-d.la,d.la=0)):d.time+=b,0<d.la||
(d.time>=d.duration?(d.kind.end(d),Z.eb[c]=void 0):d.kind.update(d),e=!0));e&&(Z.canvas.X=!0)},Ma:function(){var b,c;for(b=0;b<Z.eb.length;b+=1)c=Z.eb[b],void 0!==c&&(0<c.la||c.kind.pb(c))},eb:[],yx:function(b,c,d){Z.Ts();void 0===b&&(b=I.Pl);void 0===c&&(c=-1E6);void 0===d&&(d=["game"]);Z.visible=!0;Z.j=!0;I.d.bb(Z,b);Z.depth=c;Nb(Z);Pb(Z,d);Z.Qr();Z.Rr()},ow:function(b,c,d,e,g,h,k,m,n){void 0===m&&(m=void 0!==b.la?b.la:0);void 0===n&&(n=Z.rg);void 0===g&&void 0!==b.qu&&(g=d+b.qu);void 0===h&&void 0!==
b.ru&&(h=e+b.ru);void 0===k&&void 0!==b.duration&&(k=b.duration);b={kind:b,value:c,ag:d,bg:e,Uo:g,Vo:h,x:d,y:e,Wf:1,Xf:1,alpha:1,na:0,time:0,duration:k,la:m,ge:n};b.kind.Tb(b);for(c=0;c<Z.eb.length;c+=1)if(void 0===Z.eb[c])return Z.eb[c]=b,c;Z.eb.push(b);return Z.eb.length-1},$y:function(b){var c;0>b||b>=Z.eb.length||(c=Z.eb[b],void 0!==c&&(c.kind.end(c),Z.eb[b]=void 0))},Xu:function(){var b,c;for(b=0;b<Z.eb.length;b+=1)c=Z.eb[b],void 0!==c&&(c.kind.end(c),Z.eb[b]=void 0);Z.eb=[]},Ts:function(){Z.Xu();
Z.Yu();H(G,Z)}};I.Fb=I.Fb||{};I.Fb.hv=!1;I.Fb.Cp=function(b){b instanceof Array&&(this.Ql=b[0],this.kn=b[1],this.qs="http://api.gameanalytics.com/1/"+this.Ql,this.Dp=!0)};
I.Fb.Qk=function(b,c){var d,e=JSON.stringify(c),g=Ff(e+this.kn),h=this.qs+"/"+b;try{d=new XMLHttpRequest,d.open("POST",h,!0),this.hv&&(d.onreadystatechange=function(){4===d.readyState&&(200===d.status?(console.log("GOOD! statusText: "+d.statusText),console.log(c)):console.log("ERROR ajax call error: "+d.statusText+", url: "+h))}),d.setRequestHeader("Content-Type","text/plain"),d.setRequestHeader("Authorization",g),d.send(e)}catch(k){}};
I.Fb.Jk=function(){return{user_id:this.Gn,session_id:this.dv,build:this.ts}};
I.Fb.wv=function(){var b;b=Gf();var c=I.q.Ou,d=Hf(),e=If("userId","");""===e&&(e=Gf(),Jf("userId",e));var g={Gn:e},e=I.Hs;this.dv=b;g&&"object"===typeof g&&(this.Gn=g.Gn);this.ts=d;this.j=!0;this.Dp&&(b=this.Jk(),b.device=e.Gs,b.platform=e.xa,b.os_major=e.Du,b.os_minor=e.Eu,b.install_publisher=c,b.install_site=window.location!==window.parent.location?document.referrer:document.location.href,this.Qk("user",b));this.Va("start","session")};I.Fb.bx=function(){this.j=!1;this.Va("end","session")};
I.Fb.Va=function(b,c,d){if(this.j&&this.Dp){var e="";c&&(e=c instanceof Array?c.toString().replace(",",":"):e+c);c=this.Jk();c.event_id=e+":"+b;c.value=d;this.Qk("design",c)}};I.Fb.az=function(b,c,d){this.Va(b,c,d)};I.Fb.uq=function(b,c){var d=this.Jk();d.message=b;d.severity=c;this.Qk("error",d)};function Kf(){this.ua=this.depth=0;this.visible=!1;this.j=!0;this.a=I.a.r.Ja;this.Nu=this.a.Rv;Nb(this);Pb(this,"system")}
function Gf(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(b){var c=16*Math.random()|0;return("x"===b?c:c&3|8).toString(16)})}a=Kf.prototype;a.start=function(b){I.Fb.Cp(b);I.Fb.wv()};a.Va=function(b,c,d){I.Fb.Va(b,c,d)};function Lf(b,c,d,e){var g,h;for(g=0;g<b.L.length;g++)void 0!==b.L[g]&&b.L[g].tag===c&&(h=b.L[g],b.Va(void 0!==d?d:h.Wo,void 0!==e?e:h.mq,h.t),h.j=!1)}
function Mf(){var b=I.Ja,c=I.b.ci,d;for(d=0;d<b.L.length;d++)void 0!==b.L[d]&&b.L[d].tag===c&&(b.L[d].paused+=1)}a.uq=function(b,c){I.Fb.uq(b,c)};a.Pb=function(){this.L=[]};a.ma=function(b){var c,d=0;for(c=0;c<this.L.length;c++)this.L[c].j&&(0===this.L[c].paused&&(this.L[c].t+=b),d=c);d<this.L.length-1&&(b=this.L.length-Math.max(this.Nu,d+1),0<b&&this.L.splice(this.L.length-b,b))};
function Re(b,c,d){this.$p=b||!1;this.host=c||"http://localhost:8080";this.cv=d||this.host+"/services/storage/gamestate";this.Yq="undefined"!==typeof window.localStorage;this.rm=this.En=!1;var e=this;window.parent!==window&&(l.s.hn||l.xa.xj)&&(window.addEventListener("message",function(b){b=b.data;var c=b.command;"init"===c?e.En="ok"===b.result:"getItem"===c&&e.mj&&("ok"===b.result?e.mj(b.value):e.mj(b.defaultValue))},!1),this.mj=null,window.parent.postMessage({command:"init"},"*"));this.Mh=[];window.setTimeout(function(){e.rm=
!0;for(var b=0;b<e.Mh.length;++b)e.Mh[b]();e.Mh=[]},2E3)}function Nf(){return"string"===typeof I.q.Vq&&""!==I.q.Vq?I.q.Vq:void 0!==I.a.o.Ke&&void 0!==I.a.o.Ke.ep?I.a.o.Ke.ep:"0"}function Se(b){var c=I.b.Ph;"function"===typeof b&&(c.rm?Of(c,b):c.Mh.push(function(){Of(c,b)}))}function Te(b){var c=I.b.Ph;c.rm?Pf(c,b):c.Mh.push(function(){Pf(c,b)})}
function Pf(b,c){var d=null,e=Nf();try{d=JSON.stringify({lastChanged:new Date,gameState:JSON.stringify(c)})}catch(g){}if(b.En)window.parent.postMessage({command:"setItem",key:"TG_"+e,value:d},"*");else{if(b.Yq)try{window.localStorage.setItem(e,d)}catch(h){}b.$p||(d=new pb("gameState_"+e),d.text=void 0===JSON?"":JSON.stringify(c),qb(d,b.cv+"/my_ip/"+e))}}
function Of(b,c){var d=null,e=null,g=Nf();if(b.En)b.mj=function(b){var e;try{d=JSON.parse(b),e=JSON.parse(d.gameState)}catch(g){e=null}c(e)},window.parent.postMessage({command:"getItem",key:"TG_"+g},"*");else{if(b.Yq)try{(d=window.localStorage.getItem(g))&&(d=JSON.parse(d))}catch(h){c(null);return}if(!b.$p){var k=new pb("gameState_"+g),e=null;rb(k,Re.Zy+"/my_ip/"+g)&&(e=void 0===JSON?{}:JSON.parse(k.text))}try{if(d){if(e&&Date.parse(e.lastChanged)>Date.parse(d.lastChanged)){c(JSON.parse(e.gameState));
return}c(JSON.parse(d.gameState));return}if(e){c(JSON.parse(e.gameState));return}}catch(m){c(null);return}c(null)}}
function Qf(b,c,d){console&&console.log&&console.log("Hosted on: "+(window.location.origin?window.location.origin:window.location.protocol+"//"+window.location.hostname));this.depth=1E3;this.Zc=this.visible=!1!==d;this.j=!0;I.d.bb(this,I.oc);var e;this.a=I.a.r.Lc;if("landscape"===I.orientation&&I.a.r.Bm)for(e in I.a.r.Bm)this.a[e]=I.a.r.Bm[e];for(e in I.a.S.Lc)this.a[e]=I.a.S.Lc[e];if(I.q.Lc)for(e in I.q.Lc)this.a[e]=I.q.Lc[e];this.yb=b;this.yo=c;this.No=!1;this.Tg=0;this.al=!1;this.Bi=0;this.Ug=
this.a.ls;this.cn=!0;this.Qt=.6/Math.log(this.a.Dj+1);this.Er=void 0!==I.q.Pt?I.q.Pt:this.a.lu;this.Zt=this.Er+this.a.cu;Nb(this)}a=Qf.prototype;a.on=function(b){var c;I.d.nb(I.Le);pa(0,0,this.canvas.width,this.canvas.height,"white",!1);c=S.da();(I.q.Lc&&I.q.Lc.bi||this.a.bi)&&D(c,I.q.Lc&&I.q.Lc.bi?I.q.Lc.bi:this.a.bi);b=I.l.N(b,"<"+b.toUpperCase()+">");c.n(b,this.canvas.width/2,this.canvas.height/2,this.a.jk);this.error=!0;this.visible=this.Zc=!1;this.canvas.X=!0};
a.Hd=function(){this.$&&(this.kb=I.d.h(this.a.kb,I.T.width,this.$.width)+I.T.left,this.Wb=I.d.h(this.a.Wb,I.T.height,this.$.height)+I.T.top)};
a.sl=function(){var b,c,d,e,g,h;if("function"===typeof I.i.vh&&(h=this.a.Ve,(this.ja=I.i.vh())&&0<this.ja.length)){this.$?this.$.clear():this.$=new x(this.a.Ve,this.a.Jh);y(this.$);h/=this.ja.length;for(d=0;d<this.ja.length;d++)try{g=this.ja[d].e,e=Math.min(1,Math.min((h-20)/g.width,this.a.Jh/g.height)),b="center"===this.a.Hh?h*d+Math.round((h-g.width*e)/2):h*d+Math.round(h-g.width*e)-10,c=this.$.height-g.height*e,g instanceof w?g.V(0,b,c,e,e,0,1):p.context.drawImage(g,b,c,g.width*e,g.height*e)}catch(k){}A(this.$);
this.Cj=0;this.Em=!0;this.Ih=0;this.Ue=Ub(0,0,this.$.width,this.$.height);this.Hd()}};
a.sa=function(){var b,c,d,e;this.cn?p.clear():I.d.nb(I.Le);if(this.a.backgroundImage)if(e=this.a.backgroundImage,b=Math.abs(I.pa),1<e.G){d=(p.canvas.height-b)/e.yf;c=-(e.eh*d-p.canvas.width)/2;d=p.context;var g=d.globalAlpha,h,k,m;d.globalAlpha=this.Tg;for(h=0;h<e.G;h+=1)k=c+h%e.Sf*e.width,m=b+e.height*Math.floor(h/e.Sf),e.Od.I(e.Ld[h],e.Md[h],e.Nd[h],e.gd[h],e.fd[h],k-e.Ha+e.hd[h],m-e.Ia+e.jd[h]);d.globalAlpha=g}else d=(this.canvas.height-b)/e.height,c=-Math.floor((e.width*d-this.canvas.width)/2),
e instanceof w?e.V(0,c,b,d,d,0,this.Tg):e instanceof x&&e.V(c,b,d,d,0,this.Tg);e=this.a.ie+this.a.zm+this.a.Lf;c=Qd.height;b=Qd.width-(this.a.ie+this.a.zm);this.Mf=I.d.h(this.a.Mf,p.canvas.width,e);this.Te=I.d.h(this.a.Te,p.canvas.height,c);Qd.I(0,0,0,this.a.ie,c,this.Mf,this.Te,1);Qd.Vi(0,this.a.ie,0,b,c,this.Mf+this.a.ie,this.Te,this.a.Lf,c,1);Qd.I(0,this.a.ie+b,0,this.a.zm,c,this.Mf+this.a.ie+this.a.Lf,this.Te,1)};
function Rf(b){b.cn&&(b.al=!0);b.visible&&(b.sa(),b.sl(),"function"===typeof I.i.bm&&(b.Kd=I.i.bm(),b.Kd instanceof x&&(b.$f=!0,b.Gq=Math.floor((b.canvas.width-b.Kd.width)/2),b.Hq=Math.floor((b.canvas.height-b.Kd.height)/2))));I.b.Fh&&ia.ed("audio");I.b.Eh&&ia.ed("audio_music");ia.ed("fonts")}
a.Pb=function(){var b,c=!1;if(void 0!==I.q.Xh)if(!1===I.q.Xh.Rt)c=!0;else{if(void 0!==I.q.Xh.vl)for(b=0;b<I.q.Xh.vl.length;b++){var d;a:{d=I.q.Xh.vl[b];var e=void 0,g=void 0,h=e=void 0,g=void 0,g=window.location.origin?window.location.origin:window.location.protocol+"//"+window.location.hostname;if(0===g.indexOf("file://")&&d===Ff("file://"))d=!0;else{g=g.split(".");e=g.shift().split("://");e[0]+="://";g=e.concat(g);h="";for(e=g.length-1;0<=e;e--)if(h=g[e]+(0<e&&e<g.length-1?".":"")+h,Ff(h)===d){d=
!0;break a}d=!1}}if(d){c=!0;break}}}else c=!0;c&&"number"===typeof I.q.Pv&&(new Date).getTime()>I.q.Pv&&(c=!1);c?(this.uf=[],this.error=!1,this.gr=this.Ll=this.zi=this.t=0,this.ready=this.$f=!1,this.Mt=void 0!==this.a.Yp?this.a.Yp:this.a.ie-this.a.Gh,this.Nt=void 0!==this.a.Zp?this.a.Zp:Math.floor((Qd.height-Pd.height)/2),this.Am=Pd.width-(this.a.Gh+this.a.Xp),this.Kl=this.eq=this.no=!1,(this.Zh=ia.complete("start"))&&Rf(this),this.Wp=ia.complete("load"),this.visible&&(this.hr=document.getElementById("throbber_image"),
this.Pd=this.a.Pd,this.zn=I.d.h(this.a.zn,this.canvas.width,this.Pd),this.kk=I.d.h(this.a.kk,this.canvas.height,this.Pd))):G.pause()};
a.ma=function(b){this.t+=b;"function"===typeof I.i.bm&&void 0===this.Kd&&(this.Kd=I.i.bm(),this.Kd instanceof x&&(this.$f=!0,this.Gq=Math.floor((this.canvas.width-this.Kd.width)/2),this.Hq=Math.floor((this.canvas.height-this.Kd.height)/2)));this.$f&&0<=this.a.Iq&&this.t>=this.a.Iq&&(this.$f=!1);this.al&&(this.Bi+=b,this.Bi>=this.Ug?(this.al=!1,this.Tg=1):this.Tg=dc(this.Bi,0,1,this.Ug));this.Zh&&(this.zi+=b,this.Ll+=b);this.gr=Math.round(this.t/this.a.Nv%(this.a.Ov-1));this.Em&&(this.Cj=0+this.Ih/
this.a.Dm*1,this.Ih+=b,this.Ih>=this.a.Dm&&(this.Em=!1,this.Cj=1));"function"===typeof this.yo&&this.yo(Math.round((ja("load")+ja("audio")+ja("audio_music"))/2));!this.ready&&this.Wp&&(this.Kl||this.Ll>=this.a.Dj)&&(!I.b.Fh||this.no||F.Ea&&this.zi>=this.a.Dj)&&(!I.b.Eh||this.eq||F.Ea&&this.zi>=this.a.Dj)&&(this.ready=!0);if(b=!this.No&&!this.error&&this.ready&&this.t>=this.Er)b=I.b,b=(b.Fc&&b.Gb&&!b.Gb.Bt()?!1:!0)||this.t>=this.Zt;b&&(this.No=!0,this.yb())};
a.Hf=function(b,c,d){!this.$f&&this.Ue&&Wb(this.Ue,this.kb,this.Wb,c,d)&&(this.Ua=Math.floor((c-this.kb)/(this.$.width/this.ja.length)))};a.If=function(b,c,d){void 0!==this.Ua&&(this.ja[this.Ua].url||this.ja[this.Ua].action)&&Wb(this.Ue,this.kb,this.Wb,c,d)&&(c-=this.kb,c>=this.$.width/this.ja.length*this.Ua&&c<this.$.width/this.ja.length*(this.Ua+1)&&(this.ja[this.Ua].url?I.i.Gd(this.ja[this.Ua].url):this.ja[this.Ua].action()));this.Ua=void 0};
a.Rb=function(b,c){"Load Complete"===b&&"start"===c.Ga?(this.Zh=!0,Rf(this)):"Load Complete"===b&&"load"===c.Ga?this.Wp=!0:"Load Complete"===b&&"audio"===c.Ga?this.no=!0:"Load Complete"===b&&"audio_music"===c.Ga?this.eq=!0:"Load Complete"===b&&"fonts"===c.Ga&&(this.Kl=!0);b===I.pe&&this.Hd()};
a.Ma=function(){if(!this.error){this.cn&&this.Zh?this.sa():p.clear();try{this.hr&&p.context.drawImage(this.hr,this.Pd*this.gr,0,this.Pd,this.Pd,this.zn,this.kk,this.Pd,this.Pd)}catch(b){}if(this.Zh){var c=0,d=this.Mf+this.Mt,e=this.Te+this.Nt,g=Pd.height;Pd.I(0,c,0,this.a.Gh,g,d,e,1);c+=this.a.Gh;d+=this.a.Gh;this.ready?(Pd.Vi(0,c,0,this.Am,g,d,e,this.a.Lf,g,1),c+=this.Am,d+=this.a.Lf,Pd.I(0,c,0,this.a.Xp,g,d,e,1)):Pd.Vi(0,c,0,this.Am,g,d,e,Math.floor(Math.min((ja("load")+ja("audio"))/500+this.Qt*
Math.log(this.t+1),1)*this.a.Lf),g,1);this.$&&this.$.kc(this.kb,this.Wb,this.Cj)}this.$f&&this.Kd.n(this.Gq,this.Hq)}};
function Sf(){var b,c;c=this;this.depth=100;this.j=this.visible=!0;I.d.bb(this,I.oc);this.a=I.a.r.Yh;if("landscape"===I.orientation&&I.a.r.gk)for(b in I.a.r.gk)this.a[b]=I.a.r.gk[b];this.gb=I.a.r.gb;if("landscape"===I.orientation&&I.a.r.Hi)for(b in I.a.r.Hi)this.gb[b]=I.a.r.Hi[b];for(b in I.a.S.Yh)this.a[b]=I.a.S.Yh[b];this.uf=[];b=hf(I.b);this.zo=void 0!==b&&null!==b;this.gg=new Xb;this.gg.rd(this.a.dt,function(){c.Nq.call(c)});this.gg.rd(this.a.fq,function(){c.Pq.call(c)});this.gg.rd(I.k.fk&&!this.zo?
this.a.Ju:this.a.fq,function(){c.Qq.call(c)});this.gg.rd(this.a.gu,function(){c.Oq.call(c)});Nb(this,!1)}a=Sf.prototype;a.Nq=function(){this.hj=!0;this.a.Ff&&(this.qh=I.d.h(this.a.qh,this.canvas.width,Rd.width),this.gj=I.d.h(this.a.gj,this.canvas.width,Rd.width),this.rh=I.d.h(this.a.rh,this.canvas.height,Rd.height),this.Ef=I.d.h(this.a.Ef,this.canvas.height,Rd.height),this.Xl=this.qh,this.ij=this.rh,this.Sl=this.a.Vl,this.Tl=this.a.Wl,this.Rl=this.a.Ul,this.Ob=0,this.Hd())};
a.Pq=function(b){function c(b,c,d,e){return c+d*gc(e-b,e,3,15)}var d,e;I.k.fk&&!this.zo&&(d=I.d.h(this.a.Mo,this.canvas.width,this.a.ih,Math.floor(this.a.ih/2)),e=I.d.h(this.a.jh,this.canvas.height,Kd.height,Math.floor(Kd.height/2)),d=new Tf("difficulty_toggle",d,e,this.depth-20,pf()+"",this.a.ih,{U:function(b){Uf(parseInt(b,10));return!0},Jb:!0}),d.le=Math.floor(this.a.ih/2),d.me=Math.floor(Kd.height/2),!1!==b&&(Vf(d,"xScale",c,0,1,this.a.Lo),Vf(d,"yScale",c,0,1,this.a.Lo)),this.Ui=d,this.jh=d.y,
this.uf.push(d),this.Hd())};
a.Qq=function(b){function c(b,c,d,e){return c+d*gc(e-b,e,3,15)}var d,e=this;this.$m=!0;d=new Wf("bigPlay",I.d.h(this.a.Iu,this.canvas.width,this.a.Xe,Math.floor(this.a.Xe/2)),I.d.h(this.a.Rh,this.canvas.height,ud.height,Math.floor(ud.height/2)),this.depth-20,"startScreenPlay",this.a.Xe,{U:function(){H(G,e);var b=I.b,c,d,m;void 0===I.b.Ab&&(void 0!==I.a.S.Ab&&(void 0!==I.a.S.Ab.ns&&(c=I.a.S.Ab.ns),void 0!==I.a.S.Ab.bl&&(Xa(F,"music",I.a.S.Ab.bl),b.Ye()||mb("music"),I.b.tu=I.a.S.Ab.bl),d=void 0!==I.a.S.Ab.ks?
I.a.S.Ab.ks:0,m=void 0!==I.a.S.Ab.Ug?I.a.S.Ab.Ug:0),void 0===c&&"undefined"!==typeof Je&&(c=Je),void 0!==c&&(I.b.Ab=F.play(c,d,m),I.b.Ab&&(F.ho(I.b.Ab,"music"),F.Bq(I.b.Ab,!0))));0!==b.Qm&&I.i.yp();I.k.bf&&!b.Fc?b.screen=new Xf:Yf(b,0);return!0},Jb:!0});d.le=Math.floor(this.a.Xe/2);d.me=Math.floor(ud.height/2);!1!==b?(Vf(d,"xScale",c,0,1,this.a.Pj),Vf(d,"yScale",c,0,1,this.a.Pj),this.Qj=0):this.Qj=this.a.Pj;this.Oj=d;this.Rh=d.y;this.uf.push(d);this.Hd()};
function Zf(b){var c=kc([ic,function(b,c,g,h){return c+g*gc(h-b,h,3,2)},$b],[!0,!1,!1],[.02,.1,.88]);b.oq=!0;Vf(b.Oj,"xScale",jc(c),1,.25,4E3);Vf(b.Oj,"yScale",jc(c),1,-.1,4E3)}a.Oq=function(b){var c;this.bq=!0;c=new Ze(I.d.h(this.a.Jm,this.canvas.width,zd.width),I.d.h(this.a.Ej,this.canvas.height,zd.height),this.depth-20,new Vb(zd),[zd],{U:I.b.Yf,Jb:!0});!1!==b&&Vf(c,"alpha",ac,0,1,this.a.fu);this.Im=c;this.Ej=c.y;this.uf.push(c);this.Hd()};
a.sa=function(){var b,c,d,e;if(b=this.a.backgroundImage)I.d.nb(I.Le),d=Math.abs(I.pa),1<b.G?(c=(p.canvas.height-d)/b.yf,e=-(b.eh*c-p.canvas.width)/2,ua(b,e,d)):(c=(p.canvas.height-d)/b.height,e=-Math.floor((b.width*c-this.canvas.width)/2),b.V(0,e,d,c,c,0,1))};
a.sl=function(){var b,c,d,e,g,h;if("function"===typeof I.i.vh&&(h=this.a.Ve,(this.ja=I.i.vh())&&0<this.ja.length)){this.$?this.$.clear():this.$=new x(this.a.Ve,this.a.Jh);y(this.$);h/=this.ja.length;for(d in this.ja)try{g=this.ja[d].e,e=Math.min(1,Math.min((h-20)/g.width,this.a.Jh/g.height)),b="center"===this.a.Hh?h*d+Math.round((h-g.width*e)/2):h*d+Math.round(h-g.width*e)-10,c=this.$.height-g.height*e,g instanceof w?g.V(0,b,c,e,e,0,1):p.context.drawImage(g,b,c,g.width*e,g.height*e)}catch(k){}A(this.$);
this.Cj=0;this.Em=!0;this.Ih=0;this.Ue=Ub(0,0,this.$.width,this.$.height);this.Hd()}};a.Hd=function(){var b;b=0;I.T.height<this.a.el&&(b=this.a.el-I.T.height);this.$m&&(this.Oj.y=this.Rh-b);this.bq&&(this.Im.y=this.Ej-b,this.Im.x=I.d.h(this.a.Jm,I.T.width,zd.width)+I.T.left);this.Ui&&(this.Ui.y=this.jh-b);this.hj&&this.Ob>=this.a.Jc&&(this.ij=this.Ef-I.pa);this.$&&(this.kb=I.d.h(this.a.kb,I.T.width,this.$.width)+I.T.left,this.Wb=I.d.h(this.a.Wb,I.T.height,this.$.height)+I.T.top)};
a.Pb=function(){this.sa();this.a.Ff&&(I.d.nb(I.oc),this.a.Ff.n(0,0,-this.a.Ff.height-10));this.sl();this.gg.start()};a.Qb=function(){var b;for(b=0;b<this.uf.length;b++)H(G,this.uf[b])};
a.ma=function(b){this.canvas.X=!0;this.hj&&this.Ob<this.a.Jc&&(this.Xl=this.a.ht(this.Ob,this.qh,this.gj-this.qh,this.a.Jc),this.ij=this.a.it(this.Ob,this.rh,this.Ef-this.rh,this.a.Jc)-I.pa,this.Sl=this.a.ft(this.Ob,this.a.Vl,this.a.gp-this.a.Vl,this.a.Jc),this.Tl=this.a.gt(this.Ob,this.a.Wl,this.a.hp-this.a.Wl,this.a.Jc),this.Rl=this.a.et(this.Ob,this.a.Ul,this.a.fp-this.a.Ul,this.a.Jc),this.Ob+=b,this.Ob>=this.a.Jc&&(this.Xl=this.gj,this.ij=this.Ef-I.pa,this.Sl=this.a.gp,this.Tl=this.a.hp,this.Rl=
this.a.fp));this.$m&&(!this.oq&&this.Qj>=this.a.Pj+this.a.Hu&&Zf(this),this.Qj+=b)};a.Hf=function(b,c,d){this.Ue&&Wb(this.Ue,this.kb,this.Wb,c,d)&&(this.Ua=Math.floor((c-this.kb)/(this.$.width/this.ja.length)))};
a.If=function(b,c,d){void 0!==this.Ua&&(this.ja[this.Ua].url||this.ja[this.Ua].action)&&Wb(this.Ue,this.kb,this.Wb,c,d)&&(c-=this.kb,c>=this.$.width/this.ja.length*this.Ua&&c<this.$.width/this.ja.length*(this.Ua+1)&&(this.ja[this.Ua].url?I.i.Gd(this.ja[this.Ua].url):this.ja[this.Ua].action()));this.Ua=void 0};a.ab=function(){this.Za=!0};
a.jb=function(){this.Za&&(this.gg.stop(),this.hj?this.Ob<this.a.Jc&&(this.Ob=this.a.Jc-1):(this.Nq(),this.Ob=this.a.Jc-1),this.Ui?$f(this.Ui):this.Pq(!1),this.bq?$f(this.Im):this.Oq(!1),this.$m?($f(this.Oj),this.oq&&Zf(this)):this.Qq(!1),this.Za=!1)};a.Rb=function(b){b===I.pe&&(this.sa(),this.Hd())};a.Ma=function(){this.hj&&this.a.Ff&&this.a.Ff.V(0,this.Xl,this.ij,this.Sl,this.Tl,0,this.Rl);this.$&&this.$.n(this.kb,this.Wb);this.Zc=!1};
function Xf(){this.depth=100;this.j=this.visible=!0;I.d.bb(this,I.oc);var b;this.a=I.a.r.ad;if("landscape"===I.orientation)for(b in I.a.r.Np)this.a[b]=I.a.r.Np[b];this.Gf=I.a.o.Aj;if(I.a.o.ad)for(b in I.a.o.ad)this.a[b]=I.a.o.ad[b];this.Hb=I.a.r.gb;for(var c in I.a.S.ad)this.a[c]=I.a.S.ad[c];this.Se=-1;this.wa=0;this.It=[];Nb(this)}a=Xf.prototype;
a.sa=function(){var b,c,d,e;I.d.nb(I.Le);if(b=this.a.backgroundImage?this.a.backgroundImage:void 0)d=Math.abs(I.pa),1<b.G?(c=(p.canvas.height-d)/b.yf,e=-(b.eh*c-p.canvas.width)/2,ua(b,e,d)):(c=(p.canvas.height-d)/b.height,e=-Math.floor((b.width*c-this.canvas.width)/2),b.V(0,e,d,c,c,0,1));var g;c=I.a.r.rc.type[I.k.zd].cf;I.a.o.rc&&I.a.o.rc.type&&I.a.o.rc.type[I.k.zd]&&I.a.o.rc.type[I.k.zd]&&(c=!1===I.a.o.rc.type[I.k.zd].cf?!1:c);void 0!==this.Gf&&void 0!==this.Gf.cf&&(c=this.Gf.cf);d=I.d.h(this.a.Kq,
this.canvas.width,Cc.width);b=I.d.h(this.a.sn,I.T.height,Cc.height)+I.T.top;c&&(Cc.n(0,d,b),c=S.da(),D(c,this.a.Jq),Ha(c,"center"),c.n(this.R+" / "+this.Bn,d+Math.floor(Cc.width/2),b+Cc.height+this.a.Lq));if(void 0!==this.Gf&&void 0!==this.Gf.kv?this.Gf.kv:1)c=S.da(),void 0!==this.a.Ku?D(c,this.a.Ku):D(c,this.a.pq),d=I.l.N("levelMapScreenTotalScore","<TOTAL SCORE:>"),e=Pa(c,d,this.a.Mu,this.a.Lu),e<c.fontSize&&E(c,e),e=I.d.qa(this.a.qq,this.canvas.width,c.Wa(d),c.align),g=I.d.qa(this.a.an,I.T.height,
Na(c,d),c.g)+I.T.top,c.n(d,e,g),d=""+this.Sj,D(c,this.a.pq),e=I.d.qa(this.a.qq,this.canvas.width,c.Wa(d),c.align),c.n(d,e,b+Cc.height+this.a.Lq)};
function ag(b){if("grid"===b.a.type){y(b.Dh);p.clear();b.Re=[];var c;c=function(c,e,g){var h,k,m,n,q,v,z,B,r,s,t,u,C,N,K,P,U,X,ya,ha,Ya,sb,Wd;k=I.k.P[c];ya=b.ub?b.a.ot:b.a.pt;ha=b.a.cm;Ya=ya;if(b.a.xs)h=b.a.xs[c];else{X=b.ub?b.a.wu:b.a.xu;for(sb=Math.floor(k/X);1<Math.abs(sb-X);)X-=1,sb=Math.floor(k/X);for(h=[];0<k;)h.push(Math.min(X,k)),k-=X}sb=h.length;U=Math.round(((b.ub?b.a.Sp:b.a.Tp)-(sb+1)*ya)/sb);Wd=b.a.ws?b.a.ws:!1;if(!Wd){X=1;for(k=0;k<sb;k++)X=Math.max(h[k],X);P=Math.round((b.canvas.width-
2*ha)/X)}for(k=n=0;k<sb;k++){X=h[k];Wd&&(P=Math.round((b.canvas.width-2*ha)/X));for(m=0;m<X;m++){r=b.a.Oo;C=b.a.Ms;t=I.k.Af||"locked";u=0;q=bg(c,n,void 0,void 0);"object"===typeof q&&null!==q&&(void 0!==q.state&&(t=q.state),"object"===typeof q.stats&&null!==q.stats&&(u=q.stats.stars||0));N="locked"===t;"function"===typeof I.o.lt&&(v=I.o.lt(cg(I.b,c,n),c,n,t))&&(C=N=r=!1);q=ha+e;B=Ya;K=s=1;if(!1!==C){z=b.ub?oe:Dc;if("played"===t)switch(u){case 1:z=b.ub?Ld:Ec;break;case 2:z=b.ub?Md:Fc;break;case 3:z=
b.ub?Nd:Gc}else b.ub||"locked"!==t||(z=Hc);z.width>P&&(K=P/z.width);z.height>U&&(K=Math.min(s,U/z.height));q+=Math.round((P-z.width*K)/2);B+=Math.round((U-z.height*K)/2);z.V(0,q,B,K,K,0,1);g&&(b.Re[n]={x:q,y:B})}v&&(v.width>P&&(s=P/v.width),v.height>U&&(s=Math.min(s,U/v.height)),void 0!==z?(u=I.d.h(b.a.Lp,z.width*K,v.width*s),C=I.d.h(b.a.Mp,z.height*K,v.height*s)):(u=I.d.h(b.a.Lp,P,v.width*s),C=I.d.h(b.a.Mp,U,v.height*s),g&&(b.Re[n]={x:q+u,y:B+C})),v instanceof x?v.V(q+u,B+C,s,s,0,1):v.V(0,q+u,B+
C,s,s,0,1));!1===r||N||(r=""+(I.k.zk?n+1:cg(I.b,c,n)+1),s=b.fonts.lj,"locked"===t&&void 0!==b.fonts.St?s=b.fonts.St:"unlocked"===t&&void 0!==b.fonts.Yv?s=b.fonts.Yv:"played"===t&&void 0!==b.fonts.played&&(s=b.fonts.played),void 0!==z?(u=I.d.qa(b.a.Pp,z.width*K,s.Wa(r),s.align),C=I.d.qa(b.a.vm,z.height*K,Na(s,r),s.g)):(u=I.d.qa(b.a.Pp,P,s.Wa(r),s.align),C=I.d.qa(b.a.vm,U,Na(s,r),s.g)),s.n(r,q+u,B+C));b.ub&&N&&(void 0!==z?(u=I.d.h(b.a.aq,z.width*K,Od.width),C=I.d.h(b.a.Cm,z.height*K,Od.height)):(u=
I.d.h(b.a.aq,P,Od.width),C=I.d.h(b.a.Cm,U,Od.height)),Od.n(0,q+u,B+C));ha+=P;n++}ha=b.a.cm;Ya+=U+ya}};b.zh&&c(b.C-1,0);c(b.C,b.canvas.width,!0);b.yh&&c(b.C+1,2*b.canvas.width);A(b.Dh)}}function dg(b,c){switch(c-b.C){case 0:b.Pm=0;break;case 1:b.Pm=-b.canvas.width;break;case -1:b.Pm=b.canvas.width}b.Nf=!0;b.Ed=0;b.moveStart=b.wa;b.dq=b.Pm-b.wa;b.je=Math.min(b.a.pu-b.eg,Math.round(Math.abs(b.dq)/(b.hk/1E3)));b.je=Math.max(b.a.ou,b.je)}
function eg(b){if(1<I.k.P.length){var c,d;c=I.d.h(b.a.fw,b.canvas.width,Id.width);d=I.d.h(b.a.Ck,I.T.height,Id.height)+I.T.top;b.ne=new Ze(c,d,b.depth-20,new Vb(Id),[Id],function(){b.kd="previous";dg(b,b.C-1);return!0});c=I.d.h(b.a.ew,b.canvas.width,Jd.width);d=I.d.h(b.a.Bk,I.T.height,Jd.height)+I.T.top;b.ke=new Ze(c,d,b.depth-20,new Vb(Jd),[Jd],function(){b.kd="next";dg(b,b.C+1);return!0});fg(b)}else b.he-=b.a.mp}
function fg(b){if(1<I.k.P.length){var c;b.zh?(c=[Id],b.ne.qb=!0):(c=[new x(Id.width,Id.height)],y(c[0]),Id.n(1,0,0),A(c[0]),b.ne.qb=!1);gg(b.ne,c);b.yh?(c=[Jd],b.ke.qb=!0):(c=[new x(Jd.width,Jd.height)],y(c[0]),Jd.n(1,0,0),A(c[0]),b.ke.qb=!1);gg(b.ke,c)}}
function hg(b){var c,d,e;y(b.kf);p.clear();c=S.da();b.a.Pc&&D(c,b.a.Pc);Ha(c,"center");Ia(c,"middle");d=I.l.N("levelMapScreenWorld_"+b.C,"<LEVELMAPSCREENWORLD_"+b.C+">");e=Pa(c,d,b.a.Qd-(c.stroke?c.Oc:0),b.a.jf-(c.stroke?c.Oc:0),!1);e<c.fontSize&&E(c,e);c.n(d,b.kf.width/2,b.kf.height/2);A(b.kf);b.canvas.X=!0}
a.Pb=function(){var b,c,d,e=this;this.ub=this.a.ub?!0:!1;if(!this.ub){for(b=0;b<I.k.P.length;b++)if(9<I.k.P[b]){c=!0;break}c||(this.ub=!0)}this.Dh=new x(3*this.canvas.width,this.ub?this.a.Sp:this.a.Tp);this.Qp=-this.canvas.width;this.Rp=this.ub?this.a.lp:this.a.np;this.he=I.d.h(this.Rp,I.T.height,this.Dh.height)+I.T.top;this.kf=new x(this.a.Qd,this.a.jf);this.Sv=I.d.h(this.a.hg,this.canvas.width,this.a.Qd);this.jr=I.d.h(this.a.$b,I.T.height,this.kf.height)+I.T.top;this.Op="undefined"!==typeof s_level_mask?
s_level_mask:this.ub?Vb(oe):Vb(Dc);this.a.Oo&&(this.fonts={},b=function(b){var c,d;for(c in b)d=S.da(),D(d,b[c]),e.fonts[c]=d},this.fonts={},this.fonts.lj=S,this.ub?b(this.a.Kp):b(this.a.Dt));this.C=I.b.C;this.P=I.k.P[this.C];this.ik=!1;this.hk=this.vn=this.eg=0;this.wn=this.Qp;this.wa=0;this.zh=0<this.C;this.yh=this.C<I.k.P.length-1;for(c=this.Bn=this.Sj=this.R=0;c<I.k.P.length;c++)for(b=0;b<I.k.P[c];b++)d=ig(void 0,b,c),this.Bn+=3,"object"===typeof d&&null!==d&&(this.R+=void 0!==d.stars?d.stars:
0,this.Sj+=void 0!==d.highScore?d.highScore:0);I.o.nt&&(this.Sj=I.o.nt());this.sa();b=this.Hb[this.a.zu];this.Tm=new Ze(I.d.h(this.a.Au,this.canvas.width,b.p.width),I.d.h(this.a.Um,I.T.height,b.p.height)+I.T.top,this.depth-20,new Vb(b.p),[b.p],{U:I.b.Yf,ca:this});eg(this);ag(this);hg(this);this.Zc=!0};a.Qb=function(){this.ne&&H(G,this.ne);this.ke&&H(G,this.ke);H(G,this.Tm)};
a.ab=function(b,c,d){if(!this.Nf)for(b=0;b<this.Re.length;b++)if(Wb(this.Op,this.Re[b].x-this.canvas.width,this.Re[b].y+this.he,c,d)){this.Se=b;break}this.Nf=!1;1<I.k.P.length&&(this.ik=!0,this.eg=0,this.$q=this.wn=c,this.hk=this.vn=0)};
a.jb=function(b,c,d){if(!this.Nf&&-1!==this.Se&&Wb(this.Op,this.Re[this.Se].x-this.canvas.width,this.Re[this.Se].y+this.he,c,d)&&(b=I.k.Af||"locked",c=bg(this.C,this.Se,void 0,void 0),"object"===typeof c&&null!==c&&void 0!==c.state&&(b=c.state),"locked"!==b))return H(G,this),Yf(I.b,this.Se,this.C),!0;this.Se=-1;this.ik=!1;1<I.k.P.length&&(Math.abs(this.wa)>=this.a.Jv&&(this.hk>=this.a.Kv||Math.abs(this.wa)>=this.a.Iv)?"previous"===this.kd?this.zh&&0<=this.wa&&this.wa<=this.canvas.width/2?dg(this,
this.C-1):(0>this.wa||(this.kd="next"),dg(this,this.C)):"next"===this.kd&&(this.yh&&0>=this.wa&&this.wa>=-this.canvas.width/2?dg(this,this.C+1):(0<this.wa||(this.kd="previous"),dg(this,this.C))):0<Math.abs(this.wa)&&(this.kd="next"===this.kd?"previous":"next",dg(this,this.C)));return!0};
a.Rb=function(b){if(b===I.Qe||b===I.pe)this.canvas.X=!0,this.sa(),b===I.pe?(this.jr=I.d.h(this.a.$b,I.T.height,this.kf.height)+I.T.top,this.he=I.d.h(this.Rp,I.T.height,this.Dh.height)+I.T.top,this.Tm.y=I.d.h(this.a.Um,I.T.height,this.Tm.images[0].height)+I.T.top,this.ne&&(this.ne.y=I.d.h(this.a.Ck,I.T.height,Id.height)+I.T.top),this.ke&&(this.ke.y=I.d.h(this.a.Bk,I.T.height,Jd.height)+I.T.top),void 0===this.ke&&void 0===this.ne&&(this.he-=this.a.mp)):(hg(this),ag(this))};
a.pc=function(b){var c=Eb(0);this.ik&&(this.vn=Math.abs(this.wn-c),0<this.eg&&(this.hk=this.vn/(this.eg/1E3)),this.kd=c>this.wn?"previous":"next",this.eg+=b,this.wa+=c-this.$q,this.$q=c,this.canvas.X=!0);this.Nf&&(this.wa=cc(this.Ed,this.moveStart,this.dq,this.je,2),this.Ed>=this.je&&(this.Nf=!1,this.wa=0),this.Ed+=b,this.canvas.X=!0);if(this.Nf||this.ik)"previous"===this.kd&&this.wa>=this.canvas.width/2?0<=this.C-1?(this.C-=1,this.P=I.k.P[this.C],this.zh=0<this.C,this.yh=this.C<I.k.P.length-1,fg(this),
this.wa-=this.canvas.width,hg(this),ag(this),this.canvas.X=!0,this.moveStart-=this.canvas.width):this.wa=Math.round(this.canvas.width/2):"next"===this.kd&&this.wa<=-this.canvas.width/2&&(this.C+1<I.k.P.length?(this.C+=1,this.P=I.k.P[this.C],this.zh=0<this.C,this.yh=this.C<I.k.P.length-1,fg(this),this.wa+=this.canvas.width,hg(this),ag(this),this.canvas.X=!0,this.moveStart+=this.canvas.width):this.wa=Math.round(-this.canvas.width/2))};
a.Ma=function(){this.kf.n(this.Sv,this.jr);this.Dh.n(Math.round(this.Qp+this.wa),this.he);this.Zc=!1};
function jg(b,c,d,e){this.depth=-100;this.visible=!1;this.j=!0;I.d.bb(this,I.oc);var g,h;this.a=d?I.a.r.gq:I.a.r.options;if("landscape"===I.orientation)for(g in h=d?I.a.r.xy:I.a.r.Bu,h)this.a[g]=h[g];this.Hb=I.a.r.gb;h=d?I.a.S.gq:I.a.S.options;for(g in h)this.a[g]=h[g];if(I.q.options&&I.q.options.buttons)for(g in I.q.options.buttons)this.a.buttons[g]=I.q.options.buttons[g];this.type=b;this.Xv=c;this.Fc=d;this.ek=!1!==e;Nb(this)}a=jg.prototype;
a.Rg=function(b,c,d,e,g){var h=void 0,k=void 0,m=void 0,n=void 0,q=void 0,v=void 0;switch(b){case "music":h="music_toggle";n=this.lr;m=I.b.Ye()?"on":"off";break;case "music_big":h="music_big_toggle";n=this.lr;m=I.b.Ye()?"on":"off";break;case "sfx_big":h="sfx_big_toggle";n=this.mr;m=I.b.Rj()?"on":"off";break;case "sfx":h="sfx_toggle";n=this.mr;m=I.b.Rj()?"on":"off";break;case "language":h="language_toggle";n=this.kr;m=I.b.language();break;case "tutorial":h="default_text";k="optionsTutorial";n=this.Wh;
break;case "highScores":h="default_text";k="optionsHighScore";n=this.yq;this.jl=this.iv;break;case "moreGames":void 0!==I.q.mu?(h="default_image",v=I.q.mu):(h="default_text",k="optionsMoreGames");n=this.jv;q=!0;break;case "resume":h="default_text";k="optionsResume";n=this.close;break;case "exit":h="default_text";k="optionsExit";n=I.Uf.customFunctions&&"function"===typeof I.Uf.customFunctions.exit?I.Uf.customFunctions.exit:function(){};break;case "quit":h="default_text";k="optionsQuit";n=this.Vu;break;
case "restart":h="default_text";k="optionsRestart";n=this.Zu;break;case "startScreen":h="default_text";k="optionsStartScreen";n=this.yq;this.jl=this.lv;break;case "about":h="default_text";k="optionsAbout";n=this.gv;break;case "forfeitChallenge":h="default_text";k="optionsChallengeForfeit";n=this.oh;break;case "cancelChallenge":h="default_text",k="optionsChallengeCancel",n=this.$g}void 0!==h&&void 0!==n&&("image"===this.Hb[h].type?this.buttons.push(new kg(h,c,d,this.depth-20,v,e,{U:n,ca:this,Jb:q},
this.f)):"toggleText"===this.Hb[h].type?this.buttons.push(new Tf(h,c,d,this.depth-20,m,e,{U:n,ca:this,Jb:q},this.f)):"text"===this.Hb[h].type?this.buttons.push(new Wf(h,c,d,this.depth-20,k,e,{U:n,ca:this,Jb:q},this.f)):"toggle"===this.Hb[h].type&&this.buttons.push(new lg(h,c,d,this.depth-20,m,{U:n,ca:this,Jb:q},this.f)),this.buttons[this.buttons.length-1].qb=g||!1)};
a.yq=function(){var b=this;mg(b.f,"y","inGame"!==this.type?-this.f.e.height:this.canvas.height,this.a.Nh,this.a.Oh,function(){H(G,b);void 0!==b.jl&&b.jl.call(b)});return!0};
a.sa=function(b,c){var d,e,g,h;y(this.f.e);p.clear();this.a.backgroundImage.n(0,0,0);d=I.l.N("optionsTitle","<OPTIONS_TITLE>");e=S.da();this.a.Pc&&D(e,this.a.Pc);void 0!==this.a.Qd&&void 0!==this.a.jf&&(g=Pa(e,d,this.a.Qd,this.a.jf,this.a.Qd),e.fontSize>g&&E(e,g));g=I.d.qa(this.a.hg,this.canvas.width,e.Wa(d),e.align)-b;h=I.d.qa(this.a.$b,this.canvas.height,Na(e,d,e.g))-c+-1*I.pa;e.n(d,g,h);A(this.f.e)};
a.ze=function(b,c,d){var e,g,h,k,m,n,q;h=!1;var v=this.a.buttons[this.type];"inGame"===this.type&&I.a.o.Ke.hu&&(v=I.a.o.Ke.hu);if("function"!==typeof ng())for(e=0;e<v.length;e++){if("string"===typeof v[e]&&"moreGames"===v[e]){v.splice(e,1);break}for(g=0;g<v[e].length;g++)if("moreGames"===v[e][g]){v[e].splice(g,1);break}}if(!1===I.q.Ye||!1===I.b.Eh)for(e=0;e<v.length;e++)if(v[e]instanceof Array){for(g=0;g<v[e].length;g++)if("music"===v[e][g]){I.b.Fh?v[e]="sfx_big":v.splice(e,1);h=!0;break}if(h)break}else if("music_big"===
v[e]){v.splice(e,1);break}if(!I.b.Fh)for(e=0;e<v.length;e++)if(v[e]instanceof Array){for(g=0;g<v[e].length;g++)if("sfx"===v[e][g]){!1!==I.q.Ye&&I.b.Eh?v[e]="music_big":v.splice(e,1);h=!0;break}if(h)break}else if("sfx_big"===v[e]){v.splice(e,1);break}if(1===I.l.kt().length)for(e=0;e<v.length;e++)if("language"===v[e]){v.splice(e,1);break}h=this.Hb.default_text.p.height;k=this.a.Ji;b=I.d.h(this.a.Ii,this.canvas.width,k)-b;n=I.d.h(this.a.vf,this.f.e.height,h*v.length+this.a.Uc*(v.length-1))-c+-1*I.pa;
for(e=0;e<v.length;e++){m=b;q=k;if("string"===typeof v[e])this.Rg(v[e],m,n,q,d);else for(c=v[e],q=(k-(c.length-1)*this.a.Uc)/c.length,g=0;g<c.length;g++)this.Rg(c[g],m,n,q,d),m+=q+this.a.Uc;n+=h+this.a.Uc}};a.lr=function(b){var c=!0;"off"===b?(c=!1,I.Ja.Va("off","options:music")):I.Ja.Va("on","options:music");I.b.Ye(c);return!0};a.mr=function(b){var c=!0;"off"===b?(c=!1,I.Ja.Va("off","options:sfx")):I.Ja.Va("on","options:sfx");I.b.Rj(c);return!0};
a.kr=function(b){I.l.Aq(b);I.Ja.Va(b,"options:language");return!0};
a.Wh=function(){function b(){m.ac+=1;m.Wh();return!0}function c(){m.ac-=1;m.Wh();return!0}function d(){var b;m.sa(n,q);m.Fe.qb=!0;for(b=0;b<m.buttons.length;b++)H(G,m.buttons[b]);m.buttons=[];m.ze(n,q,!0)}var e,g,h,k,m=this,n=I.d.h(m.a.cd,m.canvas.width,m.a.backgroundImage.width),q=I.d.h(m.a.Xb,m.canvas.height,m.a.backgroundImage.height)+-1*I.pa;void 0===m.ac&&(m.ac=0);m.ei=void 0!==I.o.kp?I.o.kp():[];I.Ja.Va((10>m.ac?"0":"")+m.ac,"options:tutorial");for(e=0;e<m.buttons.length;e++)H(G,m.buttons[e]);
m.buttons=[];this.Fc?(y(m.f.e),p.clear(),m.Fe.qb=!1):m.sa(n,q);y(m.f.e);void 0!==m.a.Qc&&(e=I.d.h(m.a.qk,m.f.e.width,m.a.Qc.width),g=I.d.h(m.a.Rd,m.f.e.height,m.a.Qc.height),m.a.Qc.n(0,e,g));k=m.ei[m.ac].title;void 0!==k&&""!==k&&(h=S.da(),m.a.wk&&D(h,m.a.wk),e=Pa(h,k,m.a.xk,m.a.Dn,m.a.xk),h.fontSize>e&&E(h,e),e=I.d.qa(m.a.sr,m.f.e.width,h.Wa(k,m.a.xk),h.align),g=I.d.qa(m.a.yk,m.f.e.height,Na(h,k,m.a.Dn),h.g),h.n(k,e,g));m.ac<m.ei.length&&(h=m.ei[m.ac].e,e=I.d.h(m.a.qr,m.f.e.width,h.width),g=I.d.h(m.a.uk,
m.f.e.height,h.height),h.n(0,e,g),k=m.ei[m.ac].text,h=S.da(),m.a.tk&&D(h,m.a.tk),e=Pa(h,k,m.a.mg,m.a.Cn,m.a.mg),h.fontSize>e&&E(h,e),e=I.d.qa(m.a.rr,m.f.e.width,h.Wa(k,m.a.mg),h.align),g=I.d.qa(m.a.vk,m.f.e.height,Na(h,k,m.a.mg),h.g),h.n(k,e,g,m.a.mg));A(m.f.e);h=ad;e=I.d.h(m.a.pr,m.canvas.width,h.width)-m.f.x;g=I.d.h(m.a.sk,m.canvas.height,h.height)-m.f.y-I.pa;0<=m.ac-1?m.buttons.push(new Ze(e,g,m.depth-20,new Vb(h),[h],{U:c,ca:m},m.f)):(h=Zc,m.buttons.push(new Ze(e,g,m.depth-20,new Vb(h),[h],{U:d,
ca:m},m.f)));h=$c;e=I.d.h(this.a.or,m.canvas.width,h.width)-m.f.x;g=I.d.h(this.a.rk,m.canvas.height,h.height)-m.f.y-I.pa;m.ac+1<m.ei.length?m.buttons.push(new Ze(e,g,m.depth-20,new Vb(h),[h],{U:b,ca:m},m.f)):(h=Zc,m.buttons.push(new Ze(e,g,m.depth-20,new Vb(h),[h],{U:d,ca:m},m.f)));return!0};
a.gv=function(){function b(b,c,d,g,h,k){var m;m=S.da();c&&D(m,c);c=Pa(m,b,h,k,h);m.fontSize>c&&E(m,c);d=I.d.qa(d,e.f.e.width,m.Wa(b,h),m.align);g=I.d.qa(g,e.f.e.height,Na(m,b,k),m.g);m.n(b,d,g,h);return g+k}function c(b,c,d){c=I.d.h(c,e.f.e.width,b.width);d=I.d.h(d,e.f.e.height,b.height);b.n(0,c,d);return d+b.height}var d,e=this,g=I.d.h(e.a.cd,e.canvas.width,e.a.backgroundImage.width),h=I.d.h(e.a.Xb,e.canvas.height,e.a.backgroundImage.height)+-1*I.pa;I.Ja.Va("about","options");for(d=0;d<e.buttons.length;d++)H(G,
e.buttons[d]);e.buttons=[];this.Fc?(y(e.f.e),p.clear(),e.Fe.qb=!1):e.sa(g,h);y(e.f.e);void 0!==e.a.Qc&&c(e.a.Qc,e.a.qk,e.a.Rd);var k=null;"function"===typeof I.i.Ls?k=I.i.Ls(e.a,b,c,e.f.e):(d=I.l.N("optionsAbout_header","<OPTIONSABOUT_HEADER>"),b(d,e.a.Xn,e.a.$n,e.a.vi,e.a.Zn,e.a.Yn),c(bd,e.a.Tk,e.a.Pg),d=I.l.N("optionsAbout_text","<OPTIONSABOUT_TEXT>"),b(d,e.a.ao,e.a.Uk,e.a.sf,e.a.wi,e.a.Qg));b(I.l.N("optionsAbout_version","<OPTIONSABOUT_VERSION>")+" "+Hf()+("big"===I.size?"b":"s"),e.a.Vk,e.a.eo,
e.a.yi,e.a.co,e.a.bo);A(e.f.e);if(k)for(d=0;d<k.length;++d){var m=k[d];e.buttons.push(new Ze(m.x,m.y,e.depth-10,Ub(0,0,m.width,m.height),null,{U:function(b){return function(){I.i.Gd(b)}}(m.url),Jb:!0},e.f))}else void 0!==I.q.nm&&(d=I.d.h(e.a.Tk,e.f.e.width,bd.width),k=I.d.h(e.a.Pg,e.f.e.height,bd.height),d=Math.min(d,I.d.h(e.a.Uk,e.f.e.width,e.a.wi)),k=Math.min(k,I.d.h(e.a.sf,e.f.e.height,e.a.Qg)),m=Math.max(e.a.wi,bd.width),e.buttons.push(new Ze(d,k,e.depth-10,Ub(0,0,m,I.d.h(e.a.sf,e.f.e.height,
e.a.Qg)+e.a.Qg-k),null,{U:function(){I.i.Gd(I.q.nm)},Jb:!0},e.f)));e.buttons.push(new Wf("default_text",I.d.h(e.a.Sk,e.f.e.width,e.a.Og),e.a.Ng,e.depth-20,"optionsAbout_backBtn",e.a.Og,{U:function(){var b;e.sa(g,h);e.Fe.qb=!0;for(b=0;b<e.buttons.length;b++)H(G,e.buttons[b]);e.buttons=[];e.ze(g,h,!0);e.Eq=!1},ca:e},e.f));return this.Eq=!0};
function og(b){var c,d,e,g,h,k=I.d.h(b.a.cd,b.canvas.width,b.a.backgroundImage.width),m=I.d.h(b.a.Xb,b.canvas.height,b.a.backgroundImage.height)+-1*I.pa;I.Ja.Va("versions","options");for(c=0;c<b.buttons.length;c++)H(G,b.buttons[c]);b.buttons=[];b.sa(k,m);y(b.f.e);void 0!==b.a.Qc&&b.a.Qc.n(0,I.d.h(b.a.qk,b.f.width,b.a.Qc.width),I.d.h(b.a.Rd,b.f.height,b.a.Qc.height));h=S.da();D(h,b.a.Vk);Ha(h,"left");d=b.a.Cr;e=b.a.Dr;for(c in I.version)g=c+": "+I.version[c],h.n(g,d,e),e+=Na(h,g)+b.a.Br;d=I.d.h(b.a.Sk,
b.f.e.width,b.a.Og);e=b.a.Ng;b.buttons.push(new Wf("default_text",d,e,b.depth-20,"optionsAbout_backBtn",b.a.Og,{U:function(){var c;b.sa(k,m);for(c=0;c<b.buttons.length;c++)H(G,b.buttons[c]);b.buttons=[];b.ze(k,m,!0)},ca:b},b.f))}a.iv=function(){return!0};a.jv=function(){I.Ja.Va("moreGames","options");var b=ng();"function"===typeof b&&b();return!0};
a.Vu=function(){var b=this;pg(this,"optionsQuitConfirmationText","optionsQuitConfirmBtn_Yes","optionsQuitConfirmBtn_No",function(){I.Ja.Va("confirm_yes","options:quit");H(G,b);Lf(I.Ja,I.b.ci,qg(I.b),"progression:levelQuit:"+rg());I.i.zp();sg();tg(I.b);return!0})};
a.Zu=function(){var b=this;pg(this,"optionsRestartConfirmationText","optionsQuitConfirmBtn_Yes","optionsQuitConfirmBtn_No",function(){I.Ja.Va("confirm_yes","options:restart");H(G,b);var c=I.b;c.state="LEVEL_END";Lf(I.Ja,I.b.ci,qg(I.b),"progression:levelRestart:"+rg());c=I.k.zk?c.Nb+1:cg(c)+1;I.b.rc=!0;I.b.Jp="retry";ug(I.b,!0);c={failed:!0,level:c};I.i.Kf(c);I.qd.Kf(c);return!0})};
a.oh=function(){var b,c=this;b=function(b){var e=b?"challengeForfeitMessage_success":"challengeForfeitMessage_error";vg(c,I.l.N(e,"<"+e.toUpperCase()+">"));b&&(c.Fe.qb=!1,c.ek||wg())};pg(this,"challengeForfeitConfirmText","challengeForfeitConfirmBtn_yes","challengeForfeitConfirmBtn_no",function(){I.b.oh(b);return!0})};
a.$g=function(){var b,c=this;b=function(b){var e=b?"challengeCancelMessage_success":"challengeCancel_error";vg(c,I.l.N(e,"<"+e.toUpperCase()+">"));b&&(c.Fe.qb=!1,c.ek||wg())};pg(this,"challengeCancelConfirmText","challengeCancelConfirmBtn_yes","challengeCancelConfirmBtn_no",function(){I.b.$g(b);return!0})};
function pg(b,c,d,e,g){var h,k,m,n;for(h=0;h<b.buttons.length;h++)H(G,b.buttons[h]);b.buttons=[];c=I.l.N(c,"<"+c.toUpperCase()+">");h=S.da();b.a.Go?D(h,b.a.Go):b.a.Xj&&D(h,b.a.Xj);k=Pa(h,c,b.a.Qi,b.a.Pi,!0);k<h.fontSize&&E(h,k);n=h.Wa(c,b.a.Qi)+10;m=Na(h,c,b.a.Qi)+10;k=I.d.qa(b.a.Ho,b.f.e.width,n,h.align);m=I.d.qa(b.a.Ri,b.f.e.height,m,h.g);y(b.f.e);h.n(c,k,m,n);A(b.f.e);k=I.d.h(b.a.Eo,b.canvas.width,b.a.fh)-b.f.x;m=I.d.h(b.a.Ni,b.canvas.height,b.Hb.default_text.p.height)-b.f.y-I.pa;b.buttons.push(new Wf("default_text",
k,m,b.depth-20,e,b.a.fh,{U:function(){var c,d,e;d=I.d.h(b.a.cd,b.canvas.width,b.a.backgroundImage.width);e=I.d.h(b.a.Xb,b.canvas.height,b.a.backgroundImage.height)+-1*I.pa;b.sa(d,e);for(c=0;c<b.buttons.length;c++)H(G,b.buttons[c]);b.buttons=[];b.ze(d,e,!0);return!0},ca:b},b.f));k=I.d.h(b.a.Fo,b.canvas.width,b.a.fh)-b.f.x;m=I.d.h(b.a.Oi,b.canvas.height,b.Hb.default_text.p.height)-b.f.y-I.pa;b.buttons.push(new Wf("default_text",k,m,b.depth-20,d,b.a.fh,{U:function(){return"function"===typeof g?g():!0},
ca:b},b.f))}function vg(b,c){var d,e,g,h;for(d=0;d<b.buttons.length;d++)H(G,b.buttons[d]);b.buttons=[];e=I.d.h(b.a.cd,b.canvas.width,b.a.backgroundImage.width);g=I.d.h(b.a.Xb,b.canvas.height,b.a.backgroundImage.height)+-1*I.pa;b.sa(e,g);d=S.da();b.a.Km&&D(d,b.a.Km);e=Pa(d,c,b.a.Lm,b.a.iu,!0);e<d.fontSize&&E(d,e);h=d.Wa(c,b.a.Lm)+10;g=Na(d,c,b.a.Lm)+10;e=I.d.qa(b.a.ju,b.f.e.width,h,d.align);g=I.d.qa(b.a.ku,b.f.e.height,g,d.g);y(b.f.e);d.n(c,e,g,h);A(b.f.e)}
a.lv=function(){I.Ja.Va("startScreen","options");tg(I.b);return!0};a.close=function(){H(G,this);return this.canvas.X=!0};
a.Pb=function(){var b,c;this.ek&&wg(this);I.b.ye=this;this.$o=this.Zo=!1;b=this.a.backgroundImage;this.f=new xg(this.depth-10,this.ua,new x(b.width,b.height));this.f.x=I.d.h(this.a.cd,this.canvas.width,b.width);b=I.d.h(this.a.Xb,this.canvas.height,b.height)+-1*I.pa;this.f.y=b;this.sa(this.f.x,this.f.y);this.buttons=[];this.Xv?this.Wh():this.ze(this.f.x,this.f.y);this.Fe=new Ze(this.a.dh,this.a.xf,this.depth-20,new Ub(0,0,this.a.bh,this.a.ah),void 0,{U:this.close,ca:this},this.f);this.og="versions";
this.Be=new Yb;I.d.bb(this.Be,I.oc);Ob(this.Be,this.depth-1);Zb(this.Be,"keyAreaLeft",this.f.x,this.f.y+this.a.Rd,this.a.tf,this.a.xi,76);Zb(this.Be,"keyAreaRight",this.f.x+this.f.width-this.a.tf,this.f.y+this.a.Rd,this.a.tf,this.a.xi,82);Zb(this.Be,"keyAreaCentre",I.Xt/2-this.a.tf/2,this.f.y+this.a.Rd,this.a.tf,this.a.xi,67);c=this;this.f.y="inGame"!==this.type?this.canvas.height:-this.f.e.height;mg(this.f,"y",b,this.a.Pf,this.a.Qf,function(){var b;for(b=0;b<c.buttons.length;b++)c.buttons[b].qb=
!0})};a.Qb=function(){var b;this.ek&&yg();this.Zo&&la(I.Qe,I.l.$l());this.$o&&la(I.pe);for(b=0;b<this.buttons.length;b++)H(G,this.buttons[b]);this.Be.clear();H(G,this.Be);H(G,this.Fe);H(G,this.f);I.b.ye=null};a.jb=function(){return!0};a.ab=function(){return!0};a.Jf=function(b){this.Eq&&(67===b?this.og="":76===b?this.og+="l":82===b&&(this.og+="r"),"lrl"===this.og&&og(this))};a.Rb=function(b){b===I.Qe?(this.sa(this.f.x,this.f.y),this.Zo=!0):b===I.pe?this.$o=!0:b===I.is&&this.close()};
function zg(){this.depth=-200;this.j=this.visible=!0;I.d.bb(this,I.Le);var b;this.a=I.a.r.dj;if("landscape"===I.orientation&&I.a.r.ej)for(b in I.a.r.ej)this.a[b]=I.a.r.ej[b];this.Hb=I.a.r.gb;for(b in I.a.S.dj)this.a[b]=I.a.S.dj[b];Nb(this)}
zg.prototype.sa=function(){var b,c,d,e;d=this.a.backgroundImage;e=(I.Ut-Math.abs(I.pa))/d.yf;this.f.e=new x(e*d.eh,e*d.yf);y(this.f.e);this.f.y=Math.abs(I.pa);b=p.context;1E-4>Math.abs(e)||1E-4>Math.abs(e)||(b.save(),b.translate(0,0),b.rotate(-0*Math.PI/180),b.scale(e,e),b.globalAlpha=1,ua(d,0,0),b.restore());d=S.da();D(d,this.a.font);e=I.l.N("gameEndScreenTitle","<GAMEENDSCREENTITLE>");b=Pa(d,e,this.a.jk-(d.stroke?d.Oc:0),this.a.Mv-(d.stroke?d.Oc:0),!0);b<d.fontSize&&E(d,b);b=I.d.qa(this.a.er,this.canvas.width,
d.Wa(e),d.align);c=I.d.qa(this.a.yn,this.canvas.height,Na(d,e),d.g);d.n(e,b,c,this.a.jk);A(this.f.e);this.f.canvas.X=!0};zg.prototype.Pb=function(){var b=this,c=this.a.backgroundImage,c=new x(c.width,c.height);this.f=new xg(this.depth,I.oc,c);this.f.x=0;this.f.y=Math.abs(I.pa);this.sa();this.button=new Wf(this.a.fl,I.d.h(this.a.ss,this.canvas.width,this.a.gl),I.d.h(this.a.Fi,this.canvas.height,this.Hb[this.a.fl].p.height),this.depth-10,"gameEndScreenBtnText",this.a.gl,function(){H(G,b);tg(I.b)},this.f)};
zg.prototype.Qb=function(){H(G,this.f);H(G,this.button)};zg.prototype.Rb=function(b){b!==I.Qe&&b!==I.pe||this.sa()};
function Ze(b,c,d,e,g,h,k){function m(b,c,d){var e,g;g=I.d.Zl(q.canvas);b=Math.round(q.x+q.parent.x-q.le*q.Ya);e=Math.round(q.y+q.parent.y-q.me*q.cb);if(q.images&&0<q.Oe||0<q.$h)q.Oe=0,q.$h=0,q.canvas.X=!0;if(q.Sh&&q.qb&&Wb(q.sc,b,e,c-g.x,d-g.y))return q.Sh=!1,void 0!==q.ca?q.Ij.call(q.ca,q):q.Ij(q)}function n(b,c,d){var e,g,h;h=I.d.Zl(q.canvas);e=Math.round(q.x+q.parent.x-q.le*q.Ya);g=Math.round(q.y+q.parent.y-q.me*q.cb);if(q.qb&&Wb(q.sc,e,g,c-h.x,d-h.y))return q.Sh=!0,q.images&&(1<q.images.length?
(q.Oe=1,q.canvas.X=!0):1<q.images[0].G&&(q.$h=1,q.canvas.X=!0)),void 0!==typeof Ie&&F.play(Ie),q.Je=b,!0}this.depth=d;this.j=this.visible=!0;this.group="TG_Token";I.d.bb(this,I.oc);this.me=this.le=0;this.x=b;this.y=c;this.width=g?g[0].width:e.Ka-e.oa;this.height=g?g[0].height:e.fb-e.Ba;this.alpha=this.cb=this.Ya=1;this.na=0;this.sc=e;this.images=g;this.$h=this.Oe=0;this.Sh=!1;this.qb=!0;this.parent=void 0!==k?k:{x:0,y:0};this.bk=this.ak=0;this.Zc=!0;this.Ij=function(){};this.Jb=!1;"object"===typeof h?
(this.Ij=h.U,this.ca=h.ca,this.Jb=h.Jb):"function"===typeof h&&(this.Ij=h);var q=this;this.Jb?(this.Hf=n,this.If=m):(this.ab=n,this.jb=m);Nb(this)}function Vf(b,c,d,e,g,h){void 0===b.Yd&&(b.Yd=[]);b.Yd.push({type:c,start:e,ic:g,Ra:d,duration:h,t:0})}
function $f(b){var c,d;if(void 0!==b.Yd){for(c=0;c<b.Yd.length;c++)if(d=b.Yd[c],d.j){switch(d.type){case "xScale":b.Ya=d.start+d.ic;break;case "yScale":b.cb=d.start+d.ic;break;case "alpha":b.alpha=d.start+d.ic;break;case "angle":b.na=d.start+d.ic;break;case "x":b.x=d.start+d.ic;break;case "y":b.y=d.start+d.ic}d.j=!1}b.canvas.X=!0}}function gg(b,c){b.images=c;b.canvas.X=!0}a=Ze.prototype;a.Dq=function(b){this.visible=this.j=b};a.Qb=function(){this.images&&(this.canvas.X=!0)};
a.ma=function(b){var c,d;if(void 0!==this.Yd){for(c=0;c<this.Yd.length;c++)switch(d=this.Yd[c],d.t+=b,d.type){case "xScale":var e=this.Ya,g=this.ak;this.Ya=d.Ra(d.t,d.start,d.ic,d.duration);this.ak=-(this.images[0].width*this.Ya-this.images[0].width*d.start)/2;if(isNaN(this.Ya)||isNaN(this.ak))this.Ya=e,this.ak=g;break;case "yScale":e=this.cb;g=this.bk;this.cb=d.Ra(d.t,d.start,d.ic,d.duration);this.bk=-(this.images[0].height*this.cb-this.images[0].height*d.start)/2;if(isNaN(this.cb)||isNaN(this.bk))this.cb=
e,this.bk=g;break;case "alpha":this.alpha=d.Ra(d.t,d.start,d.ic,d.duration);break;case "angle":this.na=d.Ra(d.t,d.start,d.ic,d.duration);break;case "x":e=this.x;this.x=d.Ra(d.t,d.start,d.ic,d.duration);isNaN(this.x)&&(this.x=e);break;case "y":e=this.y,this.y=d.Ra(d.t,d.start,d.ic,d.duration),isNaN(this.y)&&(this.y=e)}this.canvas.X=!0}};
a.pc=function(){var b,c,d;d=I.d.Zl(this.canvas);b=Math.round(this.x+this.parent.x-this.le*this.Ya);c=Math.round(this.y+this.parent.y-this.me*this.cb);this.Sh&&!Wb(this.sc,b,c,Eb(this.Je)-d.x,G.ba[this.Je].y-d.y)&&(this.images&&(this.$h=this.Oe=0,this.canvas.X=!0),this.Sh=!1)};
a.Ma=function(){var b,c;b=Math.round(this.x+this.parent.x-this.le*this.Ya);c=Math.round(this.y+this.parent.y-this.me*this.cb);this.images&&(this.images[this.Oe]instanceof x?this.images[this.Oe].V(b,c,this.Ya,this.cb,this.na,this.alpha):this.images[this.Oe].V(this.$h,b,c,this.Ya,this.cb,this.na,this.alpha));this.Zc=!1};
function Wf(b,c,d,e,g,h,k,m){this.M=I.a.r.gb[b];b=void 0!==I.a.S.buttons?I.a.r.Xg[I.a.S.buttons[b]||I.a.S.buttons.default_color]:I.a.r.Xg[I.a.r.buttons.default_color];this.font=S.da();b.font&&D(this.font,b.font);this.M.fontSize&&E(this.font,this.M.fontSize);this.H=g;this.text=I.l.N(this.H,"<"+g.toUpperCase()+">");void 0!==h&&(this.width=h);this.height=this.M.p.height;this.e={source:this.M.p,Y:this.M.Y,Da:this.M.Da};g=this.ud(this.e);h=new Ub(0,0,g[0].width,g[0].height);Ze.call(this,c,d,e,h,g,k,m)}
I.d.Bh(Wf);a=Wf.prototype;a.$j=function(b){this.text=I.l.N(this.H,"<"+this.H.toUpperCase()+">");b&&D(this.font,b);gg(this,this.ud(this.e))};a.ur=function(b,c){this.H=b;this.$j(c)};a.fi=function(b,c,d){"string"===typeof c&&(this.text=c);d&&D(this.font,d);b instanceof w?this.e.source=b:void 0!==b.Y&&void 0!==b.Da&&void 0!==b.source&&(this.e=b);gg(this,this.ud(this.e))};
a.ud=function(b){var c,d,e,g,h,k,m=b.Y+b.Da;e=this.height-(this.M.Yb||0);var n=b.source;d=this.font.Wa(this.text);void 0===this.width?c=d:"number"===typeof this.width?c=this.width-m:"object"===typeof this.width&&(void 0!==this.width.width?c=this.width.width-m:(void 0!==this.width.minWidth&&(c=Math.max(this.width.minWidth-m,d)),void 0!==this.width.maxWidth&&(c=Math.min(this.width.maxWidth-m,d))));d=Pa(this.font,this.text,c,e,!0);d<this.M.fontSize?E(this.font,d):E(this.font,this.M.fontSize);d=b.Y;e=
this.font.align;"center"===e?d+=Math.round(c/2):"right"===e&&(d+=c);e=Math.round(this.height/2);void 0!==this.M.Cb&&(e+=this.M.Cb);h=[];for(g=0;g<n.G;g++)k=new x(c+m,this.height),y(k),n.I(g,0,0,b.Y,this.height,0,0,1),n.$a(g,b.Y,0,n.width-m,this.height,b.Y,0,c,this.height,1),n.I(g,b.Y+n.width-m,0,b.Da,this.height,b.Y+c,0,1),this.font.n(this.text,d,e,c),A(k),h.push(k);return h};a.Rb=function(b){b===I.Qe&&this.$j()};
function kg(b,c,d,e,g,h,k,m){this.M=I.a.r.gb[b];void 0!==h&&(this.width=h);this.height=this.M.p.height;this.Tc={source:this.M.p,Y:this.M.Y,Da:this.M.Da};this.e=g;b=this.ud();g=new Ub(0,0,b[0].width,b[0].height);Ze.call(this,c,d,e,g,b,k,m)}I.d.Bh(kg);
kg.prototype.ud=function(){var b,c,d,e,g,h,k,m=this.Tc.Y+this.Tc.Da;c=this.height-(this.M.Yb||0);var n=this.Tc.source;void 0===this.width?b=this.e.width:"number"===typeof this.width?b=this.width-m:"object"===typeof this.width&&(void 0!==this.width.width?b=this.width.width-m:(void 0!==this.width.minWidth&&(b=Math.max(this.width.minWidth-m,this.e.width)),void 0!==this.width.maxWidth&&(b=Math.min(this.width.maxWidth-m,this.e.width))));k=Math.min(b/this.e.width,c/this.e.height);k=Math.min(k,1);g=Math.round(this.Tc.Y+
(b-this.e.width*k)/2);h=Math.round((c-this.e.height*k)/2);d=[];for(c=0;c<n.G;c++){e=new x(b+m,this.height);y(e);n.I(c,0,0,this.Tc.Y,this.height,0,0,1);n.$a(c,this.Tc.Y,0,n.width-m,this.height,this.Tc.Y,0,b,this.height,1);n.I(c,this.Tc.Y+n.width-m,0,this.Tc.Da,this.height,this.Tc.Y+b,0,1);try{p.context.drawImage(this.e,g,h,this.e.width*k,this.e.height*k)}catch(q){}A(e);d.push(e)}return d};I.d.Bh(function(b,c,d,e,g,h,k){Ze.call(this,b,c,d,g,e,h,k)});
function Tf(b,c,d,e,g,h,k,m){var n;this.M=I.a.r.gb[b];b=void 0!==I.a.S.buttons?I.a.r.Xg[I.a.S.buttons[b]||I.a.S.buttons.default_color]:I.a.r.Xg[I.a.r.buttons.default_color];this.font=S.da();b.font&&D(this.font,b.font);this.M.fontSize&&E(this.font,this.M.fontSize);void 0!==h&&(this.width=h);this.height=this.M.p.height;this.O=this.M.O;if(this.O.length){for(h=0;h<this.O.length;h++)if(this.O[h].id===g){this.ra=h;break}void 0===this.ra&&(this.ra=0);this.text=I.l.N(this.O[this.ra].H,"<"+this.O[this.ra].id.toUpperCase()+
">");this.lf=this.O[this.ra].p;h=this.ud();b=new Ub(0,0,h[0].width,h[0].height);n=this;"function"===typeof k?g=function(){n.af();return k(n.O[n.ra].id)}:"object"===typeof k?(g={},g.Jb=k.Jb,g.ca=this,g.U=function(){n.af();return k.U.call(k.ca,n.O[n.ra].id)}):g=function(){n.af()};Ze.call(this,c,d,e,b,h,g,m)}}I.d.Bh(Tf);a=Tf.prototype;
a.af=function(b){var c;if(void 0===b)this.ra=(this.ra+1)%this.O.length;else for(c=0;c<this.O.length;c++)if(this.O[c].id===b){this.ra=c;break}this.fi(this.O[this.ra].p,I.l.N(this.O[this.ra].H,"<"+this.O[this.ra].id.toUpperCase()+">"))};a.$j=function(b){b&&D(this.font,b);this.text=I.l.N(this.O[this.ra].H,"<"+this.O[this.ra].id.toUpperCase()+">");gg(this,this.ud())};a.fi=function(b,c,d){this.text=c;this.lf=b;d&&D(this.font,d);gg(this,this.ud())};
a.ud=function(){var b,c,d,e,g,h,k=this.M.Y,m=this.M.Da,n=k+m;g=Math.abs(k-m);e=this.height-(this.M.Yb||0);var q=this.M.p,v=this.font.da();c=v.Wa(this.text);void 0===this.width?b=c:"number"===typeof this.width?b=this.width-n:"object"===typeof this.width&&(void 0!==this.width.width?b=this.width.width-n:(void 0!==this.width.minWidth&&(b=Math.max(this.width.minWidth-n,c)),void 0!==this.width.maxWidth&&(b=Math.min(this.width.maxWidth-n,c))));e=Pa(v,this.text,b,e,!0);e<v.fontSize&&E(v,e);c=v.Wa(this.text,
b);e=k;d=v.align;"center"===d?e=b-g>=c?e+Math.round((b-g)/2):e+(this.M.ff+Math.round(c/2)):"left"===d?e+=this.M.ff:"right"===d&&(e+=b);g=Math.round(this.height/2);void 0!==this.M.Cb&&(g+=this.M.Cb);d=[];for(c=0;c<q.G;c++)h=new x(b+n,this.height),y(h),q.I(c,0,0,k,this.height,0,0,1),q.$a(c,k,0,q.width-n,this.height,k,0,b,this.height,1),q.I(c,k+q.width-n,0,m,this.height,k+b,0,1),this.lf.n(0,this.M.ig,this.M.jg),v.n(this.text,e,g,b),A(h),d.push(h);return d};a.Rb=function(b){b===I.Qe&&this.$j()};
function lg(b,c,d,e,g,h,k){var m;this.O=I.a.r.gb[b].O;if(this.O.length){for(b=0;b<this.O.length;b++)if(this.O[b].id===g){this.ra=b;break}void 0===this.ra&&(this.ra=0);this.lf=this.O[this.ra].p;b=new Vb(this.lf);m=this;g="function"===typeof h?function(){m.af();return h(m.O[m.ra].id)}:"object"===typeof h?{ca:this,U:function(){m.af();return h.U.call(h.ca,m.O[m.ra].id)}}:function(){m.af()};Ze.call(this,c,d,e,b,[this.lf],g,k)}}I.d.Bh(lg);
lg.prototype.af=function(b){var c;if(void 0===b)this.ra=(this.ra+1)%this.O.length;else for(c=0;c<this.O.length;c++)if(this.O[c].id===b){this.ra=c;break}this.fi(this.O[this.ra].p)};lg.prototype.fi=function(b){this.lf=b;gg(this,[].concat(this.lf))};
function Ag(b,c,d,e){this.depth=10;this.visible=!1;this.j=!0;I.d.bb(this,I.oc);var g;this.a=I.a.r.Bj;if("landscape"===I.orientation&&I.a.r.wm)for(g in I.a.r.wm)this.a[g]=I.a.r.wm[g];for(g in I.a.S.Bj)this.a[g]=I.a.S.Bj[g];this.mm=b;this.Xk=c;this.U=d;this.ca=e;this.Qh="entering";this.nr=!1;Nb(this,!1);Pb(this,"LevelStartDialog")}
function Bg(b){var c,d,e,g,h;if("leaving"!==b.Qh){b.Qh="leaving";b.De=0;c=function(){H(G,b);b.ca?b.U.call(b.ca):b.U&&b.U()};if(void 0!==b.a.Xm)for(d=0;d<b.a.Xm.length;d++)e=b.a.Xm[d],g=void 0,e.uo&&(b.De++,g=c),h=e.end,"x"===e.type?h=I.d.h(h,b.canvas.width,b.f.e.width):"y"===e.type&&(h=I.d.h(h,b.canvas.height,b.f.e.height)+Math.abs(I.pa)),mg(b.f,e.type,h,e.duration,e.Ra,g,e.la,e.loop,e.Gm);0===b.De&&c()}}a=Ag.prototype;
a.Pb=function(){var b,c,d,e,g,h,k=this;b=this.a.tc;c=b.width;g=b.height;this.f=new xg(this.depth+10,this.ua,new x(c,g));y(this.f.e);b.n(0,0,0);""!==this.Xk&&(d=I.d.h(this.a.lo,c,0),e=I.d.h(this.a.mo,g,0),b=S.da(),D(b,this.a.ko),void 0!==this.a.Sg&&void 0!==this.a.Wk&&(h=Pa(b,this.Xk,this.a.Sg,this.a.Wk,this.a.Sg),b.fontSize>h&&E(b,h)),b.n(this.Xk,d,e,this.a.Sg));""!==this.mm&&(d=I.d.h(this.a.wt,c,0),e=I.d.h(this.a.tp,g,0),b=S.da(),D(b,this.a.rp),void 0!==this.a.sj&&void 0!==this.a.sp&&(h=Pa(b,this.mm,
this.a.sj,this.a.sp,this.a.sj),b.fontSize>h&&E(b,h)),b.n(this.mm,d,e,this.a.sj));A(this.f.e);this.f.x=I.d.h(this.a.kq,this.canvas.width,c);this.f.y=I.d.h(this.a.lq,this.canvas.height,g)+Math.abs(I.pa);this.De=0;b=function(){k.De--;0===k.De&&(k.Qh="paused")};if(void 0!==this.a.Lj)for(c=0;c<this.a.Lj.length;c++)g=this.a.Lj[c],d=void 0,g.uo&&(this.De++,d=b),e=g.end,"x"===g.type?e=I.d.h(e,this.canvas.width,this.f.e.width):"y"===g.type&&(e=I.d.h(e,this.canvas.height,this.f.e.height)+Math.abs(I.pa)),mg(this.f,
g.type,e,g.duration,g.Ra,d,g.la,g.loop,g.Gm),void 0!==g.Bb&&F.play(g.Bb);0===this.De&&(this.Qh="paused");this.t=0};a.Qb=function(){H(G,this.f)};a.ma=function(b){"paused"!==this.state&&(this.t+=b,this.t>=this.a.nq&&Bg(this))};a.ab=function(){return this.nr=!0};a.jb=function(){this.nr&&"paused"===this.Qh&&Bg(this);return!0};
function xg(b,c,d){this.depth=b;this.j=this.visible=!0;I.d.bb(this,c);this.e=d;this.Aa=0;this.width=d.width;this.height=d.height;this.me=this.le=this.y=this.x=0;this.cb=this.Ya=1;this.na=0;this.alpha=1;this.Ae=[];this.jo=0;this.parent={x:0,y:0};this.Zc=!0;Nb(this,!1)}
function mg(b,c,d,e,g,h,k,m,n){var q,v=0<k;switch(c){case "x":q=b.x;break;case "y":q=b.y;break;case "xScale":q=b.Ya;break;case "yScale":q=b.cb;break;case "scale":c="xScale";q=b.Ya;mg(b,"yScale",d,e,g,void 0,k,m,n);break;case "angle":q=b.na;break;case "alpha":q=b.alpha;break;case "subImage":q=0}b.Ae.push({id:b.jo,t:0,j:!0,Ti:v,type:c,start:q,end:d,yb:h,duration:e,Ra:g,la:k,loop:m,Gm:n});b.jo++}
xg.prototype.ma=function(b){var c,d,e;for(c=0;c<this.Ae.length;c++)if(d=this.Ae[c],d.j&&(d.t+=b,d.Ti&&d.t>=d.la&&(d.t%=d.la,d.Ti=!1),!d.Ti)){d.t>=d.duration?(e=d.end,d.loop?(d.Ti=!0,d.la=d.Gm,d.t%=d.duration):("function"===typeof d.yb&&d.yb.call(this),this.Ae[c]=void 0)):"subImage"===d.type?(e=this.e instanceof Array?this.e.length:this.e.G,e=Math.floor(d.t*e/d.duration)):e=d.Ra(d.t,d.start,d.end-d.start,d.duration);switch(d.type){case "x":this.x=e;break;case "y":this.y=e;break;case "xScale":this.Ya=
e;break;case "yScale":this.cb=e;break;case "angle":this.na=e;break;case "alpha":this.alpha=e;break;case "subImage":this.Aa=e}this.canvas.X=!0}for(c=this.Ae.length-1;0<=c;c--)void 0===this.Ae[c]&&this.Ae.splice(c,1)};
xg.prototype.Ma=function(){var b,c,d;c=Math.round(this.x-this.Ya*this.le)+this.parent.x;d=Math.round(this.y-this.cb*this.me)+this.parent.y;b=this.e;b instanceof Array&&(b=this.e[this.Aa%this.e.length]);b instanceof x?b.V(c,d,this.Ya,this.cb,this.na,this.alpha):b.V(this.Aa,c,d,this.Ya,this.cb,this.na,this.alpha);this.Zc=!1};
function Cg(b,c,d){this.depth=-100;this.visible=!1;this.j=!0;this.Pu=b;I.d.bb(this,I.oc);this.a=I.a.r.ae;this.Hb=I.a.r.gb;this.wo=c;for(var e in I.a.S.ae)this.a[e]=I.a.S.ae[e];this.Zm=!1!==d;Nb(this)}a=Cg.prototype;a.kr=function(){};a.Rg=function(b,c,d,e,g){c=new Wf("default_text",c,d,this.depth-20,b.H||"NO_TEXT_KEY_GIVEN",e,{U:function(){b.U&&(b.ca?b.U.call(b.ca,b):b.U(b))},ca:this},this.f);this.buttons.push(c);b.text&&c.fi(c.e,b.text);this.buttons[this.buttons.length-1].qb=g||!1};
a.sa=function(b,c,d){y(this.f.e);p.clear();this.a.backgroundImage.n(0,0,0);b=d?d:this.Pu;c=S.da();this.a.bn&&D(c,this.a.bn);d=Pa(c,b,this.a.Wj,this.a.Vj,!0);d<c.fontSize&&E(c,d);d=c.Wa(b,this.a.Wj)+10;var e=Na(c,b,this.a.Vj)+10;c.n(b,I.d.qa(this.a.Uu,this.f.e.width,d,c.align),I.d.qa(this.a.sq,this.f.e.height-Dg(this),e,c.g),d);A(this.f.e)};function Dg(b){var c=b.wo;return I.d.h(b.a.vf,b.f.e.height,b.Hb.default_text.p.height*c.length+b.a.Uc*(c.length-1))}
a.ze=function(b,c){var d,e,g,h,k,m,n,q,v,z=[],z=this.wo;g=this.Hb.default_text.p.height;h=this.a.Ji;k=I.d.h(this.a.Ii,this.canvas.width,h)-b;q=Dg(this);for(d=z.length-1;0<=d;d--){n=k;v=h;if("object"===typeof z[d]&&z[d].hasOwnProperty("length")&&z[d].length)for(m=z[d],v=(h-(m.length-1)*this.a.Uc)/m.length,e=0;e<m.length;e++)this.Rg(m[e],n,q,v,c),n+=v+this.a.Uc;else this.Rg(z[d],n,q,v,c);q-=g+this.a.Uc}};
a.show=function(){var b,c;for(b=0;b<this.buttons.length;b++)c=this.buttons[b],c.Dq(!0);this.f.visible=!0};a.close=function(){H(G,this);return this.canvas.X=!0};function Eg(b){var c=I.b.Xd;c.sa(c.f.x,c.f.y,b);for(b=0;b<c.buttons.length;b++)H(G,c.buttons[b]);c.canvas.X=!0}
a.Pb=function(){var b,c;this.Zm&&wg(this);b=this.a.backgroundImage;this.f=new xg(this.depth-10,this.ua,new x(b.width,b.height));this.f.x=I.d.h(this.a.cd,this.canvas.width,b.width);b=I.d.h(this.a.Xb,this.canvas.height,b.height)+-1*("landscape"===I.orientation?I.a.r.ol:I.a.r.sd).Fj;this.f.y=b;this.sa(this.f.x,this.f.y);this.buttons=[];this.ze(this.f.x);c=this;this.f.y=-this.f.e.height;mg(this.f,"y",b,this.a.Pf,this.a.Qf,function(){var b;for(b=0;b<c.buttons.length;b++)c.buttons[b].qb=!0})};
a.Qb=function(){var b;this.Zm&&yg();for(b=0;b<this.buttons.length;b++)H(G,this.buttons[b]);H(G,this.f);I.b.ye===this&&(I.b.ye=null)};a.jb=function(){return!0};a.ab=function(){return!0};
function Fg(b){if(null===b||"undefined"===typeof b)return"";b+="";var c="",d,e,g=0;d=e=0;for(var g=b.length,h=0;h<g;h++){var k=b.charCodeAt(h),m=null;if(128>k)e++;else if(127<k&&2048>k)m=String.fromCharCode(k>>6|192,k&63|128);else if(55296!==(k&63488))m=String.fromCharCode(k>>12|224,k>>6&63|128,k&63|128);else{if(55296!==(k&64512))throw new RangeError("Unmatched trail surrogate at "+h);m=b.charCodeAt(++h);if(56320!==(m&64512))throw new RangeError("Unmatched lead surrogate at "+(h-1));k=((k&1023)<<
10)+(m&1023)+65536;m=String.fromCharCode(k>>18|240,k>>12&63|128,k>>6&63|128,k&63|128)}null!==m&&(e>d&&(c+=b.slice(d,e)),c+=m,d=e=h+1)}e>d&&(c+=b.slice(d,g));return c}
function Ff(b){function c(b){var c="",d="",e;for(e=0;3>=e;e++)d=b>>>8*e&255,d="0"+d.toString(16),c+=d.substr(d.length-2,2);return c}function d(b,c,d,e,g,h,m){b=k(b,k(k(d^(c|~e),g),m));return k(b<<h|b>>>32-h,c)}function e(b,c,d,e,g,h,m){b=k(b,k(k(c^d^e,g),m));return k(b<<h|b>>>32-h,c)}function g(b,c,d,e,g,h,m){b=k(b,k(k(c&e|d&~e,g),m));return k(b<<h|b>>>32-h,c)}function h(b,c,d,e,g,h,m){b=k(b,k(k(c&d|~c&e,g),m));return k(b<<h|b>>>32-h,c)}function k(b,c){var d,e,g,h,k;g=b&2147483648;h=c&2147483648;
d=b&1073741824;e=c&1073741824;k=(b&1073741823)+(c&1073741823);return d&e?k^2147483648^g^h:d|e?k&1073741824?k^3221225472^g^h:k^1073741824^g^h:k^g^h}var m=[],n,q,v,z,B,r,s,t,u;b=Fg(b);m=function(b){var c,d=b.length;c=d+8;for(var e=16*((c-c%64)/64+1),g=Array(e-1),h=0,k=0;k<d;)c=(k-k%4)/4,h=k%4*8,g[c]|=b.charCodeAt(k)<<h,k++;c=(k-k%4)/4;g[c]|=128<<k%4*8;g[e-2]=d<<3;g[e-1]=d>>>29;return g}(b);r=1732584193;s=4023233417;t=2562383102;u=271733878;b=m.length;for(n=0;n<b;n+=16)q=r,v=s,z=t,B=u,r=h(r,s,t,u,m[n+
0],7,3614090360),u=h(u,r,s,t,m[n+1],12,3905402710),t=h(t,u,r,s,m[n+2],17,606105819),s=h(s,t,u,r,m[n+3],22,3250441966),r=h(r,s,t,u,m[n+4],7,4118548399),u=h(u,r,s,t,m[n+5],12,1200080426),t=h(t,u,r,s,m[n+6],17,2821735955),s=h(s,t,u,r,m[n+7],22,4249261313),r=h(r,s,t,u,m[n+8],7,1770035416),u=h(u,r,s,t,m[n+9],12,2336552879),t=h(t,u,r,s,m[n+10],17,4294925233),s=h(s,t,u,r,m[n+11],22,2304563134),r=h(r,s,t,u,m[n+12],7,1804603682),u=h(u,r,s,t,m[n+13],12,4254626195),t=h(t,u,r,s,m[n+14],17,2792965006),s=h(s,t,
u,r,m[n+15],22,1236535329),r=g(r,s,t,u,m[n+1],5,4129170786),u=g(u,r,s,t,m[n+6],9,3225465664),t=g(t,u,r,s,m[n+11],14,643717713),s=g(s,t,u,r,m[n+0],20,3921069994),r=g(r,s,t,u,m[n+5],5,3593408605),u=g(u,r,s,t,m[n+10],9,38016083),t=g(t,u,r,s,m[n+15],14,3634488961),s=g(s,t,u,r,m[n+4],20,3889429448),r=g(r,s,t,u,m[n+9],5,568446438),u=g(u,r,s,t,m[n+14],9,3275163606),t=g(t,u,r,s,m[n+3],14,4107603335),s=g(s,t,u,r,m[n+8],20,1163531501),r=g(r,s,t,u,m[n+13],5,2850285829),u=g(u,r,s,t,m[n+2],9,4243563512),t=g(t,
u,r,s,m[n+7],14,1735328473),s=g(s,t,u,r,m[n+12],20,2368359562),r=e(r,s,t,u,m[n+5],4,4294588738),u=e(u,r,s,t,m[n+8],11,2272392833),t=e(t,u,r,s,m[n+11],16,1839030562),s=e(s,t,u,r,m[n+14],23,4259657740),r=e(r,s,t,u,m[n+1],4,2763975236),u=e(u,r,s,t,m[n+4],11,1272893353),t=e(t,u,r,s,m[n+7],16,4139469664),s=e(s,t,u,r,m[n+10],23,3200236656),r=e(r,s,t,u,m[n+13],4,681279174),u=e(u,r,s,t,m[n+0],11,3936430074),t=e(t,u,r,s,m[n+3],16,3572445317),s=e(s,t,u,r,m[n+6],23,76029189),r=e(r,s,t,u,m[n+9],4,3654602809),
u=e(u,r,s,t,m[n+12],11,3873151461),t=e(t,u,r,s,m[n+15],16,530742520),s=e(s,t,u,r,m[n+2],23,3299628645),r=d(r,s,t,u,m[n+0],6,4096336452),u=d(u,r,s,t,m[n+7],10,1126891415),t=d(t,u,r,s,m[n+14],15,2878612391),s=d(s,t,u,r,m[n+5],21,4237533241),r=d(r,s,t,u,m[n+12],6,1700485571),u=d(u,r,s,t,m[n+3],10,2399980690),t=d(t,u,r,s,m[n+10],15,4293915773),s=d(s,t,u,r,m[n+1],21,2240044497),r=d(r,s,t,u,m[n+8],6,1873313359),u=d(u,r,s,t,m[n+15],10,4264355552),t=d(t,u,r,s,m[n+6],15,2734768916),s=d(s,t,u,r,m[n+13],21,
1309151649),r=d(r,s,t,u,m[n+4],6,4149444226),u=d(u,r,s,t,m[n+11],10,3174756917),t=d(t,u,r,s,m[n+2],15,718787259),s=d(s,t,u,r,m[n+9],21,3951481745),r=k(r,q),s=k(s,v),t=k(t,z),u=k(u,B);return(c(r)+c(s)+c(t)+c(u)).toLowerCase()}
function Gg(b){var c=I.q.wp.url+"api";try{var d=new XMLHttpRequest;d.open("POST",c);d.setRequestHeader("Content-Type","application/x-www-form-urlencoded");d.onload=function(){"application/json"===d.getResponseHeader("Content-Type")&&b(JSON.parse(d.responseText))};d.onerror=function(b){console.log("error: "+b)};d.send("call=api_is_valid")}catch(e){}}function Hg(b){Gg(function(c){b(c.is_valid)})}
TG_StatObjectFactory={Mw:function(b){return new TG_StatObject("totalScore",b,"levelEndScreenTotalScore_"+b,0,0,!0,!0)},Kw:function(b){return new TG_StatObject("highScore",b,"levelEndScreenHighScore_"+b,Ig(),Ig(),!0)},Jw:function(b,c,d,e,g){return new TG_StatObject(b,c,d,0,e,g,!0,"max"===I.k.Mi?function(b){return b+e}:function(b){return b-e})},Lw:function(b,c,d,e,g){return new TG_StatObject(b,c,d,0,e,g,!0,"max"===I.k.Mi?function(b){return b-e}:function(b){return b+e})}};
TG_StatObject=function(b,c,d,e,g,h,k,m,n){this.id=b;this.type=c;this.key=d;this.zl=e;this.Sq=void 0!==g?g:this.zl;this.visible=void 0!==h?h:!0;this.fs=void 0!==k?k:this.zl!==this.Sq;this.$v=m;this.xv=void 0!==n?n:"totalScore";switch(this.type){case "text":this.toString=function(b){return b};break;case "number":this.toString=function(b){return b+""};break;case "time":this.toString=function(b){return I.d.Qv(1E3*b)}}};
TG_StatObject.prototype.da=function(){return new TG_StatObject(this.id,this.type,this.key,this.zl,this.Sq,this.visible,this.fs,this.$v,this.xv)};I.version=I.version||{};I.version.tg="2.13.0";
function Jg(){this.j=this.visible=!0;var b=I.a.o.pg.Jj.length,c=Math.ceil(b/I.a.o.Aj.ym),b=b%I.a.o.Aj.ym,d=[],e;for(e=0;e<c-1;e++)d.push(I.a.o.Aj.ym);d.push(b);I.a.o.Ke.P=d;for(var g in W)for(e=1;e<c;e++)W[g]["levelMapScreenWorld_"+e]=W[g].levelMapScreenWorld_0;for(var h in mc)Kg.push(mc[h]);for(h in nc)Lg.push(nc[h])}
Jg.prototype.kp=function(){var b,c,d;b=[];c=[Yd,Xd,Sd,Td,Ud,Vd,Zd,$d];for(d=0;d<c.length;d++)b.push({e:c[d],text:I.l.N("TutorialText_"+d,"<TutorialText_"+d+">"),title:I.l.N("TutorialTitle_"+d,"<TutorialTitle_"+d+">")});return b};var Kg=[],Lg=[];function Mg(b){this.j=!1;this.visible=!0;this.Ch=b;this.tl=this.Ch+1;this.Kc=10;this.Zs=1E3;this.Sa=new Ng;this.result=new Og;this.Ib=-1;this.depth=10;I.d.bb(this,I.Df);this.il=this.kl=null;Nb(this);this.state="INTRO"}a=Mg.prototype;
a.Ur=function(){this.Kc=this.Zs;this.j=!0;this.xc.nk=1;this.state="PLAYING"};
a.Pb=function(){this.canvas.X=!0;var b=new ff;b.nn=Ef.Fk;this.xc=new gf(b);this.xc.pv.dk(this.tl);this.xc.setTime(0);this.xc.nk=0;var c=this;this.kl=this.xc.buttons.fillButton;this.il=this.xc.buttons.blockButton;Pg(this);tf(this.xc,function(){Pg(c)},"fillButton");tf(this.xc,function(){c.Sa.mode=Qg;c.kl.e=vd;c.il.e=he;Rg(Fe)},"blockButton");tf(this.xc,function(){Sg(c)},"retryButton");b=I.a.o.pg[I.a.o.pg.Jj[this.Ch]];this.Sa.rl(b);this.result.rl(b);this.result.mn(this.Sa.offset.x+I.sh,this.Sa.offset.y+
I.th);b=I.l.N("levelStartText","<levelStartText>");b=b.replace("<VALUE>",this.tl);Tg(I.l.N("levelStartHeader","<levelStartHeader>"),b,this.Ur,this)};a.Qb=function(){this.canvas.X=!0;H(G,this.xc);var b=G,c,d=Qb(b,"item");for(c=0;c<d.length;c+=1)H(b,d[c])};a.ma=function(){};function Pg(b){b.Sa.mode=Ug;b.kl.e=ge;b.il.e=wd;Rg(Fe)}
function Sg(b){if("PLAYING"===b.state){var c=[];c[0]={vt:I.l.N("restartCancelBtnHeader","<restartCancelBtnHeader>"),text:I.l.N("restartCancelBtnText","<restartCancelBtnText>"),U:function(){this.ae.close()},ca:b};c[1]={vt:I.l.N("restartConfirmBtnHeader","<restartConfirmBtnHeader>"),text:I.l.N("restartConfirmBtnText","<restartConfirmBtnText>"),U:function(){this.ae&&this.ae.close();this.state="INTRO";this.Qb();this.Sa=new Ng;this.result=new Og;this.Ib=-1;Rg(Fe);this.Pb()},ca:b};b.ae=new Cg(I.l.N("restartConfirmation",
"<restartConfirmation>"),c)}}a.ab=function(b,c,d){-1===this.Ib&&"PLAYING"===this.state&&(this.Ib=b,b=this.Sa,c=Math.floor((c-I.sh-b.offset.x)/I.a.o.ia.size),d=Math.floor((d-I.th-b.offset.y)/I.a.o.ia.size),!(0>c||c>=b.width||0>d||d>=b.height)&&(b.ha.start.$d=c,b.ha.start.$e=d,b.ha.wc=b.cells[c][d].state,b.ha.wc===Vg&&b.mode===Ug||b.ha.wc===Wg&&b.mode===Qg))&&(b.ha.wc=Xg)};
a.jb=function(b){if(b==this.Ib||"PLAYING"===this.state){this.Ib=-1;b=this.Sa;b.ha.start={$d:-1,$e:-1};b.ha.wc=Xg;b.ha.direction=Yg;a:{b=this.Sa;var c,d;for(c=0;c<b.width;c++)for(d=0;d<b.height;d++)if(b.cells[c][d].state===Wg!==b.Zf[c][d]){b=!1;break a}b=!0}b&&(b=Math.floor(this.xc.getTime()/1E3),30<b&&(this.Kc-=b-30),10>this.Kc&&(this.Kc=10),this.Kc=this.Kc,b=this.result,b.j=!0,b.visible=!0,this.state="OUTRO")}};
a.Rb=function(b){"levelEnd_next"===b&&Zg(this,"next");"levelEnd_retry"===b&&Zg(this,"retry");"levelEnd_exit"===b&&Zg(this,"exit")};a.pc=function(b){this.canvas.X=!0;$g.update(b);this.xc.gh.numberOfLevels.Cq(this.tl+"/"+I.a.o.pg.Jj.length);-1!==this.Ib&&ah(this.Sa,Eb(this.Ib)-I.sh,G.ba[this.Ib].y-I.th)};
function Zg(b,c){I.b.state="LEVEL_END";I.b.rc=!0;I.b.Jp=c;ug(I.b,!0);var d={totalScore:0,level:b.Ch,highScore:b.Kc,failed:!1,stars:0,stage:0};if(b.Ch+1<I.a.o.pg.Jj.length){for(var e=0,g=b.Ch+1;e<I.k.P.length&&g>=I.k.P[e];)g-=I.k.P[e],e++;"locked"===bg(e,g,"state","locked")&&bh(e,g)}I.i.Kf(d);I.qd.Kf(d)}
function Ng(){this.height=this.width=1;this.a=ch;this.Zf=[];this.cells=[];this.vq=[];this.Co=[];this.offset={x:0,y:0};this.mode=Ug;this.ha={start:{$d:-1,$e:-1},wc:Xg,direction:Yg};this.$i=this.wh=this.bd=this.Ci=this.Tf=null;this.pl=!1;this.y=this.x=0;this.op=!0;this.depth=10;this.visible=this.j=!0;I.d.bb(this,I.Df);Nb(this);Pb(this,["item"])}var Ug=0,Qg=1,Yg=0;a=Ng.prototype;
a.rl=function(b){var c,d,e;this.width=b.width/50;this.height=b.height/50;this.offset.x=I.kj/2-this.width*I.a.o.ia.size/2;this.offset.y=I.fj/2-this.height*I.a.o.ia.size/2;this.offset.x=Math.max(this.offset.x,I.a.o.Sa.cq.x);this.offset.y=Math.max(this.offset.y,I.a.o.Sa.cq.y);var g=I.a.o.ia.size,h=this.width*g,g=this.height*g;e=[];for(c=0;c<this.width;c++)for(this.cells[c]=[],this.Zf[c]=[],e[c]=[],d=0;d<this.height;d++)this.cells[c][d]=new dh(c,d),this.Zf[c][d]=!1,e[c][d]=-1;for(c=0;c<b.items.length;c++)e=
b.items[c],"cell"===e.id&&(d=e.x/50,e=e.y/50,this.Zf[d][e]=!0);for(c=0;c<this.width;c++)eh(this,c);for(c=0;c<this.height;c++)fh(this,c);this.Tf=new gh(this.offset.x+I.a.o.Tf.offset.x,this.offset.y+I.a.o.Tf.offset.y,this.width,this.height);this.bd=new x(h+this.a.margin,g+this.a.margin);y(this.bd);ke.be(0,0,0,h+this.a.margin,g+this.a.margin,1);A(this.bd);d=I.a.o.ia.size;this.Ci=new x(this.width*d,this.height*d);y(this.Ci);for(b=0;b<this.width;b++)for(c=0;c<this.height;c++)1!==b%2&&1!==c%2||R.n(0,b*
d,c*d);p.context.globalCompositeOperation="destination-in";this.bd.n(-this.a.margin/2,-this.a.margin/2);p.context.globalCompositeOperation="source-over";A(this.Ci);this.wh=new x(h,g);this.ql()};function eh(b,c){var d;d=hh(b,c,b.Zf,function(b){return b});d=new ih(b.offset.x+c*I.a.o.ia.size,b.offset.y,d);b.Co[c]=d}function fh(b,c){var d;d=jh(b,c,b.Zf,function(b){return b});d=new kh(b.offset.x,b.offset.y+c*I.a.o.ia.size,d);b.vq[c]=d}
function hh(b,c,d,e){var g,h=0,k=[],m=!1,n;for(g=k[0]=0;g<b.height;g++)(n=e(d[c][g]))&&!m&&(k[h]=0),n&&(k[h]++,m=!0),!n&&m&&(h++,m=!1);return k}function jh(b,c,d,e){var g,h=0,k=[],m=!1,n;for(g=k[0]=0;g<b.width;g++)(n=e(d[g][c]))&&!m&&(k[h]=0),n&&(k[h]++,m=!0),!n&&m&&(h++,m=!1);return k}
function ah(b,c,d){c=Math.floor((c-b.offset.x)/I.a.o.ia.size);d=Math.floor((d-b.offset.y)/I.a.o.ia.size);if(!(0>c||c>=b.width||0>d||d>=b.height)){-1===b.ha.start.$d&&(b.ha.start.$d=c,b.ha.start.$e=d,b.ha.wc=b.cells[c][d].state,b.ha.wc===Vg&&b.mode===Ug||b.ha.wc===Wg&&b.mode===Qg)&&(b.ha.wc=Xg);if(b.ha.direction===Yg){var e=d-b.ha.start.$e;0!==c-b.ha.start.$d?b.ha.direction=1:0!==e&&(b.ha.direction=2)}b.cells[c][d].state!==b.ha.wc||1===b.ha.direction&&d!==b.ha.start.$e||2===b.ha.direction&&c!==b.ha.start.$d||
(b.mode===Ug?(lh(b.cells[c][d],b.ha.wc!==Wg),Rg(Kg)):(mh(b.cells[c][d],b.ha.wc!==Vg),Rg(Lg)),b.Co[c].Zj(hh(b,c,b.cells,function(b){return b.state===Wg})),b.vq[d].Zj(jh(b,d,b.cells,function(b){return b.state===Wg})),nh(b.Tf,c,d,b.cells[c][d].state===Wg),b.pl=!0)}}a.xh=function(){};a.Rb=function(b){"hideGrid"===b&&(this.op=!1)};
a.pc=function(){if(this.pl){this.pl=!1;var b,c;this.wh.clear();y(this.wh);for(b=0;b<this.width;b++)for(c=0;c<this.height;c++)this.cells[b][c].pb();p.context.globalCompositeOperation="destination-in";this.bd.n(-this.a.margin/2,-this.a.margin/2);p.context.globalCompositeOperation="source-over";A(this.wh)}};a.Ma=function(){this.Ci.n(this.offset.x,this.offset.y);this.op&&this.wh.n(this.offset.x,this.offset.y);this.$i.n(0,0)};
a.ql=function(){var b,c,d=I.a.o.ia.size,e=this.width*d,g=this.height*d;this.$i=new x(I.kj,I.fj);y(this.$i);for(c=1;c<this.width;c++)b=this.offset.x+c*d,qa(b,this.offset.y,b,this.offset.y+g,this.a.nj.color,this.a.nj.lineWidth);for(c=1;c<this.height;c++)b=this.offset.y+c*d,qa(this.offset.x,b,this.offset.x+e,b,this.a.nj.color,this.a.nj.lineWidth);var h,k,m,n,q;c=this.a.margin;d=this.offset.y;b=this.offset.y+this.height*I.a.o.ia.size;h=I.fj-this.a.margin;m=h-b>R.height;for(k=1;k<this.width;k+=2)n=this.offset.x+
k*I.a.o.ia.size,q=c,R.V(2,n,q,1,1,0,1),q+=R.height,R.kh(0,n,q,R.width,d-(c+R.height),1),m&&(q=h,n+=R.width,R.V(2,n,q,1,1,180,1),n-=R.width,q=b,R.kh(0,n,q,R.width,h-R.height-b,1));b=this.a.margin;h=this.offset.x;c=this.offset.x+this.width*I.a.o.ia.size;d=I.kj-this.a.margin;m=d-c>R.width;for(k=1;k<this.height;k+=2)q=this.offset.y+k*I.a.o.ia.size,n=b,q+=R.height,R.V(2,n,q,1,1,90,1),q-=R.height,n+=R.width,R.kh(0,n,q,h-(b+R.width),R.height,1),m&&(n=d,R.V(2,n,q,1,1,270,1),n=c,R.kh(0,n,q,d-R.width-c,R.height,
1));le.be(0,this.offset.x-this.a.margin/2,this.offset.y-this.a.margin/2,e+this.a.margin,g+this.a.margin,1);A(this.$i)};function dh(b,c){this.$d=b;this.$e=c;this.x=this.$d*I.a.o.ia.size;this.y=this.$e*I.a.o.ia.size;this.state=Xg}var Xg=0,Wg=1,Vg=2;function lh(b,c){if(b.state===Xg||b.state===Wg)b.state=c?Wg:Xg}function mh(b,c){if(b.state===Xg||b.state===Vg)b.state=c?Vg:Xg}dh.prototype.pb=function(){this.state===Wg&&ie.n(0,this.x,this.y);this.state===Vg&&je.n(0,this.x,this.y)};
function Og(){this.depth=-1E3;this.ua=0;this.j=this.visible=!1;this.y=this.x=0;this.a=oh;this.offset={x:0,y:0};this.target={x:0,y:0};I.d.bb(this,I.Pl);Nb(this);Pb(this,["item"]);this.aj=this.Dc=this.Lh=this.Lb=null;this.Ed=this.alpha=this.Zi=0;this.Fd=-1;this.We=-999;this.Yg=-1;this.xo=-999;this.Gi=-this.a.us;this.Kj=0;this.Rf=[];for(var b=0;120>b;b++)this.Rf[b]={x:0,y:0,j:!1};this.Vp=0;this.state="FADING";this.lc={};this.Kb={};this.vc={};this.buttons=[this.lc,this.Kb,this.vc];this.lc.action="levelEnd_exit";
this.lc.e=ce;this.lc.x=-999;this.lc.y=-999;this.lc.uc=J(this.a.Vs);this.lc.Aa=0;this.lc.scale=1;this.Kb.action="levelEnd_next";this.Kb.e=ee;this.Kb.uc=ee.width/2;this.Kb.x=-999;this.Kb.y=-999;this.Kb.Aa=0;this.Kb.scale=0;this.vc.action="levelEnd_retry";this.vc.e=fe;this.vc.uc=fe.width/2;this.vc.x=-999;this.vc.y=-999;this.vc.Aa=0;this.vc.scale=0;this.pd=null;this.Ib=-1;this.action="exit"}a=Og.prototype;
a.rl=function(b){var c=b.width/50*I.a.o.ia.size,d=b.height/50*I.a.o.ia.size,e=b.items,g,h,k;this.Lb=new x(c,d);y(this.Lb);pa(0,0,c,d,"#fff");for(g=0;g<e.length;g++)"color"===e[g].id&&(h=e[g].x/50*I.a.o.ia.size,k=e[g].y/50*I.a.o.ia.size,Q.n(e[g].kind,h,k));A(this.Lb);this.ql(c,d);d=b.name.key;b=this.a.Nm+20;d=I.l.N("desc_"+d,"<desc_"+d+">");this.Lh=new x(c+this.a.gc,b);e=Ce.da();g=Math.min(e.fontSize,Pa(e,d,c-2*this.a.uu,100,!1));E(e,g);y(this.Lh);ae.be(0,0,0,c+this.a.gc,b,1);e.n(d,c/2,(b-20)/2);A(this.Lh);
b=this.a.vs+20;this.Dc=new x(c+this.a.gc,b);y(this.Dc);ae.be(1,0,0,c+this.a.gc,b,1);A(this.Dc);this.target.x=I.sh+I.kj/2-this.Lb.width/2+this.a.offset.x;this.target.y=I.th+I.fj/2-this.Lb.height/2+this.a.offset.y};a.ql=function(b,c){this.aj=new x(b+this.a.gc,c+this.a.gc);y(this.aj);be.be(0,0,0,b+this.a.gc,c+this.a.gc,1);A(this.aj)};a.mn=function(b,c){this.offset.x=b;this.offset.y=c;this.x=b;this.y=c};
a.ab=function(b,c,d){if(-1===this.Ib||"OUTRO"===this.state){this.Ib=b;var e,g,h;for(b=0;b<this.buttons.length;b++)if(e=this.buttons[b],g=c-e.x,h=d-e.y,g*g+h*h<e.uc*e.uc*e.scale){this.pd=e;this.pd.Aa=1;break}}};a.jb=function(b,c,d){this.Ib=-1;null!==this.pd&&(b=this.pd,c-=b.x,d-=b.y,c*c+d*d<b.uc*b.uc&&(this.state="OUTRO",this.action=b.action),this.pd.Aa=0,this.pd=null)};
a.pc=function(b){this.canvas.X=!0;if(null!==this.pd){var c,d,e;c=this.pd;d=Eb(this.Ib)-c.x;e=G.ba[this.Ib].y-c.y;this.pd.Aa=d*d+e*e<c.uc*c.uc?1:0}switch(this.state){case "FADING":this.Zi=Math.min(this.Zi+b,this.a.ib);this.alpha+=0+this.Zi/this.a.ib*1;this.Zi===this.a.ib&&(this.alpha=1,this.state="MOVING",la("hideGrid"));break;case "MOVING":this.Ed=Math.min(this.a.je,this.Ed+b);this.x=ic(this.Ed,this.offset.x,this.target.x-this.offset.x,this.a.je);this.y=ic(this.Ed,this.offset.y,this.target.y-this.offset.y,
this.a.je);this.x===this.target.x&&this.y===this.target.y&&(this.state="SHOWNAME",this.lc.x=this.x+this.Lh.width+this.a.Yi.x,Rg(Ge));break;case "SHOWNAME":this.Fd=Math.min(this.a.Of,this.Fd+b);this.We=ic(this.Fd,0,-this.a.Nm,this.a.Of);this.lc.y=this.y+this.a.Yi.y+this.We;this.Fd>this.a.Of/2&&(this.state="SHOWBUTTONTRAY");ph(this,b);break;case "SHOWBUTTONTRAY":this.Fd=Math.min(this.a.Of,this.Fd+b);this.We=ic(this.Fd,0,-this.a.Nm,this.a.Of);this.lc.y=this.y+this.a.Yi.y+this.We;this.Yg=Math.min(this.a.ll,
this.Yg+b);this.xo=ic(this.Yg,0,140,this.a.ll);this.Yg===this.a.ll&&this.Fd===this.a.Of&&(this.state="SHOWBUTTONS",c=this.x-this.a.gc/2,this.Kb.x=c+this.Dc.width-this.Kb.uc-this.a.vu,this.Kb.y=this.y+this.Lb.height+(this.Dc.height-20)/2,this.vc.x=c+this.Kb.uc+this.a.$u,this.vc.y=this.y+this.Lb.height+(this.Dc.height-20)/2);ph(this,b);break;case "SHOWBUTTONS":this.Gi=Math.min(this.a.hl,this.Gi+b);c=this.Gi/this.a.hl;c=Math.max(0,Math.min(.7,c));d=this.Gi/this.a.hl-.3;d=Math.max(0,Math.min(.7,d));this.Kb.scale=
0+1*gc(.7-c,.7,void 0,void 0);this.vc.scale=0+1*gc(.7-d,.7,void 0,void 0);ph(this,b);break;case "IDLE":ph(this,b);break;case "OUTRO":this.Kj=Math.min(this.a.Wm,this.Kj+b),this.y=hc(this.Kj,this.target.y,-this.target.y-(this.Lb.height+this.Dc.height),this.a.Wm),this.Kb.y=this.y+this.Lb.height+(this.Dc.height-20)/2,this.vc.y=this.y+this.Lb.height+(this.Dc.height-20)/2,this.lc.y=this.y+this.a.Yi.y+this.We,this.Kj===this.a.Wm&&(la(this.action),this.state="ENDED")}};
function ph(b,c){for(var d=Math.floor(Math.random()*(120-b.Vp)*.1),d=Math.min(d,6),e=0;0<d;){var g=b.Rf[e++];if(!g.j){g.j=!0;g.duration=800+1200*Math.random();g.time=0;var h=Math.random()*Math.PI*2,k=200+200*Math.random();g.ag=120*Math.cos(h);g.bg=120*Math.sin(h);g.Is=Math.cos(h)*(k-120);g.Js=Math.sin(h)*(k-120);g.alpha=1;g.as=360*Math.random()-180;g.na=h;g.Rq=.5+.5*Math.random();g.av=-(.6*Math.random()+.2)*g.scale;g.scale=g.Rq;d--;b.Vp++}}d=c/1E3;for(e=0;e<b.Rf.length;e++)g=b.Rf[e],g.j&&(g.time=
Math.min(g.duration,g.time+c),g.x=cc(g.time,g.ag,g.Is,g.duration,2),g.y=cc(g.time,g.bg,g.Js,g.duration,2),g.alpha=ec(g.time,1,-1,g.duration),h=g.duration,g.scale=g.Rq+g.av*(1+-1*(1-Math.cos((h-g.time)/h*Math.PI/2))),g.na+=d*g.as,g.time===g.duration&&(g.j=!1))}
a.Ma=function(){var b=p.context.globalAlpha;p.context.globalAlpha=this.alpha;pa(0,0,p.canvas.width,p.canvas.height,this.a.backgroundColor,!1);p.context.globalAlpha=b;for(var c=this.x+this.Lb.width/2,d=this.y+this.Lb.height/2,b=0;b<this.Rf.length;b++){var e=this.Rf[b];e.j&&de.V(0,c+e.x,d+e.y,e.scale,e.scale,e.na,e.alpha*this.alpha)}c=this.x-this.a.gc/2;-1!==this.Fd&&this.Lh.n(c,this.y+this.We);-1!==this.Yg&&this.Dc.n(c,this.y+this.Lb.height-this.Dc.height+this.xo);for(b=0;b<this.buttons.length;b++)c=
this.buttons[b],c.e.V(c.Aa,c.x,c.y,c.scale,c.scale,1,this.alpha);this.Lb.V(this.x,this.y,1,1,0,this.alpha);this.aj.V(this.x-this.a.gc/2,this.y-this.a.gc/2,1,1,0,this.alpha)};
function gh(b,c,d,e){this.depth=-100;this.ua=0;this.j=this.visible=!0;this.x=b;this.y=c;this.width=d;this.height=e;this.hb=1;I.d.bb(this,I.Df);Nb(this);Pb(this,["item"]);this.va=this.bd=null;this.Sa=[];this.Om=!1;b=Math.max(this.width,this.height);this.hb=I.a.o.Tf.au/b;this.hb=2*Math.floor(this.hb/2);this.x-=this.hb*this.width;this.y-=this.hb*this.height;this.va=new x(this.hb*this.width,this.hb*this.height);this.bd=new x(this.hb*this.width,this.hb*this.height);y(this.bd);me.be(0,0,0,this.width*this.hb,
this.height*this.hb,1);A(this.bd);for(b=0;b<this.width;b++)for(this.Sa[b]=[],c=0;c<this.height;c++)this.Sa[b][c]=!1;this.oe()}gh.prototype.oe=function(){var b,c;this.va.clear();y(this.va);for(b=0;b<this.width;b++)for(c=0;c<this.height;c++)!1!==this.Sa[b][c]&&pa(b*this.hb,c*this.hb,this.hb,this.hb,"#93648f");ne.be(0,0,0,this.width*this.hb,this.height*this.hb,1);p.context.globalCompositeOperation="destination-in";this.bd.n(0,0);p.context.globalCompositeOperation="source-over";A(this.va)};
function nh(b,c,d,e){b.Sa[c][d]!==e&&(b.Sa[c][d]=e,b.Om=!0)}gh.prototype.pc=function(){this.Om&&(this.oe(),this.Om=!1)};gh.prototype.Ma=function(){this.va.n(this.x,this.y)};function qh(b,c,d){this.depth=0;this.j=this.visible=!0;this.x=b;this.y=c;this.yc=d;this.anchor={x:0,y:0};this.sb=null;this.Zj();I.d.bb(this,I.Df);Nb(this);Pb(this,["item"])}qh.prototype.Ma=function(){null!==this.sb&&this.sb.n(this.x-this.anchor.x,this.y-this.anchor.y)};
function kh(b,c,d){qh.call(this,b,c,d);this.anchor.x=this.sb.width}kh.prototype=Object.create(qh.prototype);kh.prototype.Zj=function(b){var c,d,e;b=b||[0];null===this.sb&&(this.sb=new x(I.a.o.label.width,I.a.o.ia.size));this.sb.clear();y(this.sb);for(c=this.yc.length-1;0<=c;c--)d=this.yc.length-c-1,d=this.sb.width-I.a.o.ia.size/2-d*I.a.o.label.yt,e=I.a.o.ia.size/2,b.length>c&&b[c]===this.yc[c]&&b.length<=this.yc.length?Be.n(""+this.yc[c],d,e):Ae.n(""+this.yc[c],d,e);A(this.sb)};
function ih(b,c,d){qh.call(this,b,c,d);this.anchor.y=this.sb.height}ih.prototype=Object.create(qh.prototype);ih.prototype.Zj=function(b){var c,d,e;b=b||[0];null===this.sb&&(this.sb=new x(I.a.o.ia.size,I.a.o.label.height));this.sb.clear();y(this.sb);for(c=this.yc.length-1;0<=c;c--)d=this.yc.length-c-1,e=I.a.o.ia.size/2,d=this.sb.height-I.a.o.ia.size/2-d*I.a.o.label.cw,b.length>c&&b[c]===this.yc[c]&&b.length<=this.yc.length?Be.n(""+this.yc[c],e,d):Ae.n(""+this.yc[c],e,d);A(this.sb)};
function rh(){this.L={}}var $g=new rh;rh.prototype.update=function(b){for(var c in this.L)this.L[c]-=b};function Rg(b){var c;if(b.constructor===Array){var d=Math.floor(Math.random()*b.length);b=b[d]}F.play(b,c||0)}I.version=I.version||{};I.version.theme="1.0";var ch={margin:J(12),nj:{color:"#93648F",lineWidth:J(4)}},Ef=Ef||{},Y={ya:J(0),za:J(0)};
Ef.Fk={ua:I.uh,background:{e:qe,pm:J(10),qm:J(30),elements:[{H:"ui_level_text",x:J(30)+Y.ya,y:J(40,"round")+Y.za,Pa:J(80),Ta:J(40),Zb:.2,font:V,Ic:{fillColor:"#24918a",fontSize:J(40),nc:"lower",align:"center",g:"top"}}]},gh:{numberOfLevels:{ys:"GameUIText",text:"0/000",x:J(30)+Y.ya,y:J(75,"round")+Y.za,Pa:J(80),Ta:J(40),Zb:.2,font:V,Ic:{fillColor:"#24918a",fontSize:J(30),nc:"lower",align:"center",g:"top"}}},time:{x:J(30)+Y.ya,y:J(110)+Y.za,Pa:J(80),Ta:J(40),lk:50,Zb:.2,gi:!1,separator:"",font:V,Ic:{fontSize:J(40),
fillColor:"#24918a",align:"center",g:"top"}},Ym:{x:J(24)+Y.ya,y:J(477)+Y.za},buttons:{fillButton:{x:J(24)+Y.ya,y:J(162)+Y.za,M:3,e:ge},blockButton:{x:J(24)+Y.ya,y:J(267)+Y.za,M:3,e:he},retryButton:{x:J(24)+Y.ya,y:J(372)+Y.za,M:3,e:Ad}}};jf=Ef.hw;
function sh(b,c){if(void 0===b)console.log("ANALYTICS WARNING: No ID passed");else{var d;d=[];for(var e="[levelnumber];[amount of stars];[tutorialnumber];[number of day];[rewardname];[booster name];[gate number];[stagenumber]".split(";"),g=b,h=0;h<e.length;h++)b.xp(e[h])&&d.push(e[h]);if("[object Array]"===Object.prototype.toString.call(c)&&c.length===d.length)for(h=0;h<d.length;h++)g=g.replace(d[h],c[h].toString());else void 0!==c&&"[object Array]"!==Object.prototype.toString.call(c)&&1===d.length?
g=b.replace(d[0],c.toString()):void 0===c&&0===d.length||console.log("ANALYTICS WARNING: Some arguments are not correct!");d=g;console.log("ID SEND TO ANALYTICS: "+d);try{analytics.customEvent(d)}catch(k){console.log("error calling analytics.menu: "+k)}}}function th(){String.prototype.xp||(String.prototype.xp=function(b,c){"number"!==typeof c&&(c=0);return c+b.length>this.length?!1:-1!==this.indexOf(b,c)})}
var $=new function(){this.K={gw:"Initialize-loading",Jr:"Initialize-finished",Ir:"Game-loading",Hr:"Game-finished",Gt:"level-[levelnumber]-start",Ht:"level-[levelnumber]-won-[amount of stars]",Et:"level-[levelnumber]-lost",xm:"level-[levelnumber]-completeonce",Ft:"level-[levelnumber]-restart",Cl:"firsttime-initialize",El:"firsttime-menu",Fl:"firsttime-play",Dl:"firsttime-level-[levelnumber]-start",fx:"firsttime-tutorial[tutorialnumber]-step[step number]",Ys:"firsttime-level-[levelnumber]-won-[amount of stars]",
sv:"stage-[stagenumber]-start",tv:"stage-[stagenumber]-won",qv:"stage-[stagenumber]-lost",rn:"stage-[stagenumber]-completeonce",rv:"stage-[stagenumber]-restart",Hl:"firsttime-stage-[stagenumber]-start",Il:"firsttime-stage-[stagenumber]-won",Gl:"firsttime-stage-[stagenumber]-lost",Rw:"dailyspin_counter reset_day[number of day]",Sw:"dailyspin_day[number of day]  ",bz:"reward_[rewardname]",cz:"reward_no reward",dz:"reward_spin again",Jy:"premiumspin_day[number of day]",Iy:"premiumreward_[rewardname]",
Ly:"purchase_booster_[booster name]_[levelnumber]",pA:"use_booster_[booster name]_[levelnumber]",My:"purchase_extramoves_[levelnumber]",Ny:"purchase_gate unlock_[gate number]",Ky:"purchase_adremoval"};th()};I.i=I.i||{};var uh=window.publisher,vh=!1,wh=-1;I.i.pj=function(){document.title=uh.gameName;I.i.td($.K.Cl)||(sh($.K.Cl),I.i.Jd($.K.Cl));sh($.K.Jr);sh($.K.Ir);uh.geoLocking?xh(this.Io):this.Io()};
I.i.Io=function(){I.orientation&&(I.orientation=0<=ba.indexOf("landscape")?"landscape":"portrait");new lc(uh,I.orientation,I.b.$c,I.b.rb,I.b.Gc,this);var b=window.navigator.userAgent,c=!1,d=/Chrome/.test(window.navigator.userAgent)&&/Google Inc/.test(window.navigator.vendor),e=/SHL24|SHL23|SHL22|SHL25|SHL21/i.test(b)&&!d,d=/SH-01F/i.test(b)&&!d,b=/Android/.test(b)&&(!e||!d);uh.removeMoreGamesButton&&(this.tq("startScreen","moreGames"),this.tq("levelMapScreen","moreGames"),this.tq("inGame","moreGames"));
if(window.ActiveXObject||"ActiveXObject"in window)c=!0;if(e||d||b)I.b.Eh=!1;if(c||d||e)I.b.Fh=!1;uh.moreGames||(I.i.qj=void 0)};I.i.Bp=function(){I.i.td($.K.El)||(sh($.K.El),I.i.Jd($.K.El));sh($.K.Hr);try{analytics.customEvent("menu")}catch(b){console.log("error calling analytics.menu: "+b)}};
I.i.Ap=function(b,c){var d=this;uh.enableAds&&!vh&&(setTimeout(function(){d.pp()},1E3*uh.firstAd),setTimeout(function(){d.uv()},1E3*uh.firstAd),vh=!0);wh=c?c:-1;I.i.td($.K.Fl)||(sh($.K.Fl),I.i.Jd($.K.Fl));I.i.td($.K.Dl+"_"+wh)||(sh($.K.Dl,wh),I.i.Jd($.K.Dl+"_"+wh));sh($.K.Gt,wh)};I.i.uv=function(){var b=this;setInterval(function(){b.pp()},1E3*uh.adFreq)};I.i.pp=function(){I.q.fe=!0};
I.i.zz=function(){if(I.q.fe)try{I.b.$c(),adSense.showAdvertising({callback:I.b.rb}),I.q.fe=!1}catch(b){console.log("error calling adSense.showAdvertising: "+b),I.b.rb()}};I.i.yz=function(b){try{I.b.$c(),adSense.showAdvertising({callback:function(){I.b.rb();b&&b()}})}catch(c){console.log("error calling adSense.showAdvertising: "+c),I.b.rb()}};
I.i.At=function(b){try{var c=b.totalScore||yh();b.timeBonus&&(c+=b.timeBonus);community.submitScore({score:c,callback:function(){if(I.q.fe)try{I.b.$c(),adSense.showAdvertising({callback:I.b.rb}),I.q.fe=!1}catch(b){console.log("error calling adSense.showAdvertising: "+b),I.b.rb()}}});analytics.customEvent("score"+c)}catch(d){console.log("error submitting highscore: "+c+", "+d)}};
I.i.Kf=function(b){var c=-1;b.level&&(c=b.level);if(b.failed){sh($.K.Et,c);try{analytics.customEvent("levelFailed"+c)}catch(d){console.log("error calling analytics.levelFailed: "+d)}}else{void 0===b.stars&&(b.stars="undefined stars");sh($.K.Ht,[c,b.stars]);I.i.td($.K.xm+"_"+c)||(sh($.K.xm,c),sh($.K.Ys,[c,b.stars]),I.i.Jd($.K.xm+"_"+c));try{analytics.customEvent("level"+c)}catch(e){console.log("error calling analytics.level: "+e)}}if(I.q.fe)try{I.b.$c(),adSense.showAdvertising({callback:function(){I.b.rb();
I.b.Gc()}}),I.q.fe=!1}catch(g){console.log("error calling adSense.showAdvertising: "+g),I.b.rb(),I.b.Gc()}else I.b.Gc()};I.i.yp=function(){sh($.K.Ft,wh)};I.i.zp=function(){if(I.q.fe)try{I.b.$c(),adSense.showAdvertising({callback:function(){I.b.rb()}}),I.q.fe=!1}catch(b){console.log("error calling adSense.showAdvertising: "+b),I.b.rb()}};
I.i.qj=function(){if(uh.moreGamesUrl&&""!==uh.moreGamesUrl)I.i.Gd(uh.moreGamesURL);else try{moregames.redirect()}catch(b){console.log("error calling moregames.redirect: "+b)}};I.i.vh=function(){return uh.stripBranding?[]:[{e:cd,url:I.q.nm,yb:this.qj}]};I.i.Ey=function(b,c,d,e,g){freemium.purchase(b,c,d,e,g)};I.i.Cz=function(b,c){I.b.$c();try{zh.Gu(function(){b&&b();I.b.rb()},this)}catch(d){c&&c(),I.b.rb()}};I.i.td=function(b){if(void 0!==If(b,void 0,"game"))return!0;!1};
I.i.Jd=function(b){Jf(b,1,"game")};I.i.Dz=function(b,c){switch(b){case "start":sh($.K.sv,c);I.i.td($.K.Hl+" "+c)||(sh($.K.Hl,c),I.i.Jd($.K.Hl+" "+c));break;case "won":sh($.K.tv,c);I.i.td($.K.Il+" "+c)||(sh($.K.Il,c),I.i.Jd($.K.Il+" "+c));break;case "lost":sh($.K.qv,c);I.i.td($.K.Gl+" "+c)||(sh($.K.Gl,c),I.i.Jd($.K.Gl+" "+c));break;case "complete":I.i.td($.K.rn+" "+c)||(sh($.K.rn,c),I.i.Jd($.K.rn+" "+c));break;case "restart":sh($.K.rv,c)}};I.version=I.version||{};
I.version.configuration_boostermedia="2.6";"use strict";function Ah(){this.ui=uh;this.li=new XMLHttpRequest;this.Wr="http://geoip.api.boostermedia.com/"}
function xh(b){var c=new Ah;c.li.onload=function(){var d=JSON.parse(this.responseText),e=c.ui.allowedCountries&&-1!==c.ui.allowedCountries.indexOf(d.country_code);if(c.ui.allowedIPs&&-1!==c.ui.allowedIPs.indexOf(d.ip)||e)b(0);else if(console.error("GeoLocking: Accessing from wrong location: "+d.country_code),d=document.getElementById("geolocking"))d.style.display="block"};c.li.onerror=function(){b(0);console.warn("GeoLocking: Couldn't access location service due to error: "+error)};c.li.open("GET",
c.Wr);c.li.send(null)}"use strict";
var zh=new (function(){function b(){window.addEventListener("message",function(b){this.Wu(b)}.bind(this),!1)}b.prototype.Pr=function(){return l.Yc.Mm||l.Yc.xn||l.Yc.Uv?{bp:"adFrameMobile",fo:"adtechMobile",width:320,height:250,Gr:publisher.mobileRewardId}:{bp:"adFrame",fo:"adtech",width:640,height:480,Gr:publisher.desktopRewardId}};b.prototype.Gu=function(b,d){this.Xr=b;this.Yr=d;var e=this.Pr(),g=Math.floor(1E9*Math.random());this.Bc=document.createElement("div");this.Bc.className="adOverlay";var h=
document.createElement("div");h.className="adBg";var k=document.createElement("div");k.className=e.bp;this.te=document.createElement("iframe");this.te.src="http://media.oadts.com/www/delivery/afv.php?zoneid="+e.Gr+"&cb="+g;this.te.ix="0";this.te.scrolling="no";this.te.width=e.width;this.te.height=e.height;this.te.className=e.fo;this.Bc.appendChild(h);this.Bc.appendChild(k);this.Bc.appendChild(this.te);document.body.appendChild(this.Bc)};b.prototype.Do=function(){this.Bc&&(document.body.removeChild(this.Bc),
this.Bc=null);this.Xr.call(this.Yr,!0)};b.prototype.Wu=function(b){if("http://media.oadts.com"===b.origin&&this.Bc)switch(console.log(b),b.data){case "noVideo":case "NoVideo":document.body.removeChild(this.Bc);this.Bc=null;this.Do();break;case "videoEnds":case "videoComplete":this.Do()}};return b}()),oh={backgroundColor:"rgba(0, 0, 0, 0.6)",gc:12,vs:140,Vs:16,uu:24,Nm:60,offset:{x:0,y:-J(24)},ib:600,Of:500,ll:800,je:600,Wm:900,hl:800,us:300,Yi:{x:-28,y:16},vu:J(24),$u:J(24)};
function Bh(){this.depth=-1E6;this.j=this.visible=!0;this.ua=I.cp;this.end=this.rc=this.um=this.tm=this.load=this.Tb=!1;this.Jl=0;this.Hn=this.ii=!1;this.state="GAME_INIT";this.screen=null;this.Qm=this.Nb=this.C=0;this.Kl=!1;this.Eh=this.Fh=!0;this.tu=1;this.Fc=!1;this.Nc={};this.W={difficulty:1,playMusic:!0,playSFX:!0,language:I.l.$l()};window.addEventListener("gameSetPause",this.$c,!1);window.addEventListener("gameResume",this.rb,!1);document.addEventListener("visibilitychange",this.ut,!1);this.ci=
"timedLevelEvent"}a=Bh.prototype;a.$c=function(){F.pause("master");G.pause()};a.rb=function(){F.Uh("master");xb(G);Cb(G);Hb(G);G.Uh()};a.ut=function(){document.hidden?I.b.$c():I.b.rb()};
a.Lk=function(){var b,c=this;void 0!==I.a.S.background&&void 0!==I.a.S.background.color&&(document.body.style.background=I.a.S.background.color);I.Ja=new Kf;I.q.wp&&I.q.wp.j&&(c.aw=Hg(function(b){c.aw=b}));I.k=I.a.o.Ke||{};I.k.zd=I.k.zd||"level";I.k.bf=void 0!==I.k.bf?I.k.bf:"level"===I.k.zd;I.k.P=void 0!==I.k.P?I.k.P instanceof Array?I.k.P:[I.k.P]:[20];I.k.Af=void 0!==I.k.Af?I.k.Af:"locked";I.k.fk=void 0!==I.k.fk?I.k.fk:"difficulty"===I.k.zd;I.k.zk=void 0!==I.k.zk?I.k.zk:!1;I.k.pn=void 0!==I.k.pn?
I.k.pn:"level"===I.k.zd;I.k.Mi=void 0!==I.k.Mi?I.k.Mi:"max";I.k.xq=void 0!==I.k.xq?I.k.xq:"number";I.i.mt(function(b){var e,g,h;b&&(c.Nc=b);c.W=If("preferences",{});c.W.difficulty=void 0!==c.W.difficulty?c.W.difficulty:1;void 0!==I.k.Zq&&0>I.k.Zq.indexOf(pf())&&(c.W.difficulty=I.k.Zq[0]);c.W.playMusic=void 0!==c.W.playMusic?c.W.playMusic:!0;c.Ye(c.W.playMusic);c.W.playSFX=void 0!==c.W.playSFX?c.W.playSFX:!0;c.Rj(c.W.playSFX);c.W.language=void 0!==c.W.language&&I.l.Ct(c.W.language)?c.W.language:I.l.$l();
I.l.Aq(c.W.language);void 0===bg(c.C,0,"state",void 0)&&bh(c.C,0);if(I.k.bf)if("locked"===I.k.Af)for(h=!1,e=0;e<I.k.P.length;e++){for(b=0;b<I.k.P[e];b++)if(g=bg(e,b,"state","locked"),"locked"===g){c.C=0<=b-1?e:0<=e-1?e-1:0;h=!0;break}if(h)break}else void 0!==c.W.lastPlayed&&(c.C=c.W.lastPlayed.world||0)});c.ng=Ch();void 0!==c.ng.authToken&&void 0!==c.ng.challengeId&&(c.Fc=!0);I.q.oA&&(this.Gb=this.iA?new TestBackendServiceProvider:new BackendServiceProvider,this.Gb.Cp(function(b){b&&I.b.Gb.Dx(c.ng.authToken)}));
b=parseFloat(l.s.version);F.Ea&&(l.xa.In&&l.s.Gj||l.s.cg&&b&&4.4>b)&&(F.si=1);this.Tb=!0;this.tj=0};function Ch(){var b,c,d,e,g;c={};if(b=window.location.search.substring(1))for(b=b.split("&"),e=0,g=b.length;e<g;e++)d=b[e].split("="),c[d[0]]=d[1];return c}function Dh(b){b.state="GAME_LOAD";b.screen=new Qf(function(){I.b.load=!0;ug(I.b,!0);I.qd.fm();I.i.fm()},function(){},I.q.Bz)}function ug(b,c){b.ii=c||!1;b.Hn=!0;b.Jl++}
function Eh(){var b=I.b;b.Jl--;switch(b.state){case "GAME_INIT":b.Tb&&!b.rA&&(b.Fc&&b.Gb&&b.Gb.Sz(b.ng.challengeId,function(c){!c&&b.screen&&"function"===typeof b.screen.on&&b.screen.on("challengeLoadingError_notValid")}),Dh(b));break;case "GAME_LOAD":if(b.load){if(b.Fc&&b.Gb)if(b.Gb.Bt())hf(b),Uf(b.Rc.mode);else{b.screen.on("challengeLoadingError_notStarted");break}H(G,b.screen);"function"===typeof Jg&&(I.o=new Jg);void 0!==I.q.os&&!1!==I.q.os.show&&I.d.$r();tg(b)}break;case "LEVEL_INIT":b.tm&&Fh(b);
break;case "LEVEL_LOAD":b.um&&Gh(b);break;case "LEVEL_END":if(b.rc)switch(sg(),I.b.tm=!1,I.b.um=!1,I.sm=void 0,I.d.Ne(I.Df).X=!0,I.d.Ne(I.uh).X=!0,I.b.Jp){case "retry":Yf(I.b,I.b.Nb);break;case "next":I.k.bf?I.b.Nb+1<I.k.P[I.b.C]?Yf(I.b,I.b.Nb+1):I.b.C+1<I.k.P.length?Yf(I.b,0,I.b.C+1):I.k.pn?(I.b.state="GAME_END",I.b.end=!0,ug(I.b,!1),I.i.qt()):I.b.screen=new Xf:Yf(I.b,0);break;case "exit":I.k.bf?I.b.screen=new Xf:tg(I.b)}break;case "GAME_END":b.end&&(b.end=!1,I.b.screen=null,I.b.screen=new zg)}}
a.Gc=function(){I.b.Hn=!1};function ng(){var b;if(void 0!==I.b.ng.more_games)try{return b=decodeURIComponent(I.b.ng.more_games),function(){I.i.Gd(b)}}catch(c){}if("string"===typeof I.Uf.moreGamesUrl&&""!==I.Uf.moreGamesUrl)return function(){I.i.Gd(I.Uf.moreGamesUrl)};if(void 0!==I.q.nu)return function(){I.i.Gd(I.q.nu)};if("function"===typeof I.i.qj)return I.i.qj}function hf(b){if(b.Fc&&void 0!==b.Gb)return void 0===b.Rc&&(b.Rc=b.Gb.px()),b.Rc}a.oh=function(b){I.b.Fc&&I.b.Gb&&I.b.Gb.oh(b)};
a.$g=function(b){I.b.Fc&&I.b.Gb&&I.b.Gb.$g(b)};function pf(){return I.b.W.difficulty}function rg(){switch(pf()){case 0:return"easy";case 1:return"medium";case 2:return"hard";default:throw"Unknown difficulty: "+pf();}}function of(){var b="optionsDifficulty_"+rg();return I.l.N(b,"<"+b+">")}function Uf(b){I.b.W.difficulty=b;Jf("preferences",I.b.W)}a.Ye=function(b){void 0!==b&&(I.b.W.playMusic=b,Jf("preferences",I.b.W),b?nb("music"):mb("music"));return I.b.W.playMusic};
a.Rj=function(b){void 0!==b&&(I.b.W.playSFX=b,Jf("preferences",I.b.W),b?(nb("game"),nb("sfx")):(mb("game"),mb("sfx")));return I.b.W.playSFX};a.language=function(b){void 0!==b&&(I.b.W.language=b,Jf("preferences",I.b.W));return I.b.W.language};function bh(b,c){var d="game";"game"!==d&&(d="tg");void 0===I.b.Nc["level_"+b+"_"+c]&&(I.b.Nc["level_"+b+"_"+c]={tg:{},game:{}});I.b.Nc["level_"+b+"_"+c][d].state="unlocked";I.i.tr()}
function bg(b,c,d,e){var g="game";"game"!==g&&(g="tg");b=I.b.Nc["level_"+b+"_"+c];return void 0!==b&&(b=void 0===d?b[g]:b[g][d],void 0!==b)?b:e}function If(b,c,d){var e;"game"!==d&&(d="tg");e=I.b.Nc.game;return void 0!==e&&(e=void 0===b?e[d]:e[d][b],void 0!==e)?e:c}function Jf(b,c,d){"game"!==d&&(d="tg");void 0===I.b.Nc.game&&(I.b.Nc.game={tg:{},game:{}});void 0===b?I.b.Nc.game[d]=c:I.b.Nc.game[d][b]=c;I.i.tr()}
function ig(b,c,d){var e=I.b;void 0===c&&(c=e.Nb);void 0===d&&(d=e.C);return void 0===b?bg(d,c,"stats",{}):bg(d,c,"stats",{})[b]}function Ig(){var b=ig("highScore",void 0,void 0);return"number"!==typeof b?0:b}function yh(){var b,c,d,e=0;for(b=0;b<I.k.P.length;b++)for(c=0;c<I.k.P[b];c++)d=ig(void 0,c,b),"object"===typeof d&&null!==d&&(e+=void 0!==d.highScore?d.highScore:0);return e}function tg(b){b.screen&&H(G,b.screen);b.screen=new Sf;b.Nb=-1;I.i.Bp()}
function yf(b,c,d,e){var g;g=void 0!==I.a.S.Ah&&void 0!==I.a.S.Ah.backgroundImage?I.a.S.Ah.backgroundImage:void 0!==I.a.r.Ah?I.a.r.Ah.backgroundImage:void 0;I.d.nb(I.Le);b=b||0;c=c||0;d=d||p.width;e=e||p.height;if(g)if(d=Math.min(Math.min(d,p.width),g.eh),e=Math.min(Math.min(e,p.height),g.yf),void 0!==g){var h=b,k=c-I.qo,m,n,q;for(m=0;m<g.G;m+=1)n=m%g.Sf*g.width,q=g.height*Math.floor(m/g.Sf),n>h+d||n+g.width<h||q>k+e||q+g.height<k||g.I(m,h-n,k-q,d,e,b,c,1)}else pa(b,c,d,e,"white",!1)}
function Yf(b,c,d){b.state="LEVEL_INIT";void 0===d||(b.C=d);b.Nb=c;b.tm=!0;ug(b,!1);I.i.rt()}function Fh(b){b.state="LEVEL_LOAD";b.um=!0;ug(b,!1);I.i.st()}
function Gh(b){var c,d=0;if(b.C<I.k.P.length&&b.Nb<I.k.P[b.C]){b.state="LEVEL_PLAY";b.Qm+=1;b.rc=!1;b.screen=null;yf(0,I.qo);c=I.Ja;var e=qg(b,3),g="progression:levelStarted:"+rg(),h=b.ci,k;for(k=0;k<c.L.length;k++)if(!c.L[k].j){c.L[k].t=0;c.L[k].paused=0;c.L[k].j=!0;c.L[k].Wo=e;c.L[k].mq=g;c.L[k].tag=h;break}k===c.L.length&&c.L.push({j:!0,t:0,paused:0,Wo:e,mq:g,tag:h});c.Va(e,g);for(c=0;c<b.C;c++)d+=I.k.P[c];I.i.Ap(b.C,b.Nb);b.W.lastPlayed={world:b.C,level:b.Nb};I.sm=new Mg(d+b.Nb)}}
function cg(b,c,d){var e=0;void 0===c&&(c=b.C);void 0===d&&(d=b.Nb);for(b=0;b<c;b++)e+=I.k.P[b];return e+d}function Tg(b,c,d,e){new Ag(b,c,d,e)}function qg(b,c){var d,e=b.Nb+"",g=c-e.length;if("number"===typeof c&&1<c)for(d=0;d<g;d++)e="0"+e;return e}a.Wh=function(){I.b.Yf(!0)};
a.Yf=function(b,c,d){var e="inGame";I.b.screen instanceof Sf?e="startScreen":I.b.screen instanceof Xf?e="levelMapScreen":c&&(e=I.b.Rc.zs===I.b.Rc.Ao?"inGame_challenger":"inGame_challengee");I.b.ye||(I.b.ye=new jg(e,!0===b,c,d))};
function Df(b){var c=[],d,e,g,h,k;I.b.ye||I.b.Xd||(I.b.Rc.zs===I.b.Rc.Ao?(d=I.l.N("challengeCancelConfirmText","<CHALLENGECANCELCONFIRMTEXT>"),e="challengeCancelConfirmBtn_yes",g="challengeCancelConfirmBtn_no",k=function(b){var c=b?"challengeCancelMessage_success":"challengeCancelMessage_error",c=I.l.N(c,"<"+c.toUpperCase()+"<");I.b.Xd&&Eg(c);b&&wg()},h=function(){I.b.$g(k);return!0}):(d=I.l.N("challengeForfeitConfirmText","<CHALLENGEFORFEITCONFIRMTEXT>"),e="challengeForfeitConfirmBtn_yes",g="challengeForfeitConfirmBtn_no",
k=function(b){var c=b?"challengeForfeitMessage_success":"challengeForfeitMessage_error",c=I.l.N(c,"<"+c.toUpperCase()+"<");if(I.b.Xd&&(Eg(c),b)){var c=I.l.N("challengeForfeitMessage_winnings",""),c=c.replace("<NAME>",I.b.Rc.Gy[I.b.Rc.Ao]),c=c.replace("<AMOUNT>",I.b.Rc.qA),d=I.b.Xd,e,g,h,k;e=S.da();d.a.un&&D(e,d.a.un);g=Pa(e,c,d.a.Ru,d.a.Qu,!0);g<e.fontSize&&E(e,g);g=e.Wa(c,d.a.Wj)+10;h=Na(e,c,d.a.Vj)+10;k=I.d.qa(d.a.Su,d.f.e.width,g,e.align);h=I.d.qa(d.a.Tu,d.f.e.height-Dg(d),h,e.g);y(d.f.e);e.n(c,
k,h,g);A(d.f.e)}b&&wg()},h=function(){I.b.oh(k);return!0}),c.push({H:e,U:h,ca:I.b}),c.push({H:g,U:function(){I.b.Xd.close();I.b.Xd=null;return!0}}),I.b.Xd=new Cg(d,c,b),I.b.ye=I.b.Xd)}a.Zm=function(){var b,c;c=Qb(G,"game");for(b=0;b<c.length;b++)"function"===typeof c[b].lm&&c[b].lm();Mf();Rb("game");Ib()};function wg(b){var c,d;d=Qb(G);for(c=0;c<d.length;c++)"function"===typeof d[c].lm&&d[c].lm();Rb();Ib();Mf();b&&(b.D=Math.max(0,b.D-1));Sb("system")}
function yg(){var b,c;c=Qb(G);for(b=0;b<c.length;b++)"function"===typeof c[b].tt&&c[b].tt();Sb();b=G;for(c=0;c<b.Ud.length;c+=1)b.Ud[c].paused=Math.max(0,b.Ud[c].paused-1);b=I.Ja;c=I.b.ci;var d;for(d=0;d<b.L.length;d++)void 0!==b.L[d]&&b.L[d].tag===c&&(b.L[d].paused-=1,b.L[d].paused=Math.max(b.L[d].paused,0))}function sg(){var b;I.sm&&H(G,I.sm);for(b=Qb(G,"LevelStartDialog");0<b.length;)H(G,b.pop())}
function Hf(){var b="";I.version.builder&&(b=I.version.builder);I.version.tg&&(b+="-"+I.version.tg);I.version.game&&(b+="-"+I.version.game);I.version.config&&(b+="-"+I.version.config);return b}a.Pb=function(){this.Tb||(this.Lk(),ug(I.b,!0),I.qd.pj(),I.i.pj())};
a.ma=function(b){"function"===typeof this.dp&&(this.dp(),this.dp||I.b.Gc());0<this.Jl&&(this.ii||this.Hn||Eh());700>this.tj&&(this.tj+=b,700<=this.tj&&(I.q.Vv&&void 0!==I.q.cj&&I.q.cj.Ql&&I.q.cj.kn&&I.Ja.start([I.q.cj.Ql,I.q.cj.kn]),void 0===bg(this.C,0,"state",void 0)&&bh(this.C,0)))};a.Rb=function(b,c){"languageSet"===b&&I.b.language(c)};a.pc=function(){var b,c;for(b=0;b<I.sd.length;b++)c=I.sd[b],c.X&&(p.nb(c),p.clear())};a.Ma=function(){var b;for(b=0;b<I.sd.length;b++)I.sd[b].X=!1};
I.vv=function(){I.b=new Bh;Nb(I.b);Pb(I.b,"system")};(void 0===I.hs||I.hs)&&I.vv();I.a.r.Yh.Xe=ud.width;I.a.r.gb.bigPlay={type:"image",p:ud,Y:J(0),Da:J(0),Cb:2E3,fontSize:0};I.a.r.gk.Xe=ud.width;I.a.r.Hi.bigPlay={type:"image",p:ud,Y:J(0),Da:J(0),Cb:2E3,fontSize:0};I.a.r.Xg.puzzle={font:{w:T.w,align:"center",g:"middle",fillColor:"#24918a",Ca:-.15}};I.a.r.ad.Kp={lj:{fontSize:J(48),w:T.w,fillColor:"#3F4F5E",align:"center",g:"middle"}};I.a.r.ad.vm={align:"center",offset:J(0)};
I.a.r.ad.Cm={align:"center",offset:J(0)};
